"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "schemas": { "GoogleCloudDialogflowV2IntentMessageCard": { "description": "The card response message.", "type": "object", "properties": { "imageUri": { "description": "Optional. The public URI to an image file for the card.", "type": "string" }, "title": { "description": "Optional. The title of the card.", "type": "string" }, "buttons": { "description": "Optional. The collection of card buttons.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageCardButton" } }, "subtitle": { "description": "Optional. The subtitle of the card.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageCard" }, "GoogleCloudDialogflowV2beta1IntentMessageListSelect": { "description": "The card for presenting a list of options to select from.", "type": "object", "properties": { "items": { "description": "Required. List items.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageListSelectItem" } }, "title": { "description": "Optional. The overall title of the list.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageListSelect" }, "GoogleCloudDialogflowV2IntentBatch": { "properties": { "intents": { "description": "A collection of intents.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Intent" } } }, "id": "GoogleCloudDialogflowV2IntentBatch", "description": "This message is a wrapper around a collection of intents.", "type": "object" }, "GoogleCloudDialogflowV2DetectIntentRequest": { "description": "The request to detect user's intent.", "type": "object", "properties": { "queryInput": { "description": "Required. The input specification. It can be set to:\n\n1.  an audio config\n    which instructs the speech recognizer how to process the speech audio,\n\n2.  a conversational query in the form of text, or\n\n3.  an event that specifies which intent to trigger.", "$ref": "GoogleCloudDialogflowV2QueryInput" }, "queryParams": { "description": "Optional. The parameters of this query.", "$ref": "GoogleCloudDialogflowV2QueryParameters" }, "inputAudio": { "description": "Optional. The natural language speech audio to be processed. This field\nshould be populated iff `query_input` is set to an input audio config.\nA single request can contain up to 1 minute of speech audio data.", "format": "byte", "type": "string" } }, "id": "GoogleCloudDialogflowV2DetectIntentRequest" }, "GoogleCloudDialogflowV2IntentMessageBasicCardButton": { "properties": { "openUriAction": { "$ref": "GoogleCloudDialogflowV2IntentMessageBasicCardButtonOpenUriAction", "description": "Required. Action to take when a user taps on the button." }, "title": { "description": "Required. The title of the button.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageBasicCardButton", "description": "The button object that appears at the bottom of a card.", "type": "object" }, "GoogleCloudDialogflowV2beta1BatchUpdateIntentsResponse": { "properties": { "intents": { "description": "The collection of updated or created intents.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Intent" } } }, "id": "GoogleCloudDialogflowV2beta1BatchUpdateIntentsResponse", "description": "The response message for Intents.BatchUpdateIntents.", "type": "object" }, "GoogleCloudDialogflowV2beta1Context": { "description": "Represents a context.", "type": "object", "properties": { "lifespanCount": { "description": "Optional. The number of conversational query requests after which the\ncontext expires. If set to `0` (the default) the context expires\nimmediately. Contexts expire automatically after 10 minutes even if there\nare no matching queries.", "format": "int32", "type": "integer" }, "name": { "description": "Required. The unique identifier of the context. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`,\nor `projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>/contexts/<Context ID>`. The `Context ID` is\nalways converted to lowercase. If `Environment ID` is not specified, we\nassume default 'draft' environment. If `User ID` is not specified, we\nassume default '-' user.", "type": "string" }, "parameters": { "description": "Optional. The collection of parameters associated with this context.\nRefer to [this doc](https://dialogflow.com/docs/actions-and-parameters) for\nsyntax.", "type": "object", "additionalProperties": { "description": "Properties of the object.", "type": "any" } } }, "id": "GoogleCloudDialogflowV2beta1Context" }, "GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo": { "description": "Additional info about the select item for when it is triggered in a\ndialog.", "type": "object", "properties": { "key": { "description": "Required. A unique key that will be sent back to the agent if this\nresponse is given.", "type": "string" }, "synonyms": { "description": "Optional. A list of synonyms that can also be used to trigger this\nitem in dialog.", "type": "array", "items": { "type": "string" } } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo" }, "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponses": { "description": "The collection of simple response candidates.\nThis message in `QueryResult.fulfillment_messages` and\n`WebhookResponse.fulfillment_messages` should contain only one\n`SimpleResponse`.", "type": "object", "properties": { "simpleResponses": { "description": "Required. The list of simple responses.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponse" } } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponses" }, "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelect": { "properties": { "items": { "description": "Required. Carousel items.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelectItem" } } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelect", "description": "The card for presenting a carousel of options to select from.", "type": "object" }, "GoogleCloudDialogflowV2BatchDeleteEntitiesRequest": { "properties": { "languageCode": { "description": "Optional. The language of entity synonyms defined in `entities`. If not\nspecified, the agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string" }, "entityValues": { "description": "Required. The canonical `values` of the entities to delete. Note that\nthese are not fully-qualified names, i.e. they don't start with\n`projects/<Project ID>`.", "type": "array", "items": { "type": "string" } } }, "id": "GoogleCloudDialogflowV2BatchDeleteEntitiesRequest", "description": "The request message for EntityTypes.BatchDeleteEntities.", "type": "object" }, "GoogleCloudDialogflowV2SessionEntityType": { "description": "Represents a session entity type.\n\nExtends or replaces a developer entity type at the user session level (we\nrefer to the entity types defined at the agent level as \"developer entity\ntypes\").\n\nNote: session entity types apply to all queries, regardless of the language.", "type": "object", "properties": { "entityOverrideMode": { "enumDescriptions": ["Not specified. This value should be never used.", "The collection of session entities overrides the collection of entities\nin the corresponding developer entity type.", "The collection of session entities extends the collection of entities in\nthe corresponding developer entity type.\nCalls to `ListSessionEntityTypes`, `GetSessionEntityType`,\n`CreateSessionEntityType` and `UpdateSessionEntityType` return the full\ncollection of entities from the developer entity type in the agent's\ndefault language and the session entity type."], "enum": ["ENTITY_OVERRIDE_MODE_UNSPECIFIED", "ENTITY_OVERRIDE_MODE_OVERRIDE", "ENTITY_OVERRIDE_MODE_SUPPLEMENT"], "description": "Required. Indicates whether the additional data should override or\nsupplement the developer entity type definition.", "type": "string" }, "entities": { "description": "Required. The collection of entities associated with this session entity\ntype.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2EntityTypeEntity" } }, "name": { "description": "Required. The unique identifier of this session entity type. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type\nDisplay Name>`.", "type": "string" } }, "id": "GoogleCloudDialogflowV2SessionEntityType" }, "GoogleCloudDialogflowV2beta1IntentMessageCard": { "description": "The card response message.", "type": "object", "properties": { "imageUri": { "description": "Optional. The public URI to an image file for the card.", "type": "string" }, "title": { "description": "Optional. The title of the card.", "type": "string" }, "buttons": { "description": "Optional. The collection of card buttons.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageCardButton" } }, "subtitle": { "description": "Optional. The subtitle of the card.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageCard" }, "GoogleCloudDialogflowV2EventInput": { "properties": { "name": { "description": "Required. The unique identifier of the event.", "type": "string" }, "parameters": { "description": "Optional. The collection of parameters associated with the event.", "type": "object", "additionalProperties": { "description": "Properties of the object.", "type": "any" } }, "languageCode": { "description": "Required. The language of this query. See [Language\nSupport](https://dialogflow.com/docs/languages) for a list of the\ncurrently supported language codes. Note that queries in the same session\ndo not necessarily need to specify the same language.", "type": "string" } }, "id": "GoogleCloudDialogflowV2EventInput", "description": "Events allow for matching intents by event name instead of the natural\nlanguage input. For instance, input `<event: { name: “welcome_event”,\nparameters: { name: “Sam” } }>` can trigger a personalized welcome response.\nThe parameter `name` may be used by the agent in the response:\n`“Hello #welcome_event.name! What can I do for you today?”`.", "type": "object" }, "GoogleCloudDialogflowV2beta1IntentMessageSuggestion": { "properties": { "title": { "description": "Required. The text shown the in the suggestion chip.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageSuggestion", "description": "The suggestion chip message that the user can tap to quickly post a reply\nto the conversation.", "type": "object" }, "GoogleCloudDialogflowV2IntentMessageSuggestions": { "properties": { "suggestions": { "description": "Required. The list of suggested replies.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageSuggestion" } } }, "id": "GoogleCloudDialogflowV2IntentMessageSuggestions", "description": "The collection of suggestions.", "type": "object" }, "GoogleCloudDialogflowV2ListContextsResponse": { "description": "The response message for Contexts.ListContexts.", "type": "object", "properties": { "contexts": { "description": "The list of contexts. There will be a maximum number of items\nreturned based on the page_size field in the request.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Context" } }, "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" } }, "id": "GoogleCloudDialogflowV2ListContextsResponse" }, "GoogleCloudDialogflowV2QueryInput": { "description": "Represents the query input. It can contain either:\n\n1.  An audio config which\n    instructs the speech recognizer how to process the speech audio.\n\n2.  A conversational query in the form of text,.\n\n3.  An event that specifies which intent to trigger.", "type": "object", "properties": { "audioConfig": { "$ref": "GoogleCloudDialogflowV2InputAudioConfig", "description": "Instructs the speech recognizer how to process the speech audio." }, "event": { "$ref": "GoogleCloudDialogflowV2EventInput", "description": "The event to be processed." }, "text": { "$ref": "GoogleCloudDialogflowV2TextInput", "description": "The natural language text to be processed." } }, "id": "GoogleCloudDialogflowV2QueryInput" }, "GoogleCloudDialogflowV2beta1IntentTrainingPhrase": { "properties": { "parts": { "description": "Required. The collection of training phrase parts (can be annotated).\nFields: `entity_type`, `alias` and `user_defined` should be populated\nonly for the annotated parts of the training phrase.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart" } }, "name": { "description": "Output only. The unique identifier of this training phrase.", "type": "string" }, "timesAddedCount": { "description": "Optional. Indicates how many times this example or template was added to\nthe intent. Each time a developer adds an existing sample by editing an\nintent or training, this counter is increased.", "format": "int32", "type": "integer" }, "type": { "description": "Required. The type of the training phrase.", "type": "string", "enumDescriptions": ["Not specified. This value should never be used.", "Examples do not contain @-prefixed entity type names, but example parts\ncan be annotated with entity types.", "Templates are not annotated with entity types, but they can contain\n@-prefixed entity type names as substrings."], "enum": ["TYPE_UNSPECIFIED", "EXAMPLE", "TEMPLATE"] } }, "id": "GoogleCloudDialogflowV2beta1IntentTrainingPhrase", "description": "Represents an example or template that the agent is trained on.", "type": "object" }, "GoogleCloudDialogflowV2IntentMessageSimpleResponses": { "properties": { "simpleResponses": { "description": "Required. The list of simple responses.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageSimpleResponse" } } }, "id": "GoogleCloudDialogflowV2IntentMessageSimpleResponses", "description": "The collection of simple response candidates.\nThis message in `QueryResult.fulfillment_messages` and\n`WebhookResponse.fulfillment_messages` should contain only one\n`SimpleResponse`.", "type": "object" }, "GoogleCloudDialogflowV2IntentMessageImage": { "description": "The image response message.", "type": "object", "properties": { "imageUri": { "description": "Optional. The public URI to an image file.", "type": "string" }, "accessibilityText": { "description": "Optional. A text description of the image to be used for accessibility,\ne.g., screen readers.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageImage" }, "GoogleCloudDialogflowV2IntentMessageText": { "description": "The text response message.", "type": "object", "properties": { "text": { "description": "Optional. The collection of the agent's responses.", "type": "array", "items": { "type": "string" } } }, "id": "GoogleCloudDialogflowV2IntentMessageText" }, "GoogleCloudDialogflowV2BatchDeleteIntentsRequest": { "description": "The request message for Intents.BatchDeleteIntents.", "type": "object", "properties": { "intents": { "description": "Required. The collection of intents to delete. Only intent `name` must be\nfilled in.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Intent" } } }, "id": "GoogleCloudDialogflowV2BatchDeleteIntentsRequest" }, "GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion": { "description": "The suggestion chip message that allows the user to jump out to the app\nor website associated with this agent.", "type": "object", "properties": { "destinationName": { "description": "Required. The name of the app or site this chip is linking to.", "type": "string" }, "uri": { "description": "Required. The URI of the app or site to open when the user taps the\nsuggestion chip.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion" }, "GoogleCloudDialogflowV2EntityTypeEntity": { "description": "Optional. Represents an entity.", "type": "object", "properties": { "value": { "description": "Required.\nFor `KIND_MAP` entity types:\n  A canonical name to be used in place of synonyms.\nFor `KIND_LIST` entity types:\n  A string that can contain references to other entity types (with or\n  without aliases).", "type": "string" }, "synonyms": { "description": "Required. A collection of synonyms. For `KIND_LIST` entity types this\nmust contain exactly one synonym equal to `value`.", "type": "array", "items": { "type": "string" } } }, "id": "GoogleCloudDialogflowV2EntityTypeEntity" }, "GoogleCloudDialogflowV2QueryResult": { "description": "Represents the result of conversational query or event processing.", "type": "object", "properties": { "fulfillmentText": { "description": "The text to be pronounced to the user or shown on the screen.", "type": "string" }, "parameters": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "The collection of extracted parameters.", "type": "object" }, "intentDetectionConfidence": { "description": "The intent detection confidence. Values range from 0.0\n(completely uncertain) to 1.0 (completely certain).\nIf there are `multiple knowledge_answers` messages, this value is set to\nthe greatest `knowledgeAnswers.match_confidence` value in the list.", "format": "float", "type": "number" }, "allRequiredParamsPresent": { "description": "This field is set to:\n- `false` if the matched intent has required parameters and not all of\n   the required parameter values have been collected.\n- `true` if all required parameter values have been collected, or if the\n   matched intent doesn't contain any required parameters.", "type": "boolean" }, "speechRecognitionConfidence": { "description": "The Speech recognition confidence between 0.0 and 1.0. A higher number\nindicates an estimated greater likelihood that the recognized words are\ncorrect. The default of 0.0 is a sentinel value indicating that confidence\nwas not set.\n\nThis field is not guaranteed to be accurate or set. In particular this\nfield isn't set for StreamingDetectIntent since the streaming endpoint has\nseparate confidence estimates per portion of the audio in\nStreamingRecognitionResult.", "format": "float", "type": "number" }, "queryText": { "description": "The original conversational query text:\n- If natural language text was provided as input, `query_text` contains\n  a copy of the input.\n- If natural language speech audio was provided as input, `query_text`\n  contains the speech recognition result. If speech recognizer produced\n  multiple alternatives, a particular one is picked.\n- If an event was provided as input, `query_text` is not set.", "type": "string" }, "diagnosticInfo": { "description": "The free-form diagnostic info. For example, this field\ncould contain webhook call latency.", "type": "object", "additionalProperties": { "description": "Properties of the object.", "type": "any" } }, "intent": { "$ref": "GoogleCloudDialogflowV2Intent", "description": "The intent that matched the conversational query. Some, not\nall fields are filled in this message, including but not limited to:\n`name`, `display_name` and `webhook_state`." }, "languageCode": { "description": "The language that was triggered during intent detection.\nSee [Language Support](https://dialogflow.com/docs/reference/language)\nfor a list of the currently supported language codes.", "type": "string" }, "outputContexts": { "description": "The collection of output contexts. If applicable,\n`output_contexts.parameters` contains entries with name\n`<parameter name>.original` containing the original parameter values\nbefore the query.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Context" } }, "webhookPayload": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "If the query was fulfilled by a webhook call, this field is set to the\nvalue of the `payload` field returned in the webhook response.", "type": "object" }, "fulfillmentMessages": { "description": "The collection of rich messages to present to the user.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessage" } }, "action": { "description": "The action name from the matched intent.", "type": "string" }, "webhookSource": { "description": "If the query was fulfilled by a webhook call, this field is set to the\nvalue of the `source` field returned in the webhook response.", "type": "string" } }, "id": "GoogleCloudDialogflowV2QueryResult" }, "GoogleCloudDialogflowV2beta1IntentMessageText": { "properties": { "text": { "description": "Optional. The collection of the agent's responses.", "type": "array", "items": { "type": "string" } } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageText", "description": "The text response message.", "type": "object" }, "GoogleCloudDialogflowV2IntentMessageCarouselSelect": { "description": "The card for presenting a carousel of options to select from.", "type": "object", "properties": { "items": { "description": "Required. Carousel items.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageCarouselSelectItem" } } }, "id": "GoogleCloudDialogflowV2IntentMessageCarouselSelect" }, "GoogleTypeLatLng": { "properties": { "longitude": { "description": "The longitude in degrees. It must be in the range [-180.0, +180.0].", "format": "double", "type": "number" }, "latitude": { "description": "The latitude in degrees. It must be in the range [-90.0, +90.0].", "format": "double", "type": "number" } }, "id": "GoogleTypeLatLng", "description": "An object representing a latitude/longitude pair. This is expressed as a pair\nof doubles representing degrees latitude and degrees longitude. Unless\nspecified otherwise, this must conform to the\n<a href=\"http://www.unoosa.org/pdf/icg/2012/template/WGS_84.pdf\">WGS84\nstandard</a>. Values must be within normalized ranges.", "type": "object" }, "GoogleCloudDialogflowV2IntentFollowupIntentInfo": { "description": "Represents a single followup intent in the chain.", "type": "object", "properties": { "followupIntentName": { "description": "The unique identifier of the followup intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "parentFollowupIntentName": { "description": "The unique identifier of the followup intent parent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentFollowupIntentInfo" }, "GoogleCloudDialogflowV2beta1IntentMessageSuggestions": { "description": "The collection of suggestions.", "type": "object", "properties": { "suggestions": { "description": "Required. The list of suggested replies.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSuggestion" } } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageSuggestions" }, "GoogleCloudDialogflowV2EntityType": { "properties": { "entities": { "description": "Optional. The collection of entities associated with the entity type.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2EntityTypeEntity" } }, "name": { "description": "Required for all methods except `create` (`create` populates the name\nautomatically.\nThe unique identifier of the entity type. Format:\n`projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "type": "string" }, "displayName": { "description": "Required. The name of the entity.", "type": "string" }, "kind": { "enumDescriptions": ["Not specified. This value should be never used.", "Map entity types allow mapping of a group of synonyms to a canonical\nvalue.", "List entity types contain a set of entries that do not map to canonical\nvalues. However, list entity types can contain references to other entity\ntypes (with or without aliases)."], "enum": ["KIND_UNSPECIFIED", "KIND_MAP", "KIND_LIST"], "description": "Required. Indicates the kind of entity type.", "type": "string" }, "autoExpansionMode": { "enumDescriptions": ["Auto expansion disabled for the entity.", "Allows an agent to recognize values that have not been explicitly\nlisted in the entity."], "enum": ["AUTO_EXPANSION_MODE_UNSPECIFIED", "AUTO_EXPANSION_MODE_DEFAULT"], "description": "Optional. Indicates whether the entity type can be automatically\nexpanded.", "type": "string" } }, "id": "GoogleCloudDialogflowV2EntityType", "description": "Represents an entity type.\nEntity types serve as a tool for extracting parameter values from natural\nlanguage queries.", "type": "object" }, "GoogleCloudDialogflowV2beta1IntentMessageQuickReplies": { "description": "The quick replies response message.", "type": "object", "properties": { "quickReplies": { "description": "Optional. The collection of quick replies.", "type": "array", "items": { "type": "string" } }, "title": { "description": "Optional. The title of the collection of quick replies.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageQuickReplies" }, "GoogleCloudDialogflowV2WebhookRequest": { "description": "The request message for a webhook call.", "type": "object", "properties": { "responseId": { "description": "The unique identifier of the response. Contains the same value as\n`[Streaming]DetectIntentResponse.response_id`.", "type": "string" }, "session": { "description": "The unique identifier of detectIntent request session.\nCan be used to identify end-user inside webhook implementation.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>`.", "type": "string" }, "queryResult": { "description": "The result of the conversational query or event processing. Contains the\nsame value as `[Streaming]DetectIntentResponse.query_result`.", "$ref": "GoogleCloudDialogflowV2QueryResult" }, "originalDetectIntentRequest": { "$ref": "GoogleCloudDialogflowV2OriginalDetectIntentRequest", "description": "Optional. The contents of the original request that was passed to\n`[Streaming]DetectIntent` call." } }, "id": "GoogleCloudDialogflowV2WebhookRequest" }, "GoogleCloudDialogflowV2beta1IntentFollowupIntentInfo": { "properties": { "followupIntentName": { "description": "The unique identifier of the followup intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "parentFollowupIntentName": { "description": "The unique identifier of the followup intent parent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentFollowupIntentInfo", "description": "Represents a single followup intent in the chain.", "type": "object" }, "GoogleCloudDialogflowV2TrainAgentRequest": { "properties": {}, "id": "GoogleCloudDialogflowV2TrainAgentRequest", "description": "The request message for Agents.TrainAgent.", "type": "object" }, "GoogleCloudDialogflowV2ExportAgentResponse": { "properties": { "agentContent": { "description": "The exported agent.\n\nExample for how to export an agent to a zip file via a command line:\n<pre>curl \\\n  'https://dialogflow.googleapis.com/v2/projects/&lt;project_name&gt;/agent:export'\\\n  -X POST \\\n  -H 'Authorization: Bearer '$(gcloud auth application-default\n  print-access-token) \\\n  -H 'Accept: application/json' \\\n  -H 'Content-Type: application/json' \\\n  --compressed \\\n  --data-binary '{}' \\\n| grep agentContent | sed -e 's/.*\"agentContent\": \"\\([^\"]*\\)\".*/\\1/' \\\n| base64 --decode > &lt;agent zip file&gt;</pre>", "format": "byte", "type": "string" }, "agentUri": { "description": "The URI to a file containing the exported agent. This field is populated\nonly if `agent_uri` is specified in `ExportAgentRequest`.", "type": "string" } }, "id": "GoogleCloudDialogflowV2ExportAgentResponse", "description": "The response message for Agents.ExportAgent.", "type": "object" }, "GoogleCloudDialogflowV2beta1EntityTypeEntity": { "description": "Optional. Represents an entity.", "type": "object", "properties": { "synonyms": { "description": "Required. A collection of synonyms. For `KIND_LIST` entity types this\nmust contain exactly one synonym equal to `value`.", "type": "array", "items": { "type": "string" } }, "value": { "description": "Required.\nFor `KIND_MAP` entity types:\n  A canonical name to be used in place of synonyms.\nFor `KIND_LIST` entity types:\n  A string that can contain references to other entity types (with or\n  without aliases).", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1EntityTypeEntity" }, "GoogleCloudDialogflowV2QueryParameters": { "properties": { "contexts": { "description": "Optional. The collection of contexts to be activated before this query is\nexecuted.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Context" } }, "timeZone": { "description": "Optional. The time zone of this conversational query from the\n[time zone database](https://www.iana.org/time-zones), e.g.,\nAmerica/New_York, Europe/Paris. If not provided, the time zone specified in\nagent settings is used.", "type": "string" }, "sessionEntityTypes": { "description": "Optional. The collection of session entity types to replace or extend\ndeveloper entities with for this query only. The entity synonyms apply\nto all languages.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2SessionEntityType" } }, "payload": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Optional. This field can be used to pass custom data into the webhook\nassociated with the agent. Arbitrary JSON objects are supported.", "type": "object" }, "geoLocation": { "description": "Optional. The geo location of this conversational query.", "$ref": "GoogleTypeLatLng" }, "resetContexts": { "description": "Optional. Specifies whether to delete all contexts in the current session\nbefore the new ones are activated.", "type": "boolean" } }, "id": "GoogleCloudDialogflowV2QueryParameters", "description": "Represents the parameters of the conversational query.", "type": "object" }, "GoogleCloudDialogflowV2WebhookResponse": { "properties": { "followupEventInput": { "$ref": "GoogleCloudDialogflowV2EventInput", "description": "Optional. Makes the platform immediately invoke another `DetectIntent` call\ninternally with the specified event as input." }, "outputContexts": { "description": "Optional. The collection of output contexts. This value is passed directly\nto `QueryResult.output_contexts`.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Context" } }, "fulfillmentText": { "description": "Optional. The text to be shown on the screen. This value is passed directly\nto `QueryResult.fulfillment_text`.", "type": "string" }, "fulfillmentMessages": { "description": "Optional. The collection of rich messages to present to the user. This\nvalue is passed directly to `QueryResult.fulfillment_messages`.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessage" } }, "payload": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Optional. This value is passed directly to `QueryResult.webhook_payload`.\nSee the related `fulfillment_messages[i].payload field`, which may be used\nas an alternative to this field.\n\nThis field can be used for Actions on Google responses.\nIt should have a structure similar to the JSON message shown here. For more\ninformation, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"google\": {\n    \"expectUserResponse\": true,\n    \"richResponse\": {\n      \"items\": [\n        {\n          \"simpleResponse\": {\n            \"textToSpeech\": \"this is a simple response\"\n          }\n        }\n      ]\n    }\n  }\n}</pre>", "type": "object" }, "source": { "description": "Optional. This value is passed directly to `QueryResult.webhook_source`.", "type": "string" } }, "id": "GoogleCloudDialogflowV2WebhookResponse", "description": "The response message for a webhook call.", "type": "object" }, "GoogleCloudDialogflowV2BatchCreateEntitiesRequest": { "description": "The request message for EntityTypes.BatchCreateEntities.", "type": "object", "properties": { "entities": { "description": "Required. The collection of entities to create.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2EntityTypeEntity" } }, "languageCode": { "description": "Optional. The language of entity synonyms defined in `entities`. If not\nspecified, the agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string" } }, "id": "GoogleCloudDialogflowV2BatchCreateEntitiesRequest" }, "GoogleCloudDialogflowV2IntentMessageCardButton": { "description": "Optional. Contains information about a button.", "type": "object", "properties": { "postback": { "description": "Optional. The text to send back to the Dialogflow API or a URI to\nopen.", "type": "string" }, "text": { "description": "Optional. The text to show on the button.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageCardButton" }, "GoogleCloudDialogflowV2beta1KnowledgeAnswers": { "description": "Represents the result of querying a Knowledge base.", "type": "object", "properties": { "answers": { "description": "A list of answers from Knowledge Connector.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer" } } }, "id": "GoogleCloudDialogflowV2beta1KnowledgeAnswers" }, "GoogleCloudDialogflowV2beta1SentimentAnalysisResult": { "properties": { "queryTextSentiment": { "$ref": "GoogleCloudDialogflowV2beta1Sentiment", "description": "The sentiment analysis result for `query_text`." } }, "id": "GoogleCloudDialogflowV2beta1SentimentAnalysisResult", "description": "The result of sentiment analysis as configured by\n`sentiment_analysis_request_config`.", "type": "object" }, "GoogleCloudDialogflowV2ListIntentsResponse": { "description": "The response message for Intents.ListIntents.", "type": "object", "properties": { "intents": { "description": "The list of agent intents. There will be a maximum number of items\nreturned based on the page_size field in the request.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Intent" } }, "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" } }, "id": "GoogleCloudDialogflowV2ListIntentsResponse" }, "GoogleCloudDialogflowV2beta1ExportAgentResponse": { "description": "The response message for Agents.ExportAgent.", "type": "object", "properties": { "agentUri": { "description": "The URI to a file containing the exported agent. This field is populated\nonly if `agent_uri` is specified in `ExportAgentRequest`.", "type": "string" }, "agentContent": { "description": "The exported agent.\n\nExample for how to export an agent to a zip file via a command line:\n<pre>curl \\\n  'https://dialogflow.googleapis.com/v2beta1/projects/&lt;project_name&gt;/agent:export'\\\n  -X POST \\\n  -H 'Authorization: Bearer '$(gcloud auth application-default\n  print-access-token) \\\n  -H 'Accept: application/json' \\\n  -H 'Content-Type: application/json' \\\n  --compressed \\\n  --data-binary '{}' \\\n| grep agentContent | sed -e 's/.*\"agentContent\": \"\\([^\"]*\\)\".*/\\1/' \\\n| base64 --decode > &lt;agent zip file&gt;</pre>", "format": "byte", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1ExportAgentResponse" }, "GoogleCloudDialogflowV2OriginalDetectIntentRequest": { "description": "Represents the contents of the original request that was passed to\nthe `[Streaming]DetectIntent` call.", "type": "object", "properties": { "payload": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Optional. This field is set to the value of the `QueryParameters.payload`\nfield passed in the request. Some integrations that query a Dialogflow\nagent may provide additional information in the payload.\n\nIn particular for the Telephony Gateway this field has the form:\n<pre>{\n \"telephony\": {\n   \"caller_id\": \"+18558363987\"\n }\n}</pre>\nNote: The caller ID field (`caller_id`) will be redacted for Standard\nEdition agents and populated with the caller ID in [E.164\nformat](https://en.wikipedia.org/wiki/E.164) for Enterprise Edition agents.", "type": "object" }, "source": { "description": "The source of this request, e.g., `google`, `facebook`, `slack`. It is set\nby Dialogflow-owned servers.", "type": "string" }, "version": { "description": "Optional. The version of the protocol used for this request.\nThis field is AoG-specific.", "type": "string" } }, "id": "GoogleCloudDialogflowV2OriginalDetectIntentRequest" }, "GoogleLongrunningOperation": { "description": "This resource represents a long-running operation that is the result of a\nnetwork API call.", "type": "object", "properties": { "error": { "description": "The error result of the operation in case of failure or cancellation.", "$ref": "GoogleRpcStatus" }, "metadata": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "Service-specific metadata associated with the operation.  It typically\ncontains progress information and common metadata such as create time.\nSome services might not provide such metadata.  Any method that returns a\nlong-running operation should document the metadata type, if any.", "type": "object" }, "done": { "description": "If the value is `false`, it means the operation is still in progress.\nIf `true`, the operation is completed, and either `error` or `response` is\navailable.", "type": "boolean" }, "response": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "The normal response of the operation in case of success.  If the original\nmethod returns no data on success, such as `Delete`, the response is\n`google.protobuf.Empty`.  If the original method is standard\n`Get`/`Create`/`Update`, the response should be the resource.  For other\nmethods, the response should have the type `XxxResponse`, where `Xxx`\nis the original method name.  For example, if the original method name\nis `TakeSnapshot()`, the inferred response type is\n`TakeSnapshotResponse`.", "type": "object" }, "name": { "description": "The server-assigned name, which is only unique within the same service that\noriginally returns it. If you use the default HTTP mapping, the\n`name` should have the format of `operations/some/unique/name`.", "type": "string" } }, "id": "GoogleLongrunningOperation" }, "GoogleCloudDialogflowV2beta1IntentMessageTelephonyTransferCall": { "properties": { "phoneNumber": { "description": "Required. The phone number to transfer the call to\nin [E.164 format](https://en.wikipedia.org/wiki/E.164).\n\nWe currently only allow transferring to US numbers (+1xxxyyyzzzz).", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageTelephonyTransferCall", "description": "Transfers the call in Telephony Gateway.", "type": "object" }, "GoogleCloudDialogflowV2beta1IntentMessageImage": { "description": "The image response message.", "type": "object", "properties": { "imageUri": { "description": "Optional. The public URI to an image file.", "type": "string" }, "accessibilityText": { "description": "A text description of the image to be used for accessibility,\ne.g., screen readers. Required if image_uri is set for CarouselSelect.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageImage" }, "GoogleCloudDialogflowV2ListEntityTypesResponse": { "description": "The response message for EntityTypes.ListEntityTypes.", "type": "object", "properties": { "entityTypes": { "description": "The list of agent entity types. There will be a maximum number of items\nreturned based on the page_size field in the request.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2EntityType" } }, "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" } }, "id": "GoogleCloudDialogflowV2ListEntityTypesResponse" }, "GoogleCloudDialogflowV2IntentMessageSimpleResponse": { "description": "The simple response message containing speech or text.", "type": "object", "properties": { "textToSpeech": { "description": "One of text_to_speech or ssml must be provided. The plain text of the\nspeech output. Mutually exclusive with ssml.", "type": "string" }, "ssml": { "description": "One of text_to_speech or ssml must be provided. Structured spoken\nresponse to the user in the SSML format. Mutually exclusive with\ntext_to_speech.", "type": "string" }, "displayText": { "description": "Optional. The text to display.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageSimpleResponse" }, "GoogleCloudDialogflowV2IntentMessageCarouselSelectItem": { "description": "An item in the carousel.", "type": "object", "properties": { "description": { "description": "Optional. The body text of the card.", "type": "string" }, "info": { "description": "Required. Additional info about the option item.", "$ref": "GoogleCloudDialogflowV2IntentMessageSelectItemInfo" }, "title": { "description": "Required. Title of the carousel item.", "type": "string" }, "image": { "$ref": "GoogleCloudDialogflowV2IntentMessageImage", "description": "Optional. The image to display." } }, "id": "GoogleCloudDialogflowV2IntentMessageCarouselSelectItem" }, "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButton": { "description": "The button object that appears at the bottom of a card.", "type": "object", "properties": { "openUriAction": { "description": "Required. Action to take when a user taps on the button.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButtonOpenUriAction" }, "title": { "description": "Required. The title of the button.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButton" }, "GoogleCloudDialogflowV2IntentTrainingPhrase": { "description": "Represents an example or template that the agent is trained on.", "type": "object", "properties": { "parts": { "description": "Required. The collection of training phrase parts (can be annotated).\nFields: `entity_type`, `alias` and `user_defined` should be populated\nonly for the annotated parts of the training phrase.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentTrainingPhrasePart" } }, "name": { "description": "Output only. The unique identifier of this training phrase.", "type": "string" }, "timesAddedCount": { "description": "Optional. Indicates how many times this example or template was added to\nthe intent. Each time a developer adds an existing sample by editing an\nintent or training, this counter is increased.", "format": "int32", "type": "integer" }, "type": { "description": "Required. The type of the training phrase.", "type": "string", "enumDescriptions": ["Not specified. This value should never be used.", "Examples do not contain @-prefixed entity type names, but example parts\ncan be annotated with entity types.", "Templates are not annotated with entity types, but they can contain\n@-prefixed entity type names as substrings."], "enum": ["TYPE_UNSPECIFIED", "EXAMPLE", "TEMPLATE"] } }, "id": "GoogleCloudDialogflowV2IntentTrainingPhrase" }, "GoogleCloudDialogflowV2SearchAgentsResponse": { "description": "The response message for Agents.SearchAgents.", "type": "object", "properties": { "agents": { "description": "The list of agents. There will be a maximum number of items returned based\non the page_size field in the request.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Agent" } }, "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" } }, "id": "GoogleCloudDialogflowV2SearchAgentsResponse" }, "GoogleCloudDialogflowV2EntityTypeBatch": { "properties": { "entityTypes": { "description": "A collection of entity types.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2EntityType" } } }, "id": "GoogleCloudDialogflowV2EntityTypeBatch", "description": "This message is a wrapper around a collection of entity types.", "type": "object" }, "GoogleCloudDialogflowV2beta1IntentMessageTelephonyPlayAudio": { "description": "Plays audio from a file in Telephony Gateway.", "type": "object", "properties": { "audioUri": { "description": "Required. URI to a Google Cloud Storage object containing the audio to\nplay, e.g., \"gs://bucket/object\". The object must contain a single\nchannel (mono) of linear PCM audio (2 bytes / sample) at 8kHz.\n\nThis object must be readable by the `service-<Project\nNumber>@gcp-sa-dialogflow.iam.gserviceaccount.com` service account\nwhere <Project Number> is the number of the Telephony Gateway project\n(usually the same as the Dialogflow agent project). If the Google Cloud\nStorage bucket is in the Telephony Gateway project, this permission is\nadded by default when enabling the Dialogflow V2 API.\n\nFor audio from other sources, consider using the\n`TelephonySynthesizeSpeech` message with SSML.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageTelephonyPlayAudio" }, "GoogleCloudDialogflowV2beta1WebhookRequest": { "description": "The request message for a webhook call.", "type": "object", "properties": { "session": { "description": "The unique identifier of detectIntent request session.\nCan be used to identify end-user inside webhook implementation.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>`.", "type": "string" }, "queryResult": { "$ref": "GoogleCloudDialogflowV2beta1QueryResult", "description": "The result of the conversational query or event processing. Contains the\nsame value as `[Streaming]DetectIntentResponse.query_result`." }, "originalDetectIntentRequest": { "$ref": "GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest", "description": "Optional. The contents of the original request that was passed to\n`[Streaming]DetectIntent` call." }, "alternativeQueryResults": { "description": "Alternative query results from KnowledgeService.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1QueryResult" } }, "responseId": { "description": "The unique identifier of the response. Contains the same value as\n`[Streaming]DetectIntentResponse.response_id`.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1WebhookRequest" }, "GoogleCloudDialogflowV2IntentMessageListSelect": { "description": "The card for presenting a list of options to select from.", "type": "object", "properties": { "items": { "description": "Required. List items.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageListSelectItem" } }, "title": { "description": "Optional. The overall title of the list.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageListSelect" }, "GoogleCloudDialogflowV2beta1IntentMessageCardButton": { "description": "Optional. Contains information about a button.", "type": "object", "properties": { "text": { "description": "Optional. The text to show on the button.", "type": "string" }, "postback": { "description": "Optional. The text to send back to the Dialogflow API or a URI to\nopen.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageCardButton" }, "GoogleProtobufEmpty": { "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.", "type": "object", "properties": {}, "id": "GoogleProtobufEmpty" }, "GoogleCloudDialogflowV2ImportAgentRequest": { "properties": { "agentContent": { "description": "The agent to import.\n\nExample for how to import an agent via the command line:\n<pre>curl \\\n  'https://dialogflow.googleapis.com/v2/projects/&lt;project_name&gt;/agent:import\\\n   -X POST \\\n   -H 'Authorization: Bearer '$(gcloud auth application-default\n   print-access-token) \\\n   -H 'Accept: application/json' \\\n   -H 'Content-Type: application/json' \\\n   --compressed \\\n   --data-binary \"{\n      'agentContent': '$(cat &lt;agent zip file&gt; | base64 -w 0)'\n   }\"</pre>", "format": "byte", "type": "string" }, "agentUri": { "description": "The URI to a Google Cloud Storage file containing the agent to import.\nNote: The URI must start with \"gs://\".", "type": "string" } }, "id": "GoogleCloudDialogflowV2ImportAgentRequest", "description": "The request message for Agents.ImportAgent.", "type": "object" }, "GoogleCloudDialogflowV2IntentMessageListSelectItem": { "description": "An item in the list.", "type": "object", "properties": { "description": { "description": "Optional. The main text describing the item.", "type": "string" }, "info": { "$ref": "GoogleCloudDialogflowV2IntentMessageSelectItemInfo", "description": "Required. Additional information about this option." }, "title": { "description": "Required. The title of the list item.", "type": "string" }, "image": { "description": "Optional. The image to display.", "$ref": "GoogleCloudDialogflowV2IntentMessageImage" } }, "id": "GoogleCloudDialogflowV2IntentMessageListSelectItem" }, "GoogleCloudDialogflowV2BatchDeleteEntityTypesRequest": { "description": "The request message for EntityTypes.BatchDeleteEntityTypes.", "type": "object", "properties": { "entityTypeNames": { "description": "Required. The names entity types to delete. All names must point to the\nsame agent as `parent`.", "type": "array", "items": { "type": "string" } } }, "id": "GoogleCloudDialogflowV2BatchDeleteEntityTypesRequest" }, "GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest": { "description": "Represents the contents of the original request that was passed to\nthe `[Streaming]DetectIntent` call.", "type": "object", "properties": { "source": { "description": "The source of this request, e.g., `google`, `facebook`, `slack`. It is set\nby Dialogflow-owned servers.", "type": "string" }, "version": { "description": "Optional. The version of the protocol used for this request.\nThis field is AoG-specific.", "type": "string" }, "payload": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Optional. This field is set to the value of the `QueryParameters.payload`\nfield passed in the request. Some integrations that query a Dialogflow\nagent may provide additional information in the payload.\n\nIn particular for the Telephony Gateway this field has the form:\n<pre>{\n \"telephony\": {\n   \"caller_id\": \"+18558363987\"\n }\n}</pre>\nNote: The caller ID field (`caller_id`) will be redacted for Standard\nEdition agents and populated with the caller ID in [E.164\nformat](https://en.wikipedia.org/wiki/E.164) for Enterprise Edition agents.", "type": "object" } }, "id": "GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest" }, "GoogleCloudDialogflowV2beta1WebhookResponse": { "description": "The response message for a webhook call.", "type": "object", "properties": { "source": { "description": "Optional. This value is passed directly to `QueryResult.webhook_source`.", "type": "string" }, "endInteraction": { "description": "Optional. Indicates that this intent ends an interaction. Some integrations\n(e.g., Actions on Google or Dialogflow phone gateway) use this information\nto close interaction with an end user. Default is false.", "type": "boolean" }, "followupEventInput": { "description": "Optional. Makes the platform immediately invoke another `DetectIntent` call\ninternally with the specified event as input.", "$ref": "GoogleCloudDialogflowV2beta1EventInput" }, "outputContexts": { "description": "Optional. The collection of output contexts. This value is passed directly\nto `QueryResult.output_contexts`.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Context" } }, "fulfillmentText": { "description": "Optional. The text to be shown on the screen. This value is passed directly\nto `QueryResult.fulfillment_text`.", "type": "string" }, "fulfillmentMessages": { "description": "Optional. The collection of rich messages to present to the user. This\nvalue is passed directly to `QueryResult.fulfillment_messages`.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessage" } }, "payload": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Optional. This value is passed directly to `QueryResult.webhook_payload`.\nSee the related `fulfillment_messages[i].payload field`, which may be used\nas an alternative to this field.\n\nThis field can be used for Actions on Google responses.\nIt should have a structure similar to the JSON message shown here. For more\ninformation, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"google\": {\n    \"expectUserResponse\": true,\n    \"richResponse\": {\n      \"items\": [\n        {\n          \"simpleResponse\": {\n            \"textToSpeech\": \"this is a simple response\"\n          }\n        }\n      ]\n    }\n  }\n}</pre>", "type": "object" } }, "id": "GoogleCloudDialogflowV2beta1WebhookResponse" }, "GoogleCloudDialogflowV2IntentMessageSelectItemInfo": { "description": "Additional info about the select item for when it is triggered in a\ndialog.", "type": "object", "properties": { "synonyms": { "description": "Optional. A list of synonyms that can also be used to trigger this\nitem in dialog.", "type": "array", "items": { "type": "string" } }, "key": { "description": "Required. A unique key that will be sent back to the agent if this\nresponse is given.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageSelectItemInfo" }, "GoogleCloudDialogflowV2IntentMessageBasicCardButtonOpenUriAction": { "description": "Opens the given URI.", "type": "object", "properties": { "uri": { "description": "Required. The HTTP or HTTPS scheme URI.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageBasicCardButtonOpenUriAction" }, "GoogleCloudDialogflowV2RestoreAgentRequest": { "properties": { "agentContent": { "description": "The agent to restore.\n\nExample for how to restore an agent via the command line:\n<pre>curl \\\n  'https://dialogflow.googleapis.com/v2/projects/&lt;project_name&gt;/agent:restore\\\n   -X POST \\\n   -H 'Authorization: Bearer '$(gcloud auth application-default\n   print-access-token) \\\n   -H 'Accept: application/json' \\\n   -H 'Content-Type: application/json' \\\n   --compressed \\\n   --data-binary \"{\n       'agentContent': '$(cat &lt;agent zip file&gt; | base64 -w 0)'\n   }\"</pre>", "format": "byte", "type": "string" }, "agentUri": { "description": "The URI to a Google Cloud Storage file containing the agent to restore.\nNote: The URI must start with \"gs://\".", "type": "string" } }, "id": "GoogleCloudDialogflowV2RestoreAgentRequest", "description": "The request message for Agents.RestoreAgent.", "type": "object" }, "GoogleCloudDialogflowV2DetectIntentResponse": { "description": "The message returned from the DetectIntent method.", "type": "object", "properties": { "queryResult": { "$ref": "GoogleCloudDialogflowV2QueryResult", "description": "The selected results of the conversational query or event processing.\nSee `alternative_query_results` for additional potential results." }, "webhookStatus": { "description": "Specifies the status of the webhook request. `webhook_status`\nis never populated in webhook requests.", "$ref": "GoogleRpcStatus" }, "responseId": { "description": "The unique identifier of the response. It can be used to\nlocate a response in the training example set or for reporting issues.", "type": "string" } }, "id": "GoogleCloudDialogflowV2DetectIntentResponse" }, "GoogleCloudDialogflowV2IntentMessageQuickReplies": { "description": "The quick replies response message.", "type": "object", "properties": { "quickReplies": { "description": "Optional. The collection of quick replies.", "type": "array", "items": { "type": "string" } }, "title": { "description": "Optional. The title of the collection of quick replies.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageQuickReplies" }, "GoogleCloudDialogflowV2BatchUpdateEntityTypesResponse": { "description": "The response message for EntityTypes.BatchUpdateEntityTypes.", "type": "object", "properties": { "entityTypes": { "description": "The collection of updated or created entity types.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2EntityType" } } }, "id": "GoogleCloudDialogflowV2BatchUpdateEntityTypesResponse" }, "GoogleCloudDialogflowV2beta1EntityType": { "description": "Represents an entity type.\nEntity types serve as a tool for extracting parameter values from natural\nlanguage queries.", "type": "object", "properties": { "name": { "description": "Required for all methods except `create` (`create` populates the name\nautomatically.\nThe unique identifier of the entity type. Format:\n`projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "type": "string" }, "displayName": { "description": "Required. The name of the entity.", "type": "string" }, "kind": { "description": "Required. Indicates the kind of entity type.", "type": "string", "enumDescriptions": ["Not specified. This value should be never used.", "Map entity types allow mapping of a group of synonyms to a canonical\nvalue.", "List entity types contain a set of entries that do not map to canonical\nvalues. However, list entity types can contain references to other entity\ntypes (with or without aliases)."], "enum": ["KIND_UNSPECIFIED", "KIND_MAP", "KIND_LIST"] }, "autoExpansionMode": { "enumDescriptions": ["Auto expansion disabled for the entity.", "Allows an agent to recognize values that have not been explicitly\nlisted in the entity."], "enum": ["AUTO_EXPANSION_MODE_UNSPECIFIED", "AUTO_EXPANSION_MODE_DEFAULT"], "description": "Optional. Indicates whether the entity type can be automatically\nexpanded.", "type": "string" }, "entities": { "description": "Optional. The collection of entities associated with the entity type.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1EntityTypeEntity" } } }, "id": "GoogleCloudDialogflowV2beta1EntityType" }, "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponse": { "description": "The simple response message containing speech or text.", "type": "object", "properties": { "textToSpeech": { "description": "One of text_to_speech or ssml must be provided. The plain text of the\nspeech output. Mutually exclusive with ssml.", "type": "string" }, "ssml": { "description": "One of text_to_speech or ssml must be provided. Structured spoken\nresponse to the user in the SSML format. Mutually exclusive with\ntext_to_speech.", "type": "string" }, "displayText": { "description": "Optional. The text to display.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponse" }, "GoogleCloudDialogflowV2BatchUpdateEntityTypesRequest": { "description": "The request message for EntityTypes.BatchUpdateEntityTypes.", "type": "object", "properties": { "entityTypeBatchUri": { "description": "The URI to a Google Cloud Storage file containing entity types to update\nor create. The file format can either be a serialized proto (of\nEntityBatch type) or a JSON object. Note: The URI must start with\n\"gs://\".", "type": "string" }, "entityTypeBatchInline": { "description": "The collection of entity type to update or create.", "$ref": "GoogleCloudDialogflowV2EntityTypeBatch" }, "languageCode": { "description": "Optional. The language of entity synonyms defined in `entity_types`. If not\nspecified, the agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string" }, "updateMask": { "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" } }, "id": "GoogleCloudDialogflowV2BatchUpdateEntityTypesRequest" }, "GoogleCloudDialogflowV2beta1IntentMessageTelephonySynthesizeSpeech": { "description": "Synthesizes speech and plays back the synthesized audio to the caller in\nTelephony Gateway.\n\nTelephony Gateway takes the synthesizer settings from\n`DetectIntentResponse.output_audio_config` which can either be set\nat request-level or can come from the agent-level synthesizer config.", "type": "object", "properties": { "ssml": { "description": "The SSML to be synthesized. For more information, see\n[SSML](https://developers.google.com/actions/reference/ssml).", "type": "string" }, "text": { "description": "The raw text to be synthesized.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageTelephonySynthesizeSpeech" }, "GoogleCloudDialogflowV2beta1QueryResult": { "description": "Represents the result of conversational query or event processing.", "type": "object", "properties": { "fulfillmentText": { "description": "The text to be pronounced to the user or shown on the screen.", "type": "string" }, "parameters": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "The collection of extracted parameters.", "type": "object" }, "knowledgeAnswers": { "$ref": "GoogleCloudDialogflowV2beta1KnowledgeAnswers", "description": "The result from Knowledge Connector (if any), ordered by decreasing\n`KnowledgeAnswers.match_confidence`." }, "sentimentAnalysisResult": { "$ref": "GoogleCloudDialogflowV2beta1SentimentAnalysisResult", "description": "The sentiment analysis result, which depends on the\n`sentiment_analysis_request_config` specified in the request." }, "intentDetectionConfidence": { "description": "The intent detection confidence. Values range from 0.0\n(completely uncertain) to 1.0 (completely certain).\nIf there are `multiple knowledge_answers` messages, this value is set to\nthe greatest `knowledgeAnswers.match_confidence` value in the list.", "format": "float", "type": "number" }, "allRequiredParamsPresent": { "description": "This field is set to:\n- `false` if the matched intent has required parameters and not all of\n   the required parameter values have been collected.\n- `true` if all required parameter values have been collected, or if the\n   matched intent doesn't contain any required parameters.", "type": "boolean" }, "speechRecognitionConfidence": { "description": "The Speech recognition confidence between 0.0 and 1.0. A higher number\nindicates an estimated greater likelihood that the recognized words are\ncorrect. The default of 0.0 is a sentinel value indicating that confidence\nwas not set.\n\nThis field is not guaranteed to be accurate or set. In particular this\nfield isn't set for StreamingDetectIntent since the streaming endpoint has\nseparate confidence estimates per portion of the audio in\nStreamingRecognitionResult.", "format": "float", "type": "number" }, "queryText": { "description": "The original conversational query text:\n- If natural language text was provided as input, `query_text` contains\n  a copy of the input.\n- If natural language speech audio was provided as input, `query_text`\n  contains the speech recognition result. If speech recognizer produced\n  multiple alternatives, a particular one is picked.\n- If an event was provided as input, `query_text` is not set.", "type": "string" }, "diagnosticInfo": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "The free-form diagnostic info. For example, this field\ncould contain webhook call latency.", "type": "object" }, "outputContexts": { "description": "The collection of output contexts. If applicable,\n`output_contexts.parameters` contains entries with name\n`<parameter name>.original` containing the original parameter values\nbefore the query.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Context" } }, "languageCode": { "description": "The language that was triggered during intent detection.\nSee [Language Support](https://dialogflow.com/docs/reference/language)\nfor a list of the currently supported language codes.", "type": "string" }, "intent": { "$ref": "GoogleCloudDialogflowV2beta1Intent", "description": "The intent that matched the conversational query. Some, not\nall fields are filled in this message, including but not limited to:\n`name`, `display_name` and `webhook_state`." }, "webhookPayload": { "description": "If the query was fulfilled by a webhook call, this field is set to the\nvalue of the `payload` field returned in the webhook response.", "type": "object", "additionalProperties": { "description": "Properties of the object.", "type": "any" } }, "fulfillmentMessages": { "description": "The collection of rich messages to present to the user.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessage" } }, "action": { "description": "The action name from the matched intent.", "type": "string" }, "webhookSource": { "description": "If the query was fulfilled by a webhook call, this field is set to the\nvalue of the `source` field returned in the webhook response.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1QueryResult" }, "GoogleCloudDialogflowV2ExportAgentRequest": { "description": "The request message for Agents.ExportAgent.", "type": "object", "properties": { "agentUri": { "description": "Optional. The\n[Google Cloud Storage](https://cloud.google.com/storage/docs/)\nURI to export the agent to.\nThe format of this URI must be `gs://<bucket-name>/<object-name>`.\nIf left unspecified, the serialized agent is returned inline.", "type": "string" } }, "id": "GoogleCloudDialogflowV2ExportAgentRequest" }, "GoogleCloudDialogflowV2TextInput": { "properties": { "text": { "description": "Required. The UTF-8 encoded natural language text to be processed.\nText length must not exceed 256 bytes.", "type": "string" }, "languageCode": { "description": "Required. The language of this conversational query. See [Language\nSupport](https://dialogflow.com/docs/languages) for a list of the\ncurrently supported language codes. Note that queries in the same session\ndo not necessarily need to specify the same language.", "type": "string" } }, "id": "GoogleCloudDialogflowV2TextInput", "description": "Represents the natural language text to be processed.", "type": "object" }, "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelectItem": { "description": "An item in the carousel.", "type": "object", "properties": { "description": { "description": "Optional. The body text of the card.", "type": "string" }, "info": { "description": "Required. Additional info about the option item.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo" }, "title": { "description": "Required. Title of the carousel item.", "type": "string" }, "image": { "description": "Optional. The image to display.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageImage" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelectItem" }, "GoogleCloudDialogflowV2Context": { "properties": { "lifespanCount": { "description": "Optional. The number of conversational query requests after which the\ncontext expires. If set to `0` (the default) the context expires\nimmediately. Contexts expire automatically after 10 minutes even if there\nare no matching queries.", "format": "int32", "type": "integer" }, "name": { "description": "Required. The unique identifier of the context. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`.", "type": "string" }, "parameters": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Optional. The collection of parameters associated with this context.\nRefer to [this doc](https://dialogflow.com/docs/actions-and-parameters) for\nsyntax.", "type": "object" } }, "id": "GoogleCloudDialogflowV2Context", "description": "Represents a context.", "type": "object" }, "GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer": { "description": "An answer from Knowledge Connector.", "type": "object", "properties": { "source": { "description": "Indicates which Knowledge Document this answer was extracted from.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base\nID>/documents/<Document ID>`.", "type": "string" }, "answer": { "description": "The piece of text from the `source` knowledge base document that answers\nthis conversational query.", "type": "string" }, "faqQuestion": { "description": "The corresponding FAQ question if the answer was extracted from a FAQ\nDocument, empty otherwise.", "type": "string" }, "matchConfidenceLevel": { "description": "The system's confidence level that this knowledge answer is a good match\nfor this conversational query.\nNOTE: The confidence level for a given `<query, answer>` pair may change\nwithout notice, as it depends on models that are constantly being\nimproved. However, it will change less frequently than the confidence\nscore below, and should be preferred for referencing the quality of an\nanswer.", "type": "string", "enumDescriptions": ["Not specified.", "Indicates that the confidence is low.", "Indicates our confidence is medium.", "Indicates our confidence is high."], "enum": ["MATCH_CONFIDENCE_LEVEL_UNSPECIFIED", "LOW", "MEDIUM", "HIGH"] }, "matchConfidence": { "description": "The system's confidence score that this Knowledge answer is a good match\nfor this converstational query, range from 0.0 (completely uncertain)\nto 1.0 (completely certain).\nNote: The confidence score is likely to vary somewhat (possibly even for\nidentical requests), as the underlying model is under constant\nimprovement, we may deprecate it in the future. We recommend using\n`match_confidence_level` which should be generally more stable.", "format": "float", "type": "number" } }, "id": "GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer" }, "GoogleCloudDialogflowV2BatchUpdateEntitiesRequest": { "properties": { "entities": { "description": "Required. The collection of new entities to replace the existing entities.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2EntityTypeEntity" } }, "languageCode": { "description": "Optional. The language of entity synonyms defined in `entities`. If not\nspecified, the agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string" }, "updateMask": { "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" } }, "id": "GoogleCloudDialogflowV2BatchUpdateEntitiesRequest", "description": "The response message for EntityTypes.BatchCreateEntities.", "type": "object" }, "GoogleCloudDialogflowV2BatchUpdateIntentsResponse": { "properties": { "intents": { "description": "The collection of updated or created intents.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Intent" } } }, "id": "GoogleCloudDialogflowV2BatchUpdateIntentsResponse", "description": "The response message for Intents.BatchUpdateIntents.", "type": "object" }, "GoogleCloudDialogflowV2Agent": { "description": "Represents a conversational agent.", "type": "object", "properties": { "parent": { "description": "Required. The project of this agent.\nFormat: `projects/<Project ID>`.", "type": "string" }, "matchMode": { "enum": ["MATCH_MODE_UNSPECIFIED", "MATCH_MODE_HYBRID", "MATCH_MODE_ML_ONLY"], "description": "Optional. Determines how intents are detected from user queries.", "type": "string", "enumDescriptions": ["Not specified.", "Best for agents with a small number of examples in intents and/or wide\nuse of templates syntax and composite entities.", "Can be used for agents with a large number of examples in intents,\nespecially the ones using @sys.any or very large developer entities."] }, "supportedLanguageCodes": { "description": "Optional. The list of all languages supported by this agent (except for the\n`default_language_code`).", "type": "array", "items": { "type": "string" } }, "enableLogging": { "description": "Optional. Determines whether this agent should log conversation queries.", "type": "boolean" }, "avatarUri": { "description": "Optional. The URI of the agent's avatar.\nAvatars are used throughout the Dialogflow console and in the self-hosted\n[Web Demo](https://dialogflow.com/docs/integrations/web-demo) integration.", "type": "string" }, "classificationThreshold": { "description": "Optional. To filter out false positive results and still get variety in\nmatched natural language inputs for your agent, you can tune the machine\nlearning classification threshold. If the returned score value is less than\nthe threshold value, then a fallback intent is be triggered or, if there\nare no fallback intents defined, no intent will be triggered. The score\nvalues range from 0.0 (completely uncertain) to 1.0 (completely certain).\nIf set to 0.0, the default of 0.3 is used.", "format": "float", "type": "number" }, "defaultLanguageCode": { "description": "Required. The default language of the agent as a language tag. See\n[Language Support](https://dialogflow.com/docs/reference/language) for a\nlist of the currently supported language codes.\nThis field cannot be set by the `Update` method.", "type": "string" }, "timeZone": { "description": "Required. The time zone of this agent from the\n[time zone database](https://www.iana.org/time-zones), e.g.,\nAmerica/New_York, Europe/Paris.", "type": "string" }, "description": { "description": "Optional. The description of this agent.\nThe maximum length is 500 characters. If exceeded, the request is rejected.", "type": "string" }, "displayName": { "description": "Required. The name of this agent.", "type": "string" } }, "id": "GoogleCloudDialogflowV2Agent" }, "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButtonOpenUriAction": { "description": "Opens the given URI.", "type": "object", "properties": { "uri": { "description": "Required. The HTTP or HTTPS scheme URI.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButtonOpenUriAction" }, "GoogleCloudDialogflowV2IntentMessage": { "properties": { "carouselSelect": { "description": "The carousel card response for Actions on Google.", "$ref": "GoogleCloudDialogflowV2IntentMessageCarouselSelect" }, "linkOutSuggestion": { "description": "The link out suggestion chip for Actions on Google.", "$ref": "GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion" }, "simpleResponses": { "description": "The voice and text-only responses for Actions on Google.", "$ref": "GoogleCloudDialogflowV2IntentMessageSimpleResponses" }, "image": { "$ref": "GoogleCloudDialogflowV2IntentMessageImage", "description": "The image response." }, "payload": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Returns a response containing a custom, platform-specific payload.\nSee the Intent.Message.Platform type for a description of the\nstructure that may be required for your platform.", "type": "object" }, "text": { "description": "The text response.", "$ref": "GoogleCloudDialogflowV2IntentMessageText" }, "platform": { "enumDescriptions": ["Not specified.", "Facebook.", "Slack.", "Telegram.", "Kik.", "Skype.", "Line.", "Viber.", "Actions on Google.\nWhen using Actions on Google, you can choose one of the specific\nIntent.Message types that mention support for Actions on Google,\nor you can use the advanced Intent.Message.payload field.\nThe payload field provides access to AoG features not available in the\nspecific message types.\nIf using the Intent.Message.payload field, it should have a structure\nsimilar to the JSON message shown here. For more information, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"expectUserResponse\": true,\n  \"isSsml\": false,\n  \"noInputPrompts\": [],\n  \"richResponse\": {\n    \"items\": [\n      {\n        \"simpleResponse\": {\n          \"displayText\": \"hi\",\n          \"textToSpeech\": \"hello\"\n        }\n      }\n    ],\n    \"suggestions\": [\n      {\n        \"title\": \"Say this\"\n      },\n      {\n        \"title\": \"or this\"\n      }\n    ]\n  },\n  \"systemIntent\": {\n    \"data\": {\n      \"@type\": \"type.googleapis.com/google.actions.v2.OptionValueSpec\",\n      \"listSelect\": {\n        \"items\": [\n          {\n            \"optionInfo\": {\n              \"key\": \"key1\",\n              \"synonyms\": [\n                \"key one\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          },\n          {\n            \"optionInfo\": {\n              \"key\": \"key2\",\n              \"synonyms\": [\n                \"key two\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          }\n        ]\n      }\n    },\n    \"intent\": \"actions.intent.OPTION\"\n  }\n}</pre>"], "enum": ["PLATFORM_UNSPECIFIED", "FACEBOOK", "SLACK", "TELEGRAM", "KIK", "SKYPE", "LINE", "VIBER", "ACTIONS_ON_GOOGLE"], "description": "Optional. The platform that this message is intended for.", "type": "string" }, "suggestions": { "description": "The suggestion chips for Actions on Google.", "$ref": "GoogleCloudDialogflowV2IntentMessageSuggestions" }, "listSelect": { "$ref": "GoogleCloudDialogflowV2IntentMessageListSelect", "description": "The list card response for Actions on Google." }, "quickReplies": { "description": "The quick replies response.", "$ref": "GoogleCloudDialogflowV2IntentMessageQuickReplies" }, "card": { "description": "The card response.", "$ref": "GoogleCloudDialogflowV2IntentMessageCard" }, "basicCard": { "description": "The basic card response for Actions on Google.", "$ref": "GoogleCloudDialogflowV2IntentMessageBasicCard" } }, "id": "GoogleCloudDialogflowV2IntentMessage", "description": "Corresponds to the `Response` field in the Dialogflow console.", "type": "object" }, "GoogleCloudDialogflowV2IntentMessageBasicCard": { "description": "The basic card message. Useful for displaying information.", "type": "object", "properties": { "title": { "description": "Optional. The title of the card.", "type": "string" }, "image": { "description": "Optional. The image for the card.", "$ref": "GoogleCloudDialogflowV2IntentMessageImage" }, "formattedText": { "description": "Required, unless image is present. The body text of the card.", "type": "string" }, "buttons": { "description": "Optional. The collection of card buttons.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageBasicCardButton" } }, "subtitle": { "description": "Optional. The subtitle of the card.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageBasicCard" }, "GoogleCloudDialogflowV2ListSessionEntityTypesResponse": { "description": "The response message for SessionEntityTypes.ListSessionEntityTypes.", "type": "object", "properties": { "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" }, "sessionEntityTypes": { "description": "The list of session entity types. There will be a maximum number of items\nreturned based on the page_size field in the request.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2SessionEntityType" } } }, "id": "GoogleCloudDialogflowV2ListSessionEntityTypesResponse" }, "GoogleCloudDialogflowV2beta1Sentiment": { "properties": { "score": { "description": "Sentiment score between -1.0 (negative sentiment) and 1.0 (positive\nsentiment).", "format": "float", "type": "number" }, "magnitude": { "description": "A non-negative number in the [0, +inf) range, which represents the absolute\nmagnitude of sentiment, regardless of score (positive or negative).", "format": "float", "type": "number" } }, "id": "GoogleCloudDialogflowV2beta1Sentiment", "description": "The sentiment, such as positive/negative feeling or association, for a unit\nof analysis, such as the query text.", "type": "object" }, "GoogleCloudDialogflowV2beta1Intent": { "description": "Represents an intent.\nIntents convert a number of user expressions or patterns into an action. An\naction is an extraction of a user command or sentence semantics.", "type": "object", "properties": { "displayName": { "description": "Required. The name of this intent.", "type": "string" }, "rootFollowupIntentName": { "description": "The unique identifier of the root intent in the chain of followup intents.\nIt identifies the correct followup intents chain for this intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "mlDisabled": { "description": "Optional. Indicates whether Machine Learning is disabled for the intent.\nNote: If `ml_disabled` setting is set to true, then this intent is not\ntaken into account during inference in `ML ONLY` match mode. Also,\nauto-markup in the UI is turned off.", "type": "boolean" }, "isFallback": { "description": "Optional. Indicates whether this is a fallback intent.", "type": "boolean" }, "mlEnabled": { "description": "Optional. Indicates whether Machine Learning is enabled for the intent.\nNote: If `ml_enabled` setting is set to false, then this intent is not\ntaken into account during inference in `ML ONLY` match mode. Also,\nauto-markup in the UI is turned off.\nDEPRECATED! Please use `ml_disabled` field instead.\nNOTE: If both `ml_enabled` and `ml_disabled` are either not set or false,\nthen the default value is determined as follows:\n- Before April 15th, 2018 the default is:\n  ml_enabled = false / ml_disabled = true.\n- After April 15th, 2018 the default is:\n  ml_enabled = true / ml_disabled = false.", "type": "boolean" }, "parameters": { "description": "Optional. The collection of parameters associated with the intent.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentParameter" } }, "resetContexts": { "description": "Optional. Indicates whether to delete all contexts in the current\nsession when this intent is matched.", "type": "boolean" }, "trainingPhrases": { "description": "Optional. The collection of examples/templates that the agent is\ntrained on.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentTrainingPhrase" } }, "parentFollowupIntentName": { "description": "The unique identifier of the parent intent in the chain of followup\nintents.\nIt identifies the parent followup intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "events": { "description": "Optional. The collection of event names that trigger the intent.\nIf the collection of input contexts is not empty, all of the contexts must\nbe present in the active user session for an event to trigger this intent.", "type": "array", "items": { "type": "string" } }, "priority": { "description": "Optional. The priority of this intent. Higher numbers represent higher\npriorities. Zero or negative numbers mean that the intent is disabled.", "format": "int32", "type": "integer" }, "endInteraction": { "description": "Optional. Indicates that this intent ends an interaction. Some integrations\n(e.g., Actions on Google or Dialogflow phone gateway) use this information\nto close interaction with an end user. Default is false.", "type": "boolean" }, "outputContexts": { "description": "Optional. The collection of contexts that are activated when the intent\nis matched. Context messages in this collection should not set the\nparameters field. Setting the `lifespan_count` to 0 will reset the context\nwhen the intent is matched.\nFormat: `projects/<Project ID>/agent/sessions/-/contexts/<Context ID>`.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Context" } }, "defaultResponsePlatforms": { "description": "Optional. The list of platforms for which the first response will be\ntaken from among the messages assigned to the DEFAULT_PLATFORM.", "type": "array", "items": { "enum": ["PLATFORM_UNSPECIFIED", "FACEBOOK", "SLACK", "TELEGRAM", "KIK", "SKYPE", "LINE", "VIBER", "ACTIONS_ON_GOOGLE", "TELEPHONY"], "type": "string" }, "enumDescriptions": ["Not specified.", "Facebook.", "Slack.", "Telegram.", "Kik.", "Skype.", "Line.", "Viber.", "Actions on Google.\nWhen using Actions on Google, you can choose one of the specific\nIntent.Message types that mention support for Actions on Google,\nor you can use the advanced Intent.Message.payload field.\nThe payload field provides access to AoG features not available in the\nspecific message types.\nIf using the Intent.Message.payload field, it should have a structure\nsimilar to the JSON message shown here. For more information, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"expectUserResponse\": true,\n  \"isSsml\": false,\n  \"noInputPrompts\": [],\n  \"richResponse\": {\n    \"items\": [\n      {\n        \"simpleResponse\": {\n          \"displayText\": \"hi\",\n          \"textToSpeech\": \"hello\"\n        }\n      }\n    ],\n    \"suggestions\": [\n      {\n        \"title\": \"Say this\"\n      },\n      {\n        \"title\": \"or this\"\n      }\n    ]\n  },\n  \"systemIntent\": {\n    \"data\": {\n      \"@type\": \"type.googleapis.com/google.actions.v2.OptionValueSpec\",\n      \"listSelect\": {\n        \"items\": [\n          {\n            \"optionInfo\": {\n              \"key\": \"key1\",\n              \"synonyms\": [\n                \"key one\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          },\n          {\n            \"optionInfo\": {\n              \"key\": \"key2\",\n              \"synonyms\": [\n                \"key two\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          }\n        ]\n      }\n    },\n    \"intent\": \"actions.intent.OPTION\"\n  }\n}</pre>", "Telephony Gateway."] }, "name": { "description": "Required for all methods except `create` (`create` populates the name\nautomatically.\nThe unique identifier of this intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "action": { "description": "Optional. The name of the action associated with the intent.\nNote: The action name must not contain whitespaces.", "type": "string" }, "messages": { "description": "Optional. The collection of rich messages corresponding to the\n`Response` field in the Dialogflow console.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessage" } }, "inputContextNames": { "description": "Optional. The list of context names required for this intent to be\ntriggered.\nFormat: `projects/<Project ID>/agent/sessions/-/contexts/<Context ID>`.", "type": "array", "items": { "type": "string" } }, "webhookState": { "description": "Optional. Indicates whether webhooks are enabled for the intent.", "type": "string", "enumDescriptions": ["Webhook is disabled in the agent and in the intent.", "Webhook is enabled in the agent and in the intent.", "Webhook is enabled in the agent and in the intent. Also, each slot\nfilling prompt is forwarded to the webhook."], "enum": ["WEBHOOK_STATE_UNSPECIFIED", "WEBHOOK_STATE_ENABLED", "WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING"] }, "followupIntentInfo": { "description": "Optional. Collection of information about all followup intents that have\nname of this intent as a root_name.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentFollowupIntentInfo" } } }, "id": "GoogleCloudDialogflowV2beta1Intent" }, "GoogleCloudDialogflowV2beta1BatchUpdateEntityTypesResponse": { "description": "The response message for EntityTypes.BatchUpdateEntityTypes.", "type": "object", "properties": { "entityTypes": { "description": "The collection of updated or created entity types.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1EntityType" } } }, "id": "GoogleCloudDialogflowV2beta1BatchUpdateEntityTypesResponse" }, "GoogleCloudDialogflowV2IntentMessageSuggestion": { "description": "The suggestion chip message that the user can tap to quickly post a reply\nto the conversation.", "type": "object", "properties": { "title": { "description": "Required. The text shown the in the suggestion chip.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageSuggestion" }, "GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart": { "description": "Represents a part of a training phrase.", "type": "object", "properties": { "text": { "description": "Required. The text corresponding to the example or template,\nif there are no annotations. For\nannotated examples, it is the text for one of the example's parts.", "type": "string" }, "entityType": { "description": "Optional. The entity type name prefixed with `@`. This field is\nrequired for the annotated part of the text and applies only to\nexamples.", "type": "string" }, "alias": { "description": "Optional. The parameter name for the value extracted from the\nannotated part of the example.", "type": "string" }, "userDefined": { "description": "Optional. Indicates whether the text was manually annotated by the\ndeveloper.", "type": "boolean" } }, "id": "GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart" }, "GoogleCloudDialogflowV2beta1EventInput": { "properties": { "languageCode": { "description": "Required. The language of this query. See [Language\nSupport](https://dialogflow.com/docs/languages) for a list of the\ncurrently supported language codes. Note that queries in the same session\ndo not necessarily need to specify the same language.", "type": "string" }, "name": { "description": "Required. The unique identifier of the event.", "type": "string" }, "parameters": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Optional. The collection of parameters associated with the event.", "type": "object" } }, "id": "GoogleCloudDialogflowV2beta1EventInput", "description": "Events allow for matching intents by event name instead of the natural\nlanguage input. For instance, input `<event: { name: “welcome_event”,\nparameters: { name: “Sam” } }>` can trigger a personalized welcome response.\nThe parameter `name` may be used by the agent in the response:\n`“Hello #welcome_event.name! What can I do for you today?”`.", "type": "object" }, "GoogleCloudDialogflowV2beta1IntentMessageListSelectItem": { "description": "An item in the list.", "type": "object", "properties": { "description": { "description": "Optional. The main text describing the item.", "type": "string" }, "info": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo", "description": "Required. Additional information about this option." }, "title": { "description": "Required. The title of the list item.", "type": "string" }, "image": { "description": "Optional. The image to display.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageImage" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageListSelectItem" }, "GoogleCloudDialogflowV2InputAudioConfig": { "description": "Instructs the speech recognizer how to process the audio content.", "type": "object", "properties": { "languageCode": { "description": "Required. The language of the supplied audio. Dialogflow does not do\ntranslations. See [Language\nSupport](https://dialogflow.com/docs/languages) for a list of the\ncurrently supported language codes. Note that queries in the same session\ndo not necessarily need to specify the same language.", "type": "string" }, "phraseHints": { "description": "Optional. The collection of phrase hints which are used to boost accuracy\nof speech recognition.\nRefer to\n[Cloud Speech API\ndocumentation](https://cloud.google.com/speech-to-text/docs/basics#phrase-hints)\nfor more details.", "type": "array", "items": { "type": "string" } }, "audioEncoding": { "description": "Required. Audio encoding of the audio content to process.", "type": "string", "enumDescriptions": ["Not specified.", "Uncompressed 16-bit signed little-endian samples (Linear PCM).", "[`FLAC`](https://xiph.org/flac/documentation.html) (Free Lossless Audio\nCodec) is the recommended encoding because it is lossless (therefore\nrecognition is not compromised) and requires only about half the\nbandwidth of `LINEAR16`. `FLAC` stream encoding supports 16-bit and\n24-bit samples, however, not all fields in `STREAMINFO` are supported.", "8-bit samples that compand 14-bit audio samples using G.711 PCMU/mu-law.", "Adaptive Multi-Rate Narrowband codec. `sample_rate_hertz` must be 8000.", "Adaptive Multi-Rate Wideband codec. `sample_rate_hertz` must be 16000.", "Opus encoded audio frames in Ogg container\n([OggOpus](https://wiki.xiph.org/OggOpus)).\n`sample_rate_hertz` must be 16000.", "Although the use of lossy encodings is not recommended, if a very low\nbitrate encoding is required, `OGG_OPUS` is highly preferred over\nSpeex encoding. The [Speex](https://speex.org/) encoding supported by\nDialogflow API has a header byte in each block, as in MIME type\n`audio/x-speex-with-header-byte`.\nIt is a variant of the RTP Speex encoding defined in\n[RFC 5574](https://tools.ietf.org/html/rfc5574).\nThe stream is a sequence of blocks, one block per RTP packet. Each block\nstarts with a byte containing the length of the block, in bytes, followed\nby one or more frames of Speex data, padded to an integral number of\nbytes (octets) as specified in RFC 5574. In other words, each RTP header\nis replaced with a single byte containing the block length. Only Speex\nwideband is supported. `sample_rate_hertz` must be 16000."], "enum": ["AUDIO_ENCODING_UNSPECIFIED", "AUDIO_ENCODING_LINEAR_16", "AUDIO_ENCODING_FLAC", "AUDIO_ENCODING_MULAW", "AUDIO_ENCODING_AMR", "AUDIO_ENCODING_AMR_WB", "AUDIO_ENCODING_OGG_OPUS", "AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE"] }, "sampleRateHertz": { "description": "Required. Sample rate (in Hertz) of the audio content sent in the query.\nRefer to\n[Cloud Speech API\ndocumentation](https://cloud.google.com/speech-to-text/docs/basics) for\nmore details.", "format": "int32", "type": "integer" } }, "id": "GoogleCloudDialogflowV2InputAudioConfig" }, "GoogleCloudDialogflowV2BatchUpdateIntentsRequest": { "description": "The request message for Intents.BatchUpdateIntents.", "type": "object", "properties": { "intentBatchUri": { "description": "The URI to a Google Cloud Storage file containing intents to update or\ncreate. The file format can either be a serialized proto (of IntentBatch\ntype) or JSON object. Note: The URI must start with \"gs://\".", "type": "string" }, "intentView": { "description": "Optional. The resource view to apply to the returned intent.", "type": "string", "enumDescriptions": ["Training phrases field is not populated in the response.", "All fields are populated."], "enum": ["INTENT_VIEW_UNSPECIFIED", "INTENT_VIEW_FULL"] }, "intentBatchInline": { "$ref": "GoogleCloudDialogflowV2IntentBatch", "description": "The collection of intents to update or create." }, "languageCode": { "description": "Optional. The language of training phrases, parameters and rich messages\ndefined in `intents`. If not specified, the agent's default language is\nused. [More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string" }, "updateMask": { "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" } }, "id": "GoogleCloudDialogflowV2BatchUpdateIntentsRequest" }, "GoogleCloudDialogflowV2beta1KnowledgeOperationMetadata": { "description": "Metadata in google::longrunning::Operation for Knowledge operations.", "type": "object", "properties": { "state": { "enum": ["STATE_UNSPECIFIED", "PENDING", "RUNNING", "DONE"], "description": "Required. The current state of this operation.", "type": "string", "enumDescriptions": ["State unspecified.", "The operation has been created.", "The operation is currently running.", "The operation is done, either cancelled or completed."] } }, "id": "GoogleCloudDialogflowV2beta1KnowledgeOperationMetadata" }, "GoogleCloudDialogflowV2IntentTrainingPhrasePart": { "description": "Represents a part of a training phrase.", "type": "object", "properties": { "text": { "description": "Required. The text corresponding to the example or template,\nif there are no annotations. For\nannotated examples, it is the text for one of the example's parts.", "type": "string" }, "entityType": { "description": "Optional. The entity type name prefixed with `@`. This field is\nrequired for the annotated part of the text and applies only to\nexamples.", "type": "string" }, "alias": { "description": "Optional. The parameter name for the value extracted from the\nannotated part of the example.", "type": "string" }, "userDefined": { "description": "Optional. Indicates whether the text was manually annotated by the\ndeveloper.", "type": "boolean" } }, "id": "GoogleCloudDialogflowV2IntentTrainingPhrasePart" }, "GoogleCloudDialogflowV2beta1IntentMessage": { "description": "Corresponds to the `Response` field in the Dialogflow console.", "type": "object", "properties": { "quickReplies": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageQuickReplies", "description": "Displays quick replies." }, "telephonySynthesizeSpeech": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageTelephonySynthesizeSpeech", "description": "Synthesizes speech in Telephony Gateway." }, "card": { "description": "Displays a card.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageCard" }, "basicCard": { "description": "Displays a basic card for Actions on Google.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageBasicCard" }, "carouselSelect": { "description": "Displays a carousel card for Actions on Google.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelect" }, "linkOutSuggestion": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageLinkOutSuggestion", "description": "Displays a link out suggestion chip for Actions on Google." }, "simpleResponses": { "description": "Returns a voice or text-only response for Actions on Google.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponses" }, "telephonyTransferCall": { "description": "Transfers the call in Telephony Gateway.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageTelephonyTransferCall" }, "image": { "description": "Displays an image.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageImage" }, "payload": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Returns a response containing a custom, platform-specific payload.\nSee the Intent.Message.Platform type for a description of the\nstructure that may be required for your platform.", "type": "object" }, "text": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageText", "description": "Returns a text response." }, "suggestions": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSuggestions", "description": "Displays suggestion chips for Actions on Google." }, "platform": { "description": "Optional. The platform that this message is intended for.", "type": "string", "enumDescriptions": ["Not specified.", "Facebook.", "Slack.", "Telegram.", "Kik.", "Skype.", "Line.", "Viber.", "Actions on Google.\nWhen using Actions on Google, you can choose one of the specific\nIntent.Message types that mention support for Actions on Google,\nor you can use the advanced Intent.Message.payload field.\nThe payload field provides access to AoG features not available in the\nspecific message types.\nIf using the Intent.Message.payload field, it should have a structure\nsimilar to the JSON message shown here. For more information, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"expectUserResponse\": true,\n  \"isSsml\": false,\n  \"noInputPrompts\": [],\n  \"richResponse\": {\n    \"items\": [\n      {\n        \"simpleResponse\": {\n          \"displayText\": \"hi\",\n          \"textToSpeech\": \"hello\"\n        }\n      }\n    ],\n    \"suggestions\": [\n      {\n        \"title\": \"Say this\"\n      },\n      {\n        \"title\": \"or this\"\n      }\n    ]\n  },\n  \"systemIntent\": {\n    \"data\": {\n      \"@type\": \"type.googleapis.com/google.actions.v2.OptionValueSpec\",\n      \"listSelect\": {\n        \"items\": [\n          {\n            \"optionInfo\": {\n              \"key\": \"key1\",\n              \"synonyms\": [\n                \"key one\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          },\n          {\n            \"optionInfo\": {\n              \"key\": \"key2\",\n              \"synonyms\": [\n                \"key two\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          }\n        ]\n      }\n    },\n    \"intent\": \"actions.intent.OPTION\"\n  }\n}</pre>", "Telephony Gateway."], "enum": ["PLATFORM_UNSPECIFIED", "FACEBOOK", "SLACK", "TELEGRAM", "KIK", "SKYPE", "LINE", "VIBER", "ACTIONS_ON_GOOGLE", "TELEPHONY"] }, "telephonyPlayAudio": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageTelephonyPlayAudio", "description": "Plays audio from a file in Telephony Gateway." }, "listSelect": { "description": "Displays a list card for Actions on Google.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageListSelect" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessage" }, "GoogleCloudDialogflowV2Intent": { "description": "Represents an intent.\nIntents convert a number of user expressions or patterns into an action. An\naction is an extraction of a user command or sentence semantics.", "type": "object", "properties": { "displayName": { "description": "Required. The name of this intent.", "type": "string" }, "rootFollowupIntentName": { "description": "The unique identifier of the root intent in the chain of followup intents.\nIt identifies the correct followup intents chain for this intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "mlDisabled": { "description": "Optional. Indicates whether Machine Learning is disabled for the intent.\nNote: If `ml_diabled` setting is set to true, then this intent is not\ntaken into account during inference in `ML ONLY` match mode. Also,\nauto-markup in the UI is turned off.", "type": "boolean" }, "isFallback": { "description": "Optional. Indicates whether this is a fallback intent.", "type": "boolean" }, "trainingPhrases": { "description": "Optional. The collection of examples/templates that the agent is\ntrained on.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentTrainingPhrase" } }, "resetContexts": { "description": "Optional. Indicates whether to delete all contexts in the current\nsession when this intent is matched.", "type": "boolean" }, "parameters": { "description": "Optional. The collection of parameters associated with the intent.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentParameter" } }, "events": { "description": "Optional. The collection of event names that trigger the intent.\nIf the collection of input contexts is not empty, all of the contexts must\nbe present in the active user session for an event to trigger this intent.", "type": "array", "items": { "type": "string" } }, "parentFollowupIntentName": { "description": "The unique identifier of the parent intent in the chain of followup\nintents.\nIt identifies the parent followup intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "priority": { "description": "Optional. The priority of this intent. Higher numbers represent higher\npriorities. Zero or negative numbers mean that the intent is disabled.", "format": "int32", "type": "integer" }, "outputContexts": { "description": "Optional. The collection of contexts that are activated when the intent\nis matched. Context messages in this collection should not set the\nparameters field. Setting the `lifespan_count` to 0 will reset the context\nwhen the intent is matched.\nFormat: `projects/<Project ID>/agent/sessions/-/contexts/<Context ID>`.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Context" } }, "defaultResponsePlatforms": { "enumDescriptions": ["Not specified.", "Facebook.", "Slack.", "Telegram.", "Kik.", "Skype.", "Line.", "Viber.", "Actions on Google.\nWhen using Actions on Google, you can choose one of the specific\nIntent.Message types that mention support for Actions on Google,\nor you can use the advanced Intent.Message.payload field.\nThe payload field provides access to AoG features not available in the\nspecific message types.\nIf using the Intent.Message.payload field, it should have a structure\nsimilar to the JSON message shown here. For more information, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"expectUserResponse\": true,\n  \"isSsml\": false,\n  \"noInputPrompts\": [],\n  \"richResponse\": {\n    \"items\": [\n      {\n        \"simpleResponse\": {\n          \"displayText\": \"hi\",\n          \"textToSpeech\": \"hello\"\n        }\n      }\n    ],\n    \"suggestions\": [\n      {\n        \"title\": \"Say this\"\n      },\n      {\n        \"title\": \"or this\"\n      }\n    ]\n  },\n  \"systemIntent\": {\n    \"data\": {\n      \"@type\": \"type.googleapis.com/google.actions.v2.OptionValueSpec\",\n      \"listSelect\": {\n        \"items\": [\n          {\n            \"optionInfo\": {\n              \"key\": \"key1\",\n              \"synonyms\": [\n                \"key one\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          },\n          {\n            \"optionInfo\": {\n              \"key\": \"key2\",\n              \"synonyms\": [\n                \"key two\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          }\n        ]\n      }\n    },\n    \"intent\": \"actions.intent.OPTION\"\n  }\n}</pre>"], "description": "Optional. The list of platforms for which the first response will be\ntaken from among the messages assigned to the DEFAULT_PLATFORM.", "type": "array", "items": { "type": "string", "enum": ["PLATFORM_UNSPECIFIED", "FACEBOOK", "SLACK", "TELEGRAM", "KIK", "SKYPE", "LINE", "VIBER", "ACTIONS_ON_GOOGLE"] } }, "messages": { "description": "Optional. The collection of rich messages corresponding to the\n`Response` field in the Dialogflow console.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessage" } }, "name": { "description": "Required for all methods except `create` (`create` populates the name\nautomatically.\nThe unique identifier of this intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "action": { "description": "Optional. The name of the action associated with the intent.\nNote: The action name must not contain whitespaces.", "type": "string" }, "inputContextNames": { "description": "Optional. The list of context names required for this intent to be\ntriggered.\nFormat: `projects/<Project ID>/agent/sessions/-/contexts/<Context ID>`.", "type": "array", "items": { "type": "string" } }, "webhookState": { "enumDescriptions": ["Webhook is disabled in the agent and in the intent.", "Webhook is enabled in the agent and in the intent.", "Webhook is enabled in the agent and in the intent. Also, each slot\nfilling prompt is forwarded to the webhook."], "enum": ["WEBHOOK_STATE_UNSPECIFIED", "WEBHOOK_STATE_ENABLED", "WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING"], "description": "Optional. Indicates whether webhooks are enabled for the intent.", "type": "string" }, "followupIntentInfo": { "description": "Optional. Collection of information about all followup intents that have\nname of this intent as a root_name.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentFollowupIntentInfo" } } }, "id": "GoogleCloudDialogflowV2Intent" }, "GoogleCloudDialogflowV2beta1IntentMessageLinkOutSuggestion": { "description": "The suggestion chip message that allows the user to jump out to the app\nor website associated with this agent.", "type": "object", "properties": { "destinationName": { "description": "Required. The name of the app or site this chip is linking to.", "type": "string" }, "uri": { "description": "Required. The URI of the app or site to open when the user taps the\nsuggestion chip.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageLinkOutSuggestion" }, "GoogleCloudDialogflowV2beta1IntentParameter": { "properties": { "displayName": { "description": "Required. The name of the parameter.", "type": "string" }, "entityTypeDisplayName": { "description": "Optional. The name of the entity type, prefixed with `@`, that\ndescribes values of the parameter. If the parameter is\nrequired, this must be provided.", "type": "string" }, "prompts": { "description": "Optional. The collection of prompts that the agent can present to the\nuser in order to collect value for the parameter.", "type": "array", "items": { "type": "string" } }, "mandatory": { "description": "Optional. Indicates whether the parameter is required. That is,\nwhether the intent cannot be completed without collecting the parameter\nvalue.", "type": "boolean" }, "defaultValue": { "description": "Optional. The default value to use when the `value` yields an empty\nresult.\nDefault values can be extracted from contexts by using the following\nsyntax: `#context_name.parameter_name`.", "type": "string" }, "name": { "description": "The unique identifier of this parameter.", "type": "string" }, "isList": { "description": "Optional. Indicates whether the parameter represents a list of values.", "type": "boolean" }, "value": { "description": "Optional. The definition of the parameter value. It can be:\n- a constant string,\n- a parameter value defined as `$parameter_name`,\n- an original parameter value defined as `$parameter_name.original`,\n- a parameter value from some context defined as\n  `#context_name.parameter_name`.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentParameter", "description": "Represents intent parameters.", "type": "object" }, "GoogleCloudDialogflowV2IntentParameter": { "description": "Represents intent parameters.", "type": "object", "properties": { "prompts": { "description": "Optional. The collection of prompts that the agent can present to the\nuser in order to collect value for the parameter.", "type": "array", "items": { "type": "string" } }, "mandatory": { "description": "Optional. Indicates whether the parameter is required. That is,\nwhether the intent cannot be completed without collecting the parameter\nvalue.", "type": "boolean" }, "defaultValue": { "description": "Optional. The default value to use when the `value` yields an empty\nresult.\nDefault values can be extracted from contexts by using the following\nsyntax: `#context_name.parameter_name`.", "type": "string" }, "name": { "description": "The unique identifier of this parameter.", "type": "string" }, "isList": { "description": "Optional. Indicates whether the parameter represents a list of values.", "type": "boolean" }, "value": { "description": "Optional. The definition of the parameter value. It can be:\n- a constant string,\n- a parameter value defined as `$parameter_name`,\n- an original parameter value defined as `$parameter_name.original`,\n- a parameter value from some context defined as\n  `#context_name.parameter_name`.", "type": "string" }, "displayName": { "description": "Required. The name of the parameter.", "type": "string" }, "entityTypeDisplayName": { "description": "Optional. The name of the entity type, prefixed with `@`, that\ndescribes values of the parameter. If the parameter is\nrequired, this must be provided.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentParameter" }, "GoogleRpcStatus": { "description": "The `Status` type defines a logical error model that is suitable for different\nprogramming environments, including REST APIs and RPC APIs. It is used by\n[gRPC](https://github.com/grpc). The error model is designed to be:\n\n- Simple to use and understand for most users\n- Flexible enough to meet unexpected needs\n\n# Overview\n\nThe `Status` message contains three pieces of data: error code, error message,\nand error details. The error code should be an enum value of\ngoogle.rpc.Code, but it may accept additional error codes if needed.  The\nerror message should be a developer-facing English message that helps\ndevelopers *understand* and *resolve* the error. If a localized user-facing\nerror message is needed, put the localized message in the error details or\nlocalize it in the client. The optional error details may contain arbitrary\ninformation about the error. There is a predefined set of error detail types\nin the package `google.rpc` that can be used for common error conditions.\n\n# Language mapping\n\nThe `Status` message is the logical representation of the error model, but it\nis not necessarily the actual wire format. When the `Status` message is\nexposed in different client libraries and different wire protocols, it can be\nmapped differently. For example, it will likely be mapped to some exceptions\nin Java, but more likely mapped to some error codes in C.\n\n# Other uses\n\nThe error model and the `Status` message can be used in a variety of\nenvironments, either with or without APIs, to provide a\nconsistent developer experience across different environments.\n\nExample uses of this error model include:\n\n- Partial errors. If a service needs to return partial errors to the client,\n    it may embed the `Status` in the normal response to indicate the partial\n    errors.\n\n- Workflow errors. A typical workflow has multiple steps. Each step may\n    have a `Status` message for error reporting.\n\n- Batch operations. If a client uses batch request and batch response, the\n    `Status` message should be used directly inside batch response, one for\n    each error sub-response.\n\n- Asynchronous operations. If an API call embeds asynchronous operation\n    results in its response, the status of those operations should be\n    represented directly using the `Status` message.\n\n- Logging. If some API errors are stored in logs, the message `Status` could\n    be used directly after any stripping needed for security/privacy reasons.", "type": "object", "properties": { "details": { "description": "A list of messages that carry the error details.  There is a common set of\nmessage types for APIs to use.", "type": "array", "items": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "type": "object" } }, "code": { "description": "The status code, which should be an enum value of google.rpc.Code.", "format": "int32", "type": "integer" }, "message": { "description": "A developer-facing error message, which should be in English. Any\nuser-facing error message should be localized and sent in the\ngoogle.rpc.Status.details field, or localized by the client.", "type": "string" } }, "id": "GoogleRpcStatus" }, "GoogleCloudDialogflowV2beta1IntentMessageBasicCard": { "properties": { "title": { "description": "Optional. The title of the card.", "type": "string" }, "image": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageImage", "description": "Optional. The image for the card." }, "formattedText": { "description": "Required, unless image is present. The body text of the card.", "type": "string" }, "buttons": { "description": "Optional. The collection of card buttons.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButton" } }, "subtitle": { "description": "Optional. The subtitle of the card.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageBasicCard", "description": "The basic card message. Useful for displaying information.", "type": "object" } }, "protocol": "rest", "icons": { "x32": "http://www.google.com/images/icons/product/search-32.gif", "x16": "http://www.google.com/images/icons/product/search-16.gif" }, "canonicalName": "Dialogflow", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/cloud-platform": { "description": "View and manage your data across Google Cloud Platform services" } } } }, "rootUrl": "https://dialogflow.googleapis.com/", "ownerDomain": "google.com", "name": "dialogflow", "batchPath": "batch", "fullyEncodeReservedExpansion": true, "title": "Dialogflow API", "ownerName": "Google", "resources": { "projects": { "methods": { "getAgent": { "description": "Retrieves the specified agent.", "response": { "$ref": "GoogleCloudDialogflowV2Agent" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "pattern": "^projects/[^/]+$", "location": "path", "description": "Required. The project that the agent to fetch is associated with.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string" } }, "flatPath": "v2/projects/{projectsId}/agent", "path": "v2/{+parent}/agent", "id": "dialogflow.projects.getAgent" } }, "resources": { "agent": { "methods": { "export": { "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "description": "Required. The project that the agent to export is associated with.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/agent:export", "path": "v2/{+parent}/agent:export", "id": "dialogflow.projects.agent.export", "description": "Exports the specified agent to a ZIP file.\n\nOperation <response: ExportAgentResponse,\n           metadata: google.protobuf.Struct>", "request": { "$ref": "GoogleCloudDialogflowV2ExportAgentRequest" } }, "restore": { "flatPath": "v2/projects/{projectsId}/agent:restore", "path": "v2/{+parent}/agent:restore", "id": "dialogflow.projects.agent.restore", "description": "Restores the specified agent from a ZIP file.\n\nReplaces the current agent version with a new one. All the intents and\nentity types in the older version are deleted.\n\nOperation <response: google.protobuf.Empty,\n           metadata: google.protobuf.Struct>", "request": { "$ref": "GoogleCloudDialogflowV2RestoreAgentRequest" }, "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "description": "Required. The project that the agent to restore is associated with.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] }, "import": { "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "pattern": "^projects/[^/]+$", "location": "path", "description": "Required. The project that the agent to import is associated with.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/agent:import", "path": "v2/{+parent}/agent:import", "id": "dialogflow.projects.agent.import", "description": "Imports the specified agent from a ZIP file.\n\nUploads new intents and entity types without deleting the existing ones.\nIntents and entity types with the same name are replaced with the new\nversions from ImportAgentRequest.\n\nOperation <response: google.protobuf.Empty,\n           metadata: google.protobuf.Struct>", "request": { "$ref": "GoogleCloudDialogflowV2ImportAgentRequest" } }, "search": { "path": "v2/{+parent}/agent:search", "id": "dialogflow.projects.agent.search", "description": "Returns the list of agents.\n\nSince there is at most one conversational agent per project, this method is\nuseful primarily for listing all agents across projects the caller has\naccess to. One can achieve that with a wildcard project collection id \"-\".\nRefer to [List\nSub-Collections](https://cloud.google.com/apis/design/design_patterns#list_sub-collections).", "response": { "$ref": "GoogleCloudDialogflowV2SearchAgentsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "pageToken": { "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string", "location": "query" }, "pageSize": { "location": "query", "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32", "type": "integer" }, "parent": { "description": "Required. The project to list agents from.\nFormat: `projects/<Project ID or '-'>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+$", "location": "path" } }, "flatPath": "v2/projects/{projectsId}/agent:search" }, "train": { "description": "Trains the specified agent.\n\nOperation <response: google.protobuf.Empty,\n           metadata: google.protobuf.Struct>", "request": { "$ref": "GoogleCloudDialogflowV2TrainAgentRequest" }, "httpMethod": "POST", "parameterOrder": ["parent"], "response": { "$ref": "GoogleLongrunningOperation" }, "parameters": { "parent": { "location": "path", "description": "Required. The project that the agent to train is associated with.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/agent:train", "id": "dialogflow.projects.agent.train", "path": "v2/{+parent}/agent:train" } }, "resources": { "entityTypes": { "resources": { "entities": { "methods": { "batchCreate": { "path": "v2/{+parent}/entities:batchCreate", "id": "dialogflow.projects.agent.entityTypes.entities.batchCreate", "request": { "$ref": "GoogleCloudDialogflowV2BatchCreateEntitiesRequest" }, "description": "Creates multiple new entities in the specified entity type (extends the\nexisting collection of entries).\n\nOperation <response: google.protobuf.Empty>", "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "description": "Required. The name of the entity type to create entities in. Format:\n`projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$", "location": "path" } }, "flatPath": "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}/entities:batchCreate" }, "batchUpdate": { "description": "Updates entities in the specified entity type (replaces the existing\ncollection of entries).\n\nOperation <response: google.protobuf.Empty,\n           metadata: google.protobuf.Struct>", "request": { "$ref": "GoogleCloudDialogflowV2BatchUpdateEntitiesRequest" }, "httpMethod": "POST", "parameterOrder": ["parent"], "response": { "$ref": "GoogleLongrunningOperation" }, "parameters": { "parent": { "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$", "location": "path", "description": "Required. The name of the entity type to update the entities in. Format:\n`projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}/entities:batchUpdate", "id": "dialogflow.projects.agent.entityTypes.entities.batchUpdate", "path": "v2/{+parent}/entities:batchUpdate" }, "batchDelete": { "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "description": "Required. The name of the entity type to delete entries for. Format:\n`projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}/entities:batchDelete", "path": "v2/{+parent}/entities:batchDelete", "id": "dialogflow.projects.agent.entityTypes.entities.batchDelete", "description": "Deletes entities in the specified entity type.\n\nOperation <response: google.protobuf.Empty,\n           metadata: google.protobuf.Struct>", "request": { "$ref": "GoogleCloudDialogflowV2BatchDeleteEntitiesRequest" } } } } }, "methods": { "patch": { "response": { "$ref": "GoogleCloudDialogflowV2EntityType" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "parameters": { "languageCode": { "location": "query", "description": "Optional. The language of entity synonyms defined in `entity_type`. If not\nspecified, the agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string" }, "updateMask": { "location": "query", "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" }, "name": { "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$", "location": "path", "description": "Required for all methods except `create` (`create` populates the name\nautomatically.\nThe unique identifier of the entity type. Format:\n`projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}", "path": "v2/{+name}", "id": "dialogflow.projects.agent.entityTypes.patch", "description": "Updates the specified entity type.", "request": { "$ref": "GoogleCloudDialogflowV2EntityType" } }, "get": { "response": { "$ref": "GoogleCloudDialogflowV2EntityType" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "languageCode": { "location": "query", "description": "Optional. The language to retrieve entity synonyms for. If not specified,\nthe agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string" }, "name": { "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$", "location": "path", "description": "Required. The name of the entity type.\nFormat: `projects/<Project ID>/agent/entityTypes/<EntityType ID>`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}", "path": "v2/{+name}", "id": "dialogflow.projects.agent.entityTypes.get", "description": "Retrieves the specified entity type." }, "batchUpdate": { "flatPath": "v2/projects/{projectsId}/agent/entityTypes:batchUpdate", "path": "v2/{+parent}/entityTypes:batchUpdate", "id": "dialogflow.projects.agent.entityTypes.batchUpdate", "description": "Updates/Creates multiple entity types in the specified agent.\n\nOperation <response: BatchUpdateEntityTypesResponse,\n           metadata: google.protobuf.Struct>", "request": { "$ref": "GoogleCloudDialogflowV2BatchUpdateEntityTypesRequest" }, "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "location": "path", "description": "Required. The name of the agent to update or create entity types in.\nFormat: `projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] }, "delete": { "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "parameters": { "name": { "location": "path", "description": "Required. The name of the entity type to delete.\nFormat: `projects/<Project ID>/agent/entityTypes/<EntityType ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}", "path": "v2/{+name}", "id": "dialogflow.projects.agent.entityTypes.delete", "description": "Deletes the specified entity type." }, "list": { "path": "v2/{+parent}/entityTypes", "id": "dialogflow.projects.agent.entityTypes.list", "description": "Returns the list of all entity types in the specified agent.", "response": { "$ref": "GoogleCloudDialogflowV2ListEntityTypesResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "languageCode": { "description": "Optional. The language to list entity synonyms for. If not specified,\nthe agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string", "location": "query" }, "pageToken": { "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string", "location": "query" }, "pageSize": { "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32", "type": "integer", "location": "query" }, "parent": { "description": "Required. The agent to list all entity types from.\nFormat: `projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$", "location": "path" } }, "flatPath": "v2/projects/{projectsId}/agent/entityTypes" }, "batchDelete": { "path": "v2/{+parent}/entityTypes:batchDelete", "id": "dialogflow.projects.agent.entityTypes.batchDelete", "request": { "$ref": "GoogleCloudDialogflowV2BatchDeleteEntityTypesRequest" }, "description": "Deletes entity types in the specified agent.\n\nOperation <response: google.protobuf.Empty,\n           metadata: google.protobuf.Struct>", "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "location": "path", "description": "Required. The name of the agent to delete all entities types for. Format:\n`projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$" } }, "flatPath": "v2/projects/{projectsId}/agent/entityTypes:batchDelete" }, "create": { "response": { "$ref": "GoogleCloudDialogflowV2EntityType" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "description": "Required. The agent to create a entity type for.\nFormat: `projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$", "location": "path" }, "languageCode": { "location": "query", "description": "Optional. The language of entity synonyms defined in `entity_type`. If not\nspecified, the agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/agent/entityTypes", "path": "v2/{+parent}/entityTypes", "id": "dialogflow.projects.agent.entityTypes.create", "description": "Creates an entity type in the specified agent.", "request": { "$ref": "GoogleCloudDialogflowV2EntityType" } } } }, "intents": { "methods": { "delete": { "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "pattern": "^projects/[^/]+/agent/intents/[^/]+$", "location": "path", "description": "Required. The name of the intent to delete.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "required": true, "type": "string" } }, "flatPath": "v2/projects/{projectsId}/agent/intents/{intentsId}", "path": "v2/{+name}", "id": "dialogflow.projects.agent.intents.delete", "description": "Deletes the specified intent." }, "list": { "description": "Returns the list of all intents in the specified agent.", "response": { "$ref": "GoogleCloudDialogflowV2ListIntentsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "parameters": { "pageSize": { "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32", "type": "integer", "location": "query" }, "intentView": { "location": "query", "enum": ["INTENT_VIEW_UNSPECIFIED", "INTENT_VIEW_FULL"], "description": "Optional. The resource view to apply to the returned intent.", "type": "string" }, "parent": { "description": "Required. The agent to list all intents from.\nFormat: `projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$", "location": "path" }, "languageCode": { "description": "Optional. The language to list training phrases, parameters and rich\nmessages for. If not specified, the agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent before they can be used.", "type": "string", "location": "query" }, "pageToken": { "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string", "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/agent/intents", "path": "v2/{+parent}/intents", "id": "dialogflow.projects.agent.intents.list" }, "create": { "path": "v2/{+parent}/intents", "id": "dialogflow.projects.agent.intents.create", "description": "Creates an intent in the specified agent.", "request": { "$ref": "GoogleCloudDialogflowV2Intent" }, "response": { "$ref": "GoogleCloudDialogflowV2Intent" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "languageCode": { "location": "query", "description": "Optional. The language of training phrases, parameters and rich messages\ndefined in `intent`. If not specified, the agent's default language is\nused. [More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string" }, "intentView": { "enum": ["INTENT_VIEW_UNSPECIFIED", "INTENT_VIEW_FULL"], "description": "Optional. The resource view to apply to the returned intent.", "type": "string", "location": "query" }, "parent": { "location": "path", "description": "Required. The agent to create a intent for.\nFormat: `projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/agent/intents" }, "batchDelete": { "description": "Deletes intents in the specified agent.\n\nOperation <response: google.protobuf.Empty>", "request": { "$ref": "GoogleCloudDialogflowV2BatchDeleteIntentsRequest" }, "httpMethod": "POST", "parameterOrder": ["parent"], "response": { "$ref": "GoogleLongrunningOperation" }, "parameters": { "parent": { "location": "path", "description": "Required. The name of the agent to delete all entities types for. Format:\n`projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/agent/intents:batchDelete", "id": "dialogflow.projects.agent.intents.batchDelete", "path": "v2/{+parent}/intents:batchDelete" }, "get": { "response": { "$ref": "GoogleCloudDialogflowV2Intent" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "description": "Required. The name of the intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/intents/[^/]+$", "location": "path" }, "intentView": { "location": "query", "enum": ["INTENT_VIEW_UNSPECIFIED", "INTENT_VIEW_FULL"], "description": "Optional. The resource view to apply to the returned intent.", "type": "string" }, "languageCode": { "description": "Optional. The language to retrieve training phrases, parameters and rich\nmessages for. If not specified, the agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string", "location": "query" } }, "flatPath": "v2/projects/{projectsId}/agent/intents/{intentsId}", "path": "v2/{+name}", "id": "dialogflow.projects.agent.intents.get", "description": "Retrieves the specified intent." }, "patch": { "flatPath": "v2/projects/{projectsId}/agent/intents/{intentsId}", "path": "v2/{+name}", "id": "dialogflow.projects.agent.intents.patch", "description": "Updates the specified intent.", "request": { "$ref": "GoogleCloudDialogflowV2Intent" }, "response": { "$ref": "GoogleCloudDialogflowV2Intent" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "parameters": { "intentView": { "description": "Optional. The resource view to apply to the returned intent.", "type": "string", "location": "query", "enum": ["INTENT_VIEW_UNSPECIFIED", "INTENT_VIEW_FULL"] }, "languageCode": { "location": "query", "description": "Optional. The language of training phrases, parameters and rich messages\ndefined in `intent`. If not specified, the agent's default language is\nused. [More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string" }, "updateMask": { "location": "query", "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" }, "name": { "description": "Required for all methods except `create` (`create` populates the name\nautomatically.\nThe unique identifier of this intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/intents/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] }, "batchUpdate": { "httpMethod": "POST", "parameterOrder": ["parent"], "response": { "$ref": "GoogleLongrunningOperation" }, "parameters": { "parent": { "description": "Required. The name of the agent to update or create intents in.\nFormat: `projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/agent/intents:batchUpdate", "id": "dialogflow.projects.agent.intents.batchUpdate", "path": "v2/{+parent}/intents:batchUpdate", "description": "Updates/Creates multiple intents in the specified agent.\n\nOperation <response: BatchUpdateIntentsResponse>", "request": { "$ref": "GoogleCloudDialogflowV2BatchUpdateIntentsRequest" } } } }, "sessions": { "resources": { "entityTypes": { "methods": { "delete": { "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes/{entityTypesId}", "path": "v2/{+name}", "id": "dialogflow.projects.agent.sessions.entityTypes.delete", "description": "Deletes the specified session entity type.", "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "parameters": { "name": { "location": "path", "description": "Required. The name of the entity type to delete. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type\nDisplay Name>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+/entityTypes/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] }, "list": { "description": "Returns the list of all session entity types in the specified session.", "response": { "$ref": "GoogleCloudDialogflowV2ListSessionEntityTypesResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "pageSize": { "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32", "type": "integer", "location": "query" }, "parent": { "description": "Required. The session to list all session entity types from.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+$", "location": "path" }, "pageToken": { "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string", "location": "query" } }, "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes", "path": "v2/{+parent}/entityTypes", "id": "dialogflow.projects.agent.sessions.entityTypes.list" }, "get": { "response": { "$ref": "GoogleCloudDialogflowV2SessionEntityType" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "description": "Required. The name of the session entity type. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type\nDisplay Name>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+/entityTypes/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes/{entityTypesId}", "path": "v2/{+name}", "id": "dialogflow.projects.agent.sessions.entityTypes.get", "description": "Retrieves the specified session entity type." }, "patch": { "response": { "$ref": "GoogleCloudDialogflowV2SessionEntityType" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "updateMask": { "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string", "location": "query" }, "name": { "location": "path", "description": "Required. The unique identifier of this session entity type. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type\nDisplay Name>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+/entityTypes/[^/]+$" } }, "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes/{entityTypesId}", "path": "v2/{+name}", "id": "dialogflow.projects.agent.sessions.entityTypes.patch", "request": { "$ref": "GoogleCloudDialogflowV2SessionEntityType" }, "description": "Updates the specified session entity type." }, "create": { "id": "dialogflow.projects.agent.sessions.entityTypes.create", "path": "v2/{+parent}/entityTypes", "description": "Creates a session entity type.", "request": { "$ref": "GoogleCloudDialogflowV2SessionEntityType" }, "httpMethod": "POST", "parameterOrder": ["parent"], "response": { "$ref": "GoogleCloudDialogflowV2SessionEntityType" }, "parameters": { "parent": { "pattern": "^projects/[^/]+/agent/sessions/[^/]+$", "location": "path", "description": "Required. The session to create a session entity type for.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes" } } }, "contexts": { "methods": { "delete": { "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "description": "Required. The name of the context to delete. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+/contexts/[^/]+$", "location": "path" } }, "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts/{contextsId}", "path": "v2/{+name}", "id": "dialogflow.projects.agent.sessions.contexts.delete", "description": "Deletes the specified context." }, "list": { "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts", "path": "v2/{+parent}/contexts", "id": "dialogflow.projects.agent.sessions.contexts.list", "description": "Returns the list of all contexts in the specified session.", "response": { "$ref": "GoogleCloudDialogflowV2ListContextsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "parameters": { "pageToken": { "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string", "location": "query" }, "pageSize": { "location": "query", "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32", "type": "integer" }, "parent": { "pattern": "^projects/[^/]+/agent/sessions/[^/]+$", "location": "path", "description": "Required. The session to list all contexts from.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] }, "get": { "response": { "$ref": "GoogleCloudDialogflowV2Context" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "pattern": "^projects/[^/]+/agent/sessions/[^/]+/contexts/[^/]+$", "location": "path", "description": "Required. The name of the context. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts/{contextsId}", "path": "v2/{+name}", "id": "dialogflow.projects.agent.sessions.contexts.get", "description": "Retrieves the specified context." }, "patch": { "path": "v2/{+name}", "id": "dialogflow.projects.agent.sessions.contexts.patch", "description": "Updates the specified context.", "request": { "$ref": "GoogleCloudDialogflowV2Context" }, "response": { "$ref": "GoogleCloudDialogflowV2Context" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "parameters": { "name": { "description": "Required. The unique identifier of the context. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+/contexts/[^/]+$", "location": "path" }, "updateMask": { "location": "query", "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts/{contextsId}" }, "create": { "request": { "$ref": "GoogleCloudDialogflowV2Context" }, "description": "Creates a context.", "response": { "$ref": "GoogleCloudDialogflowV2Context" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "location": "path", "description": "Required. The session to create a context for.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+$" } }, "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts", "path": "v2/{+parent}/contexts", "id": "dialogflow.projects.agent.sessions.contexts.create" } } } }, "methods": { "deleteContexts": { "path": "v2/{+parent}/contexts", "id": "dialogflow.projects.agent.sessions.deleteContexts", "description": "Deletes all active contexts in the specified session.", "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["parent"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "description": "Required. The name of the session to delete all contexts from. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+$", "location": "path" } }, "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts" }, "detectIntent": { "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}:detectIntent", "path": "v2/{+session}:detectIntent", "id": "dialogflow.projects.agent.sessions.detectIntent", "description": "Processes a natural language query and returns structured, actionable data\nas a result. This method is not idempotent, because it may cause contexts\nand session entity types to be updated, which in turn might affect\nresults of future queries.", "request": { "$ref": "GoogleCloudDialogflowV2DetectIntentRequest" }, "response": { "$ref": "GoogleCloudDialogflowV2DetectIntentResponse" }, "parameterOrder": ["session"], "httpMethod": "POST", "parameters": { "session": { "pattern": "^projects/[^/]+/agent/sessions/[^/]+$", "location": "path", "description": "Required. The name of the session this query is sent to. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>`. It's up to the API\ncaller to choose an appropriate session ID. It can be a random number or\nsome type of user identifier (preferably hashed). The length of the session\nID must not exceed 36 bytes.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] } } } } }, "operations": { "methods": { "get": { "httpMethod": "GET", "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["name"], "parameters": { "name": { "description": "The name of the operation resource.", "required": true, "type": "string", "pattern": "^projects/[^/]+/operations/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v2/projects/{projectsId}/operations/{operationsId}", "id": "dialogflow.projects.operations.get", "path": "v2/{+name}", "description": "Gets the latest state of a long-running operation.  Clients can use this\nmethod to poll the operation result at intervals as recommended by the API\nservice." } } } } } }, "parameters": { "callback": { "location": "query", "description": "JSONP", "type": "string" }, "oauth_token": { "location": "query", "description": "OAuth 2.0 token for the current user.", "type": "string" }, "$.xgafv": { "enumDescriptions": ["v1 error format", "v2 error format"], "location": "query", "enum": ["1", "2"], "description": "V1 error format.", "type": "string" }, "alt": { "enum": ["json", "media", "proto"], "type": "string", "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response.", "default": "json" }, "key": { "location": "query", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string" }, "access_token": { "location": "query", "description": "OAuth access token.", "type": "string" }, "upload_protocol": { "location": "query", "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string" }, "quotaUser": { "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string", "location": "query" }, "prettyPrint": { "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true", "location": "query" }, "uploadType": { "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string", "location": "query" }, "fields": { "location": "query", "description": "Selector specifying which fields to include in a partial response.", "type": "string" } }, "version": "v2", "baseUrl": "https://dialogflow.googleapis.com/", "kind": "discovery#restDescription", "description": "An end-to-end development suite for conversational interfaces (e.g., chatbots, voice-powered apps and devices).", "servicePath": "", "basePath": "", "id": "dialogflow:v2", "documentationLink": "https://cloud.google.com/dialogflow-enterprise/", "revision": "20180908", "discoveryVersion": "v1", "version_module": true };
//# sourceMappingURL=dialogflow-v2.js.map