"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "schemas": { "RunPipelineRequest": { "description": "The arguments to the `RunPipeline` method. The requesting user must have\nthe `iam.serviceAccounts.actAs` permission for the Cloud Genomics service\naccount or the request will fail.", "type": "object", "properties": { "labels": { "type": "object", "additionalProperties": { "type": "string" }, "description": "User-defined labels to associate with the returned operation. These\nlabels are not propagated to any Google Cloud Platform resources used by\nthe operation, and can be modified at any time.\n\nTo associate labels with resources created while executing the operation,\nsee the appropriate resource message (for example, `VirtualMachine`)." }, "pipeline": { "description": "The description of the pipeline to run.", "$ref": "Pipeline" } }, "id": "RunPipelineRequest" }, "CancelOperationRequest": { "description": "The request message for Operations.CancelOperation.", "type": "object", "properties": {}, "id": "CancelOperationRequest" }, "PullStoppedEvent": { "description": "An event generated when the worker stops pulling an image.", "type": "object", "properties": { "imageUri": { "description": "The URI of the image that was pulled.", "type": "string" } }, "id": "PullStoppedEvent" }, "Operation": { "id": "Operation", "description": "This resource represents a long-running operation that is the result of a\nnetwork API call.", "type": "object", "properties": { "name": { "description": "The server-assigned name, which is only unique within the same service that originally returns it. For example&#58; `operations/CJHU7Oi_ChDrveSpBRjfuL-qzoWAgEw`", "type": "string" }, "error": { "$ref": "Status", "description": "The error result of the operation in case of failure or cancellation." }, "metadata": { "additionalProperties": { "type": "any", "description": "Properties of the object. Contains field @type with type URL." }, "description": "An OperationMetadata or Metadata object. This will always be returned with the Operation.", "type": "object" }, "done": { "description": "If the value is `false`, it means the operation is still in progress.\nIf `true`, the operation is completed, and either `error` or `response` is\navailable.", "type": "boolean" }, "response": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "If importing ReadGroupSets, an ImportReadGroupSetsResponse is returned. If importing Variants, an ImportVariantsResponse is returned. For pipelines and exports, an Empty response is returned.", "type": "object" } } }, "RuntimeMetadata": { "description": "Runtime metadata that will be populated in the\nruntimeMetadata\nfield of the Operation associated with a RunPipeline execution.", "type": "object", "properties": { "computeEngine": { "$ref": "ComputeEngine", "description": "Execution information specific to Google Compute Engine." } }, "id": "RuntimeMetadata" }, "ImportReadGroupSetsResponse": { "type": "object", "properties": { "readGroupSetIds": { "description": "IDs of the read group sets that were created.", "type": "array", "items": { "type": "string" } } }, "id": "ImportReadGroupSetsResponse", "description": "The read group set import response." }, "RunPipelineResponse": { "id": "RunPipelineResponse", "description": "The response to the RunPipeline method, returned in the operation's result\nfield on success.", "type": "object", "properties": {} }, "Status": { "properties": { "code": { "type": "integer", "description": "The status code, which should be an enum value of google.rpc.Code.", "format": "int32" }, "message": { "description": "A developer-facing error message, which should be in English. Any\nuser-facing error message should be localized and sent in the\ngoogle.rpc.Status.details field, or localized by the client.", "type": "string" }, "details": { "description": "A list of messages that carry the error details.  There is a common set of\nmessage types for APIs to use.", "type": "array", "items": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "type": "object" } } }, "id": "Status", "description": "The `Status` type defines a logical error model that is suitable for different\nprogramming environments, including REST APIs and RPC APIs. It is used by\n[gRPC](https://github.com/grpc). The error model is designed to be:\n\n- Simple to use and understand for most users\n- Flexible enough to meet unexpected needs\n\n# Overview\n\nThe `Status` message contains three pieces of data: error code, error message,\nand error details. The error code should be an enum value of\ngoogle.rpc.Code, but it may accept additional error codes if needed.  The\nerror message should be a developer-facing English message that helps\ndevelopers *understand* and *resolve* the error. If a localized user-facing\nerror message is needed, put the localized message in the error details or\nlocalize it in the client. The optional error details may contain arbitrary\ninformation about the error. There is a predefined set of error detail types\nin the package `google.rpc` that can be used for common error conditions.\n\n# Language mapping\n\nThe `Status` message is the logical representation of the error model, but it\nis not necessarily the actual wire format. When the `Status` message is\nexposed in different client libraries and different wire protocols, it can be\nmapped differently. For example, it will likely be mapped to some exceptions\nin Java, but more likely mapped to some error codes in C.\n\n# Other uses\n\nThe error model and the `Status` message can be used in a variety of\nenvironments, either with or without APIs, to provide a\nconsistent developer experience across different environments.\n\nExample uses of this error model include:\n\n- Partial errors. If a service needs to return partial errors to the client,\n    it may embed the `Status` in the normal response to indicate the partial\n    errors.\n\n- Workflow errors. A typical workflow has multiple steps. Each step may\n    have a `Status` message for error reporting.\n\n- Batch operations. If a client uses batch request and batch response, the\n    `Status` message should be used directly inside batch response, one for\n    each error sub-response.\n\n- Asynchronous operations. If an API call embeds asynchronous operation\n    results in its response, the status of those operations should be\n    represented directly using the `Status` message.\n\n- Logging. If some API errors are stored in logs, the message `Status` could\n    be used directly after any stripping needed for security/privacy reasons.", "type": "object" }, "Event": { "description": "Carries information about events that occur during pipeline execution.", "type": "object", "properties": { "timestamp": { "description": "The time at which the event occurred.", "format": "google-datetime", "type": "string" }, "details": { "additionalProperties": { "type": "any", "description": "Properties of the object. Contains field @type with type URL." }, "description": "Machine-readable details about the event.", "type": "object" }, "description": { "description": "A human-readable description of the event. Note that these strings can\nchange at any time without notice. Any application logic must use the\ninformation in the `details` field.", "type": "string" } }, "id": "Event" }, "ServiceAccount": { "description": "Carries information about a Google Cloud service account.", "type": "object", "properties": { "email": { "description": "Email address of the service account. If not specified, the default\nCompute Engine service account for the project will be used.", "type": "string" }, "scopes": { "description": "List of scopes to be enabled for this service account on the VM, in\naddition to the Cloud Genomics API scope.", "type": "array", "items": { "type": "string" } } }, "id": "ServiceAccount" }, "Pipeline": { "description": "Specifies a series of actions to execute, expressed as Docker containers.", "type": "object", "properties": { "actions": { "description": "The list of actions to execute, in the order they are specified.", "type": "array", "items": { "$ref": "Action" } }, "environment": { "additionalProperties": { "type": "string" }, "description": "The environment to pass into every action. Each action can also specify\nadditional environment variables but cannot delete an entry from this map\n(though they can overwrite it with a different value).", "type": "object" }, "timeout": { "description": "The maximum amount of time to give the pipeline to complete.  This includes\nthe time spent waiting for a worker to be allocated.  If the pipeline fails\nto complete before the timeout, it will be cancelled and the error code\nwill be set to DEADLINE_EXCEEDED.\n\nIf unspecified, it will default to 7 days.", "format": "google-duration", "type": "string" }, "resources": { "$ref": "Resources", "description": "The resources required for execution." } }, "id": "Pipeline" }, "Accelerator": { "description": "Carries information about an accelerator that can be attached to a VM.", "type": "object", "properties": { "count": { "description": "How many accelerators of this type to attach.", "format": "int64", "type": "string" }, "type": { "description": "The accelerator type string (for example, \"nvidia-tesla-k80\").\n\nOnly NVIDIA GPU accelerators are currently supported. If an NVIDIA GPU is\nattached, the required runtime libraries will be made available to all\ncontainers under `/usr/local/nvidia`. The driver version to install must\nbe specified using the NVIDIA driver version parameter on the virtual\nmachine specification. Note that attaching a GPU increases the worker VM\nstartup time by a few minutes.", "type": "string" } }, "id": "Accelerator" }, "OperationEvent": { "description": "An event that occurred during an Operation.", "type": "object", "properties": { "endTime": { "description": "Optional time of when event finished. An event can have a start time and no\nfinish time. If an event has a finish time, there must be a start time.", "format": "google-datetime", "type": "string" }, "startTime": { "description": "Optional time of when event started.", "format": "google-datetime", "type": "string" }, "description": { "description": "Required description of event.", "type": "string" } }, "id": "OperationEvent" }, "Resources": { "description": "The system resources for the pipeline run.\n\nAt least one zone or region must be specified or the pipeline run will fail.", "type": "object", "properties": { "virtualMachine": { "description": "The virtual machine specification.", "$ref": "VirtualMachine" }, "projectId": { "description": "The project ID to allocate resources in.", "type": "string" }, "regions": { "description": "The list of regions allowed for VM allocation. If set, the `zones` field\nmust not be set.", "type": "array", "items": { "type": "string" } }, "zones": { "description": "The list of zones allowed for VM allocation. If set, the `regions` field\nmust not be set.", "type": "array", "items": { "type": "string" } } }, "id": "Resources" }, "VirtualMachine": { "description": "Carries information about a Compute Engine VM resource.", "type": "object", "properties": { "cpuPlatform": { "description": "The CPU platform to request. An instance based on a newer platform can be\nallocated, but never one with fewer capabilities. The value of this\nparameter must be a valid Compute Engine CPU platform name (such as \"Intel\nSkylake\"). This parameter is only useful for carefully optimized work\nloads where the CPU platform has a significant impact.\n\nFor more information about the effect of this parameter, see\nhttps://cloud.google.com/compute/docs/instances/specify-min-cpu-platform.", "type": "string" }, "disks": { "type": "array", "items": { "$ref": "Disk" }, "description": "The list of disks to create and attach to the VM." }, "bootImage": { "description": "The host operating system image to use.\n\nCurrently, only Container-Optimized OS images can be used.\n\nThe default value is `projects/cos-cloud/global/images/family/cos-stable`,\nwhich selects the latest stable release of Container-Optimized OS.\n\nThis option is provided to allow testing against the beta release of the\noperating system to ensure that the new version does not interact\nnegatively with production pipelines.\n\nTo test a pipeline against the beta release of Container-Optimized OS,\nuse the value `projects/cos-cloud/global/images/family/cos-beta`.", "type": "string" }, "serviceAccount": { "description": "The service account to install on the VM. This account does not need\nany permissions other than those required by the pipeline.", "$ref": "ServiceAccount" }, "accelerators": { "description": "The list of accelerators to attach to the VM.", "type": "array", "items": { "$ref": "Accelerator" } }, "machineType": { "description": "The machine type of the virtual machine to create. Must be the short name\nof a standard machine type (such as \"n1-standard-1\") or a custom machine\ntype (such as \"custom-1-4096\").", "type": "string" }, "network": { "description": "The VM network configuration.", "$ref": "Network" }, "bootDiskSizeGb": { "description": "The size of the boot disk, in GB. The boot disk must be large\nenough to accommodate all of the Docker images from each action in the\npipeline at the same time. If not specified, a small but reasonable\ndefault value is used.", "format": "int32", "type": "integer" }, "nvidiaDriverVersion": { "description": "The NVIDIA driver version to use when attaching an NVIDIA GPU accelerator.\nThe version specified here must be compatible with the GPU libraries\ncontained in the container being executed, and must be one of the drivers\nhosted in the `nvidia-drivers-us-public` bucket on Google Cloud Storage.", "type": "string" }, "preemptible": { "description": "If true, allocate a preemptible VM.", "type": "boolean" }, "labels": { "additionalProperties": { "type": "string" }, "description": "Optional set of labels to apply to the VM and any attached disk resources.\nThese labels must adhere to the name and value restrictions on VM labels\nimposed by Compute Engine.\n\nLabels applied at creation time to the VM. Applied on a best-effort basis\nto attached disk resources shortly after VM creation.", "type": "object" } }, "id": "VirtualMachine" }, "CheckInResponse": { "description": "The response to the CheckIn method.", "type": "object", "properties": { "metadata": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "The metadata that describes the operation assigned to the worker.", "type": "object" }, "deadline": { "description": "The deadline by which the worker must request an extension.  The backend\nwill allow for network transmission time and other delays, but the worker\nmust attempt to transmit the extension request no later than the deadline.", "format": "google-datetime", "type": "string" } }, "id": "CheckInResponse" }, "ListOperationsResponse": { "properties": { "nextPageToken": { "type": "string", "description": "The standard List next-page token." }, "operations": { "description": "A list of operations that matches the specified filter in the request.", "type": "array", "items": { "$ref": "Operation" } } }, "id": "ListOperationsResponse", "description": "The response message for Operations.ListOperations.", "type": "object" }, "OperationMetadata": { "type": "object", "properties": { "endTime": { "description": "The time at which the job stopped running.", "format": "google-datetime", "type": "string" }, "events": { "description": "Optional event messages that were generated during the job's execution.\nThis also contains any warnings that were generated during import\nor export.", "type": "array", "items": { "$ref": "OperationEvent" } }, "startTime": { "type": "string", "description": "The time at which the job began to run.", "format": "google-datetime" }, "request": { "additionalProperties": { "type": "any", "description": "Properties of the object. Contains field @type with type URL." }, "description": "The original request that started the operation. Note that this will be in\ncurrent version of the API. If the operation was started with v1beta2 API\nand a GetOperation is performed on v1 API, a v1 request will be returned.", "type": "object" }, "runtimeMetadata": { "description": "Runtime metadata on this Operation.", "type": "object", "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" } }, "labels": { "additionalProperties": { "type": "string" }, "description": "Optionally provided by the caller when submitting the request that creates\nthe operation.", "type": "object" }, "createTime": { "description": "The time at which the job was submitted to the Genomics service.", "format": "google-datetime", "type": "string" }, "projectId": { "description": "The Google Cloud Project in which the job is scoped.", "type": "string" }, "clientId": { "description": "This field is deprecated. Use `labels` instead. Optionally provided by the\ncaller when submitting the request that creates the operation.", "type": "string" } }, "id": "OperationMetadata", "description": "Metadata describing an Operation." }, "ContainerStartedEvent": { "description": "An event generated when a container starts.", "type": "object", "properties": { "ipAddress": { "type": "string", "description": "The public IP address that can be used to connect to the container. This\nfield is only populated when at least one port mapping is present. If the\ninstance was created with a private address, this field will be empty even\nif port mappings exist." }, "portMappings": { "additionalProperties": { "format": "int32", "type": "integer" }, "description": "The container-to-host port mappings installed for this container. This\nset will contain any ports exposed using the `PUBLISH_EXPOSED_PORTS` flag\nas well as any specified in the `Action` definition.", "type": "object" }, "actionId": { "description": "The numeric ID of the action that started this container.", "format": "int32", "type": "integer" } }, "id": "ContainerStartedEvent" }, "CheckInRequest": { "properties": { "deadlineExpired": { "$ref": "Empty", "description": "The deadline has expired and the worker needs more time." }, "workerStatus": { "$ref": "WorkerStatus", "description": "Data about the status of the worker VM." }, "event": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "A workflow specific event occurred.", "type": "object" }, "result": { "description": "The operation has finished with the given result.", "$ref": "Status" } }, "id": "CheckInRequest", "description": "The parameters to the CheckIn method.", "type": "object" }, "Mount": { "description": "Carries information about a particular disk mount inside a container.", "type": "object", "properties": { "disk": { "type": "string", "description": "The name of the disk to mount, as specified in the resources section." }, "readOnly": { "type": "boolean", "description": "If true, the disk is mounted read-only inside the container." }, "path": { "type": "string", "description": "The path to mount the disk inside the container." } }, "id": "Mount" }, "ImportVariantsResponse": { "properties": { "callSetIds": { "description": "IDs of the call sets created during the import.", "type": "array", "items": { "type": "string" } } }, "id": "ImportVariantsResponse", "description": "The variant data import response.", "type": "object" }, "WorkerStatus": { "id": "WorkerStatus", "description": "The status of the worker VM.", "type": "object", "properties": { "uptimeSeconds": { "type": "string", "description": "System uptime.", "format": "int64" }, "freeRamBytes": { "description": "Free RAM.", "format": "uint64", "type": "string" }, "bootDisk": { "$ref": "DiskStatus", "description": "Status of the boot disk." }, "attachedDisks": { "description": "Status of attached disks.", "type": "object", "additionalProperties": { "$ref": "DiskStatus" } }, "totalRamBytes": { "description": "Total RAM.", "format": "uint64", "type": "string" } } }, "ComputeEngine": { "description": "Describes a Compute Engine resource that is being managed by a running\npipeline.", "type": "object", "properties": { "machineType": { "description": "The machine type of the instance.", "type": "string" }, "diskNames": { "description": "The names of the disks that were created for this pipeline.", "type": "array", "items": { "type": "string" } }, "instanceName": { "description": "The instance on which the operation is running.", "type": "string" }, "zone": { "description": "The availability zone in which the instance resides.", "type": "string" } }, "id": "ComputeEngine" }, "WorkerAssignedEvent": { "description": "An event generated after a worker VM has been assigned to run the\npipeline.", "type": "object", "properties": { "instance": { "type": "string", "description": "The worker's instance name." }, "zone": { "description": "The zone the worker is running in.", "type": "string" } }, "id": "WorkerAssignedEvent" }, "Network": { "description": "VM networking options.", "type": "object", "properties": { "subnetwork": { "description": "If the specified network is configured for custom subnet creation, the\nname of the subnetwork to attach the instance to must be specified here.\n\nThe value is prefixed with `regions/*/subnetworks/` unless it contains a\n`/`, in which case it is assumed to be a fully specified subnetwork\nresource URL.\n\nIf the `*` character appears in the value, it is replaced with the region\nthat the virtual machine has been allocated in.", "type": "string" }, "name": { "description": "The network name to attach the VM's network interface to. The value will\nbe prefixed with `global/networks/` unless it contains a `/`, in which\ncase it is assumed to be a fully specified network resource URL.\n\nIf unspecified, the global default network is used.", "type": "string" }, "usePrivateAddress": { "description": "If set to true, do not attach a public IP address to the VM. Note that\nwithout a public IP address, additional configuration is required to\nallow the VM to access Google services.\n\nSee https://cloud.google.com/vpc/docs/configure-private-google-access\nfor more information.", "type": "boolean" } }, "id": "Network" }, "Secret": { "type": "object", "properties": { "keyName": { "description": "The name of the Cloud KMS key that will be used to decrypt the secret\nvalue. The VM service account must have the required permissions and\nauthentication scopes to invoke the `decrypt` method on the specified key.", "type": "string" }, "cipherText": { "description": "The value of the cipherText response from the `encrypt` method. This field\nis intentionally unaudited.", "type": "string" } }, "id": "Secret", "description": "Holds encrypted information that is only decrypted and stored in RAM\nby the worker VM when running the pipeline." }, "DelayedEvent": { "type": "object", "properties": { "metrics": { "description": "If the delay was caused by a resource shortage, this field lists the\nCompute Engine metrics that are preventing this operation from running\n(for example, `CPUS` or `INSTANCES`). If the particular metric is not\nknown, a single `UNKNOWN` metric will be present.", "type": "array", "items": { "type": "string" } }, "cause": { "description": "A textual description of the cause of the delay. The string can change\nwithout notice because it is often generated by another service (such as\nCompute Engine).", "type": "string" } }, "id": "DelayedEvent", "description": "An event generated whenever a resource limitation or transient error\ndelays execution of a pipeline that was otherwise ready to run." }, "Empty": { "properties": {}, "id": "Empty", "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.", "type": "object" }, "Disk": { "description": "Carries information about a disk that can be attached to a VM.\n\nSee https://cloud.google.com/compute/docs/disks/performance for more\ninformation about disk type, size, and performance considerations.", "type": "object", "properties": { "sourceImage": { "description": "An optional image to put on the disk before attaching it to the VM.", "type": "string" }, "sizeGb": { "type": "integer", "description": "The size, in GB, of the disk to attach. If the size is not\nspecified, a default is chosen to ensure reasonable I/O performance.\n\nIf the disk type is specified as `local-ssd`, multiple local drives are\nautomatically combined to provide the requested size. Note, however, that\neach physical SSD is 375GB in size, and no more than 8 drives can be\nattached to a single instance.", "format": "int32" }, "name": { "description": "A user-supplied name for the disk. Used when mounting the disk into\nactions. The name must contain only upper and lowercase alphanumeric\ncharacters and hypens and cannot start with a hypen.", "type": "string" }, "type": { "description": "The Compute Engine disk type. If unspecified, `pd-standard` is used.", "type": "string" } }, "id": "Disk" }, "WorkerReleasedEvent": { "id": "WorkerReleasedEvent", "description": "An event generated when the worker VM that was assigned to the pipeline\nhas been released (deleted).", "type": "object", "properties": { "zone": { "type": "string", "description": "The zone the worker was running in." }, "instance": { "description": "The worker's instance name.", "type": "string" } } }, "Action": { "description": "Specifies a single action that runs a Docker container.", "type": "object", "properties": { "mounts": { "description": "A list of mounts to make available to the action.\n\nIn addition to the values specified here, every action has a special\nvirtual disk mounted under `/google` that contains log files and other\noperational components.\n\n<ul>\n  <li><code>/google/logs</code> All logs written during the pipeline\n  execution.</li>\n  <li><code>/google/logs/output</code> The combined standard output and\n  standard error of all actions run as part of the pipeline\n  execution.</li>\n  <li><code>/google/logs/action/*/stdout</code> The complete contents of\n  each individual action's standard output.</li>\n  <li><code>/google/logs/action/*/stderr</code> The complete contents of\n  each individual action's standard error output.</li>\n</ul>", "type": "array", "items": { "$ref": "Mount" } }, "timeout": { "description": "The maximum amount of time to give the action to complete. If the action\nfails to complete before the timeout, it will be terminated and the exit\nstatus will be non-zero. The pipeline will continue or terminate based\non the rules defined by the `ALWAYS_RUN` and `IGNORE_EXIT_STATUS` flags.", "format": "google-duration", "type": "string" }, "credentials": { "$ref": "Secret", "description": "If the specified image is hosted on a private registry other than Google\nContainer Registry, the credentials required to pull the image must be\nspecified here as an encrypted secret.\n\nThe secret must decrypt to a JSON-encoded dictionary containing both\n`username` and `password` keys." }, "name": { "description": "An optional name for the container. The container hostname will be set to\nthis name, making it useful for inter-container communication. The name\nmust contain only upper and lowercase alphanumeric characters and hypens\nand cannot start with a hypen.", "type": "string" }, "imageUri": { "type": "string", "description": "The URI to pull the container image from. Note that all images referenced\nby actions in the pipeline are pulled before the first action runs. If\nmultiple actions reference the same image, it is only pulled once,\nensuring that the same image is used for all actions in a single pipeline." }, "commands": { "type": "array", "items": { "type": "string" }, "description": "If specified, overrides the `CMD` specified in the container. If the\ncontainer also has an `ENTRYPOINT` the values are used as entrypoint\narguments. Otherwise, they are used as a command and arguments to run\ninside the container." }, "flags": { "enumDescriptions": ["Unspecified flag.", "Normally, a non-zero exit status causes the pipeline to fail. This flag\nallows execution of other actions to continue instead.", "This flag allows an action to continue running in the background while\nexecuting subsequent actions. This is useful to provide services to\nother actions (or to provide debugging support tools like SSH servers).", "By default, after an action fails, no further actions are run. This flag\nindicates that this action must be run even if the pipeline has already\nfailed. This is useful for actions that copy output files off of the VM\nor for debugging.", "Enable access to the FUSE device for this action. Filesystems can then\nbe mounted into disks shared with other actions. The other actions do\nnot need the `ENABLE_FUSE` flag to access the mounted filesystem.\n\nThis has the effect of causing the container to be executed with\n`CAP_SYS_ADMIN` and exposes `/dev/fuse` to the container, so use it only\nfor containers you trust.", "Exposes all ports specified by `EXPOSE` statements in the container. To\ndiscover the host side port numbers, consult the `ACTION_STARTED` event\nin the operation metadata.", "All container images are typically downloaded before any actions are\nexecuted. This helps prevent typos in URIs or issues like lack of disk\nspace from wasting large amounts of compute resources.\n\nIf set, this flag prevents the worker from downloading the image until\njust before the action is executed.", "A small portion of the container's standard error stream is typically\ncaptured and returned inside the `ContainerStoppedEvent`. Setting this\nflag disables this functionality."], "description": "The set of flags to apply to this action.", "type": "array", "items": { "enum": ["FLAG_UNSPECIFIED", "IGNORE_EXIT_STATUS", "RUN_IN_BACKGROUND", "ALWAYS_RUN", "ENABLE_FUSE", "PUBLISH_EXPOSED_PORTS", "DISABLE_IMAGE_PREFETCH", "DISABLE_STANDARD_ERROR_CAPTURE"], "type": "string" } }, "environment": { "type": "object", "additionalProperties": { "type": "string" }, "description": "The environment to pass into the container. This environment is merged\nwith any values specified in the `Pipeline` message. These values\noverwrite any in the `Pipeline` message.\n\nIn addition to the values passed here, a few other values are\nautomatically injected into the environment. These cannot be hidden or\noverwritten.\n\n`GOOGLE_PIPELINE_FAILED` will be set to \"1\" if the pipeline failed\nbecause an action has exited with a non-zero status (and did not have the\n`IGNORE_EXIT_STATUS` flag set). This can be used to determine if additional\ndebug or logging actions should execute.\n\n`GOOGLE_LAST_EXIT_STATUS` will be set to the exit status of the last\nnon-background action that executed. This can be used by workflow engine\nauthors to determine whether an individual action has succeeded or failed." }, "portMappings": { "additionalProperties": { "format": "int32", "type": "integer" }, "description": "A map of containers to host port mappings for this container. If the\ncontainer already specifies exposed ports, use the\n`PUBLISH_EXPOSED_PORTS` flag instead.\n\nThe host port number must be less than 65536. If it is zero, an unused\nrandom port is assigned. To determine the resulting port number, consult\nthe `ContainerStartedEvent` in the operation metadata.", "type": "object" }, "labels": { "type": "object", "additionalProperties": { "type": "string" }, "description": "Labels to associate with the action. This field is provided to assist\nworkflow engine authors in identifying actions (for example, to indicate\nwhat sort of action they perform, such as localization or debugging).\nThey are returned in the operation metadata, but are otherwise ignored." }, "entrypoint": { "description": "If specified, overrides the `ENTRYPOINT` specified in the container.", "type": "string" }, "pidNamespace": { "description": "The PID namespace to run the action inside. If unspecified, a separate\nisolated namespace is used.", "type": "string" } }, "id": "Action" }, "FailedEvent": { "type": "object", "properties": { "cause": { "description": "The human-readable description of the cause of the failure.", "type": "string" }, "code": { "enum": ["OK", "CANCELLED", "UNKNOWN", "INVALID_ARGUMENT", "DEADLINE_EXCEEDED", "NOT_FOUND", "ALREADY_EXISTS", "PERMISSION_DENIED", "UNAUTHENTICATED", "RESOURCE_EXHAUSTED", "FAILED_PRECONDITION", "ABORTED", "OUT_OF_RANGE", "UNIMPLEMENTED", "INTERNAL", "UNAVAILABLE", "DATA_LOSS"], "description": "The Google standard error code that best describes this failure.", "type": "string", "enumDescriptions": ["Not an error; returned on success\n\nHTTP Mapping: 200 OK", "The operation was cancelled, typically by the caller.\n\nHTTP Mapping: 499 Client Closed Request", "Unknown error.  For example, this error may be returned when\na `Status` value received from another address space belongs to\nan error space that is not known in this address space.  Also\nerrors raised by APIs that do not return enough error information\nmay be converted to this error.\n\nHTTP Mapping: 500 Internal Server Error", "The client specified an invalid argument.  Note that this differs\nfrom `FAILED_PRECONDITION`.  `INVALID_ARGUMENT` indicates arguments\nthat are problematic regardless of the state of the system\n(e.g., a malformed file name).\n\nHTTP Mapping: 400 Bad Request", "The deadline expired before the operation could complete. For operations\nthat change the state of the system, this error may be returned\neven if the operation has completed successfully.  For example, a\nsuccessful response from a server could have been delayed long\nenough for the deadline to expire.\n\nHTTP Mapping: 504 Gateway Timeout", "Some requested entity (e.g., file or directory) was not found.\n\nNote to server developers: if a request is denied for an entire class\nof users, such as gradual feature rollout or undocumented whitelist,\n`NOT_FOUND` may be used. If a request is denied for some users within\na class of users, such as user-based access control, `PERMISSION_DENIED`\nmust be used.\n\nHTTP Mapping: 404 Not Found", "The entity that a client attempted to create (e.g., file or directory)\nalready exists.\n\nHTTP Mapping: 409 Conflict", "The caller does not have permission to execute the specified\noperation. `PERMISSION_DENIED` must not be used for rejections\ncaused by exhausting some resource (use `RESOURCE_EXHAUSTED`\ninstead for those errors). `PERMISSION_DENIED` must not be\nused if the caller can not be identified (use `UNAUTHENTICATED`\ninstead for those errors). This error code does not imply the\nrequest is valid or the requested entity exists or satisfies\nother pre-conditions.\n\nHTTP Mapping: 403 Forbidden", "The request does not have valid authentication credentials for the\noperation.\n\nHTTP Mapping: 401 Unauthorized", "Some resource has been exhausted, perhaps a per-user quota, or\nperhaps the entire file system is out of space.\n\nHTTP Mapping: 429 Too Many Requests", "The operation was rejected because the system is not in a state\nrequired for the operation's execution.  For example, the directory\nto be deleted is non-empty, an rmdir operation is applied to\na non-directory, etc.\n\nService implementors can use the following guidelines to decide\nbetween `FAILED_PRECONDITION`, `ABORTED`, and `UNAVAILABLE`:\n (a) Use `UNAVAILABLE` if the client can retry just the failing call.\n (b) Use `ABORTED` if the client should retry at a higher level\n     (e.g., when a client-specified test-and-set fails, indicating the\n     client should restart a read-modify-write sequence).\n (c) Use `FAILED_PRECONDITION` if the client should not retry until\n     the system state has been explicitly fixed.  E.g., if an \"rmdir\"\n     fails because the directory is non-empty, `FAILED_PRECONDITION`\n     should be returned since the client should not retry unless\n     the files are deleted from the directory.\n\nHTTP Mapping: 400 Bad Request", "The operation was aborted, typically due to a concurrency issue such as\na sequencer check failure or transaction abort.\n\nSee the guidelines above for deciding between `FAILED_PRECONDITION`,\n`ABORTED`, and `UNAVAILABLE`.\n\nHTTP Mapping: 409 Conflict", "The operation was attempted past the valid range.  E.g., seeking or\nreading past end-of-file.\n\nUnlike `INVALID_ARGUMENT`, this error indicates a problem that may\nbe fixed if the system state changes. For example, a 32-bit file\nsystem will generate `INVALID_ARGUMENT` if asked to read at an\noffset that is not in the range [0,2^32-1], but it will generate\n`OUT_OF_RANGE` if asked to read from an offset past the current\nfile size.\n\nThere is a fair bit of overlap between `FAILED_PRECONDITION` and\n`OUT_OF_RANGE`.  We recommend using `OUT_OF_RANGE` (the more specific\nerror) when it applies so that callers who are iterating through\na space can easily look for an `OUT_OF_RANGE` error to detect when\nthey are done.\n\nHTTP Mapping: 400 Bad Request", "The operation is not implemented or is not supported/enabled in this\nservice.\n\nHTTP Mapping: 501 Not Implemented", "Internal errors.  This means that some invariants expected by the\nunderlying system have been broken.  This error code is reserved\nfor serious errors.\n\nHTTP Mapping: 500 Internal Server Error", "The service is currently unavailable.  This is most likely a\ntransient condition, which can be corrected by retrying with\na backoff.\n\nSee the guidelines above for deciding between `FAILED_PRECONDITION`,\n`ABORTED`, and `UNAVAILABLE`.\n\nHTTP Mapping: 503 Service Unavailable", "Unrecoverable data loss or corruption.\n\nHTTP Mapping: 500 Internal Server Error"] } }, "id": "FailedEvent", "description": "An event generated when the execution of a pipeline has failed. Note\nthat other events can continue to occur after this event." }, "ContainerKilledEvent": { "id": "ContainerKilledEvent", "description": "An event generated when a container is forcibly terminated by the\nworker. Currently, this only occurs when the container outlives the\ntimeout specified by the user.", "type": "object", "properties": { "actionId": { "description": "The numeric ID of the action that started the container.", "format": "int32", "type": "integer" } } }, "ContainerStoppedEvent": { "description": "An event generated when a container exits.", "type": "object", "properties": { "actionId": { "type": "integer", "description": "The numeric ID of the action that started this container.", "format": "int32" }, "stderr": { "description": "The tail end of any content written to standard error by the container.\nIf the content emits large amounts of debugging noise or contains\nsensitive information, you can prevent the content from being printed by\nsetting the `DISABLE_STANDARD_ERROR_CAPTURE` flag.\n\nNote that only a small amount of the end of the stream is captured here.\nThe entire stream is stored in the `/google/logs` directory mounted into\neach action, and can be copied off the machine as described elsewhere.", "type": "string" }, "exitStatus": { "type": "integer", "description": "The exit status of the container.", "format": "int32" } }, "id": "ContainerStoppedEvent" }, "DiskStatus": { "id": "DiskStatus", "description": "The status of a disk on a VM.", "type": "object", "properties": { "freeSpaceBytes": { "description": "Free disk space.", "format": "uint64", "type": "string" }, "totalSpaceBytes": { "description": "Total disk space.", "format": "uint64", "type": "string" } } }, "Metadata": { "description": "Carries information about the pipeline execution that is returned\nin the long running operation's metadata field.", "type": "object", "properties": { "labels": { "type": "object", "additionalProperties": { "type": "string" }, "description": "The user-defined labels associated with this operation." }, "createTime": { "type": "string", "description": "The time at which the operation was created by the API.", "format": "google-datetime" }, "endTime": { "description": "The time at which execution was completed and resources were cleaned up.", "format": "google-datetime", "type": "string" }, "events": { "description": "The list of events that have happened so far during the execution of this\noperation.", "type": "array", "items": { "$ref": "Event" } }, "pipeline": { "$ref": "Pipeline", "description": "The pipeline this operation represents." }, "startTime": { "description": "The first time at which resources were allocated to execute the pipeline.", "format": "google-datetime", "type": "string" } }, "id": "Metadata" }, "PullStartedEvent": { "description": "An event generated when the worker starts pulling an image.", "type": "object", "properties": { "imageUri": { "description": "The URI of the image that was pulled.", "type": "string" } }, "id": "PullStartedEvent" }, "UnexpectedExitStatusEvent": { "description": "An event generated when the execution of a container results in a\nnon-zero exit status that was not otherwise ignored. Execution will\ncontinue, but only actions that are flagged as `ALWAYS_RUN` will be\nexecuted. Other actions will be skipped.", "type": "object", "properties": { "exitStatus": { "description": "The exit status of the container.", "format": "int32", "type": "integer" }, "actionId": { "description": "The numeric ID of the action that started the container.", "format": "int32", "type": "integer" } }, "id": "UnexpectedExitStatusEvent" } }, "icons": { "x32": "http://www.google.com/images/icons/product/search-32.gif", "x16": "http://www.google.com/images/icons/product/search-16.gif" }, "protocol": "rest", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/cloud-platform": { "description": "View and manage your data across Google Cloud Platform services" }, "https://www.googleapis.com/auth/genomics": { "description": "View and manage Genomics data" } } } }, "rootUrl": "https://genomics.googleapis.com/", "ownerDomain": "google.com", "name": "genomics", "batchPath": "batch", "fullyEncodeReservedExpansion": true, "title": "Genomics API", "ownerName": "Google", "resources": { "workers": { "methods": { "checkIn": { "httpMethod": "POST", "parameterOrder": ["id"], "response": { "$ref": "CheckInResponse" }, "parameters": { "id": { "location": "path", "description": "The worker id, assigned when it was created.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/genomics"], "flatPath": "v2alpha1/workers/{id}:checkIn", "id": "genomics.workers.checkIn", "path": "v2alpha1/workers/{id}:checkIn", "description": "The worker uses this method to retrieve the assigned operation and\nprovide periodic status updates.", "request": { "$ref": "CheckInRequest" } } } }, "projects": { "resources": { "operations": { "methods": { "cancel": { "httpMethod": "POST", "parameterOrder": ["name"], "response": { "$ref": "Empty" }, "parameters": { "name": { "location": "path", "description": "The name of the operation resource to be cancelled.", "required": true, "type": "string", "pattern": "^projects/[^/]+/operations/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/genomics"], "flatPath": "v2alpha1/projects/{projectsId}/operations/{operationsId}:cancel", "id": "genomics.projects.operations.cancel", "path": "v2alpha1/{+name}:cancel", "description": "Starts asynchronous cancellation on a long-running operation.\nThe server makes a best effort to cancel the operation, but success is not\nguaranteed. Clients may use Operations.GetOperation\nor Operations.ListOperations\nto check whether the cancellation succeeded or the operation completed\ndespite cancellation.\nAuthorization requires the following [Google IAM](https://cloud.google.com/iam) permission&#58;\n\n* `genomics.operations.cancel`", "request": { "$ref": "CancelOperationRequest" } }, "list": { "response": { "$ref": "ListOperationsResponse" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/genomics"], "parameters": { "filter": { "location": "query", "description": "A string for filtering Operations.\nIn v2alpha1, the following filter fields are supported&#58;\n\n* createTime&#58; The time this job was created\n* events&#58; The set of event (names) that have occurred while running\n  the pipeline.  The &#58; operator can be used to determine if a\n  particular event has occurred.\n* error&#58; If the pipeline is running, this value is NULL.  Once the\n  pipeline finishes, the value is the standard Google error code.\n* labels.key or labels.\"key with space\" where key is a label key.\n* done&#58; If the pipeline is running, this value is false. Once the\n  pipeline finishes, the value is true.\n\nIn v1 and v1alpha2, the following filter fields are supported&#58;\n\n* projectId&#58; Required. Corresponds to\n  OperationMetadata.projectId.\n* createTime&#58; The time this job was created, in seconds from the\n  [epoch](http://en.wikipedia.org/wiki/Unix_time). Can use `>=` and/or `<=`\n  operators.\n* status&#58; Can be `RUNNING`, `SUCCESS`, `FAILURE`, or `CANCELED`. Only\n  one status may be specified.\n* labels.key where key is a label key.\n\nExamples&#58;\n\n* `projectId = my-project AND createTime >= 1432140000`\n* `projectId = my-project AND createTime >= 1432140000 AND createTime <= 1432150000 AND status = RUNNING`\n* `projectId = my-project AND labels.color = *`\n* `projectId = my-project AND labels.color = red`", "type": "string" }, "name": { "pattern": "^projects/[^/]+/operations$", "location": "path", "description": "The name of the operation's parent resource.", "required": true, "type": "string" }, "pageToken": { "description": "The standard list page token.", "type": "string", "location": "query" }, "pageSize": { "location": "query", "description": "The maximum number of results to return. If unspecified, defaults to\n256. The maximum value is 2048.", "format": "int32", "type": "integer" } }, "flatPath": "v2alpha1/projects/{projectsId}/operations", "path": "v2alpha1/{+name}", "id": "genomics.projects.operations.list", "description": "Lists operations that match the specified filter in the request.&#13;\nAuthorization requires the following [Google IAM](https://cloud.google.com/iam) permission&#58;\n\n* `genomics.operations.list`" }, "get": { "response": { "$ref": "Operation" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/genomics"], "parameters": { "name": { "description": "The name of the operation resource.", "required": true, "type": "string", "pattern": "^projects/[^/]+/operations/[^/]+$", "location": "path" } }, "flatPath": "v2alpha1/projects/{projectsId}/operations/{operationsId}", "path": "v2alpha1/{+name}", "id": "genomics.projects.operations.get", "description": "Gets the latest state of a long-running operation.\nClients can use this method to poll the operation result at intervals as\nrecommended by the API service.\nAuthorization requires the following [Google IAM](https://cloud.google.com/iam) permission&#58;\n\n* `genomics.operations.get`" } } } } }, "pipelines": { "methods": { "run": { "response": { "$ref": "Operation" }, "parameterOrder": [], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/genomics"], "parameters": {}, "flatPath": "v2alpha1/pipelines:run", "path": "v2alpha1/pipelines:run", "id": "genomics.pipelines.run", "request": { "$ref": "RunPipelineRequest" }, "description": "Runs a pipeline.\n\n**Note:** Before you can use this method, the Genomics Service Agent\nmust have access to your project. This is done automatically when the\nCloud Genomics API is first enabled, but if you delete this permission,\nor if you enabled the Cloud Genomics API before the v2alpha1 API\nlaunch, you must disable and re-enable the API to grant the Genomics\nService Agent the required permissions.\nAuthorization requires the following [Google\nIAM](https://cloud.google.com/iam/) permission:\n\n* `genomics.operations.create`\n\n[1]: /genomics/gsa" } } } }, "parameters": { "key": { "location": "query", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string" }, "access_token": { "description": "OAuth access token.", "type": "string", "location": "query" }, "upload_protocol": { "location": "query", "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string" }, "prettyPrint": { "location": "query", "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true" }, "quotaUser": { "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string", "location": "query" }, "uploadType": { "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string", "location": "query" }, "fields": { "location": "query", "description": "Selector specifying which fields to include in a partial response.", "type": "string" }, "$.xgafv": { "enum": ["1", "2"], "description": "V1 error format.", "type": "string", "enumDescriptions": ["v1 error format", "v2 error format"], "location": "query" }, "oauth_token": { "description": "OAuth 2.0 token for the current user.", "type": "string", "location": "query" }, "callback": { "location": "query", "description": "JSONP", "type": "string" }, "alt": { "enum": ["json", "media", "proto"], "type": "string", "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response.", "default": "json" } }, "version": "v2alpha1", "baseUrl": "https://genomics.googleapis.com/", "servicePath": "", "description": "Upload, process, query, and search Genomics data in the cloud.", "kind": "discovery#restDescription", "basePath": "", "documentationLink": "https://cloud.google.com/genomics", "revision": "20180914", "id": "genomics:v2alpha1", "discoveryVersion": "v1", "version_module": true };
//# sourceMappingURL=genomics-v2alpha1.js.map