"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "ownerDomain": "google.com", "name": "jobs", "batchPath": "batch", "fullyEncodeReservedExpansion": true, "title": "Cloud Talent Solution API", "ownerName": "Google", "resources": { "companies": { "methods": { "create": { "parameters": {}, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/jobs"], "flatPath": "v2/companies", "path": "v2/companies", "id": "jobs.companies.create", "description": "Creates a new company entity.", "request": { "$ref": "Company" }, "response": { "$ref": "Company" }, "parameterOrder": [], "httpMethod": "POST" }, "delete": { "description": "Deletes the specified company.", "response": { "$ref": "Empty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "parameters": { "name": { "pattern": "^companies/[^/]+$", "location": "path", "description": "Required.\n\nThe resource name of the company to be deleted,\nsuch as, \"companies/0000aaaa-1111-bbbb-2222-cccc3333dddd\".", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/jobs"], "flatPath": "v2/companies/{companiesId}", "path": "v2/{+name}", "id": "jobs.companies.delete" }, "list": { "description": "Lists all companies associated with a Cloud Talent Solution account.", "httpMethod": "GET", "parameterOrder": [], "response": { "$ref": "ListCompaniesResponse" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/jobs"], "parameters": { "mustHaveOpenJobs": { "description": "Optional.\n\nSet to true if the companies request must have open jobs.\n\nDefaults to false.\n\nIf true, at most page_size of companies are fetched, among which\nonly those with open jobs are returned.", "type": "boolean", "location": "query" }, "pageToken": { "type": "string", "location": "query", "description": "Optional.\n\nThe starting indicator from which to return results." }, "pageSize": { "location": "query", "description": "Optional.\n\nThe maximum number of companies to be returned, at most 100.\nDefault is 100 if a non-positive number is provided.", "format": "int32", "type": "integer" } }, "flatPath": "v2/companies", "id": "jobs.companies.list", "path": "v2/companies" }, "get": { "description": "Retrieves the specified company.", "response": { "$ref": "Company" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/jobs"], "parameters": { "name": { "pattern": "^companies/[^/]+$", "location": "path", "description": "Required.\n\nResource name of the company to retrieve,\nsuch as \"companies/0000aaaa-1111-bbbb-2222-cccc3333dddd\".", "required": true, "type": "string" } }, "flatPath": "v2/companies/{companiesId}", "path": "v2/{+name}", "id": "jobs.companies.get" }, "patch": { "flatPath": "v2/companies/{companiesId}", "path": "v2/{+name}", "id": "jobs.companies.patch", "description": "Updates the specified company. Company names can't be updated. To update a\ncompany name, delete the company and all jobs associated with it, and only\nthen re-create them.", "request": { "$ref": "Company" }, "response": { "$ref": "Company" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "parameters": { "updateCompanyFields": { "type": "string", "location": "query", "description": "Optional but strongly recommended to be provided for the best service\nexperience.\n\nIf update_company_fields is provided, only the specified fields in\ncompany are updated. Otherwise all the fields are updated.\n\nA field mask to specify the company fields to update. Valid values are:\n\n* displayName\n* website\n* imageUrl\n* companySize\n* distributorBillingCompanyId\n* companyInfoSources\n* careerPageLink\n* hiringAgency\n* hqLocation\n* eeoText\n* keywordSearchableCustomAttributes\n* title (deprecated)\n* keywordSearchableCustomFields (deprecated)", "format": "google-fieldmask" }, "name": { "description": "Required during company update.\n\nThe resource name for a company. This is generated by the service when a\ncompany is created, for example,\n\"companies/0000aaaa-1111-bbbb-2222-cccc3333dddd\".", "required": true, "type": "string", "pattern": "^companies/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/jobs"] } }, "resources": { "jobs": { "methods": { "list": { "description": "Deprecated. Use ListJobs instead.\n\nLists all jobs associated with a company.", "response": { "$ref": "ListCompanyJobsResponse" }, "parameterOrder": ["companyName"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/jobs"], "parameters": { "includeJobsCount": { "location": "query", "description": "Deprecated. Please DO NOT use this field except for small companies.\nSuggest counting jobs page by page instead.\n\nOptional.\n\nSet to true if the total number of open jobs is to be returned.\n\nDefaults to false.", "type": "boolean" }, "companyName": { "description": "Required.\n\nThe resource name of the company that owns the jobs to be listed,\nsuch as, \"companies/0000aaaa-1111-bbbb-2222-cccc3333dddd\".", "required": true, "type": "string", "pattern": "^companies/[^/]+$", "location": "path" }, "pageToken": { "description": "Optional.\n\nThe starting point of a query result.", "type": "string", "location": "query" }, "idsOnly": { "type": "boolean", "location": "query", "description": "Optional.\n\nIf set to `true`, only job ID, job requisition ID and language code will be\nreturned.\n\nA typical use is to synchronize job repositories.\n\nDefaults to false." }, "pageSize": { "location": "query", "description": "Optional.\n\nThe maximum number of jobs to be returned per page of results.\n\nIf ids_only is set to true, the maximum allowed page size\nis 1000. Otherwise, the maximum allowed page size is 100.\n\nDefault is 100 if empty or a number < 1 is specified.", "format": "int32", "type": "integer" }, "jobRequisitionId": { "type": "string", "location": "query", "description": "Optional.\n\nThe requisition ID, also known as posting ID, assigned by the company\nto the job.\n\nThe maximum number of allowable characters is 225." } }, "flatPath": "v2/companies/{companiesId}/jobs", "path": "v2/{+companyName}/jobs", "id": "jobs.companies.jobs.list" } } } } }, "jobs": { "methods": { "searchForAlert": { "request": { "$ref": "SearchJobsRequest" }, "description": "Searches for jobs using the provided SearchJobsRequest.\n\nThis API call is intended for the use case of targeting passive job\nseekers (for example, job seekers who have signed up to receive email\nalerts about potential job opportunities), and has different algorithmic\nadjustments that are targeted to passive job seekers.\n\nThis call constrains the visibility of jobs\npresent in the database, and only returns jobs the caller has\npermission to search against.", "response": { "$ref": "SearchJobsResponse" }, "parameterOrder": [], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/jobs"], "parameters": {}, "flatPath": "v2/jobs:searchForAlert", "path": "v2/jobs:searchForAlert", "id": "jobs.jobs.searchForAlert" }, "deleteByFilter": { "httpMethod": "POST", "parameterOrder": [], "response": { "$ref": "Empty" }, "parameters": {}, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/jobs"], "flatPath": "v2/jobs:deleteByFilter", "id": "jobs.jobs.deleteByFilter", "path": "v2/jobs:deleteByFilter", "description": "Deprecated. Use BatchDeleteJobs instead.\n\nDeletes the specified job by filter. You can specify whether to\nsynchronously wait for validation, indexing, and general processing to be\ncompleted before the response is returned.", "request": { "$ref": "DeleteJobsByFilterRequest" } }, "delete": { "response": { "$ref": "Empty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/jobs"], "parameters": { "disableFastProcess": { "location": "query", "description": "Deprecated. This field is not working anymore.\n\nOptional.\n\nIf set to true, this call waits for all processing steps to complete\nbefore the job is cleaned up. Otherwise, the call returns while some\nsteps are still taking place asynchronously, hence faster.", "type": "boolean" }, "name": { "description": "Required.\n\nThe resource name of the job to be deleted, such as \"jobs/11111111\".", "required": true, "type": "string", "pattern": "^jobs/[^/]+$", "location": "path" } }, "flatPath": "v2/jobs/{jobsId}", "path": "v2/{+name}", "id": "jobs.jobs.delete", "description": "Deletes the specified job.\n\nTypically, the job becomes unsearchable within 10 seconds, but it may take\nup to 5 minutes." }, "list": { "response": { "$ref": "ListJobsResponse" }, "parameterOrder": [], "httpMethod": "GET", "parameters": { "filter": { "location": "query", "description": "Required.\n\nThe filter string specifies the jobs to be enumerated.\n\nSupported operator: =, AND\n\nThe fields eligible for filtering are:\n\n* `companyName` (Required)\n* `requisitionId` (Optional)\n\nSample Query:\n\n* companyName = \"companies/123\"\n* companyName = \"companies/123\" AND requisitionId = \"req-1\"", "type": "string" }, "pageToken": { "description": "Optional.\n\nThe starting point of a query result.", "type": "string", "location": "query" }, "pageSize": { "location": "query", "description": "Optional.\n\nThe maximum number of jobs to be returned per page of results.\n\nIf ids_only is set to true, the maximum allowed page size\nis 1000. Otherwise, the maximum allowed page size is 100.\n\nDefault is 100 if empty or a number < 1 is specified.", "format": "int32", "type": "integer" }, "idsOnly": { "type": "boolean", "location": "query", "description": "Optional.\n\nIf set to `true`, only Job.name, Job.requisition_id and\nJob.language_code will be returned.\n\nA typical use case is to synchronize job repositories.\n\nDefaults to false." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/jobs"], "flatPath": "v2/jobs", "path": "v2/jobs", "id": "jobs.jobs.list", "description": "Lists jobs by filter." }, "batchDelete": { "httpMethod": "POST", "parameterOrder": [], "response": { "$ref": "Empty" }, "parameters": {}, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/jobs"], "flatPath": "v2/jobs:batchDelete", "id": "jobs.jobs.batchDelete", "path": "v2/jobs:batchDelete", "description": "Deletes a list of Job postings by filter.", "request": { "$ref": "BatchDeleteJobsRequest" } }, "create": { "httpMethod": "POST", "parameterOrder": [], "response": { "$ref": "Job" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/jobs"], "parameters": {}, "flatPath": "v2/jobs", "id": "jobs.jobs.create", "path": "v2/jobs", "request": { "$ref": "CreateJobRequest" }, "description": "Creates a new job.\n\nTypically, the job becomes searchable within 10 seconds, but it may take\nup to 5 minutes." }, "histogram": { "flatPath": "v2/jobs:histogram", "path": "v2/jobs:histogram", "id": "jobs.jobs.histogram", "request": { "$ref": "GetHistogramRequest" }, "description": "Deprecated. Use SearchJobsRequest.histogram_facets instead to make\na single call with both search and histogram.\n\nRetrieves a histogram for the given\nGetHistogramRequest. This call provides a structured\ncount of jobs that match against the search query, grouped by specified\nfacets.\n\nThis call constrains the visibility of jobs\npresent in the database, and only counts jobs the caller has\npermission to search against.\n\nFor example, use this call to generate the\nnumber of jobs in the U.S. by state.", "response": { "$ref": "GetHistogramResponse" }, "parameterOrder": [], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/jobs"], "parameters": {} }, "search": { "response": { "$ref": "SearchJobsResponse" }, "parameterOrder": [], "httpMethod": "POST", "parameters": {}, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/jobs"], "flatPath": "v2/jobs:search", "path": "v2/jobs:search", "id": "jobs.jobs.search", "description": "Searches for jobs using the provided SearchJobsRequest.\n\nThis call constrains the visibility of jobs\npresent in the database, and only returns jobs that the caller has\npermission to search against.", "request": { "$ref": "SearchJobsRequest" } }, "patch": { "flatPath": "v2/jobs/{jobsId}", "id": "jobs.jobs.patch", "path": "v2/{+name}", "description": "Updates specified job.\n\nTypically, updated contents become visible in search results within 10\nseconds, but it may take up to 5 minutes.", "request": { "$ref": "UpdateJobRequest" }, "httpMethod": "PATCH", "parameterOrder": ["name"], "response": { "$ref": "Job" }, "parameters": { "name": { "pattern": "^jobs/[^/]+$", "location": "path", "description": "Required during job update.\n\nResource name assigned to a job by the API, for example, \"/jobs/foo\". Use\nof this field in job queries and API calls is preferred over the use of\nrequisition_id since this value is unique.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/jobs"] }, "get": { "description": "Retrieves the specified job, whose status is OPEN or recently EXPIRED\nwithin the last 90 days.", "response": { "$ref": "Job" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "required": true, "type": "string", "pattern": "^jobs/[^/]+$", "location": "path", "description": "Required.\n\nThe resource name of the job to retrieve, such as \"jobs/11111111\"." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/jobs"], "flatPath": "v2/jobs/{jobsId}", "path": "v2/{+name}", "id": "jobs.jobs.get" } } }, "v2": { "methods": { "complete": { "response": { "$ref": "CompleteQueryResponse" }, "parameterOrder": [], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/jobs"], "parameters": { "companyName": { "location": "query", "description": "Optional.\n\nIf provided, restricts completion to the specified company.", "type": "string" }, "scope": { "description": "Optional.\n\nThe scope of the completion. The defaults is CompletionScope.PUBLIC.", "type": "string", "location": "query", "enum": ["COMPLETION_SCOPE_UNSPECIFIED", "TENANT", "PUBLIC"] }, "pageSize": { "location": "query", "description": "Required.\n\nCompletion result count.\nThe maximum allowed page size is 10.", "format": "int32", "type": "integer" }, "query": { "location": "query", "description": "Required.\n\nThe query used to generate suggestions.", "type": "string" }, "languageCode": { "location": "query", "description": "Required.\n\nThe language of the query. This is\nthe BCP-47 language code, such as \"en-US\" or \"sr-Latn\".\nFor more information, see\n[Tags for Identifying Languages](https://tools.ietf.org/html/bcp47).\n\nFor CompletionType.JOB_TITLE type, only open jobs with same\nlanguage_code are returned.\n\nFor CompletionType.COMPANY_NAME type,\nonly companies having open jobs with same language_code are\nreturned.\n\nFor CompletionType.COMBINED type, only open jobs with same\nlanguage_code or companies having open jobs with same\nlanguage_code are returned.", "type": "string" }, "type": { "description": "Optional.\n\nThe completion topic. The default is CompletionType.COMBINED.", "type": "string", "location": "query", "enum": ["COMPLETION_TYPE_UNSPECIFIED", "JOB_TITLE", "COMPANY_NAME", "COMBINED"] } }, "flatPath": "v2:complete", "path": "v2:complete", "id": "jobs.complete", "description": "Completes the specified prefix with job keyword suggestions.\nIntended for use by a job search auto-complete search box." } } } }, "parameters": { "$.xgafv": { "location": "query", "enum": ["1", "2"], "description": "V1 error format.", "type": "string", "enumDescriptions": ["v1 error format", "v2 error format"] }, "oauth_token": { "description": "OAuth 2.0 token for the current user.", "type": "string", "location": "query" }, "callback": { "location": "query", "description": "JSONP", "type": "string" }, "alt": { "type": "string", "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response.", "default": "json", "enum": ["json", "media", "proto"] }, "key": { "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string", "location": "query" }, "access_token": { "description": "OAuth access token.", "type": "string", "location": "query" }, "upload_protocol": { "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string", "location": "query" }, "prettyPrint": { "location": "query", "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true" }, "quotaUser": { "location": "query", "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string" }, "uploadType": { "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string", "location": "query" }, "fields": { "location": "query", "description": "Selector specifying which fields to include in a partial response.", "type": "string" } }, "version": "v2", "baseUrl": "https://jobs.googleapis.com/", "servicePath": "", "kind": "discovery#restDescription", "description": "Cloud Talent Solution provides the capability to create, read, update, and delete job postings, as well as search jobs based on keywords and filters.\n", "basePath": "", "id": "jobs:v2", "documentationLink": "https://cloud.google.com/talent-solution/job-search/docs/", "revision": "20180906", "discoveryVersion": "v1", "version_module": true, "schemas": { "CommuteInfo": { "description": "Output only.\n\nCommute details related to this job.", "type": "object", "properties": { "travelDuration": { "description": "The number of seconds required to travel to the job location from the query\nlocation. A duration of 0 seconds indicates that the job is not\nreachable within the requested duration, but was returned as part of an\nexpanded query.", "format": "google-duration", "type": "string" }, "jobLocation": { "description": "Location used as the destination in the commute calculation.", "$ref": "JobLocation" } }, "id": "CommuteInfo" }, "CompensationHistogramRequest": { "description": "Input only.\n\nCompensation based histogram request.", "type": "object", "properties": { "type": { "description": "Required.\n\nType of the request, representing which field the histogramming should be\nperformed over. A single request can only specify one histogram of each\n`CompensationHistogramRequestType`.", "type": "string", "enumDescriptions": ["Default value. Invalid.", "Histogram by job's base compensation. See CompensationEntry for\ndefinition of base compensation.", "Histogram by job's annualized base compensation. See CompensationEntry\nfor definition of annualized base compensation.", "Histogram by job's annualized total compensation. See CompensationEntry\nfor definition of annualized total compensation."], "enum": ["COMPENSATION_HISTOGRAM_REQUEST_TYPE_UNSPECIFIED", "BASE", "ANNUALIZED_BASE", "ANNUALIZED_TOTAL"] }, "bucketingOption": { "description": "Required.\n\nNumeric histogram options, like buckets, whether include min or max value.", "$ref": "NumericBucketingOption" } }, "id": "CompensationHistogramRequest" }, "UpdateJobRequest": { "description": "Input only.\n\nUpdate job request.", "type": "object", "properties": { "job": { "$ref": "Job", "description": "Required.\n\nThe Job to be updated." }, "disableStreetAddressResolution": { "description": "Deprecated. Please use processing_options. This flag is ignored if\nprocessing_options is set.\n\nOptional.\n\nIf set to `true`, the service does not attempt resolve a more precise\naddress for the job.", "type": "boolean" }, "processingOptions": { "$ref": "JobProcessingOptions", "description": "Optional.\n\nOptions for job processing.\n\nUpdateJobRequest.disable_street_address_resolution is ignored if this\nflag is set." }, "updateJobFields": { "description": "Optional but strongly recommended to be provided for the best service\nexperience.\n\nIf update_job_fields is provided, only the specified fields in\njob are updated. Otherwise all the fields are updated.\n\nA field mask to restrict the fields that are updated. Valid values are:\n\n* jobTitle\n* employmentTypes\n* description\n* applicationUrls\n* applicationEmailList\n* applicationInstruction\n* responsibilities\n* qualifications\n* educationLevels\n* level\n* department\n* startDate\n* endDate\n* compensationInfo\n* incentives\n* languageCode\n* benefits\n* expireTime\n* customAttributes\n* visibility\n* publishDate\n* promotionValue\n* locations\n* region\n* expiryDate (deprecated)\n* filterableCustomFields (deprecated)\n* unindexedCustomFields (deprecated)", "format": "google-fieldmask", "type": "string" } }, "id": "UpdateJobRequest" }, "BucketRange": { "description": "Represents starting and ending value of a range in double.", "type": "object", "properties": { "from": { "description": "Starting value of the bucket range.", "format": "double", "type": "number" }, "to": { "description": "Ending value of the bucket range.", "format": "double", "type": "number" } }, "id": "BucketRange" }, "CompensationEntry": { "description": "A compensation entry that represents one component of compensation, such\nas base pay, bonus, or other compensation type.\n\nAnnualization: One compensation entry can be annualized if\n- it contains valid amount or range.\n- and its expected_units_per_year is set or can be derived.\nIts annualized range is determined as (amount or range) times\nexpected_units_per_year.", "type": "object", "properties": { "description": { "description": "Optional.\n\nCompensation description.  For example, could\nindicate equity terms or provide additional context to an estimated\nbonus.", "type": "string" }, "unit": { "enumDescriptions": ["Default value. Equivalent to OTHER_COMPENSATION_UNIT.", "Hourly.", "Daily.", "Weekly", "Monthly.", "Yearly.", "One time.", "Other compensation units."], "enum": ["COMPENSATION_UNIT_UNSPECIFIED", "HOURLY", "DAILY", "WEEKLY", "MONTHLY", "YEARLY", "ONE_TIME", "OTHER_COMPENSATION_UNIT"], "description": "Optional.\n\nFrequency of the specified amount.\n\nDefault is CompensationUnit.OTHER_COMPENSATION_UNIT.", "type": "string" }, "amount": { "description": "Optional.\n\nCompensation amount.", "$ref": "Money" }, "type": { "enumDescriptions": ["Default value. Equivalent to OTHER_COMPENSATION_TYPE.", "Base compensation: Refers to the fixed amount of money paid to an\nemployee by an employer in return for work performed. Base compensation\ndoes not include benefits, bonuses or any other potential compensation\nfrom an employer.", "Bonus.", "Signing bonus.", "Equity.", "Profit sharing.", "Commission.", "Tips.", "Other compensation type."], "enum": ["COMPENSATION_TYPE_UNSPECIFIED", "BASE", "BONUS", "SIGNING_BONUS", "EQUITY", "PROFIT_SHARING", "COMMISSIONS", "TIPS", "OTHER_COMPENSATION_TYPE"], "description": "Required.\n\nCompensation type.", "type": "string" }, "range": { "$ref": "CompensationRange", "description": "Optional.\n\nCompensation range." }, "expectedUnitsPerYear": { "description": "Optional.\n\nExpected number of units paid each year. If not specified, when\nJob.employment_types is FULLTIME, a default value is inferred\nbased on unit. Default values:\n- HOURLY: 2080\n- DAILY: 260\n- WEEKLY: 52\n- MONTHLY: 12\n- ANNUAL: 1", "format": "double", "type": "number" } }, "id": "CompensationEntry" }, "CustomAttribute": { "type": "object", "properties": { "filterable": { "description": "Optional.\n\nIf the `filterable` flag is true, custom field values are searchable.\nIf false, values are not searchable.\n\nDefault is false.", "type": "boolean" }, "longValue": { "type": "string", "description": "Optional but at least one of string_values or long_value must\nbe specified.\n\nThis field is used to perform number range search.\n(`EQ`, `GT`, `GE`, `LE`, `LT`) over filterable `long_value`. For\n`long_value`, a value between Long.MIN and Long.MIN is allowed.", "format": "int64" }, "stringValues": { "description": "Optional but at least one of string_values or long_value must\nbe specified.\n\nThis field is used to perform a string match (`CASE_SENSITIVE_MATCH` or\n`CASE_INSENSITIVE_MATCH`) search.\nFor filterable `string_values`, a maximum total number of 200 values\nis allowed, with each `string_value` has a byte size of no more than\n255B. For unfilterable `string_values`, the maximum total byte size of\nunfilterable `string_values` is 50KB.\n\nEmpty strings are not allowed.", "$ref": "StringValues" } }, "id": "CustomAttribute", "description": "Custom attribute values that are either filterable or non-filterable." }, "JobQuery": { "description": "Input only.\n\nThe query required to perform a search query or histogram.", "type": "object", "properties": { "publishDateRange": { "enum": ["DATE_RANGE_UNSPECIFIED", "PAST_24_HOURS", "PAST_WEEK", "PAST_MONTH", "PAST_YEAR", "PAST_3_DAYS"], "description": "Optional.\n\nJobs published within a range specified by this filter are searched\nagainst, for example, DateRange.PAST_MONTH. If a value isn't\nspecified, all open jobs are searched against regardless of their\npublished date.", "type": "string", "enumDescriptions": ["Default value: Filtering on time is not performed.", "The past 24 hours", "The past week (7 days)", "The past month (30 days)", "The past year (365 days)", "The past 3 days"] }, "commuteFilter": { "$ref": "CommutePreference", "description": "Optional.\n\n Allows filtering jobs by commute time with different travel methods (for\n example, driving or public transit). Note: This only works with COMMUTE\n MODE. When specified, [JobQuery.location_filters] is\n ignored.\n\n Currently we don't support sorting by commute time." }, "languageCodes": { "description": "Optional.\n\nThis filter specifies the locale of jobs to search against,\nfor example, \"en-US\".\n\nIf a value isn't specified, the search results can contain jobs in any\nlocale.\n\n\nLanguage codes should be in BCP-47 format, such as \"en-US\" or \"sr-Latn\".\nFor more information, see\n[Tags for Identifying Languages](https://tools.ietf.org/html/bcp47).\n\nAt most 10 language code filters are allowed.", "type": "array", "items": { "type": "string" } }, "query": { "description": "Optional.\n\nThe query string that matches against the job title, description, and\nlocation fields.\n\nThe maximum query size is 255 bytes.", "type": "string" }, "compensationFilter": { "description": "Optional.\n\nThis search filter is applied only to\nJob.compensation_info. For example, if the filter is specified\nas \"Hourly job with per-hour compensation > $15\", only jobs meeting\nthese criteria are searched. If a filter isn't defined, all open jobs\nare searched.", "$ref": "CompensationFilter" }, "disableSpellCheck": { "description": "Optional.\n\nThis flag controls the spell-check feature. If false, the\nservice attempts to correct a misspelled query,\nfor example, \"enginee\" is corrected to \"engineer\".\n\nDefaults to false: a spell check is performed.", "type": "boolean" }, "companyDisplayNames": { "description": "Optional.\n\nThis filter specifies the exact company display\nname of the jobs to search against.\n\nIf a value isn't specified, jobs within the search results are\nassociated with any company.\n\nIf multiple values are specified, jobs within the search results may be\nassociated with any of the specified companies.\n\nAt most 20 company display name filters are allowed.", "type": "array", "items": { "type": "string" } }, "companyNames": { "description": "Optional.\n\nThis filter specifies the company entities to search against.\n\nIf a value isn't specified, jobs are searched for against all\ncompanies.\n\nIf multiple values are specified, jobs are searched against the\ncompanies specified.\n\nAt most 20 company filters are allowed.", "type": "array", "items": { "type": "string" } }, "employmentTypes": { "description": "Optional.\n\nThe employment type filter specifies the employment type of jobs to\nsearch against, such as EmploymentType.FULL_TIME.\n\nIf a value is not specified, jobs in the search results include any\nemployment type.\n\nIf multiple values are specified, jobs in the search results include\nany of the specified employment types.", "type": "array", "items": { "enum": ["EMPLOYMENT_TYPE_UNSPECIFIED", "FULL_TIME", "PART_TIME", "CONTRACTOR", "TEMPORARY", "INTERN", "VOLUNTEER", "PER_DIEM", "CONTRACT_TO_HIRE", "FLY_IN_FLY_OUT", "OTHER"], "type": "string" }, "enumDescriptions": ["The default value if the employment type is not specified.", "The job requires working a number of hours that constitute full\ntime employment, typically 40 or more hours per week.", "The job entails working fewer hours than a full time job,\ntypically less than 40 hours a week.", "The job is offered as a contracted, as opposed to a salaried employee,\nposition.", "The job is offered as a temporary employment opportunity, usually\na short-term engagement.", "The job is a fixed-term opportunity for students or entry-level job seekers\nto obtain on-the-job training, typically offered as a summer position.", "The is an opportunity for an individual to volunteer, where there is no\nexpectation of compensation for the provided services.", "The job requires an employee to work on an as-needed basis with a\nflexible schedule.", "The job is offered as a contracted position with the understanding\nthat it is converted into a full-time position at the end of the\ncontract. Jobs of this type are also returned by a search for\nEmploymentType.CONTRACTOR jobs.", "The job involves employing people in remote areas and flying them\ntemporarily to the work site instead of relocating employees and their\nfamilies permanently.", "The job does not fit any of the other listed types."] }, "categories": { "description": "Optional.\n\nThe category filter specifies the categories of jobs to search against.\nSee Category for more information.\n\nIf a value is not specified, jobs from any category are searched against.\n\nIf multiple values are specified, jobs from any of the specified\ncategories are searched against.", "type": "array", "items": { "enum": ["JOB_CATEGORY_UNSPECIFIED", "ACCOUNTING_AND_FINANCE", "ADMINISTRATIVE_AND_OFFICE", "ADVERTISING_AND_MARKETING", "ANIMAL_CARE", "ART_FASHION_AND_DESIGN", "BUSINESS_OPERATIONS", "CLEANING_AND_FACILITIES", "COMPUTER_AND_IT", "CONSTRUCTION", "CUSTOMER_SERVICE", "EDUCATION", "ENTERTAINMENT_AND_TRAVEL", "FARMING_AND_OUTDOORS", "HEALTHCARE", "HUMAN_RESOURCES", "INSTALLATION_MAINTENANCE_AND_REPAIR", "LEGAL", "MANAGEMENT", "MANUFACTURING_AND_WAREHOUSE", "MEDIA_COMMUNICATIONS_AND_WRITING", "OIL_GAS_AND_MINING", "PERSONAL_CARE_AND_SERVICES", "PROTECTIVE_SERVICES", "REAL_ESTATE", "RESTAURANT_AND_HOSPITALITY", "SALES_AND_RETAIL", "SCIENCE_AND_ENGINEERING", "SOCIAL_SERVICES_AND_NON_PROFIT", "SPORTS_FITNESS_AND_RECREATION", "TRANSPORTATION_AND_LOGISTICS"], "type": "string" }, "enumDescriptions": ["The default value if the category is not specified.", "An accounting and finance job, such as an Accountant.", "And administrative and office job, such as an Administrative Assistant.", "An advertising and marketing job, such as Marketing Manager.", "An animal care job, such as Veterinarian.", "An art, fashion, or design job, such as Designer.", "A business operations job, such as Business Operations Manager.", "A cleaning and facilities job, such as Custodial Staff.", "A computer and IT job, such as Systems Administrator.", "A construction job, such as General Laborer.", "A customer service job, such s Cashier.", "An education job, such as School Teacher.", "An entertainment and travel job, such as Flight Attendant.", "A farming or outdoor job, such as Park Ranger.", "A healthcare job, such as Registered Nurse.", "A human resources job, such as Human Resources Director.", "An installation, maintenance, or repair job, such as Electrician.", "A legal job, such as Law Clerk.", "A management job, often used in conjunction with another category,\nsuch as Store Manager.", "A manufacturing or warehouse job, such as Assembly Technician.", "A media, communications, or writing job, such as Media Relations.", "An oil, gas or mining job, such as Offshore Driller.", "A personal care and services job, such as Hair Stylist.", "A protective services job, such as Security Guard.", "A real estate job, such as Buyer's Agent.", "A restaurant and hospitality job, such as Restaurant Server.", "A sales and/or retail job, such Sales Associate.", "A science and engineering job, such as Lab Technician.", "A social services or non-profit job, such as Case Worker.", "A sports, fitness, or recreation job, such as Personal Trainer.", "A transportation or logistics job, such as Truck Driver."] }, "customAttributeFilter": { "type": "string", "description": "Optional.\n\nThis filter specifies a structured syntax to match against the\nJob.custom_attributes marked as `filterable`.\n\nThe syntax for this expression is a subset of Google SQL syntax.\n\nSupported operators are: =, !=, <, <=, >, >= where the left of the operator\nis a custom field key and the right of the operator is a number or string\n(surrounded by quotes) value.\n\nSupported functions are LOWER(<field_name>) to\nperform case insensitive match and EMPTY(<field_name>) to filter on the\nexistence of a key.\n\nBoolean expressions (AND/OR/NOT) are supported up to 3 levels of\nnesting (for example, \"((A AND B AND C) OR NOT D) AND E\"), a maximum of 50\ncomparisons/functions are allowed in the expression. The expression\nmust be < 2000 characters in length.\n\nSample Query:\n(key1 = \"TEST\" OR LOWER(key1)=\"test\" OR NOT EMPTY(key1)) AND key2 > 100" }, "locationFilters": { "description": "Optional.\n\nThe location filter specifies geo-regions containing the jobs to\nsearch against. See LocationFilter for more information.\n\nIf a location value isn't specified, jobs fitting the other search\ncriteria are retrieved regardless of where they're located.\n\nIf multiple values are specified, jobs are retrieved from any of the\nspecified locations, and, if different values are specified\nfor the LocationFilter.distance_in_miles parameter, the maximum\nprovided distance is used for all locations.\n\nAt most 5 location filters are allowed.", "type": "array", "items": { "$ref": "LocationFilter" } } }, "id": "JobQuery" }, "ListJobsResponse": { "description": "Output only.\n\nList jobs response.", "type": "object", "properties": { "nextPageToken": { "description": "A token to retrieve the next page of results.", "type": "string" }, "metadata": { "description": "Additional information for the API invocation, such as the request\ntracking id.", "$ref": "ResponseMetadata" }, "jobs": { "description": "The Jobs for a given company.\n\nThe maximum number of items returned is based on the limit field\nprovided in the request.", "type": "array", "items": { "$ref": "Job" } } }, "id": "ListJobsResponse" }, "CompensationFilter": { "description": "Input only.\n\nFilter on job compensation type and amount.", "type": "object", "properties": { "type": { "enum": ["FILTER_TYPE_UNSPECIFIED", "UNIT_ONLY", "UNIT_AND_AMOUNT", "ANNUALIZED_BASE_AMOUNT", "ANNUALIZED_TOTAL_AMOUNT"], "description": "Required.\n\nType of filter.", "type": "string", "enumDescriptions": ["Filter type unspecified. Position holder, INVALID, should never be used.", "Filter by `base compensation entry's` unit. A job is a match if and\nonly if the job contains a base CompensationEntry and the base\nCompensationEntry's unit matches provided units.\nPopulate one or more units.\n\nSee CompensationInfo.CompensationEntry for definition of\nbase compensation entry.", "Filter by `base compensation entry's` unit and amount / range. A job\nis a match if and only if the job contains a base CompensationEntry, and\nthe base entry's unit matches provided compensation_units and amount\nor range overlaps with provided compensation_range.\n\nSee CompensationInfo.CompensationEntry for definition of\nbase compensation entry.\n\nSet exactly one units and populate range.", "Filter by annualized base compensation amount and `base compensation\nentry's` unit. Populate range and zero or more units.", "Filter by annualized total compensation amount and `base compensation\nentry's` unit . Populate range and zero or more units."] }, "units": { "description": "Required.\n\nSpecify desired `base compensation entry's`\nCompensationInfo.CompensationUnit.", "type": "array", "items": { "enum": ["COMPENSATION_UNIT_UNSPECIFIED", "HOURLY", "DAILY", "WEEKLY", "MONTHLY", "YEARLY", "ONE_TIME", "OTHER_COMPENSATION_UNIT"], "type": "string" }, "enumDescriptions": ["Default value. Equivalent to OTHER_COMPENSATION_UNIT.", "Hourly.", "Daily.", "Weekly", "Monthly.", "Yearly.", "One time.", "Other compensation units."] }, "includeJobsWithUnspecifiedCompensationRange": { "description": "Optional.\n\nWhether to include jobs whose compensation range is unspecified.", "type": "boolean" }, "range": { "description": "Optional.\n\nCompensation range.", "$ref": "CompensationRange" } }, "id": "CompensationFilter" }, "HistogramFacets": { "description": "Input only.\n\nHistogram facets to be specified in SearchJobsRequest.", "type": "object", "properties": { "compensationHistogramFacets": { "description": "Optional.\n\nSpecifies compensation field-based histogram requests.\nDuplicate values of CompensationHistogramRequest.type are not allowed.", "type": "array", "items": { "$ref": "CompensationHistogramRequest" } }, "simpleHistogramFacets": { "type": "array", "items": { "enum": ["JOB_FIELD_UNSPECIFIED", "COMPANY_ID", "EMPLOYMENT_TYPE", "COMPANY_SIZE", "DATE_PUBLISHED", "CUSTOM_FIELD_1", "CUSTOM_FIELD_2", "CUSTOM_FIELD_3", "CUSTOM_FIELD_4", "CUSTOM_FIELD_5", "CUSTOM_FIELD_6", "CUSTOM_FIELD_7", "CUSTOM_FIELD_8", "CUSTOM_FIELD_9", "CUSTOM_FIELD_10", "CUSTOM_FIELD_11", "CUSTOM_FIELD_12", "CUSTOM_FIELD_13", "CUSTOM_FIELD_14", "CUSTOM_FIELD_15", "CUSTOM_FIELD_16", "CUSTOM_FIELD_17", "CUSTOM_FIELD_18", "CUSTOM_FIELD_19", "CUSTOM_FIELD_20", "EDUCATION_LEVEL", "EXPERIENCE_LEVEL", "ADMIN1", "COUNTRY", "CITY", "LOCALE", "LANGUAGE", "CATEGORY", "CITY_COORDINATE", "ADMIN1_COUNTRY", "COMPANY_TITLE", "COMPANY_DISPLAY_NAME", "BASE_COMPENSATION_UNIT"], "type": "string" }, "enumDescriptions": ["The default value if search type is not specified.", "Filter by the company id field.", "Filter by the employment type field, such as `FULL_TIME` or `PART_TIME`.", "Filter by the company size type field, such as `BIG`, `SMALL` or `BIGGER`.", "Filter by the date published field. Values are stringified\nwith TimeRange, for example, TimeRange.PAST_MONTH.", "Filter by custom field 1.", "Filter by custom field 2.", "Filter by custom field 3.", "Filter by custom field 4.", "Filter by custom field 5.", "Filter by custom field 6.", "Filter by custom field 7.", "Filter by custom field 8.", "Filter by custom field 9.", "Filter by custom field 10.", "Filter by custom field 11.", "Filter by custom field 12.", "Filter by custom field 13.", "Filter by custom field 14.", "Filter by custom field 15.", "Filter by custom field 16.", "Filter by custom field 17.", "Filter by custom field 18.", "Filter by custom field 19.", "Filter by custom field 20.", "Filter by the required education level of the job.", "Filter by the required experience level of the job.", "Filter by Admin1, which is a global placeholder for\nreferring to state, province, or the particular term a country uses to\ndefine the geographic structure below the country level.\nExamples include states codes such as \"CA\", \"IL\", \"NY\", and\nprovinces, such as \"BC\".", "Filter by the country code of job, such as US, JP, FR.", "Filter by the \"city name\", \"Admin1 code\", for example,\n\"Mountain View, CA\" or \"New York, NY\".", "Filter by the locale field of a job, such as \"en-US\", \"fr-FR\".\n\nThis is the BCP-47 language code, such as \"en-US\" or \"sr-Latn\".\nFor more information, see\n[Tags for Identifying Languages](https://tools.ietf.org/html/bcp47).", "Filter by the language code portion of the locale field, such as \"en\" or\n\"fr\".", "Filter by the Category.", "Filter by the city center GPS coordinate (latitude and longitude), for\nexample, 37.4038522,-122.0987765. Since the coordinates of a city center\ncan change, clients may need to refresh them periodically.", "A combination of state or province code with a country code. This field\ndiffers from `JOB_ADMIN1`, which can be used in multiple countries.", "Deprecated. Use COMPANY_DISPLAY_NAME instead.\n\nCompany display name.", "Company display name.", "Base compensation unit."], "description": "Optional. Specifies the simple type of histogram facets, for example,\n`COMPANY_SIZE`, `EMPLOYMENT_TYPE` etc. This field is equivalent to\nGetHistogramRequest." }, "customAttributeHistogramFacets": { "description": "Optional.\n\nSpecifies the custom attributes histogram requests.\nDuplicate values of CustomAttributeHistogramRequest.key are not allowed.", "type": "array", "items": { "$ref": "CustomAttributeHistogramRequest" } } }, "id": "HistogramFacets" }, "SearchJobsResponse": { "description": "Output only.\n\nResponse for SearchJob method.", "type": "object", "properties": { "totalSize": { "description": "The precise result count, which is available only if the client set\nenable_precise_result_size to `true` or if the response\nis the last page of results. Otherwise, the value will be `-1`.", "format": "int64", "type": "string" }, "histogramResults": { "description": "The histogram results that match specified\nSearchJobsRequest.HistogramFacets.", "$ref": "HistogramResults" }, "metadata": { "$ref": "ResponseMetadata", "description": "Additional information for the API invocation, such as the request\ntracking id." }, "spellResult": { "$ref": "SpellingCorrection", "description": "The spell checking result, and correction." }, "matchingJobs": { "description": "The Job entities that match the specified SearchJobsRequest.", "type": "array", "items": { "$ref": "MatchingJob" } }, "appliedCommuteFilter": { "$ref": "CommutePreference", "description": "The commute filter the service applied to the specified query. This\ninformation is only available when query has a valid CommutePreference." }, "numJobsFromBroadenedQuery": { "description": "If query broadening is enabled, we may append additional results from the\nbroadened query. This number indicates how many of the jobs returned in the\njobs field are from the broadened query. These results are always at the\nend of the jobs list. In particular, a value of 0 means all the jobs in the\njobs list are from the original (without broadening) query. If this\nfield is non-zero, subsequent requests with offset after this result set\nshould contain all broadened results.", "format": "int32", "type": "integer" }, "jobView": { "enum": ["JOB_VIEW_UNSPECIFIED", "SMALL", "MINIMAL", "FULL"], "description": "Corresponds to SearchJobsRequest.job_view.", "type": "string", "enumDescriptions": ["Default value.", "A small view of the job, with the following attributes in the search results:\nJob.name, Job.requisition_id, Job.job_title,\nJob.company_name, Job.job_locations, Job.description,\nJob.visibility.\nNote: Job.description is deprecated. It is scheduled to be removed\nfrom MatchingJob.Job objects in the SearchJobsResponse results\non 12/31/2018.", "A minimal view of the job, with the following attributes in the search\nresults: Job.name, Job.requisition_id, Job.job_title,\nJob.company_name, Job.job_locations.", "All available attributes are included in the search results.\nNote: [Job.description, Job.responsibilities,\nJob.qualifications and Job.incentives are deprecated.\nThese fields are scheduled to be removed from MatchingJob.Job objects\nin the SearchJobsResponse results on 12/31/2018.\nSee the alternative MatchingJob.search_text_snippet and\nMatchingJob.job_summary fields."] }, "nextPageToken": { "description": "The token that specifies the starting position of the next page of results.\nThis field is empty if there are no more results.", "type": "string" }, "appliedJobLocationFilters": { "description": "The location filters that the service applied to the specified query. If\nany filters are lat-lng based, the JobLocation.location_type is\nJobLocation.LocationType#LOCATION_TYPE_UNSPECIFIED.", "type": "array", "items": { "$ref": "JobLocation" } }, "estimatedTotalSize": { "description": "An estimation of the number of jobs that match the specified query.\n\nThis number is not guaranteed to be accurate. For accurate results,\nseenenable_precise_result_size.", "format": "int64", "type": "string" } }, "id": "SearchJobsResponse" }, "Job": { "description": "A Job resource represents a job posting (also referred to as a \"job listing\"\nor \"job requisition\"). A job belongs to a Company, which is the hiring\nentity responsible for the job.", "type": "object", "properties": { "expiryDate": { "$ref": "Date", "description": "Deprecated. Use expire_time instead.\n\nOptional but strongly recommended to be provided for the best service\nexperience.\n\nThe expiration date of the job in UTC time. After 12 am on this date, the\njob is marked as expired, and it no longer appears in search results.\nThe expired job can't be deleted or listed by the DeleteJob and\nListJobs APIs, but it can be retrieved with the GetJob API or\nupdated with the UpdateJob API. An expired job can be updated and\nopened again by using a future expiration date. It can also remain expired.\nUpdating an expired job to be open fails if there is another existing open\njob with same requisition_id, company_name and language_code.\n\nThe expired jobs are retained in our system for 90 days. However, the\noverall expired job count cannot exceed 3 times the maximum of open jobs\ncount over the past week, otherwise jobs with earlier expire time are\nremoved first. Expired jobs are no longer accessible after they are cleaned\nout.\n\nA valid date range is between 1970/1/1 and 2100/12/31. Invalid dates are\nignored and treated as expiry date not provided.\n\nIf this value is not provided on job creation or is invalid, the job\nposting expires after 30 days from the job's creation time. For example, if\nthe job was created on 2017/01/01 13:00AM UTC with an unspecified\nexpiration date, the job expires after 2017/01/31 13:00AM UTC.\n\nIf this value is not provided on job update, it depends on the field masks\nset by UpdateJobRequest.update_job_fields. If the field masks include\nexpiry_date, or the masks are empty meaning that every field is\nupdated, the job expires after 30 days from the job's last update time.\nOtherwise the expiration date isn't updated." }, "endDate": { "description": "Optional.\n\nThe end date of the job in UTC time zone. Typically this field\nis used for contracting engagements.\nDates prior to 1970/1/1 and invalid date formats are ignored.", "$ref": "Date" }, "customAttributes": { "additionalProperties": { "$ref": "CustomAttribute" }, "description": "Optional.\n\nA map of fields to hold both filterable and non-filterable custom job\nattributes that are not covered by the provided structured fields.\n\nThis field is a more general combination of the deprecated id-based\nfilterable_custom_fields and string-based\nnon_filterable_custom_fields.\n\nThe keys of the map are strings up to 64 bytes and must match the\npattern: a-zA-Z*.\n\nAt most 100 filterable and at most 100 unfilterable keys are supported.\nFor filterable `string_values`, across all keys at most 200 values are\nallowed, with each string no more than 255 characters. For unfilterable\n`string_values`, the maximum total size of `string_values` across all keys\nis 50KB.", "type": "object" }, "educationLevels": { "enumDescriptions": ["The default value if the level is not specified.", "A High School diploma is required for the position.", "An Associate degree is required for the position.", "A Bachelors degree is required for the position.", "A Masters degree is required for the position.", "A Doctorate degree is required for the position.", "No formal education is required for the position."], "description": "Optional.\n\nThe desired education level for the job, such as\n\"Bachelors\", \"Masters\", \"Doctorate\".", "type": "array", "items": { "type": "string", "enum": ["EDUCATION_LEVEL_UNSPECIFIED", "HIGH_SCHOOL", "ASSOCIATE", "BACHELORS", "MASTERS", "DOCTORATE", "NO_DEGREE_REQUIRED"] } }, "filterableCustomFields": { "additionalProperties": { "$ref": "CustomField" }, "description": "Deprecated. Use custom_attributes instead.\n\nOptional.\n\nA map of fields to hold filterable custom job attributes not captured by\nthe standard fields such as job_title, company_name, or\nlevel. These custom fields store arbitrary\nstring values, and can be used for purposes not covered by\nthe structured fields. For the best search experience, use of the\nstructured rather than custom fields is recommended.\n\nData stored in these custom fields fields are indexed and\nsearched against by keyword searches (see\nSearchJobsRequest.custom_field_filters][]).\n\nThe map key must be a number between 1-20. If an invalid key is\nprovided on job create or update, an error is returned.", "type": "object" }, "languageCode": { "description": "Optional.\n\nThe language of the posting. This field is distinct from\nany requirements for fluency that are associated with the job.\n\nLanguage codes must be in BCP-47 format, such as \"en-US\" or \"sr-Latn\".\nFor more information, see\n[Tags for Identifying Languages](https://tools.ietf.org/html/bcp47){: class=\"external\" target=\"_blank\" }.\n\nThe default value is `en-US`.", "type": "string" }, "visibility": { "enumDescriptions": ["Default value.", "The Job is only visible to the owner.", "The Job is visible to the owner and may be visible to other applications\nand processes at Google.\n\nNot yet supported. Use PRIVATE.", "The Job is visible to the owner and may be visible to all other API\nclients.\n\nNot yet supported. Use PRIVATE."], "enum": ["JOB_VISIBILITY_UNSPECIFIED", "PRIVATE", "GOOGLE", "PUBLIC"], "description": "Optional.\n\nThe visibility of the job.\nDefaults to JobVisibility.PRIVATE if not specified.\nCurrently only JobVisibility.PRIVATE is supported.", "type": "string" }, "name": { "description": "Required during job update.\n\nResource name assigned to a job by the API, for example, \"/jobs/foo\". Use\nof this field in job queries and API calls is preferred over the use of\nrequisition_id since this value is unique.", "type": "string" }, "distributorCompanyId": { "type": "string", "description": "Optional but one of company_name or distributor_company_id must be\nprovided.\n\nA unique company identifier used by job distributors to identify an\nemployer's company entity. company_name takes precedence over\nthis field, and is the recommended field to use to identify companies.\n\nThe maximum number of allowed characters is 255." }, "promotionValue": { "description": "Optional.\n\nA promotion value of the job, as determined by the client.\nThe value determines the sort order of the jobs returned when searching for\njobs using the featured jobs search call, with higher promotional values\nbeing returned first and ties being resolved by relevance sort. Only the\njobs with a promotionValue >0 are returned in a FEATURED_JOB_SEARCH.\n\nDefault value is 0, and negative values are treated as 0.", "format": "int32", "type": "integer" }, "publishDate": { "$ref": "Date", "description": "Optional.\n\nThe date this job was most recently published in UTC format. The default\nvalue is the time the request arrives at the server." }, "applicationUrls": { "type": "array", "items": { "type": "string" }, "description": "Optional but at least one of application_urls,\napplication_email_list or application_instruction must be\nspecified.\n\nUse this URL field to direct an applicant to a website, for example to\nlink to an online application form.\n\nThe maximum number of allowed characters is 2,000." }, "companyDisplayName": { "description": "Output only.\n\nThe name of the company listing the job.", "type": "string" }, "requisitionId": { "description": "Required.\n\nThe requisition ID, also referred to as the posting ID, assigned by the\nclient to identify a job. This field is intended to be used by clients\nfor client identification and tracking of listings. A job is not allowed\nto be created if there is another job with the same requisition_id,\ncompany_name and language_code.\n\nThe maximum number of allowed characters is 255.", "type": "string" }, "qualifications": { "description": "Optional.\n\nA description of the qualifications required to perform the\njob. The use of this field is recommended\nas an alternative to using the more general description field.\n\nThis field accepts and sanitizes HTML input, and also accepts\nbold, italic, ordered list, and unordered list markup tags.\n\nThe maximum number of allowed characters is 10,000.", "type": "string" }, "startDate": { "$ref": "Date", "description": "Optional.\n\nThe start date of the job in UTC time zone. Typically this field\nis used for contracting engagements.\nDates prior to 1970/1/1 and invalid date formats are ignored." }, "createTime": { "description": "Output only.\n\nThe timestamp when this job was created.", "format": "google-datetime", "type": "string" }, "level": { "description": "Optional.\n\nThe experience level associated with the job, such as \"Entry Level\".", "type": "string", "enumDescriptions": ["The default value if the level is not specified.", "Entry-level individual contributors, typically with less than 2 years of\nexperience in a similar role. Includes interns.", "Experienced individual contributors, typically with 2+ years of\nexperience in a similar role.", "Entry- to mid-level managers responsible for managing a team of people.", "Senior-level managers responsible for managing teams of managers.", "Executive-level managers and above, including C-level positions."], "enum": ["JOB_LEVEL_UNSPECIFIED", "ENTRY_LEVEL", "EXPERIENCED", "MANAGER", "DIRECTOR", "EXECUTIVE"] }, "applicationInstruction": { "description": "Optional but at least one of application_urls,\napplication_email_list or application_instruction must be\nspecified.\n\nUse this field to provide instructions, such as \"Mail your application\nto ...\", that a candidate can follow to apply for the job.\n\nThis field accepts and sanitizes HTML input, and also accepts\nbold, italic, ordered list, and unordered list markup tags.\n\nThe maximum number of allowed characters is 3,000.", "type": "string" }, "benefits": { "enumDescriptions": ["Default value if the type is not specified.", "The job includes access to programs that support child care, such\nas daycare.", "The job includes dental services that are covered by a dental\ninsurance plan.", "The job offers specific benefits to domestic partners.", "The job allows for a flexible work schedule.", "The job includes health services that are covered by a medical\ninsurance plan.", "The job includes a life insurance plan provided by the employer or\navailable for purchase by the employee.", "The job allows for a leave of absence to a parent to care for a newborn\nchild.", "The job includes a workplace retirement plan provided by the\nemployer or available for purchase by the employee.", "The job allows for paid time off due to illness.", "Deprecated. Set Region.TELECOMMUTE instead.\n\nThe job allows telecommuting (working remotely).", "The job includes paid time off for vacation.", "The job includes vision services that are covered by a vision\ninsurance plan."], "description": "Optional.\n\nThe benefits included with the job.", "type": "array", "items": { "enum": ["JOB_BENEFIT_TYPE_UNSPECIFIED", "CHILD_CARE", "DENTAL", "DOMESTIC_PARTNER", "FLEXIBLE_HOURS", "MEDICAL", "LIFE_INSURANCE", "PARENTAL_LEAVE", "RETIREMENT_PLAN", "SICK_DAYS", "TELECOMMUTE", "VACATION", "VISION"], "type": "string" } }, "incentives": { "description": "Optional.\n\nA description of bonus, commission, and other compensation\nincentives associated with the job not including salary or pay.\n\nThe maximum number of allowed characters is 10,000.", "type": "string" }, "employmentTypes": { "description": "Optional.\n\nThe employment type(s) of a job, for example,\nfull time or\npart time.", "type": "array", "items": { "enum": ["EMPLOYMENT_TYPE_UNSPECIFIED", "FULL_TIME", "PART_TIME", "CONTRACTOR", "TEMPORARY", "INTERN", "VOLUNTEER", "PER_DIEM", "CONTRACT_TO_HIRE", "FLY_IN_FLY_OUT", "OTHER"], "type": "string" }, "enumDescriptions": ["The default value if the employment type is not specified.", "The job requires working a number of hours that constitute full\ntime employment, typically 40 or more hours per week.", "The job entails working fewer hours than a full time job,\ntypically less than 40 hours a week.", "The job is offered as a contracted, as opposed to a salaried employee,\nposition.", "The job is offered as a temporary employment opportunity, usually\na short-term engagement.", "The job is a fixed-term opportunity for students or entry-level job seekers\nto obtain on-the-job training, typically offered as a summer position.", "The is an opportunity for an individual to volunteer, where there is no\nexpectation of compensation for the provided services.", "The job requires an employee to work on an as-needed basis with a\nflexible schedule.", "The job is offered as a contracted position with the understanding\nthat it is converted into a full-time position at the end of the\ncontract. Jobs of this type are also returned by a search for\nEmploymentType.CONTRACTOR jobs.", "The job involves employing people in remote areas and flying them\ntemporarily to the work site instead of relocating employees and their\nfamilies permanently.", "The job does not fit any of the other listed types."] }, "locations": { "description": "Optional but strongly recommended for the best service experience.\n\nLocation(s) where the emploeyer is looking to hire for this job posting.\n\nSpecifying the full street address(es) of the hiring location enables\nbetter API results, especially job searches by commute time.\n\nAt most 50 locations are allowed for best search performance. If a job has\nmore locations, it is suggested to split it into multiple jobs with unique\nrequisition_ids (e.g. 'ReqA' becomes 'ReqA-1', 'ReqA-2', etc.) as\nmultiple jobs with the same requisition_id, company_name and\nlanguage_code are not allowed. If the original requisition_id must\nbe preserved, a custom field should be used for storage. It is also\nsuggested to group the locations that close to each other in the same job\nfor better search experience.\n\nThe maximum number of allowed characters is 500.", "type": "array", "items": { "type": "string" } }, "extendedCompensationInfo": { "description": "Deprecated. Always use compensation_info.\n\nOptional.\n\nJob compensation information.\n\nThis field replaces compensation_info.", "$ref": "ExtendedCompensationInfo" }, "companyName": { "description": "Optional but one of company_name or distributor_company_id must be\nprovided.\n\nThe resource name of the company listing the job, such as\n/companies/foo. This field takes precedence over the\ndistributor-assigned company identifier, distributor_company_id.", "type": "string" }, "description": { "description": "Required.\n\nThe description of the job, which typically includes a multi-paragraph\ndescription of the company and related information. Separate fields are\nprovided on the job object for responsibilities,\nqualifications, and other job characteristics. Use of\nthese separate job fields is recommended.\n\nThis field accepts and sanitizes HTML input, and also accepts\nbold, italic, ordered list, and unordered list markup tags.\n\nThe maximum number of allowed characters is 100,000.", "type": "string" }, "applicationEmailList": { "description": "Optional but at least one of application_urls,\napplication_email_list or application_instruction must be\nspecified.\n\nUse this field to specify email address(es) to which resumes or\napplications can be sent.\n\nThe maximum number of allowed characters is 255.", "type": "array", "items": { "type": "string" } }, "jobTitle": { "description": "Required.\n\nThe title of the job, such as \"Software Engineer\"\n\nThe maximum number of allowed characters is 500.", "type": "string" }, "region": { "enum": ["REGION_UNSPECIFIED", "STATE_WIDE", "NATION_WIDE", "TELECOMMUTE"], "description": "Optional.\n\nThe job Region (for example, state, country) throughout which the job\nis available. If this field is set, a\nLocationFilter in a search query within the job region\nfinds this job if an exact location match is not specified.\nIf this field is set, setting job locations\nto the same location level as this field is strongly recommended.", "type": "string", "enumDescriptions": ["If the region is unspecified, the job is only returned if it\nmatches the LocationFilter.", "In additiona to exact location matching, job is returned when the\nLocationFilter in search query is in the same state as this job.\nFor example, if a `STATE_WIDE` job is posted in \"CA, USA\", it is\nreturned if LocationFilter has \"Mountain View\".", "In addition to exact location matching, job is returned when\nLocationFilter in search query is in the same country as this job.\nFor example, if a `NATION_WIDE` job is posted in \"USA\", it is\nreturned if LocationFilter has 'Mountain View'.", "Job allows employees to work remotely (telecommute).\nIf locations are provided with this value, the job is\nconsidered as having a location, but telecommuting is allowed."] }, "referenceUrl": { "description": "Output only.\n\nThe URL of a web page that displays job details.", "type": "string" }, "companyTitle": { "description": "Deprecated. Use company_display_name instead.\n\nOutput only.\n\nThe name of the company listing the job.", "type": "string" }, "responsibilities": { "description": "Optional.\n\nA description of job responsibilities. The use of this field is\nrecommended as an alternative to using the more general description\nfield.\n\nThis field accepts and sanitizes HTML input, and also accepts\nbold, italic, ordered list, and unordered list markup tags.\n\nThe maximum number of allowed characters is 10,000.", "type": "string" }, "compensationInfo": { "description": "Optional.\n\nJob compensation information.", "$ref": "CompensationInfo" }, "expireTime": { "description": "Optional but strongly recommended for the best service\nexperience.\n\nThe expiration timestamp of the job. After this timestamp, the\njob is marked as expired, and it no longer appears in search results. The\nexpired job can't be deleted or listed by the DeleteJob and\nListJobs APIs, but it can be retrieved with the GetJob API or\nupdated with the UpdateJob API. An expired job can be updated and\nopened again by using a future expiration timestamp. Updating an expired job fails if there is another\nexisting open job with same requisition_id, company_name and\nlanguage_code.\n\nThe expired jobs are retained in our system for 90 days. However, the\noverall expired job count cannot exceed 3 times the maximum of open jobs\ncount over the past week, otherwise jobs with earlier expire time are\ncleaned first. Expired jobs are no longer accessible after they are cleaned\nout.\nThe format of this field is RFC 3339 date strings. Example:\n2000-01-01T00:00:00.999999999Z\nSee\n[https://www.ietf.org/rfc/rfc3339.txt](https://www.ietf.org/rfc/rfc3339.txt).\n\nA valid date range is between 1970-01-01T00:00:00.0Z and\n2100-12-31T23:59:59.999Z. Invalid dates are ignored and treated as expire\ntime not provided.\n\nIf this value is not provided at the time of job creation or is invalid, the job posting\nexpires after 30 days from the job's creation time. For example, if the\njob was created on 2017/01/01 13:00AM UTC with an unspecified expiration\ndate, the job expires after 2017/01/31 13:00AM UTC.\n\nIf this value is not provided but expiry_date is, expiry_date is\nused.\n\nIf this value is not provided on job update, it depends on the field masks\nset by UpdateJobRequest.update_job_fields. If the field masks include\nexpiry_time, or the masks are empty meaning that every field is\nupdated, the job posting expires after 30 days from the job's last\nupdate time. Otherwise the expiration date isn't updated.", "format": "google-datetime", "type": "string" }, "updateTime": { "description": "Output only.\n\nThe timestamp when this job was last updated.", "format": "google-datetime", "type": "string" }, "department": { "description": "Optional.\n\nThe department or functional area within the company with the open\nposition.\n\nThe maximum number of allowed characters is 255.", "type": "string" }, "jobLocations": { "description": "Output only.\n\nStructured locations of the job, resolved from locations.", "type": "array", "items": { "$ref": "JobLocation" } }, "unindexedCustomFields": { "description": "Deprecated. Use custom_attributes instead.\n\nOptional.\n\nA map of fields to hold non-filterable custom job attributes, similar to\nfilterable_custom_fields. These fields are distinct in that the data\nin these fields are not indexed. Therefore, the client cannot search\nagainst them, nor can the client use them to list jobs.\n\nThe key of the map can be any valid string.", "type": "object", "additionalProperties": { "$ref": "CustomField" } } }, "id": "Job" }, "ExtendedCompensationFilter": { "description": "Deprecated. Always use CompensationFilter.\n\nInput only.\n\nFilter on job compensation type and amount.", "type": "object", "properties": { "includeJobWithUnspecifiedCompensationRange": { "type": "boolean", "description": "Optional.\n\nWhether to include jobs whose compensation range is unspecified." }, "compensationUnits": { "description": "Required.\n\nSpecify desired `base compensation entry's`\nExtendedCompensationInfo.CompensationUnit.", "type": "array", "items": { "type": "string", "enum": ["EXTENDED_COMPENSATION_UNIT_UNSPECIFIED", "HOURLY", "DAILY", "WEEKLY", "MONTHLY", "YEARLY", "ONE_TIME", "OTHER_COMPENSATION_UNIT"] }, "enumDescriptions": ["Default value. Equivalent to OTHER_COMPENSATION_UNIT.", "Hourly.", "Daily.", "Weekly", "Monthly.", "Yearly.", "One time.", "Other compensation units."] }, "type": { "enumDescriptions": ["Filter type unspecified. Position holder, INVALID, should never be used.", "Filter by `base compensation entry's` unit. A job is a match if and\nonly if the job contains a base CompensationEntry and the base\nCompensationEntry's unit matches provided compensation_units.\nPopulate one or more compensation_units.\n\nSee ExtendedCompensationInfo.CompensationEntry for definition of\nbase compensation entry.", "Filter by `base compensation entry's` unit and amount / range. A job\nis a match if and only if the job contains a base CompensationEntry, and\nthe base entry's unit matches provided compensation_units and amount\nor range overlaps with provided compensation_range.\n\nSee ExtendedCompensationInfo.CompensationEntry for definition of\nbase compensation entry.\n\nSet exactly one\ncompensation_units and populate\ncompensation_range.", "Filter by annualized base compensation amount and `base compensation\nentry's` unit. Populate compensation_range and zero or more\ncompensation_units.", "Filter by annualized total compensation amount and `base compensation\nentry's` unit . Populate compensation_range and zero or more\ncompensation_units."], "enum": ["FILTER_TYPE_UNSPECIFIED", "UNIT_ONLY", "UNIT_AND_AMOUNT", "ANNUALIZED_BASE_AMOUNT", "ANNUALIZED_TOTAL_AMOUNT"], "description": "Required.\n\nType of filter.", "type": "string" }, "currency": { "description": "Optional.\n\nSpecify currency in 3-letter\n[ISO 4217](https://www.iso.org/iso-4217-currency-codes.html) format. If\nunspecified, jobs are returned regardless of currency.", "type": "string" }, "compensationRange": { "description": "Optional.\n\nCompensation range.", "$ref": "ExtendedCompensationInfoCompensationRange" } }, "id": "ExtendedCompensationFilter" }, "ExtendedCompensationInfoCompensationRange": { "properties": { "max": { "description": "Required.\n\nMaximum value.", "$ref": "ExtendedCompensationInfoDecimal" }, "min": { "description": "Required.\n\nMinimum value.", "$ref": "ExtendedCompensationInfoDecimal" } }, "id": "ExtendedCompensationInfoCompensationRange", "description": "Deprecated. See CompensationInfo.\n\nCompensation range.", "type": "object" }, "Company": { "id": "Company", "description": "A Company resource represents a company in the service. A company is the\nentity that owns job listings, that is, the hiring entity responsible for\nemploying applicants for the job position.", "type": "object", "properties": { "website": { "description": "Optional.\n\nThe URL representing the company's primary web site or home page,\nsuch as, \"www.google.com\".", "type": "string" }, "hqLocation": { "description": "Optional.\n\nThe street address of the company's main headquarters, which may be\ndifferent from the job location. The service attempts\nto geolocate the provided address, and populates a more specific\nlocation wherever possible in structured_company_hq_location.", "type": "string" }, "companyInfoSources": { "description": "Optional.\n\nIdentifiers external to the application that help to further identify\nthe employer.", "type": "array", "items": { "$ref": "CompanyInfoSource" } }, "keywordSearchableCustomAttributes": { "description": "Optional.\n\nA list of keys of filterable Job.custom_attributes, whose\ncorresponding `string_values` are used in keyword search. Jobs with\n`string_values` under these specified field keys are returned if any\nof the values matches the search keyword. Custom field values with\nparenthesis, brackets and special symbols might not be properly searchable,\nand those keyword queries need to be surrounded by quotes.", "type": "array", "items": { "type": "string" } }, "suspended": { "description": "Output only.\n\nIndicates whether a company is flagged to be suspended from public\navailability by the service when job content appears suspicious,\nabusive, or spammy.", "type": "boolean" }, "imageUrl": { "description": "Optional.\n\nA URL that hosts the employer's company logo. If provided,\nthe logo image should be squared at 80x80 pixels.\n\nThe url must be a Google Photos or Google Album url.\nOnly images in these Google sub-domains are accepted.", "type": "string" }, "distributorBillingCompanyId": { "description": "Optional.\n\nThe unique company identifier provided by the client to identify an\nemployer for billing purposes. Recommended practice is to use\nthe distributor_company_id.\n\nDefaults to same value as distributor_company_id when a value\nis not provided.", "type": "string" }, "careerPageLink": { "type": "string", "description": "Optional.\n\nThe URL to employer's career site or careers page on the employer's web\nsite." }, "keywordSearchableCustomFields": { "description": "Deprecated. Use keyword_searchable_custom_attributes instead.\n\nOptional.\n\nA list of filterable custom fields that should be used in keyword\nsearch. The jobs of this company are returned if any of these custom\nfields matches the search keyword. Custom field values with parenthesis,\nbrackets and special symbols might not be properly searchable, and those\nkeyword queries need to be surrounded by quotes.", "type": "array", "items": { "format": "int32", "type": "integer" } }, "disableLocationOptimization": { "description": "Deprecated. Do not use this field.\n\nOptional.\n\nThis field is no longer used. Any value set to it is ignored.", "type": "boolean" }, "companySize": { "enumDescriptions": ["Default value if the size is not specified.", "The company has less than 50 employees.", "The company has between 50 and 99 employees.", "The company has between 100 and 499 employees.", "The company has between 500 and 999 employees.", "The company has between 1,000 and 4,999 employees.", "The company has between 5,000 and 9,999 employees.", "The company has 10,000 or more employees."], "enum": ["COMPANY_SIZE_UNSPECIFIED", "MINI", "SMALL", "SMEDIUM", "MEDIUM", "BIG", "BIGGER", "GIANT"], "description": "Optional.\n\nThe employer's company size.", "type": "string" }, "eeoText": { "description": "Optional.\n\nEqual Employment Opportunity legal disclaimer text to be\nassociated with all jobs, and typically to be displayed in all\nroles.\n\nThe maximum number of allowed characters is 500.", "type": "string" }, "name": { "description": "Required during company update.\n\nThe resource name for a company. This is generated by the service when a\ncompany is created, for example,\n\"companies/0000aaaa-1111-bbbb-2222-cccc3333dddd\".", "type": "string" }, "distributorCompanyId": { "description": "Required.\n\nA client's company identifier, used to uniquely identify the\ncompany. If an employer has a subsidiary or sub-brand, such as \"Alphabet\"\nand \"Google\", which the client wishes to use as the company displayed on\nthe job. Best practice is to create a distinct company identifier for each\ndistinct brand displayed.\n\nThe maximum number of allowed characters is 255.", "type": "string" }, "structuredCompanyHqLocation": { "description": "Output only.\n\nA structured headquarters location of the company,\nresolved from hq_location if possible.", "$ref": "JobLocation" }, "hiringAgency": { "type": "boolean", "description": "Optional.\n\nSet to true if it is the hiring agency that post jobs for other\nemployers.\n\nDefaults to false if not provided." }, "title": { "description": "Deprecated. Use display_name instead.\n\nRequired.\n\nThe name of the employer to be displayed with the job,\nfor example, \"Google, LLC.\".", "type": "string" }, "displayName": { "description": "Required.\n\nThe name of the employer to be displayed with the job,\nfor example, \"Google, LLC.\".", "type": "string" } } }, "CompensationRange": { "description": "Compensation range.", "type": "object", "properties": { "min": { "$ref": "Money", "description": "Required.\n\nThe minimum amount of compensation." }, "max": { "description": "Required.\n\nThe maximum amount of compensation.", "$ref": "Money" } }, "id": "CompensationRange" }, "CompensationInfo": { "description": "Job compensation details.", "type": "object", "properties": { "max": { "$ref": "Money", "description": "Deprecated. Use entries instead.\n\nOptional.\n\nAn upper bound on a range for compensation or pay for the job.\nThe currency type is specified in compensation_amount." }, "annualizedTotalCompensationRange": { "description": "Output only.\n\nAnnualized total compensation range. Computed as\nall compensation entries' CompensationEntry.compensation times\nCompensationEntry.expected_units_per_year.\n\nSee CompensationEntry for explanation on compensation annualization.", "$ref": "CompensationRange" }, "min": { "$ref": "Money", "description": "Deprecated. Use entries instead.\n\nOptional.\n\nA lower bound on a range for compensation or pay for the job.\nThe currency type is specified in compensation_amount." }, "entries": { "description": "Optional.\n\nJob compensation information.\n\nAt most one entry can be of type\nCompensationInfo.CompensationType.BASE, which is\nreferred as ** base compensation entry ** for the job.", "type": "array", "items": { "$ref": "CompensationEntry" } }, "annualizedBaseCompensationRange": { "$ref": "CompensationRange", "description": "Output only.\n\nAnnualized base compensation range. Computed as\nbase compensation entry's CompensationEntry.compensation times\nCompensationEntry.expected_units_per_year.\n\nSee CompensationEntry for explanation on compensation annualization." }, "amount": { "description": "Deprecated. Use entries instead.\n\nOptional.\n\nThe amount of compensation or pay for the job.\nAs an alternative, compensation_amount_min and\ncompensation_amount_max may be used to define a range of\ncompensation.", "$ref": "Money" }, "type": { "type": "string", "enumDescriptions": ["The default value if the type is not specified.", "The job compensation is quoted by the number of hours worked.", "The job compensation is quoted on an annual basis.", "The job compensation is quoted by project completion.", "The job compensation is quoted based solely on commission.", "The job compensation is not quoted according to the listed compensation\noptions."], "enum": ["JOB_COMPENSATION_TYPE_UNSPECIFIED", "HOURLY", "SALARY", "PER_PROJECT", "COMMISSION", "OTHER_TYPE"], "description": "Deprecated. Use entries instead.\n\nOptional.\n\nType of job compensation." } }, "id": "CompensationInfo" }, "CustomAttributeHistogramRequest": { "description": "Custom attributes histogram request. An error will be thrown if neither\nstring_value_histogram or long_value_histogram_bucketing_option has\nbeen defined.", "type": "object", "properties": { "key": { "description": "Required.\n\nSpecifies the custom field key to perform a histogram on. If specified\nwithout `long_value_histogram_bucketing_option`, histogram on string values\nof the given `key` is triggered, otherwise histogram is performed on long\nvalues.", "type": "string" }, "longValueHistogramBucketingOption": { "$ref": "NumericBucketingOption", "description": "Optional.\n\nSpecifies buckets used to perform a range histogram on Job's\nfilterable long custom field values, or min/max value requirements." }, "stringValueHistogram": { "description": "Optional. If set to true, the response will include the histogram value for\neach key as a string.", "type": "boolean" } }, "id": "CustomAttributeHistogramRequest" }, "ExtendedCompensationInfoCompensationEntry": { "description": "Deprecated. See CompensationInfo.\n\nA compensation entry that represents one component of compensation, such\nas base pay, bonus, or other compensation type.\n\nAnnualization: One compensation entry can be annualized if\n- it contains valid amount or range.\n- and its expected_units_per_year is set or can be derived.\nIts annualized range is determined as (amount or range) times\nexpected_units_per_year.", "type": "object", "properties": { "amount": { "description": "Optional.\n\nMonetary amount.", "$ref": "ExtendedCompensationInfoDecimal" }, "type": { "type": "string", "enumDescriptions": ["Default value. Equivalent to OTHER_COMPENSATION_TYPE.", "Base compensation: Refers to the fixed amount of money paid to an\nemployee by an employer in return for work performed. Base compensation\ndoes not include benefits, bonuses or any other potential compensation\nfrom an employer.", "Bonus.", "Signing bonus.", "Equity.", "Profit sharing.", "Commission.", "Tips.", "Other compensation type."], "enum": ["EXTENDED_COMPENSATION_TYPE_UNSPECIFIED", "BASE", "BONUS", "SIGNING_BONUS", "EQUITY", "PROFIT_SHARING", "COMMISSIONS", "TIPS", "OTHER_COMPENSATION_TYPE"], "description": "Required.\n\nCompensation type." }, "range": { "$ref": "ExtendedCompensationInfoCompensationRange", "description": "Optional.\n\nCompensation range." }, "expectedUnitsPerYear": { "$ref": "ExtendedCompensationInfoDecimal", "description": "Optional.\n\nExpected number of units paid each year. If not specified, when\nJob.employment_types is FULLTIME, a default value is inferred\nbased on unit. Default values:\n- HOURLY: 2080\n- DAILY: 260\n- WEEKLY: 52\n- MONTHLY: 12\n- ANNUAL: 1" }, "unspecified": { "description": "Optional.\n\nIndicates compensation amount and range are unset.", "type": "boolean" }, "description": { "description": "Optional.\n\nCompensation description.", "type": "string" }, "unit": { "description": "Optional.\n\nFrequency of the specified amount.\n\nDefault is CompensationUnit.OTHER_COMPENSATION_UNIT.", "type": "string", "enumDescriptions": ["Default value. Equivalent to OTHER_COMPENSATION_UNIT.", "Hourly.", "Daily.", "Weekly", "Monthly.", "Yearly.", "One time.", "Other compensation units."], "enum": ["EXTENDED_COMPENSATION_UNIT_UNSPECIFIED", "HOURLY", "DAILY", "WEEKLY", "MONTHLY", "YEARLY", "ONE_TIME", "OTHER_COMPENSATION_UNIT"] } }, "id": "ExtendedCompensationInfoCompensationEntry" }, "CompensationHistogramResult": { "properties": { "result": { "$ref": "NumericBucketingResult", "description": "Histogram result." }, "type": { "description": "Type of the request, corresponding to\nCompensationHistogramRequest.type.", "type": "string", "enumDescriptions": ["Default value. Invalid.", "Histogram by job's base compensation. See CompensationEntry for\ndefinition of base compensation.", "Histogram by job's annualized base compensation. See CompensationEntry\nfor definition of annualized base compensation.", "Histogram by job's annualized total compensation. See CompensationEntry\nfor definition of annualized total compensation."], "enum": ["COMPENSATION_HISTOGRAM_REQUEST_TYPE_UNSPECIFIED", "BASE", "ANNUALIZED_BASE", "ANNUALIZED_TOTAL"] } }, "id": "CompensationHistogramResult", "description": "Output only.\n\nCompensation based histogram result.", "type": "object" }, "PostalAddress": { "description": "Represents a postal address, e.g. for postal delivery or payments addresses.\nGiven a postal address, a postal service can deliver items to a premise, P.O.\nBox or similar.\nIt is not intended to model geographical locations (roads, towns,\nmountains).\n\nIn typical usage an address would be created via user input or from importing\nexisting data, depending on the type of process.\n\nAdvice on address input / editing:\n - Use an i18n-ready address widget such as\n   https://github.com/googlei18n/libaddressinput)\n- Users should not be presented with UI elements for input or editing of\n  fields outside countries where that field is used.\n\nFor more guidance on how to use this schema, please see:\nhttps://support.google.com/business/answer/6397478", "type": "object", "properties": { "locality": { "description": "Optional. Generally refers to the city/town portion of the address.\nExamples: US city, IT comune, UK post town.\nIn regions of the world where localities are not well defined or do not fit\ninto this structure well, leave locality empty and use address_lines.", "type": "string" }, "administrativeArea": { "description": "Optional. Highest administrative subdivision which is used for postal\naddresses of a country or region.\nFor example, this can be a state, a province, an oblast, or a prefecture.\nSpecifically, for Spain this is the province and not the autonomous\ncommunity (e.g. \"Barcelona\" and not \"Catalonia\").\nMany countries don't use an administrative area in postal addresses. E.g.\nin Switzerland this should be left unpopulated.", "type": "string" }, "organization": { "description": "Optional. The name of the organization at the address.", "type": "string" }, "regionCode": { "description": "Required. CLDR region code of the country/region of the address. This\nis never inferred and it is up to the user to ensure the value is\ncorrect. See http://cldr.unicode.org/ and\nhttp://www.unicode.org/cldr/charts/30/supplemental/territory_information.html\nfor details. Example: \"CH\" for Switzerland.", "type": "string" }, "addressLines": { "description": "Unstructured address lines describing the lower levels of an address.\n\nBecause values in address_lines do not have type information and may\nsometimes contain multiple values in a single field (e.g.\n\"Austin, TX\"), it is important that the line order is clear. The order of\naddress lines should be \"envelope order\" for the country/region of the\naddress. In places where this can vary (e.g. Japan), address_language is\nused to make it explicit (e.g. \"ja\" for large-to-small ordering and\n\"ja-Latn\" or \"en\" for small-to-large). This way, the most specific line of\nan address can be selected based on the language.\n\nThe minimum permitted structural representation of an address consists\nof a region_code with all remaining information placed in the\naddress_lines. It would be possible to format such an address very\napproximately without geocoding, but no semantic reasoning could be\nmade about any of the address components until it was at least\npartially resolved.\n\nCreating an address only containing a region_code and address_lines, and\nthen geocoding is the recommended way to handle completely unstructured\naddresses (as opposed to guessing which parts of the address should be\nlocalities or administrative areas).", "type": "array", "items": { "type": "string" } }, "postalCode": { "type": "string", "description": "Optional. Postal code of the address. Not all countries use or require\npostal codes to be present, but where they are used, they may trigger\nadditional validation with other parts of the address (e.g. state/zip\nvalidation in the U.S.A.)." }, "sortingCode": { "description": "Optional. Additional, country-specific, sorting code. This is not used\nin most regions. Where it is used, the value is either a string like\n\"CEDEX\", optionally followed by a number (e.g. \"CEDEX 7\"), or just a number\nalone, representing the \"sector code\" (Jamaica), \"delivery area indicator\"\n(Malawi) or \"post office indicator\" (e.g. Côte d'Ivoire).", "type": "string" }, "languageCode": { "type": "string", "description": "Optional. BCP-47 language code of the contents of this address (if\nknown). This is often the UI language of the input form or is expected\nto match one of the languages used in the address' country/region, or their\ntransliterated equivalents.\nThis can affect formatting in certain countries, but is not critical\nto the correctness of the data and will never affect any validation or\nother non-formatting related operations.\n\nIf this value is not known, it should be omitted (rather than specifying a\npossibly incorrect default).\n\nExamples: \"zh-Hant\", \"ja\", \"ja-Latn\", \"en\"." }, "recipients": { "description": "Optional. The recipient at the address.\nThis field may, under certain circumstances, contain multiline information.\nFor example, it might contain \"care of\" information.", "type": "array", "items": { "type": "string" } }, "sublocality": { "description": "Optional. Sublocality of the address.\nFor example, this can be neighborhoods, boroughs, districts.", "type": "string" }, "revision": { "description": "The schema revision of the `PostalAddress`. This must be set to 0, which is\nthe latest revision.\n\nAll new revisions **must** be backward compatible with old revisions.", "format": "int32", "type": "integer" } }, "id": "PostalAddress" }, "StringValues": { "description": "Represents array of string values.", "type": "object", "properties": { "values": { "description": "Required.\n\nString values.", "type": "array", "items": { "type": "string" } } }, "id": "StringValues" }, "JobFilters": { "description": "Input only.\n\nDeprecated. Use JobQuery instead.\n\nThe filters required to perform a search query or histogram.", "type": "object", "properties": { "query": { "description": "Optional.\n\nThe query filter contains the keywords that match against the job\ntitle, description, and location fields.\n\nThe maximum query size is 255 bytes/characters.", "type": "string" }, "compensationFilter": { "$ref": "CompensationFilter", "description": "Optional.\n\nThis search filter is applied only to\nJob.compensation_info. For example, if the filter is specified\nas \"Hourly job with per-hour compensation > $15\", only jobs that meet\nthis criteria are searched. If a filter is not defined, all open jobs\nare searched." }, "customFieldFilters": { "additionalProperties": { "$ref": "CustomFieldFilter" }, "description": "Deprecated. Use custom_attribute_filter instead.\n\nOptional.\n\nThis filter specifies searching against\ncustom field values. See Job.filterable_custom_fields for information.\nThe key value specifies a number between 1-20 (the service\nsupports 20 custom fields) corresponding to the desired custom field map\nvalue. If an invalid key is provided or specified together with\ncustom_attribute_filter, an error is thrown.", "type": "object" }, "disableSpellCheck": { "type": "boolean", "description": "Optional.\n\nThis flag controls the spell-check feature. If false, the\nservice attempts to correct a misspelled query,\nfor example, \"enginee\" is corrected to \"engineer\".\n\nDefaults to false: a spell check is performed." }, "extendedCompensationFilter": { "description": "Deprecated. Always use compensation_filter.\n\nOptional.\n\nThis search filter is applied only to\nJob.extended_compensation_info. For example, if the filter is specified\nas \"Hourly job with per-hour compensation > $15\", only jobs that meet\nthese criteria are searched. If a filter is not defined, all open jobs\nare searched.", "$ref": "ExtendedCompensationFilter" }, "companyNames": { "description": "Optional.\n\nThe company names filter specifies the company entities to search\nagainst.\n\nIf a value is not specified, jobs are searched for against all companies.\n\nIf multiple values are specified, jobs are searched against the\nspecified companies.\n\nAt most 20 company filters are allowed.", "type": "array", "items": { "type": "string" } }, "tenantJobOnly": { "description": "Deprecated. Do not use this field.\n\nThis flag controls whether the job search should be restricted to jobs\nowned by the current user.\n\nDefaults to false where all jobs accessible to the\nuser are searched against.", "type": "boolean" }, "employmentTypes": { "enumDescriptions": ["The default value if the employment type is not specified.", "The job requires working a number of hours that constitute full\ntime employment, typically 40 or more hours per week.", "The job entails working fewer hours than a full time job,\ntypically less than 40 hours a week.", "The job is offered as a contracted, as opposed to a salaried employee,\nposition.", "The job is offered as a temporary employment opportunity, usually\na short-term engagement.", "The job is a fixed-term opportunity for students or entry-level job seekers\nto obtain on-the-job training, typically offered as a summer position.", "The is an opportunity for an individual to volunteer, where there is no\nexpectation of compensation for the provided services.", "The job requires an employee to work on an as-needed basis with a\nflexible schedule.", "The job is offered as a contracted position with the understanding\nthat it is converted into a full-time position at the end of the\ncontract. Jobs of this type are also returned by a search for\nEmploymentType.CONTRACTOR jobs.", "The job involves employing people in remote areas and flying them\ntemporarily to the work site instead of relocating employees and their\nfamilies permanently.", "The job does not fit any of the other listed types."], "description": "Optional.\n\nThe employment type filter specifies the employment type of jobs to\nsearch against, such as EmploymentType.FULL_TIME.\n\nIf a value is not specified, jobs in the search results include any\nemployment type.\n\nIf multiple values are specified, jobs in the search results include any\nof the specified employment types.", "type": "array", "items": { "enum": ["EMPLOYMENT_TYPE_UNSPECIFIED", "FULL_TIME", "PART_TIME", "CONTRACTOR", "TEMPORARY", "INTERN", "VOLUNTEER", "PER_DIEM", "CONTRACT_TO_HIRE", "FLY_IN_FLY_OUT", "OTHER"], "type": "string" } }, "categories": { "enumDescriptions": ["The default value if the category is not specified.", "An accounting and finance job, such as an Accountant.", "And administrative and office job, such as an Administrative Assistant.", "An advertising and marketing job, such as Marketing Manager.", "An animal care job, such as Veterinarian.", "An art, fashion, or design job, such as Designer.", "A business operations job, such as Business Operations Manager.", "A cleaning and facilities job, such as Custodial Staff.", "A computer and IT job, such as Systems Administrator.", "A construction job, such as General Laborer.", "A customer service job, such s Cashier.", "An education job, such as School Teacher.", "An entertainment and travel job, such as Flight Attendant.", "A farming or outdoor job, such as Park Ranger.", "A healthcare job, such as Registered Nurse.", "A human resources job, such as Human Resources Director.", "An installation, maintenance, or repair job, such as Electrician.", "A legal job, such as Law Clerk.", "A management job, often used in conjunction with another category,\nsuch as Store Manager.", "A manufacturing or warehouse job, such as Assembly Technician.", "A media, communications, or writing job, such as Media Relations.", "An oil, gas or mining job, such as Offshore Driller.", "A personal care and services job, such as Hair Stylist.", "A protective services job, such as Security Guard.", "A real estate job, such as Buyer's Agent.", "A restaurant and hospitality job, such as Restaurant Server.", "A sales and/or retail job, such Sales Associate.", "A science and engineering job, such as Lab Technician.", "A social services or non-profit job, such as Case Worker.", "A sports, fitness, or recreation job, such as Personal Trainer.", "A transportation or logistics job, such as Truck Driver."], "description": "Optional.\n\nThe category filter specifies the categories of jobs to search against.\nSee Category for more information.\n\nIf a value is not specified, jobs from any category are searched against.\n\nIf multiple values are specified, jobs from any of the specified\ncategories are searched against.", "type": "array", "items": { "type": "string", "enum": ["JOB_CATEGORY_UNSPECIFIED", "ACCOUNTING_AND_FINANCE", "ADMINISTRATIVE_AND_OFFICE", "ADVERTISING_AND_MARKETING", "ANIMAL_CARE", "ART_FASHION_AND_DESIGN", "BUSINESS_OPERATIONS", "CLEANING_AND_FACILITIES", "COMPUTER_AND_IT", "CONSTRUCTION", "CUSTOMER_SERVICE", "EDUCATION", "ENTERTAINMENT_AND_TRAVEL", "FARMING_AND_OUTDOORS", "HEALTHCARE", "HUMAN_RESOURCES", "INSTALLATION_MAINTENANCE_AND_REPAIR", "LEGAL", "MANAGEMENT", "MANUFACTURING_AND_WAREHOUSE", "MEDIA_COMMUNICATIONS_AND_WRITING", "OIL_GAS_AND_MINING", "PERSONAL_CARE_AND_SERVICES", "PROTECTIVE_SERVICES", "REAL_ESTATE", "RESTAURANT_AND_HOSPITALITY", "SALES_AND_RETAIL", "SCIENCE_AND_ENGINEERING", "SOCIAL_SERVICES_AND_NON_PROFIT", "SPORTS_FITNESS_AND_RECREATION", "TRANSPORTATION_AND_LOGISTICS"] } }, "customAttributeFilter": { "description": "Optional.\n\nThis filter specifies a structured syntax to match against the\nJob.custom_attributes that are marked as `filterable`.\n\nThe syntax for this expression is a subset of Google SQL syntax.\n\nSupported operators are: =, !=, <, <=, >, >= where the left of the operator\nis a custom field key and the right of the operator is a number or string\n(surrounded by quotes) value.\n\nSupported functions are LOWER(<field_name>) to\nperform case insensitive match and EMPTY(<field_name>) to filter on the\nexistence of a key.\n\nBoolean expressions (AND/OR/NOT) are supported up to 3 levels of\nnesting (For example, \"((A AND B AND C) OR NOT D) AND E\"), and there can\nbe a maximum of 50 comparisons/functions in the expression. The expression\nmust be < 2000 characters in length.\n\nSample Query:\n(key1 = \"TEST\" OR LOWER(key1)=\"test\" OR NOT EMPTY(key1)) AND key2 > 100", "type": "string" }, "locationFilters": { "description": "Optional.\n\nThe location filter specifies geo-regions containing the jobs to\nsearch against. See LocationFilter for more information.\n\nIf a location value is not specified, jobs are be retrieved\nfrom all locations.\n\nIf multiple values are specified, jobs are retrieved from any of the\nspecified locations, and, if different values are specified\nfor the LocationFilter.distance_in_miles parameter, the maximum\nprovided distance is used for all locations.\n\nAt most 5 location filters are allowed.", "type": "array", "items": { "$ref": "LocationFilter" } }, "publishDateRange": { "description": "Optional.\n\nJobs published within a range specified by this filter are searched\nagainst, for example, DateRange.PAST_MONTH. If a value is not\nspecified, all open jobs are searched against regardless of the\ndate they were published.", "type": "string", "enumDescriptions": ["Default value: Filtering on time is not performed.", "The past 24 hours", "The past week (7 days)", "The past month (30 days)", "The past year (365 days)", "The past 3 days"], "enum": ["DATE_RANGE_UNSPECIFIED", "PAST_24_HOURS", "PAST_WEEK", "PAST_MONTH", "PAST_YEAR", "PAST_3_DAYS"] }, "companyTitles": { "description": "Optional.\n\nThis filter specifies the exact company titles\nof jobs to search against.\n\nIf a value is not specified, jobs within the search results can be\nassociated with any company.\n\nIf multiple values are specified, jobs within the search results may be\nassociated with any of the specified companies.\n\nAt most 20 company title filters are allowed.", "type": "array", "items": { "type": "string" } }, "languageCodes": { "type": "array", "items": { "type": "string" }, "description": "Optional.\n\nThis filter specifies the locale of jobs to search against,\nfor example, \"en-US\".\n\nIf a value is not specified, the search results may contain jobs in any\nlocale.\n\n\nLanguage codes should be in BCP-47 format, for example, \"en-US\" or \"sr-Latn\".\nFor more information, see\n[Tags for Identifying Languages](https://tools.ietf.org/html/bcp47).\n\nAt most 10 language code filters are allowed." }, "commuteFilter": { "$ref": "CommutePreference", "description": "Optional.\n\n Allows filtering jobs by commute time with different travel methods (e.g.\n driving or public transit). Note: this only works with COMMUTE\n MODE. When specified, [JobFilters.location_filters] will be\n ignored.\n\n Currently we do not support sorting by commute time." } }, "id": "JobFilters" }, "ListCompanyJobsResponse": { "properties": { "nextPageToken": { "description": "A token to retrieve the next page of results.", "type": "string" }, "totalSize": { "description": "The total number of open jobs. The result will be\nempty if ListCompanyJobsRequest.include_jobs_count is not enabled\nor if no open jobs are available.", "format": "int64", "type": "string" }, "metadata": { "$ref": "ResponseMetadata", "description": "Additional information for the API invocation, such as the request\ntracking id." }, "jobs": { "description": "The Jobs for a given company.\n\nThe maximum number of items returned is based on the limit field\nprovided in the request.", "type": "array", "items": { "$ref": "Job" } } }, "id": "ListCompanyJobsResponse", "description": "Deprecated. Use ListJobsResponse instead.\n\nOutput only.\n\nThe List jobs response object.", "type": "object" }, "SearchJobsRequest": { "description": "Input only.\n\nThe Request body of the `SearchJobs` call.", "type": "object", "properties": { "offset": { "description": "Optional.\n\nAn integer that specifies the current offset (that is, starting result location, amongst the jobs deemed by the API as relevant) in\nsearch results. This field is only considered if page_token is unset.\n\nFor example, 0 means to  return results starting from the first matching\njob, and 10 means to return from the 11th job. This can be used for\npagination, (for example, pageSize = 10 and offset = 10 means to return\nfrom the second page).", "format": "int32", "type": "integer" }, "pageSize": { "description": "Optional.\n\nA limit on the number of jobs returned in the search results.\nIncreasing this value above the default value of 10 can increase search\nresponse time. The value can be between 1 and 100.", "format": "int32", "type": "integer" }, "query": { "description": "Optional.\n\nQuery used to search against jobs, such as keyword, location filters, etc.", "$ref": "JobQuery" }, "disableRelevanceThresholding": { "description": "Deprecated. Any value provided in this field is ignored.\n\nOptional.\n\nControls whether to disable relevance thresholding. Relevance\nthresholding removes jobs that have low relevance in search results,\nfor example, removing \"Assistant to the CEO\" positions from the search\nresults of a search for \"CEO\".\n\nDisabling relevance thresholding improves the accuracy of subsequent\nsearch requests.\n\nDefaults to false.", "type": "boolean" }, "enablePreciseResultSize": { "description": "Optional.\n\nControls if the search job request requires the return of a precise\ncount of the first 300 results. Setting this to `true` ensures\nconsistency in the number of results per page. Best practice is to set this\nvalue to true if a client allows users to jump directly to a\nnon-sequential search results page.\n\nEnabling this flag may adversely impact performance.\n\nDefaults to false.", "type": "boolean" }, "histogramFacets": { "$ref": "HistogramFacets", "description": "Optional.\n\nRestrictions on what fields to perform histogram on, such as\n`COMPANY_SIZE` etc." }, "orderBy": { "enumDescriptions": ["Default value.", "By descending relevance, as determined by the API algorithms.\n\nRelevance thresholding of query results is only available for queries if\nRELEVANCE_DESC sort ordering is specified.", "Sort by published date descending.", "Sort by updated date descending.", "Sort by job title ascending.", "Sort by job title descending.", "Sort by job annualized base compensation in ascending order.\nIf job's annualized base compensation is unspecified, they are put at\nthe end of search result.", "Sort by job annualized total compensation in ascending order.\nIf job's annualized total compensation is unspecified, they are put at\nthe end of search result.", "Sort by job annualized base compensation in descending order.\nIf job's annualized base compensation is unspecified, they are put at\nthe end of search result.", "Sort by job annualized total compensation in descending order.\nIf job's annualized total compensation is unspecified, they are put at\nthe end of search result."], "enum": ["SORT_BY_UNSPECIFIED", "RELEVANCE_DESC", "PUBLISHED_DATE_DESC", "UPDATED_DATE_DESC", "TITLE", "TITLE_DESC", "ANNUALIZED_BASE_COMPENSATION", "ANNUALIZED_TOTAL_COMPENSATION", "ANNUALIZED_BASE_COMPENSATION_DESC", "ANNUALIZED_TOTAL_COMPENSATION_DESC"], "description": "Deprecated. Use sort_by instead.\n\nOptional.\n\nThe criteria determining how search results are sorted.\nDefaults to SortBy.RELEVANCE_DESC if no value is specified.", "type": "string" }, "jobView": { "type": "string", "enumDescriptions": ["Default value.", "A small view of the job, with the following attributes in the search results:\nJob.name, Job.requisition_id, Job.job_title,\nJob.company_name, Job.job_locations, Job.description,\nJob.visibility.\nNote: Job.description is deprecated. It is scheduled to be removed\nfrom MatchingJob.Job objects in the SearchJobsResponse results\non 12/31/2018.", "A minimal view of the job, with the following attributes in the search\nresults: Job.name, Job.requisition_id, Job.job_title,\nJob.company_name, Job.job_locations.", "All available attributes are included in the search results.\nNote: [Job.description, Job.responsibilities,\nJob.qualifications and Job.incentives are deprecated.\nThese fields are scheduled to be removed from MatchingJob.Job objects\nin the SearchJobsResponse results on 12/31/2018.\nSee the alternative MatchingJob.search_text_snippet and\nMatchingJob.job_summary fields."], "enum": ["JOB_VIEW_UNSPECIFIED", "SMALL", "MINIMAL", "FULL"], "description": "Optional.\n\nThe number of job attributes returned for jobs in the\nsearch response. Defaults to JobView.SMALL if no value is specified." }, "pageToken": { "description": "Optional.\n\nThe token specifying the current offset within\nsearch results. See SearchJobsResponse.next_page_token for\nan explanation of how to obtain the next set of query results.", "type": "string" }, "filters": { "description": "Deprecated. Use query instead.\n\nOptional.\n\nRestrictions on the scope of the search request, such as filtering\nby location.", "$ref": "JobFilters" }, "sortBy": { "enumDescriptions": ["Default value.", "By descending relevance, as determined by the API algorithms.\n\nRelevance thresholding of query results is only available for queries if\nRELEVANCE_DESC sort ordering is specified.", "Sort by published date descending.", "Sort by updated date descending.", "Sort by job title ascending.", "Sort by job title descending.", "Sort by job annualized base compensation in ascending order.\nIf job's annualized base compensation is unspecified, they are put at\nthe end of search result.", "Sort by job annualized total compensation in ascending order.\nIf job's annualized total compensation is unspecified, they are put at\nthe end of search result.", "Sort by job annualized base compensation in descending order.\nIf job's annualized base compensation is unspecified, they are put at\nthe end of search result.", "Sort by job annualized total compensation in descending order.\nIf job's annualized total compensation is unspecified, they are put at\nthe end of search result."], "enum": ["SORT_BY_UNSPECIFIED", "RELEVANCE_DESC", "PUBLISHED_DATE_DESC", "UPDATED_DATE_DESC", "TITLE", "TITLE_DESC", "ANNUALIZED_BASE_COMPENSATION", "ANNUALIZED_TOTAL_COMPENSATION", "ANNUALIZED_BASE_COMPENSATION_DESC", "ANNUALIZED_TOTAL_COMPENSATION_DESC"], "description": "Optional.\n\nThe criteria determining how search results are sorted.\nDefaults to SortBy.RELEVANCE_DESC if no value is specified.", "type": "string" }, "requestMetadata": { "$ref": "RequestMetadata", "description": "Required.\n\nThe meta information collected about the job searcher, used to improve the\nsearch quality of the service.. The identifiers, (such as `user_id`) are\nprovided by users, and must be unique and consistent." }, "enableBroadening": { "description": "Optional.\n\nControls whether to broaden the search when it produces sparse results.\nBroadened queries append results to the end of the matching results\nlist.\n\nDefaults to false.", "type": "boolean" }, "mode": { "description": "Required.\n\nMode of a search.", "type": "string", "enumDescriptions": ["The mode of the search method isn't specified.", "The job search doesn't include support for featured jobs.", "The job search matches only against featured jobs (jobs with a\npromotionValue > 0). This method doesn't return any jobs having a\npromotionValue <= 0. The search results order is determined by the\npromotionValue (jobs with a higher promotionValue are returned higher up in\nthe search results), with relevance being used as a tiebreaker.", "Deprecated. Please use the SearchJobsForAlert API.\n\nThe job search matches against jobs suited to email notifications."], "enum": ["SEARCH_MODE_UNSPECIFIED", "JOB_SEARCH", "FEATURED_JOB_SEARCH", "EMAIL_ALERT_SEARCH"] } }, "id": "SearchJobsRequest" }, "CommutePreference": { "id": "CommutePreference", "description": "Input only.\n\nParameters needed for commute search.", "type": "object", "properties": { "departureHourLocal": { "description": "Optional.\n\nThe departure hour to use to calculate traffic impact. Accepts an\ninteger between 0 and 23, representing the hour in the time zone of the\nstart_location. Must not be present if road_traffic is specified.", "format": "int32", "type": "integer" }, "allowNonStreetLevelAddress": { "type": "boolean", "description": "Optional.\nIf `true`, jobs without street level addresses may also be returned.\nFor city level addresses, the city center is used. For state and coarser\nlevel addresses, text matching is used.\nIf this field is set to `false` or is not specified, only jobs that include\nstreet level addresses will be returned by commute search." }, "travelTime": { "description": "Required.\n\nThe maximum travel time in seconds. The maximum allowed value is `3600s`\n(one hour). Format is `123s`.", "format": "google-duration", "type": "string" }, "startLocation": { "$ref": "LatLng", "description": "Required.\n\nThe latitude and longitude of the location from which to calculate the\ncommute time." }, "method": { "enum": ["COMMUTE_METHOD_UNSPECIFIED", "DRIVING", "TRANSIT"], "description": "Required.\n\nThe method of transportation for which to calculate the commute time.", "type": "string", "enumDescriptions": ["Commute method is not specified.", "Commute time is calculated based on driving time.", "Commute time is calculated based on public transit including bus, metro,\nsubway, etc."] }, "roadTraffic": { "enumDescriptions": ["Road traffic situation is not specified.", "Optimal commute time without considering any traffic impact.", "Commute time calculation takes in account the peak traffic impact."], "enum": ["ROAD_TRAFFIC_UNSPECIFIED", "TRAFFIC_FREE", "BUSY_HOUR"], "description": "Optional.\n\nSpecifies the traffic density to use when caculating commute time.\nMust not be present if departure_hour_local is specified.", "type": "string" } } }, "CompleteQueryResponse": { "description": "Output only.\n\nResponse of auto-complete query.", "type": "object", "properties": { "metadata": { "description": "Additional information for the API invocation, such as the request\ntracking id.", "$ref": "ResponseMetadata" }, "completionResults": { "description": "Results of the matching job/company candidates.", "type": "array", "items": { "$ref": "CompletionResult" } } }, "id": "CompleteQueryResponse" }, "ResponseMetadata": { "type": "object", "properties": { "experimentIdList": { "description": "Identifiers for the versions of the search algorithm used during\nthis API invocation if multiple algorithms are used.\nThe default value is empty.\nFor search response only.", "type": "array", "items": { "format": "int32", "type": "integer" } }, "mode": { "description": "For search response only. Indicates the mode of a performed search.", "type": "string", "enumDescriptions": ["The mode of the search method isn't specified.", "The job search doesn't include support for featured jobs.", "The job search matches only against featured jobs (jobs with a\npromotionValue > 0). This method doesn't return any jobs having a\npromotionValue <= 0. The search results order is determined by the\npromotionValue (jobs with a higher promotionValue are returned higher up in\nthe search results), with relevance being used as a tiebreaker.", "Deprecated. Please use the SearchJobsForAlert API.\n\nThe job search matches against jobs suited to email notifications."], "enum": ["SEARCH_MODE_UNSPECIFIED", "JOB_SEARCH", "FEATURED_JOB_SEARCH", "EMAIL_ALERT_SEARCH"] }, "requestId": { "description": "A unique id associated with this call.\nThis id is logged for tracking purposes.", "type": "string" } }, "id": "ResponseMetadata", "description": "Output only.\n\nAdditional information returned to client, such as debugging\ninformation." }, "NumericBucketingResult": { "properties": { "counts": { "description": "Count within each bucket. Its size is the length of\nNumericBucketingOption.bucket_bounds plus 1.", "type": "array", "items": { "$ref": "BucketizedCount" } }, "minValue": { "description": "Stores the minimum value of the numeric field. Will be populated only if\n[NumericBucketingOption.requires_min_max] is set to true.", "format": "double", "type": "number" }, "maxValue": { "description": "Stores the maximum value of the numeric field. Will be populated only if\n[NumericBucketingOption.requires_min_max] is set to true.", "format": "double", "type": "number" } }, "id": "NumericBucketingResult", "description": "Output only.\n\nCustom numeric bucketing result.", "type": "object" }, "CompanyInfoSource": { "properties": { "freebaseMid": { "type": "string", "description": "Optional.\n\nThe Google's Knowledge Graph value for the employer's company." }, "mapsCid": { "description": "Optional.\n\nThe numeric identifier for the employer's headquarters on Google Maps,\nnamely, the Google Maps CID (cell id).", "type": "string" }, "gplusId": { "description": "Optional.\n\nThe numeric identifier for the employer's Google+ business page.", "type": "string" }, "unknownTypeId": { "type": "string", "description": "Optional.\n\nA Google identifier that does not match any of the other types." } }, "id": "CompanyInfoSource", "description": "A resource that represents an external  Google identifier for a company,\nfor example, a Google+ business page or a Google Maps business page.\nFor unsupported types, use `unknown_type_id`.", "type": "object" }, "MatchingJob": { "description": "Output only.\n\nJob entry with metadata inside SearchJobsResponse.", "type": "object", "properties": { "commuteInfo": { "$ref": "CommuteInfo", "description": "Commute information which is generated based on specified\n CommutePreference." }, "job": { "description": "Job resource that matches the specified SearchJobsRequest.", "$ref": "Job" }, "searchTextSnippet": { "description": "Contains snippets of text from the Job.description and similar\nfields that most closely match a search query's keywords, if available.\nAll HTML tags in the original fields are stripped when returned in this\nfield, and matching query keywords are enclosed in HTML bold tags.", "type": "string" }, "jobSummary": { "type": "string", "description": "A summary of the job with core information that's displayed on the search\nresults listing page." }, "jobTitleSnippet": { "description": "Contains snippets of text from the Job.job_title field most\nclosely matching a search query's keywords, if available. The matching query\nkeywords are enclosed in HTML bold tags.", "type": "string" } }, "id": "MatchingJob" }, "LatLng": { "description": "An object representing a latitude/longitude pair. This is expressed as a pair\nof doubles representing degrees latitude and degrees longitude. Unless\nspecified otherwise, this must conform to the\n<a href=\"http://www.unoosa.org/pdf/icg/2012/template/WGS_84.pdf\">WGS84\nstandard</a>. Values must be within normalized ranges.", "type": "object", "properties": { "latitude": { "description": "The latitude in degrees. It must be in the range [-90.0, +90.0].", "format": "double", "type": "number" }, "longitude": { "description": "The longitude in degrees. It must be in the range [-180.0, +180.0].", "format": "double", "type": "number" } }, "id": "LatLng" }, "DeviceInfo": { "description": "Input only.\n\nDevice information collected from the job seeker, candidate, or\nother entity conducting the job search. Providing this information improves\nthe quality of the search results across devices.", "type": "object", "properties": { "deviceType": { "enumDescriptions": ["The device type isn't specified.", "A desktop web browser, such as, Chrome, Firefox, Safari, or Internet\nExplorer)", "A mobile device web browser, such as a phone or tablet with a Chrome\nbrowser.", "An Android device native application.", "An iOS device native application.", "A bot, as opposed to a device operated by human beings, such as a web crawler.", "Other devices types."], "enum": ["DEVICE_TYPE_UNSPECIFIED", "WEB", "MOBILE_WEB", "ANDROID", "IOS", "BOT", "OTHER"], "description": "Optional.\n\nType of the device.", "type": "string" }, "id": { "description": "Optional.\n\nA device-specific ID. The ID must be a unique identifier that distinguishes\nthe device from other devices.", "type": "string" } }, "id": "DeviceInfo" }, "JobLocation": { "description": "Output only.\n\nA resource that represents a location with full geographic\ninformation.", "type": "object", "properties": { "locationType": { "type": "string", "enumDescriptions": ["Default value if the type is not specified.", "A country level location.", "A state or equivalent level location.", "A county or equivalent level location.", "A city or equivalent level location.", "A postal code level location.", "A sublocality is a subdivision of a locality, for example a city borough,\nward, or arrondissement. Sublocalities are usually recognized by a local\npolitical authority. For example, Manhattan and Brooklyn are recognized\nas boroughs by the City of New York, and are therefore modeled as\nsublocalities.", "A district or equivalent level location.", "A smaller district or equivalent level display.", "A neighborhood level location.", "A street address level location."], "enum": ["LOCATION_TYPE_UNSPECIFIED", "COUNTRY", "ADMINISTRATIVE_AREA", "SUB_ADMINISTRATIVE_AREA", "LOCALITY", "POSTAL_CODE", "SUB_LOCALITY", "SUB_LOCALITY_1", "SUB_LOCALITY_2", "NEIGHBORHOOD", "STREET_ADDRESS"], "description": "The type of a location, which corresponds to the address lines field of\nPostalAddress. For example, \"Downtown, Atlanta, GA, USA\" has a type of\nLocationType#NEIGHBORHOOD, and \"Kansas City, KS, USA\" has a type of\nLocationType#LOCALITY." }, "postalAddress": { "$ref": "PostalAddress", "description": "Postal address of the location that includes human readable information,\nsuch as postal delivery and payments addresses. Given a postal address,\na postal service can deliver items to a premises, P.O. Box, or other\ndelivery location." }, "radiusMeters": { "description": "Radius in meters of the job location. This value is derived from the\nlocation bounding box in which a circle with the specified radius\ncentered from LatLng coves the area associated with the job location.\nFor example, currently, \"Mountain View, CA, USA\" has a radius of\n7885.79 meters.", "format": "double", "type": "number" }, "latLng": { "$ref": "LatLng", "description": "An object representing a latitude/longitude pair." } }, "id": "JobLocation" }, "Money": { "properties": { "units": { "description": "The whole units of the amount.\nFor example if `currencyCode` is `\"USD\"`, then 1 unit is one US dollar.", "format": "int64", "type": "string" }, "currencyCode": { "description": "The 3-letter currency code defined in ISO 4217.", "type": "string" }, "nanos": { "description": "Number of nano (10^-9) units of the amount.\nThe value must be between -999,999,999 and +999,999,999 inclusive.\nIf `units` is positive, `nanos` must be positive or zero.\nIf `units` is zero, `nanos` can be positive, zero, or negative.\nIf `units` is negative, `nanos` must be negative or zero.\nFor example $-1.75 is represented as `units`=-1 and `nanos`=-750,000,000.", "format": "int32", "type": "integer" } }, "id": "Money", "description": "Represents an amount of money with its currency type.", "type": "object" }, "LocationFilter": { "description": "Input only.\n\nGeographic region of the search.", "type": "object", "properties": { "isTelecommute": { "description": "Optional.\n\nAllows the client to return jobs without a\nset location, specifically, telecommuting jobs (telecomuting is considered\nby the service as a special location.\nJob.allow_telecommute indicates if a job permits telecommuting.\nIf this field is true, telecommuting jobs are searched, and\nname and lat_lng are\nignored.\nThis filter can be used by itself to search exclusively for telecommuting\njobs, or it can be combined with another location\nfilter to search for a combination of job locations,\nsuch as \"Mountain View\" or \"telecommuting\" jobs. However, when used in\ncombination with other location filters, telecommuting jobs can be\ntreated as less relevant than other jobs in the search response.", "type": "boolean" }, "name": { "description": "Optional.\n\nThe address name, such as \"Mountain View\" or \"Bay Area\".", "type": "string" }, "latLng": { "description": "Optional.\n\nThe latitude and longitude of the geographic center from which to\nsearch. This field is ignored if `location_name` is provided.", "$ref": "LatLng" }, "regionCode": { "description": "Optional.\n\nCLDR region code of the country/region of the address. This will be used\nto address ambiguity of the user-input location, e.g. \"Liverpool\"\nagainst \"Liverpool, NY, US\" or \"Liverpool, UK\".\n\nSet this field if all the jobs to search against are from a same region,\nor jobs are world-wide but the job seeker is from a specific region.\n\nSee http://cldr.unicode.org/ and\nhttp://www.unicode.org/cldr/charts/30/supplemental/territory_information.html\nfor details. Example: \"CH\" for Switzerland.", "type": "string" }, "distanceInMiles": { "description": "Optional.\n\n\nThe distance_in_miles is applied when the location being searched for is\nidentified as a city or smaller. When the location being searched for is a\nstate or larger, this field is ignored.", "format": "double", "type": "number" } }, "id": "LocationFilter" }, "HistogramResults": { "properties": { "simpleHistogramResults": { "description": "Specifies histogram results that matches\nHistogramFacets.simple_histogram_facets.", "type": "array", "items": { "$ref": "HistogramResult" } }, "customAttributeHistogramResults": { "description": "Specifies histogram results for custom attributes that\nmatches HistogramFacets.custom_attribute_histogram_facets.", "type": "array", "items": { "$ref": "CustomAttributeHistogramResult" } }, "compensationHistogramResults": { "description": "Specifies compensation field-based histogram results that matches\nHistogramFacets.compensation_histogram_requests.", "type": "array", "items": { "$ref": "CompensationHistogramResult" } } }, "id": "HistogramResults", "description": "Output only.\n\nHistogram results that matches HistogramFacets specified in\nSearchJobsRequest.", "type": "object" }, "NumericBucketingOption": { "description": "Input only.\n\nUse this field to specify bucketing option for the histogram search response.", "type": "object", "properties": { "requiresMinMax": { "description": "Optional.\n\nIf set to true, the histogram result includes minimum/maximum\nvalue of the numeric field.", "type": "boolean" }, "bucketBounds": { "type": "array", "items": { "format": "double", "type": "number" }, "description": "Required.\n\nTwo adjacent values form a histogram bucket. Values should be in\nascending order. For example, if [5, 10, 15] are provided, four buckets are\ncreated: (-inf, 5), 5, 10), [10, 15), [15, inf). At most 20\n[buckets_bound is supported." } }, "id": "NumericBucketingOption" }, "CustomFieldFilter": { "id": "CustomFieldFilter", "description": "Input only.\n\nCustom field filter of the search.", "type": "object", "properties": { "type": { "enum": ["FILTER_TYPE_UNSPECIFIED", "OR", "AND", "NOT"], "description": "Optional.\n\nThe type of filter.\nDefaults to FilterType.OR.", "type": "string", "enumDescriptions": ["Default value.", "Search for a match with any query.", "Search for a match with all queries.", "Negate the set of filter values for the search."] }, "queries": { "type": "array", "items": { "type": "string" }, "description": "Required.\n\nThe query strings for the filter." } } }, "ExtendedCompensationInfoDecimal": { "id": "ExtendedCompensationInfoDecimal", "description": "Deprecated. See CompensationInfo.\n\nDecimal number.", "type": "object", "properties": { "micros": { "type": "integer", "description": "Micro (10^-6) units.\nThe value must be between -999,999 and +999,999 inclusive.\nIf `units` is positive, `micros` must be positive or zero.\nIf `units` is zero, `micros` can be positive, zero, or negative.\nIf `units` is negative, `micros` must be negative or zero.\nFor example -1.75 is represented as `units`=-1 and `micros`=-750,000.", "format": "int32" }, "units": { "description": "Whole units.", "format": "int64", "type": "string" } } }, "CreateJobRequest": { "description": "Input only.\n\nCreate job request.", "type": "object", "properties": { "job": { "$ref": "Job", "description": "Required.\n\nThe Job to be created." }, "disableStreetAddressResolution": { "description": "Deprecated. Please use processing_options. This flag is ignored if\nprocessing_options is set.\n\nOptional.\n\nIf set to `true`, the service does not attempt to resolve a\nmore precise address for the job.", "type": "boolean" }, "processingOptions": { "$ref": "JobProcessingOptions", "description": "Optional.\n\nOptions for job processing." } }, "id": "CreateJobRequest" }, "GetHistogramResponse": { "type": "object", "properties": { "results": { "description": "The Histogram results.", "type": "array", "items": { "$ref": "HistogramResult" } }, "metadata": { "description": "Additional information for the API invocation, such as the request\ntracking id.", "$ref": "ResponseMetadata" } }, "id": "GetHistogramResponse", "description": "Deprecated. Use SearchJobsRequest.histogram_facets instead to make\na single call with both search and histogram.\n\nOutput only.\n\nThe response of the GetHistogram method." }, "SpellingCorrection": { "description": "Output only.\n\nSpell check result.", "type": "object", "properties": { "corrected": { "type": "boolean", "description": "Indicates if the query was corrected by the spell checker." }, "correctedText": { "description": "Correction output consisting of the corrected keyword string.", "type": "string" } }, "id": "SpellingCorrection" }, "Date": { "description": "Represents a whole calendar date, e.g. date of birth. The time of day and\ntime zone are either specified elsewhere or are not significant. The date\nis relative to the Proleptic Gregorian Calendar. The day may be 0 to\nrepresent a year and month where the day is not significant, e.g. credit card\nexpiration date. The year may be 0 to represent a month and day independent\nof year, e.g. anniversary date. Related types are google.type.TimeOfDay\nand `google.protobuf.Timestamp`.", "type": "object", "properties": { "month": { "description": "Month of year. Must be from 1 to 12, or 0 if specifying a date without a\nmonth.", "format": "int32", "type": "integer" }, "year": { "description": "Year of date. Must be from 1 to 9999, or 0 if specifying a date without\na year.", "format": "int32", "type": "integer" }, "day": { "description": "Day of month. Must be from 1 to 31 and valid for the year and month, or 0\nif specifying a year/month where the day is not significant.", "format": "int32", "type": "integer" } }, "id": "Date" }, "Filter": { "description": "Deprecated. Use BatchDeleteJobsRequest instead.\n\nInput only.\n\nFilter for jobs to be deleted.", "type": "object", "properties": { "requisitionId": { "description": "Required.\n\nThe requisition ID (or posting ID) assigned by the client to identify a\njob. This is intended for client identification and tracking of\nlistings.\nname takes precedence over this field\nThe maximum number of allowed characters is 225.", "type": "string" } }, "id": "Filter" }, "DeleteJobsByFilterRequest": { "description": "Deprecated. Use BatchDeleteJobsRequest instead.\n\nInput only.\n\nDelete job by filter request.\n\nThe job typically becomes unsearchable within 10 seconds, but it may take\nup to 5 minutes.", "type": "object", "properties": { "filter": { "$ref": "Filter", "description": "Required.\n\nRestrictions on the scope of the delete request." }, "disableFastProcess": { "description": "Optional.\n\nIf set to true, this call waits for all processing steps to complete\nbefore the job is cleaned up. Otherwise, the call returns while some\nsteps are still taking place asynchronously, hence faster.", "type": "boolean" } }, "id": "DeleteJobsByFilterRequest" }, "ExtendedCompensationInfo": { "description": "Deprecated. Use CompensationInfo.\n\nDescribes job compensation.", "type": "object", "properties": { "annualizedBaseCompensationRange": { "$ref": "ExtendedCompensationInfoCompensationRange", "description": "Output only.\n\nAnnualized base compensation range." }, "annualizedBaseCompensationUnspecified": { "description": "Output only.\n\nIndicates annualized base compensation range cannot be derived, due to\nthe job's base compensation entry cannot be annualized.\nSee CompensationEntry for explanation on annualization and base\ncompensation entry.", "type": "boolean" }, "currency": { "description": "Optional.\n\nA 3-letter [ISO 4217](https://www.iso.org/iso-4217-currency-codes.html)\ncurrency code.", "type": "string" }, "annualizedTotalCompensationRange": { "$ref": "ExtendedCompensationInfoCompensationRange", "description": "Output only.\n\nAnnualized total compensation range." }, "entries": { "description": "Optional.\n\nJob compensation information.\n\nAt most one entry can be of type\nExtendedCompensationInfo.CompensationType.BASE, which is\nreferred as ** base compensation entry ** for the job.", "type": "array", "items": { "$ref": "ExtendedCompensationInfoCompensationEntry" } }, "annualizedTotalCompensationUnspecified": { "description": "Output only.\n\nIndicates annualized total compensation range cannot be derived, due to\nthe job's all CompensationEntry cannot be annualized.\nSee CompensationEntry for explanation on annualization and base\ncompensation entry.", "type": "boolean" } }, "id": "ExtendedCompensationInfo" }, "Empty": { "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.", "type": "object", "properties": {}, "id": "Empty" }, "CompletionResult": { "description": "Output only.\n\nResource that represents completion results.", "type": "object", "properties": { "type": { "enumDescriptions": ["Default value.", "Only suggest job titles.", "Only suggest company names.", "Suggest both job titles and company names."], "enum": ["COMPLETION_TYPE_UNSPECIFIED", "JOB_TITLE", "COMPANY_NAME", "COMBINED"], "description": "The completion topic.", "type": "string" }, "imageUrl": { "description": "The URL for the company logo if `type=COMPANY_NAME`.", "type": "string" }, "suggestion": { "type": "string", "description": "The suggestion for the query." } }, "id": "CompletionResult" }, "GetHistogramRequest": { "description": "Deprecated. Use SearchJobsRequest.histogram_facets instead to make\na single call with both search and histogram.\n\nInput only.\n\nA request for the `GetHistogram` method.", "type": "object", "properties": { "searchTypes": { "type": "array", "items": { "enum": ["JOB_FIELD_UNSPECIFIED", "COMPANY_ID", "EMPLOYMENT_TYPE", "COMPANY_SIZE", "DATE_PUBLISHED", "CUSTOM_FIELD_1", "CUSTOM_FIELD_2", "CUSTOM_FIELD_3", "CUSTOM_FIELD_4", "CUSTOM_FIELD_5", "CUSTOM_FIELD_6", "CUSTOM_FIELD_7", "CUSTOM_FIELD_8", "CUSTOM_FIELD_9", "CUSTOM_FIELD_10", "CUSTOM_FIELD_11", "CUSTOM_FIELD_12", "CUSTOM_FIELD_13", "CUSTOM_FIELD_14", "CUSTOM_FIELD_15", "CUSTOM_FIELD_16", "CUSTOM_FIELD_17", "CUSTOM_FIELD_18", "CUSTOM_FIELD_19", "CUSTOM_FIELD_20", "EDUCATION_LEVEL", "EXPERIENCE_LEVEL", "ADMIN1", "COUNTRY", "CITY", "LOCALE", "LANGUAGE", "CATEGORY", "CITY_COORDINATE", "ADMIN1_COUNTRY", "COMPANY_TITLE", "COMPANY_DISPLAY_NAME", "BASE_COMPENSATION_UNIT"], "type": "string" }, "enumDescriptions": ["The default value if search type is not specified.", "Filter by the company id field.", "Filter by the employment type field, such as `FULL_TIME` or `PART_TIME`.", "Filter by the company size type field, such as `BIG`, `SMALL` or `BIGGER`.", "Filter by the date published field. Values are stringified\nwith TimeRange, for example, TimeRange.PAST_MONTH.", "Filter by custom field 1.", "Filter by custom field 2.", "Filter by custom field 3.", "Filter by custom field 4.", "Filter by custom field 5.", "Filter by custom field 6.", "Filter by custom field 7.", "Filter by custom field 8.", "Filter by custom field 9.", "Filter by custom field 10.", "Filter by custom field 11.", "Filter by custom field 12.", "Filter by custom field 13.", "Filter by custom field 14.", "Filter by custom field 15.", "Filter by custom field 16.", "Filter by custom field 17.", "Filter by custom field 18.", "Filter by custom field 19.", "Filter by custom field 20.", "Filter by the required education level of the job.", "Filter by the required experience level of the job.", "Filter by Admin1, which is a global placeholder for\nreferring to state, province, or the particular term a country uses to\ndefine the geographic structure below the country level.\nExamples include states codes such as \"CA\", \"IL\", \"NY\", and\nprovinces, such as \"BC\".", "Filter by the country code of job, such as US, JP, FR.", "Filter by the \"city name\", \"Admin1 code\", for example,\n\"Mountain View, CA\" or \"New York, NY\".", "Filter by the locale field of a job, such as \"en-US\", \"fr-FR\".\n\nThis is the BCP-47 language code, such as \"en-US\" or \"sr-Latn\".\nFor more information, see\n[Tags for Identifying Languages](https://tools.ietf.org/html/bcp47).", "Filter by the language code portion of the locale field, such as \"en\" or\n\"fr\".", "Filter by the Category.", "Filter by the city center GPS coordinate (latitude and longitude), for\nexample, 37.4038522,-122.0987765. Since the coordinates of a city center\ncan change, clients may need to refresh them periodically.", "A combination of state or province code with a country code. This field\ndiffers from `JOB_ADMIN1`, which can be used in multiple countries.", "Deprecated. Use COMPANY_DISPLAY_NAME instead.\n\nCompany display name.", "Company display name.", "Base compensation unit."], "description": "Required.\n\nA list of facets that specify the histogram data to be calculated\nagainst and returned.\n\nHistogram response times can be slow, and counts\ncan be approximations. This call may be temporarily or permanently removed\nprior to the production release of Cloud Talent Solution." }, "query": { "$ref": "JobQuery", "description": "Optional.\n\nQuery used to search against jobs, such as keyword, location filters, etc." }, "filters": { "$ref": "JobFilters", "description": "Deprecated. Use query instead.\n\nOptional.\n\nRestrictions on the scope of the histogram." }, "requestMetadata": { "description": "Meta information, such as `user_id`, collected from the job searcher or\nother entity conducting the job search, which is used to improve the search\nquality of the service. Users determine identifier values, which must be\nunique and consist.", "$ref": "RequestMetadata" }, "allowBroadening": { "description": "Optional.\n\nControls whether to broaden the search to avoid too few results for a\ngiven query in instances where a search has sparse results. Results from a\nbroadened query is a superset of the results from the original query.\n\nDefaults to false.", "type": "boolean" } }, "id": "GetHistogramRequest" }, "RequestMetadata": { "properties": { "deviceInfo": { "$ref": "DeviceInfo", "description": "Optional.\n\nThe type of device used by the job seeker at the time of the call to the\nservice." }, "sessionId": { "description": "Required.\n\nA unique session identification string. A session is defined as the\nduration of an end user's interaction with the service over a period.\nObfuscate this field for privacy concerns before\nproviding it to the API.\n\nIf this field is not available for some reason, please send \"UNKNOWN\". Note\nthat any improvements to the service model for a particular tenant site,\nrely on this field being set correctly to some unique session_id.", "type": "string" }, "domain": { "type": "string", "description": "Required.\n\nThe client-defined scope or source of the service call, which typically\nis the domain on\nwhich the service has been implemented and is currently being run.\n\nFor example, if the service is being run by client <em>Foo, Inc.</em>, on\njob board www.foo.com and career site www.bar.com, then this field is\nset to \"foo.com\" for use on the job board, and \"bar.com\" for use on the\ncareer site.\n\nIf this field is not available for some reason, send \"UNKNOWN\". Note that\nany improvements to the service model for a particular tenant site rely on\nthis field being set correctly to some domain." }, "userId": { "description": "Required.\n\nA unique user identification string, as determined by the client. The\nclient is responsible for ensuring client-level uniqueness of this value\nin order to have the strongest positive impact on search quality.\nObfuscate this field for privacy concerns before\nproviding it to the service.\n\nIf this field is not available for some reason, please send \"UNKNOWN\". Note\nthat any improvements to the service model for a particular tenant site,\nrely on this field being set correctly to some unique user_id.", "type": "string" } }, "id": "RequestMetadata", "description": "Input only.\n\nMeta information related to the job searcher or entity\nconducting the job search. This information is used to improve the\nperformance of the service.", "type": "object" }, "JobProcessingOptions": { "description": "Input only.\n\nOptions for job processing.", "type": "object", "properties": { "disableStreetAddressResolution": { "description": "Optional.\n\nIf set to `true`, the service does not attempt to resolve a\nmore precise address for the job.", "type": "boolean" }, "htmlSanitization": { "enum": ["HTML_SANITIZATION_UNSPECIFIED", "HTML_SANITIZATION_DISABLED", "SIMPLE_FORMATTING_ONLY"], "description": "Optional.\n\nOption for job HTML content sanitization. Applied fields are:\n\n* description\n* applicationInstruction\n* incentives\n* qualifications\n* responsibilities\n\nHTML tags in these fields may be stripped if sanitiazation is not disabled.\n\nDefaults to HtmlSanitization.SIMPLE_FORMATTING_ONLY.", "type": "string", "enumDescriptions": ["Default value.", "Disables sanitization on HTML input.", "Sanitizes HTML input, only accepts bold, italic, ordered list, and\nunordered list markup tags."] } }, "id": "JobProcessingOptions" }, "CustomAttributeHistogramResult": { "properties": { "key": { "description": "Stores the key of custom attribute the histogram is performed on.", "type": "string" }, "stringValueHistogramResult": { "additionalProperties": { "format": "int32", "type": "integer" }, "description": "Stores a map from the values of string custom field associated\nwith `key` to the number of jobs with that value in this histogram result.", "type": "object" }, "longValueHistogramResult": { "$ref": "NumericBucketingResult", "description": "Stores bucketed histogram counting result or min/max values for\ncustom attribute long values associated with `key`." } }, "id": "CustomAttributeHistogramResult", "description": "Output only.\n\nCustom attribute histogram result.", "type": "object" }, "ListCompaniesResponse": { "properties": { "nextPageToken": { "description": "A token to retrieve the next page of results.", "type": "string" }, "companies": { "description": "Companies for the current client.", "type": "array", "items": { "$ref": "Company" } }, "metadata": { "$ref": "ResponseMetadata", "description": "Additional information for the API invocation, such as the request\ntracking id." } }, "id": "ListCompaniesResponse", "description": "Output only.\n\nThe List companies response object.", "type": "object" }, "BucketizedCount": { "description": "Represents count of jobs within one bucket.", "type": "object", "properties": { "range": { "$ref": "BucketRange", "description": "Bucket range on which histogram was performed for the numeric field,\nthat is, the count represents number of jobs in this range." }, "count": { "description": "Number of jobs whose numeric field value fall into `range`.", "format": "int32", "type": "integer" } }, "id": "BucketizedCount" }, "CustomField": { "description": "Resource that represents the custom data not captured by the standard fields.", "type": "object", "properties": { "values": { "description": "Optional.\n\nThe values of the custom data.", "type": "array", "items": { "type": "string" } } }, "id": "CustomField" }, "BatchDeleteJobsRequest": { "type": "object", "properties": { "filter": { "description": "Required.\n\nThe filter string specifies the jobs to be deleted.\n\nSupported operator: =, AND\n\nThe fields eligible for filtering are:\n\n* `companyName` (Required)\n* `requisitionId` (Required)\n\nSample Query: companyName = \"companies/123\" AND requisitionId = \"req-1\"", "type": "string" } }, "id": "BatchDeleteJobsRequest", "description": "Input only.\n\nBatch delete jobs request." }, "HistogramResult": { "description": "Output only.\n\nResult of a histogram call. The response contains the histogram map for the\nsearch type specified by HistogramResult.field.\nThe response is a map of each filter value to the corresponding count of\njobs for that filter.", "type": "object", "properties": { "values": { "additionalProperties": { "format": "int32", "type": "integer" }, "description": "A map from the values of field to the number of jobs with that value\nin this search result.\n\nKey: search type (filter names, such as the companyName).\n\nValues: the count of jobs that match the filter for this search.", "type": "object" }, "searchType": { "enumDescriptions": ["The default value if search type is not specified.", "Filter by the company id field.", "Filter by the employment type field, such as `FULL_TIME` or `PART_TIME`.", "Filter by the company size type field, such as `BIG`, `SMALL` or `BIGGER`.", "Filter by the date published field. Values are stringified\nwith TimeRange, for example, TimeRange.PAST_MONTH.", "Filter by custom field 1.", "Filter by custom field 2.", "Filter by custom field 3.", "Filter by custom field 4.", "Filter by custom field 5.", "Filter by custom field 6.", "Filter by custom field 7.", "Filter by custom field 8.", "Filter by custom field 9.", "Filter by custom field 10.", "Filter by custom field 11.", "Filter by custom field 12.", "Filter by custom field 13.", "Filter by custom field 14.", "Filter by custom field 15.", "Filter by custom field 16.", "Filter by custom field 17.", "Filter by custom field 18.", "Filter by custom field 19.", "Filter by custom field 20.", "Filter by the required education level of the job.", "Filter by the required experience level of the job.", "Filter by Admin1, which is a global placeholder for\nreferring to state, province, or the particular term a country uses to\ndefine the geographic structure below the country level.\nExamples include states codes such as \"CA\", \"IL\", \"NY\", and\nprovinces, such as \"BC\".", "Filter by the country code of job, such as US, JP, FR.", "Filter by the \"city name\", \"Admin1 code\", for example,\n\"Mountain View, CA\" or \"New York, NY\".", "Filter by the locale field of a job, such as \"en-US\", \"fr-FR\".\n\nThis is the BCP-47 language code, such as \"en-US\" or \"sr-Latn\".\nFor more information, see\n[Tags for Identifying Languages](https://tools.ietf.org/html/bcp47).", "Filter by the language code portion of the locale field, such as \"en\" or\n\"fr\".", "Filter by the Category.", "Filter by the city center GPS coordinate (latitude and longitude), for\nexample, 37.4038522,-122.0987765. Since the coordinates of a city center\ncan change, clients may need to refresh them periodically.", "A combination of state or province code with a country code. This field\ndiffers from `JOB_ADMIN1`, which can be used in multiple countries.", "Deprecated. Use COMPANY_DISPLAY_NAME instead.\n\nCompany display name.", "Company display name.", "Base compensation unit."], "enum": ["JOB_FIELD_UNSPECIFIED", "COMPANY_ID", "EMPLOYMENT_TYPE", "COMPANY_SIZE", "DATE_PUBLISHED", "CUSTOM_FIELD_1", "CUSTOM_FIELD_2", "CUSTOM_FIELD_3", "CUSTOM_FIELD_4", "CUSTOM_FIELD_5", "CUSTOM_FIELD_6", "CUSTOM_FIELD_7", "CUSTOM_FIELD_8", "CUSTOM_FIELD_9", "CUSTOM_FIELD_10", "CUSTOM_FIELD_11", "CUSTOM_FIELD_12", "CUSTOM_FIELD_13", "CUSTOM_FIELD_14", "CUSTOM_FIELD_15", "CUSTOM_FIELD_16", "CUSTOM_FIELD_17", "CUSTOM_FIELD_18", "CUSTOM_FIELD_19", "CUSTOM_FIELD_20", "EDUCATION_LEVEL", "EXPERIENCE_LEVEL", "ADMIN1", "COUNTRY", "CITY", "LOCALE", "LANGUAGE", "CATEGORY", "CITY_COORDINATE", "ADMIN1_COUNTRY", "COMPANY_TITLE", "COMPANY_DISPLAY_NAME", "BASE_COMPENSATION_UNIT"], "description": "The Histogram search filters.", "type": "string" } }, "id": "HistogramResult" } }, "icons": { "x32": "http://www.google.com/images/icons/product/search-32.gif", "x16": "http://www.google.com/images/icons/product/search-16.gif" }, "protocol": "rest", "canonicalName": "Job Service", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/cloud-platform": { "description": "View and manage your data across Google Cloud Platform services" }, "https://www.googleapis.com/auth/jobs": { "description": "Manage job postings" } } } }, "rootUrl": "https://jobs.googleapis.com/" };
//# sourceMappingURL=jobs-v2.js.map