"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "discoveryVersion": "v1", "version_module": true, "schemas": { "ListProductsResponse": { "type": "object", "properties": { "products": { "description": "List of the products.", "type": "array", "items": { "$ref": "Product" } }, "nextPageToken": { "description": "The token for the retrieval of the next page of product statuses.", "type": "string" } }, "id": "ListProductsResponse" }, "ProductDetail": { "description": "A product detail of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#productdetail.", "type": "object", "properties": { "attributeValue": { "description": "The value of the attribute.", "type": "string" }, "sectionName": { "description": "A short section name that can be reused between multiple product details.", "type": "string" }, "attributeName": { "description": "The name of the attribute.", "type": "string" } }, "id": "ProductDetail" }, "Issue": { "description": "Product issue.", "type": "object", "properties": { "description": { "description": "Longer description of the issue focused on how to resolve it.", "type": "string" }, "resolution": { "enumDescriptions": ["Unspecified resolution, never used.", "The user who provided the data must act in order to resolve the issue\n(for example by correcting some data).", "The issue will be resolved automatically (for example image crawl or\nGoogle review). No action is required now. Resolution might lead to\nanother issue (for example if crawl fails)."], "enum": ["RESOLUTION_UNSPECIFIED", "USER_ACTION", "PENDING_PROCESSING"], "description": "What needs to happen to resolve the issue.", "type": "string" }, "severity": { "enumDescriptions": ["Unspecified severity, never used.", "Error severity. The issue prevents the usage of the whole item.", "Warning severity. The issue is either one that prevents the usage of the\nattribute that triggered it or one that will soon prevent the usage of\nthe whole item.", "Info severity. The issue is one that doesn't require immediate attention.\nIt is, for example, used to communicate which attributes are still\npending review."], "enum": ["SEVERITY_UNSPECIFIED", "ERROR", "WARNING", "INFO"], "description": "The severity of the issue.", "type": "string" }, "type": { "description": "The server-generated type of the issue, for example,\n“INCORRECT_TEXT_FORMATTING”, “IMAGE_NOT_SERVEABLE”, etc.", "type": "string" }, "attribute": { "description": "If present, the attribute that triggered the issue. For more information\nabout attributes, see\nhttps://support.google.com/manufacturers/answer/6124116.", "type": "string" }, "destination": { "description": "The destination this issue applies to.", "type": "string" }, "title": { "description": "Short title describing the nature of the issue.", "type": "string" }, "timestamp": { "description": "The timestamp when this issue appeared.", "format": "google-datetime", "type": "string" } }, "id": "Issue" }, "Image": { "description": "An image.", "type": "object", "properties": { "type": { "enumDescriptions": ["Type is unspecified. Should not be used.", "The image was crawled from a provided URL.", "The image was uploaded."], "enum": ["TYPE_UNSPECIFIED", "CRAWLED", "UPLOADED"], "description": "The type of the image, i.e., crawled or uploaded.\n@OutputOnly", "type": "string" }, "imageUrl": { "description": "The URL of the image. For crawled images, this is the provided URL. For\nuploaded images, this is a serving URL from Google if the image has been\nprocessed successfully.", "type": "string" }, "status": { "enumDescriptions": ["The image status is unspecified. Should not be used.", "The image was uploaded and is being processed.", "The image crawl is still pending.", "The image was processed and it meets the requirements.", "The image URL is protected by robots.txt file and cannot be crawled.", "The image URL is protected by X-Robots-Tag and cannot be crawled.", "There was an error while crawling the image.", "The image cannot be processed.", "The image cannot be decoded.", "The image is too big.", "The image was manually overridden and will not be crawled.", "The image crawl was postponed to avoid overloading the host.", "The image URL returned a \"404 Not Found\" error."], "enum": ["STATUS_UNSPECIFIED", "PENDING_PROCESSING", "PENDING_CRAWL", "OK", "ROBOTED", "XROBOTED", "CRAWL_ERROR", "PROCESSING_ERROR", "DECODING_ERROR", "TOO_BIG", "CRAWL_SKIPPED", "HOSTLOADED", "HTTP_404"], "description": "The status of the image.\n@OutputOnly", "type": "string" } }, "id": "Image" }, "Count": { "properties": { "value": { "description": "The numeric value of the number of products in a package.", "format": "int64", "type": "string" }, "unit": { "description": "The unit in which these products are counted.", "type": "string" } }, "id": "Count", "description": "The number of products in a single package. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#count.", "type": "object" }, "Capacity": { "description": "The capacity of a product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#capacity.", "type": "object", "properties": { "value": { "description": "The numeric value of the capacity.", "format": "int64", "type": "string" }, "unit": { "description": "The unit of the capacity, i.e., MB, GB, or TB.", "type": "string" } }, "id": "Capacity" }, "FeatureDescription": { "description": "A feature description of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#featuredesc.", "type": "object", "properties": { "image": { "description": "An optional image describing the feature.", "$ref": "Image" }, "headline": { "description": "A short description of the feature.", "type": "string" }, "text": { "description": "A detailed description of the feature.", "type": "string" } }, "id": "FeatureDescription" }, "Price": { "description": "A price.", "type": "object", "properties": { "amount": { "description": "The numeric value of the price.", "type": "string" }, "currency": { "description": "The currency in which the price is denoted.", "type": "string" } }, "id": "Price" }, "Empty": { "properties": {}, "id": "Empty", "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.", "type": "object" }, "Attributes": { "description": "Attributes of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116.", "type": "object", "properties": { "releaseDate": { "description": "The release date of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#release.", "type": "string" }, "gtin": { "description": "The Global Trade Item Number (GTIN) of the product. For more information,\nsee https://support.google.com/manufacturers/answer/6124116#gtin.", "type": "array", "items": { "type": "string" } }, "itemGroupId": { "description": "The item group id of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#itemgroupid.", "type": "string" }, "productLine": { "description": "The name of the group of products related to the product. For more\ninformation, see\nhttps://support.google.com/manufacturers/answer/6124116#productline.", "type": "string" }, "capacity": { "$ref": "Capacity", "description": "The capacity of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#capacity." }, "includedDestination": { "description": "A list of included destinations.", "type": "array", "items": { "type": "string" } }, "description": { "description": "The description of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#description.", "type": "string" }, "gender": { "description": "The target gender of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#gender.", "type": "string" }, "sizeSystem": { "description": "The size system of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#sizesystem.", "type": "string" }, "theme": { "description": "The theme of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#theme.", "type": "string" }, "targetClientId": { "description": "The target client id. Should only be used in the accounts of the data\npartners.", "type": "string" }, "pattern": { "description": "The pattern of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#pattern.", "type": "string" }, "imageLink": { "description": "The image of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#image.", "$ref": "Image" }, "productType": { "description": "The type or category of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#producttype.", "type": "array", "items": { "type": "string" } }, "format": { "description": "The format of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#format.", "type": "string" }, "additionalImageLink": { "description": "The additional images of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#addlimage.", "type": "array", "items": { "$ref": "Image" } }, "videoLink": { "description": "The videos of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#video.", "type": "array", "items": { "type": "string" } }, "color": { "description": "The color of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#color.", "type": "string" }, "excludedDestination": { "description": "A list of excluded destinations.", "type": "array", "items": { "type": "string" } }, "productName": { "description": "The canonical name of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#productname.", "type": "string" }, "sizeType": { "description": "The size type of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#sizetype.", "type": "string" }, "suggestedRetailPrice": { "$ref": "Price", "description": "The suggested retail price (MSRP) of the product. For more information,\nsee https://support.google.com/manufacturers/answer/6124116#price." }, "featureDescription": { "description": "The rich format description of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#featuredesc.", "type": "array", "items": { "$ref": "FeatureDescription" } }, "size": { "description": "The size of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#size.", "type": "string" }, "title": { "description": "The title of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#title.", "type": "string" }, "count": { "$ref": "Count", "description": "The count of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#count." }, "brand": { "description": "The brand name of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#brand.", "type": "string" }, "disclosureDate": { "description": "The disclosure date of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#disclosure.", "type": "string" }, "material": { "description": "The material of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#material.", "type": "string" }, "scent": { "description": "The scent of the product. For more information, see\n https://support.google.com/manufacturers/answer/6124116#scent.", "type": "string" }, "ageGroup": { "description": "The target age group of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#agegroup.", "type": "string" }, "productDetail": { "description": "The details of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#productdetail.", "type": "array", "items": { "$ref": "ProductDetail" } }, "flavor": { "description": "The flavor of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#flavor.", "type": "string" }, "mpn": { "description": "The Manufacturer Part Number (MPN) of the product. For more information,\nsee https://support.google.com/manufacturers/answer/6124116#mpn.", "type": "string" }, "productPageUrl": { "description": "The URL of the detail page of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#productpage.", "type": "string" } }, "id": "Attributes" }, "DestinationStatus": { "description": "The destination status.", "type": "object", "properties": { "destination": { "description": "The name of the destination.", "type": "string" }, "status": { "enum": ["UNKNOWN", "ACTIVE", "PENDING", "DISAPPROVED"], "description": "The status of the destination.", "type": "string", "enumDescriptions": ["Unspecified status, never used.", "The product is used for this destination.", "The decision is still pending.", "The product is disapproved. Please look at the issues."] } }, "id": "DestinationStatus" }, "Product": { "description": "Product data.", "type": "object", "properties": { "productId": { "description": "The ID of the product. For more information, see\nhttps://support.google.com/manufacturers/answer/6124116#id.", "type": "string" }, "parent": { "description": "Parent ID in the format `accounts/{account_id}`.\n\n`account_id` - The ID of the Manufacturer Center account.", "type": "string" }, "destinationStatuses": { "description": "The status of the destinations.", "type": "array", "items": { "$ref": "DestinationStatus" } }, "targetCountry": { "description": "The target country of the product as a CLDR territory code (for example,\nUS).", "type": "string" }, "contentLanguage": { "description": "The content language of the product as a two-letter ISO 639-1 language code\n(for example, en).", "type": "string" }, "name": { "description": "Name in the format `{target_country}:{content_language}:{product_id}`.\n\n`target_country`   - The target country of the product as a CLDR territory\n                     code (for example, US).\n\n`content_language` - The content language of the product as a two-letter\n                     ISO 639-1 language code (for example, en).\n\n`product_id`     -   The ID of the product. For more information, see\n                     https://support.google.com/manufacturers/answer/6124116#id.", "type": "string" }, "attributes": { "$ref": "Attributes", "description": "Attributes of the product uploaded to the Manufacturer Center. Manually\nedited attributes are taken into account." }, "issues": { "description": "A server-generated list of issues associated with the product.", "type": "array", "items": { "$ref": "Issue" } } }, "id": "Product" } }, "icons": { "x16": "http://www.google.com/images/icons/product/search-16.gif", "x32": "http://www.google.com/images/icons/product/search-32.gif" }, "protocol": "rest", "canonicalName": "Manufacturer Center", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/manufacturercenter": { "description": "Manage your product listings for Google Manufacturer Center" } } } }, "rootUrl": "https://manufacturers.googleapis.com/", "ownerDomain": "google.com", "name": "manufacturers", "batchPath": "batch", "title": "Manufacturer Center API", "ownerName": "Google", "resources": { "accounts": { "resources": { "products": { "methods": { "delete": { "description": "Deletes the product from a Manufacturer Center account.", "httpMethod": "DELETE", "response": { "$ref": "Empty" }, "parameterOrder": ["parent", "name"], "parameters": { "name": { "location": "path", "description": "Name in the format `{target_country}:{content_language}:{product_id}`.\n\n`target_country`   - The target country of the product as a CLDR territory\n                     code (for example, US).\n\n`content_language` - The content language of the product as a two-letter\n                     ISO 639-1 language code (for example, en).\n\n`product_id`     -   The ID of the product. For more information, see\n                     https://support.google.com/manufacturers/answer/6124116#id.", "required": true, "type": "string", "pattern": "^[^/]+$" }, "parent": { "location": "path", "description": "Parent ID in the format `accounts/{account_id}`.\n\n`account_id` - The ID of the Manufacturer Center account.", "required": true, "type": "string", "pattern": "^accounts/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/manufacturercenter"], "flatPath": "v1/accounts/{accountsId}/products/{productsId}", "id": "manufacturers.accounts.products.delete", "path": "v1/{+parent}/products/{+name}" }, "list": { "description": "Lists all the products in a Manufacturer Center account.", "response": { "$ref": "ListProductsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "parameters": { "parent": { "description": "Parent ID in the format `accounts/{account_id}`.\n\n`account_id` - The ID of the Manufacturer Center account.", "required": true, "type": "string", "pattern": "^accounts/[^/]+$", "location": "path" }, "include": { "location": "query", "enum": ["UNKNOWN", "ATTRIBUTES", "ISSUES", "DESTINATION_STATUSES"], "description": "The information to be included in the response. Only sections listed here\nwill be returned.", "type": "string", "repeated": true }, "pageToken": { "description": "The token returned by the previous request.", "type": "string", "location": "query" }, "pageSize": { "location": "query", "description": "Maximum number of product statuses to return in the response, used for\npaging.", "format": "int32", "type": "integer" } }, "scopes": ["https://www.googleapis.com/auth/manufacturercenter"], "flatPath": "v1/accounts/{accountsId}/products", "path": "v1/{+parent}/products", "id": "manufacturers.accounts.products.list" }, "get": { "response": { "$ref": "Product" }, "parameterOrder": ["parent", "name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/manufacturercenter"], "parameters": { "include": { "repeated": true, "location": "query", "enum": ["UNKNOWN", "ATTRIBUTES", "ISSUES", "DESTINATION_STATUSES"], "description": "The information to be included in the response. Only sections listed here\nwill be returned.", "type": "string" }, "name": { "description": "Name in the format `{target_country}:{content_language}:{product_id}`.\n\n`target_country`   - The target country of the product as a CLDR territory\n                     code (for example, US).\n\n`content_language` - The content language of the product as a two-letter\n                     ISO 639-1 language code (for example, en).\n\n`product_id`     -   The ID of the product. For more information, see\n                     https://support.google.com/manufacturers/answer/6124116#id.", "required": true, "type": "string", "pattern": "^[^/]+$", "location": "path" }, "parent": { "location": "path", "description": "Parent ID in the format `accounts/{account_id}`.\n\n`account_id` - The ID of the Manufacturer Center account.", "required": true, "type": "string", "pattern": "^accounts/[^/]+$" } }, "flatPath": "v1/accounts/{accountsId}/products/{productsId}", "path": "v1/{+parent}/products/{+name}", "id": "manufacturers.accounts.products.get", "description": "Gets the product from a Manufacturer Center account, including product\nissues.\n\nA recently updated product takes around 15 minutes to process. Changes are\nonly visible after it has been processed. While some issues may be\navailable once the product has been processed, other issues may take days\nto appear." }, "update": { "id": "manufacturers.accounts.products.update", "path": "v1/{+parent}/products/{+name}", "description": "Inserts or updates the attributes of the product in a Manufacturer Center\naccount.\n\nCreates a product with the provided attributes. If the product already\nexists, then all attributes are replaced with the new ones. The checks at\nupload time are minimal. All required attributes need to be present for a\nproduct to be valid. Issues may show up later after the API has accepted a\nnew upload for a product and it is possible to overwrite an existing valid\nproduct with an invalid product. To detect this, you should retrieve the\nproduct and check it for issues once the new version is available.\n\nUploaded attributes first need to be processed before they can be\nretrieved. Until then, new products will be unavailable, and retrieval\nof previously uploaded products will return the original state of the\nproduct.", "request": { "$ref": "Attributes" }, "httpMethod": "PUT", "parameterOrder": ["parent", "name"], "response": { "$ref": "Empty" }, "parameters": { "name": { "description": "Name in the format `{target_country}:{content_language}:{product_id}`.\n\n`target_country`   - The target country of the product as a CLDR territory\n                     code (for example, US).\n\n`content_language` - The content language of the product as a two-letter\n                     ISO 639-1 language code (for example, en).\n\n`product_id`     -   The ID of the product. For more information, see\n                     https://support.google.com/manufacturers/answer/6124116#id.", "required": true, "type": "string", "pattern": "^[^/]+$", "location": "path" }, "parent": { "location": "path", "description": "Parent ID in the format `accounts/{account_id}`.\n\n`account_id` - The ID of the Manufacturer Center account.", "required": true, "type": "string", "pattern": "^accounts/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/manufacturercenter"], "flatPath": "v1/accounts/{accountsId}/products/{productsId}" } } } } } }, "parameters": { "upload_protocol": { "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string", "location": "query" }, "prettyPrint": { "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true", "location": "query" }, "quotaUser": { "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string", "location": "query" }, "fields": { "description": "Selector specifying which fields to include in a partial response.", "type": "string", "location": "query" }, "uploadType": { "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string", "location": "query" }, "callback": { "description": "JSONP", "type": "string", "location": "query" }, "oauth_token": { "location": "query", "description": "OAuth 2.0 token for the current user.", "type": "string" }, "$.xgafv": { "enumDescriptions": ["v1 error format", "v2 error format"], "location": "query", "enum": ["1", "2"], "description": "V1 error format.", "type": "string" }, "alt": { "description": "Data format for response.", "default": "json", "enum": ["json", "media", "proto"], "type": "string", "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query" }, "access_token": { "location": "query", "description": "OAuth access token.", "type": "string" }, "key": { "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string", "location": "query" } }, "version": "v1", "baseUrl": "https://manufacturers.googleapis.com/", "servicePath": "", "description": "Public API for managing Manufacturer Center related data.", "kind": "discovery#restDescription", "basePath": "", "documentationLink": "https://developers.google.com/manufacturers/", "revision": "20180903", "id": "manufacturers:v1" };
//# sourceMappingURL=manufacturers-v1.js.map