"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "ownerDomain": "google.com", "name": "script", "batchPath": "batch", "fullyEncodeReservedExpansion": true, "title": "Apps Script API", "ownerName": "Google", "resources": { "projects": { "methods": { "updateContent": { "request": { "$ref": "Content" }, "description": "Updates the content of the specified script project.\nThis content is stored as the HEAD version, and is used when the script is\nexecuted as a trigger, in the script editor, in add-on preview mode, or as\na web app or Apps Script API in development mode. This clears all the\nexisting files in the project.", "response": { "$ref": "Content" }, "parameterOrder": ["scriptId"], "httpMethod": "PUT", "parameters": { "scriptId": { "location": "path", "description": "The script project's Drive ID.", "required": true, "type": "string" } }, "flatPath": "v1/projects/{scriptId}/content", "path": "v1/projects/{scriptId}/content", "id": "script.projects.updateContent" }, "create": { "response": { "$ref": "Project" }, "parameterOrder": [], "httpMethod": "POST", "parameters": {}, "flatPath": "v1/projects", "path": "v1/projects", "id": "script.projects.create", "description": "Creates a new, empty script project with no script files and a base\nmanifest file.", "request": { "$ref": "CreateProjectRequest" } }, "getContent": { "description": "Gets the content of the script project, including the code source and\nmetadata for each script file.", "httpMethod": "GET", "parameterOrder": ["scriptId"], "response": { "$ref": "Content" }, "parameters": { "versionNumber": { "description": "The version number of the project to retrieve. If not provided, the\nproject's HEAD version is returned.", "format": "int32", "type": "integer", "location": "query" }, "scriptId": { "description": "The script project's Drive ID.", "required": true, "type": "string", "location": "path" } }, "flatPath": "v1/projects/{scriptId}/content", "id": "script.projects.getContent", "path": "v1/projects/{scriptId}/content" }, "getMetrics": { "httpMethod": "GET", "parameterOrder": ["scriptId"], "response": { "$ref": "Metrics" }, "parameters": { "metricsFilter.deploymentId": { "description": "Optional field indicating a specific deployment to retrieve metrics from.", "type": "string", "location": "query" }, "scriptId": { "location": "path", "description": "Required field indicating the script to get metrics for.", "required": true, "type": "string" }, "metricsGranularity": { "enum": ["UNSPECIFIED_GRANULARITY", "WEEKLY", "DAILY"], "description": "Required field indicating what granularity of metrics are returned.", "type": "string", "location": "query" } }, "flatPath": "v1/projects/{scriptId}/metrics", "id": "script.projects.getMetrics", "path": "v1/projects/{scriptId}/metrics", "description": "Get metrics data for scripts, such as number of executions and\nactive users." }, "get": { "description": "Gets a script project's metadata.", "response": { "$ref": "Project" }, "parameterOrder": ["scriptId"], "httpMethod": "GET", "parameters": { "scriptId": { "location": "path", "description": "The script project's Drive ID.", "required": true, "type": "string" } }, "flatPath": "v1/projects/{scriptId}", "path": "v1/projects/{scriptId}", "id": "script.projects.get" } }, "resources": { "deployments": { "methods": { "delete": { "response": { "$ref": "Empty" }, "parameterOrder": ["scriptId", "deploymentId"], "httpMethod": "DELETE", "parameters": { "scriptId": { "location": "path", "description": "The script project's Drive ID.", "required": true, "type": "string" }, "deploymentId": { "description": "The deployment ID to be undeployed.", "required": true, "type": "string", "location": "path" } }, "flatPath": "v1/projects/{scriptId}/deployments/{deploymentId}", "path": "v1/projects/{scriptId}/deployments/{deploymentId}", "id": "script.projects.deployments.delete", "description": "Deletes a deployment of an Apps Script project." }, "get": { "path": "v1/projects/{scriptId}/deployments/{deploymentId}", "id": "script.projects.deployments.get", "description": "Gets a deployment of an Apps Script project.", "response": { "$ref": "Deployment" }, "parameterOrder": ["scriptId", "deploymentId"], "httpMethod": "GET", "parameters": { "deploymentId": { "description": "The deployment ID.", "required": true, "type": "string", "location": "path" }, "scriptId": { "description": "The script project's Drive ID.", "required": true, "type": "string", "location": "path" } }, "flatPath": "v1/projects/{scriptId}/deployments/{deploymentId}" }, "list": { "response": { "$ref": "ListDeploymentsResponse" }, "parameterOrder": ["scriptId"], "httpMethod": "GET", "parameters": { "pageToken": { "description": "The token for continuing a previous list request on the next page. This\nshould be set to the value of `nextPageToken` from a previous response.", "type": "string", "location": "query" }, "pageSize": { "description": "The maximum number of deployments on each returned page. Defaults to 50.", "format": "int32", "type": "integer", "location": "query" }, "scriptId": { "location": "path", "description": "The script project's Drive ID.", "required": true, "type": "string" } }, "flatPath": "v1/projects/{scriptId}/deployments", "path": "v1/projects/{scriptId}/deployments", "id": "script.projects.deployments.list", "description": "Lists the deployments of an Apps Script project." }, "update": { "response": { "$ref": "Deployment" }, "parameterOrder": ["scriptId", "deploymentId"], "httpMethod": "PUT", "parameters": { "scriptId": { "description": "The script project's Drive ID.", "required": true, "type": "string", "location": "path" }, "deploymentId": { "description": "The deployment ID for this deployment.", "required": true, "type": "string", "location": "path" } }, "flatPath": "v1/projects/{scriptId}/deployments/{deploymentId}", "path": "v1/projects/{scriptId}/deployments/{deploymentId}", "id": "script.projects.deployments.update", "description": "Updates a deployment of an Apps Script project.", "request": { "$ref": "UpdateDeploymentRequest" } }, "create": { "response": { "$ref": "Deployment" }, "parameterOrder": ["scriptId"], "httpMethod": "POST", "parameters": { "scriptId": { "location": "path", "description": "The script project's Drive ID.", "required": true, "type": "string" } }, "flatPath": "v1/projects/{scriptId}/deployments", "path": "v1/projects/{scriptId}/deployments", "id": "script.projects.deployments.create", "request": { "$ref": "DeploymentConfig" }, "description": "Creates a deployment of an Apps Script project." } } }, "versions": { "methods": { "get": { "response": { "$ref": "Version" }, "parameterOrder": ["scriptId", "versionNumber"], "httpMethod": "GET", "parameters": { "versionNumber": { "location": "path", "description": "The version number.", "format": "int32", "required": true, "type": "integer" }, "scriptId": { "description": "The script project's Drive ID.", "required": true, "type": "string", "location": "path" } }, "flatPath": "v1/projects/{scriptId}/versions/{versionNumber}", "path": "v1/projects/{scriptId}/versions/{versionNumber}", "id": "script.projects.versions.get", "description": "Gets a version of a script project." }, "list": { "response": { "$ref": "ListVersionsResponse" }, "parameterOrder": ["scriptId"], "httpMethod": "GET", "parameters": { "pageToken": { "location": "query", "description": "The token for continuing a previous list request on the next page. This\nshould be set to the value of `nextPageToken` from a previous response.", "type": "string" }, "pageSize": { "description": "The maximum number of versions on each returned page. Defaults to 50.", "format": "int32", "type": "integer", "location": "query" }, "scriptId": { "description": "The script project's Drive ID.", "required": true, "type": "string", "location": "path" } }, "flatPath": "v1/projects/{scriptId}/versions", "path": "v1/projects/{scriptId}/versions", "id": "script.projects.versions.list", "description": "List the versions of a script project." }, "create": { "description": "Creates a new immutable version using the current code, with a unique\nversion number.", "request": { "$ref": "Version" }, "response": { "$ref": "Version" }, "parameterOrder": ["scriptId"], "httpMethod": "POST", "parameters": { "scriptId": { "description": "The script project's Drive ID.", "required": true, "type": "string", "location": "path" } }, "flatPath": "v1/projects/{scriptId}/versions", "path": "v1/projects/{scriptId}/versions", "id": "script.projects.versions.create" } } } } }, "processes": { "methods": { "listScriptProcesses": { "description": "List information about a script's executed processes, such as process type\nand current status.", "httpMethod": "GET", "response": { "$ref": "ListScriptProcessesResponse" }, "parameterOrder": [], "parameters": { "pageToken": { "description": "The token for continuing a previous list request on the next page. This\nshould be set to the value of `nextPageToken` from a previous response.", "type": "string", "location": "query" }, "pageSize": { "location": "query", "description": "The maximum number of returned processes per page of results. Defaults to\n50.", "format": "int32", "type": "integer" }, "scriptProcessFilter.endTime": { "description": "Optional field used to limit returned processes to those that completed\non or before the given timestamp.", "format": "google-datetime", "type": "string", "location": "query" }, "scriptProcessFilter.userAccessLevels": { "location": "query", "enum": ["USER_ACCESS_LEVEL_UNSPECIFIED", "NONE", "READ", "WRITE", "OWNER"], "description": "Optional field used to limit returned processes to those having one of\nthe specified user access levels.", "type": "string", "repeated": true }, "scriptProcessFilter.statuses": { "enum": ["PROCESS_STATUS_UNSPECIFIED", "RUNNING", "PAUSED", "COMPLETED", "CANCELED", "FAILED", "TIMED_OUT", "UNKNOWN", "DELAYED"], "description": "Optional field used to limit returned processes to those having one of\nthe specified process statuses.", "type": "string", "repeated": true, "location": "query" }, "scriptProcessFilter.startTime": { "location": "query", "description": "Optional field used to limit returned processes to those that were\nstarted on or after the given timestamp.", "format": "google-datetime", "type": "string" }, "scriptProcessFilter.functionName": { "location": "query", "description": "Optional field used to limit returned processes to those originating from\na script function with the given function name.", "type": "string" }, "scriptProcessFilter.deploymentId": { "location": "query", "description": "Optional field used to limit returned processes to those originating from\nprojects with a specific deployment ID.", "type": "string" }, "scriptId": { "description": "The script ID of the project whose processes are listed.", "type": "string", "location": "query" }, "scriptProcessFilter.types": { "location": "query", "enum": ["PROCESS_TYPE_UNSPECIFIED", "ADD_ON", "EXECUTION_API", "TIME_DRIVEN", "TRIGGER", "WEBAPP", "EDITOR", "SIMPLE_TRIGGER", "MENU"], "description": "Optional field used to limit returned processes to those having one of\nthe specified process types.", "type": "string", "repeated": true } }, "flatPath": "v1/processes:listScriptProcesses", "id": "script.processes.listScriptProcesses", "path": "v1/processes:listScriptProcesses" }, "list": { "httpMethod": "GET", "response": { "$ref": "ListUserProcessesResponse" }, "parameterOrder": [], "parameters": { "pageSize": { "description": "The maximum number of returned processes per page of results. Defaults to\n50.", "format": "int32", "type": "integer", "location": "query" }, "userProcessFilter.startTime": { "description": "Optional field used to limit returned processes to those that were\nstarted on or after the given timestamp.", "format": "google-datetime", "type": "string", "location": "query" }, "userProcessFilter.userAccessLevels": { "repeated": true, "location": "query", "enum": ["USER_ACCESS_LEVEL_UNSPECIFIED", "NONE", "READ", "WRITE", "OWNER"], "description": "Optional field used to limit returned processes to those having one of\nthe specified user access levels.", "type": "string" }, "userProcessFilter.projectName": { "location": "query", "description": "Optional field used to limit returned processes to those originating from\nprojects with project names containing a specific string.", "type": "string" }, "userProcessFilter.functionName": { "location": "query", "description": "Optional field used to limit returned processes to those originating from\na script function with the given function name.", "type": "string" }, "userProcessFilter.scriptId": { "location": "query", "description": "Optional field used to limit returned processes to those originating from\nprojects with a specific script ID.", "type": "string" }, "userProcessFilter.types": { "location": "query", "enum": ["PROCESS_TYPE_UNSPECIFIED", "ADD_ON", "EXECUTION_API", "TIME_DRIVEN", "TRIGGER", "WEBAPP", "EDITOR", "SIMPLE_TRIGGER", "MENU"], "description": "Optional field used to limit returned processes to those having one of\nthe specified process types.", "type": "string", "repeated": true }, "userProcessFilter.statuses": { "description": "Optional field used to limit returned processes to those having one of\nthe specified process statuses.", "type": "string", "repeated": true, "location": "query", "enum": ["PROCESS_STATUS_UNSPECIFIED", "RUNNING", "PAUSED", "COMPLETED", "CANCELED", "FAILED", "TIMED_OUT", "UNKNOWN", "DELAYED"] }, "userProcessFilter.deploymentId": { "description": "Optional field used to limit returned processes to those originating from\nprojects with a specific deployment ID.", "type": "string", "location": "query" }, "userProcessFilter.endTime": { "description": "Optional field used to limit returned processes to those that completed\non or before the given timestamp.", "format": "google-datetime", "type": "string", "location": "query" }, "pageToken": { "description": "The token for continuing a previous list request on the next page. This\nshould be set to the value of `nextPageToken` from a previous response.", "type": "string", "location": "query" } }, "flatPath": "v1/processes", "id": "script.processes.list", "path": "v1/processes", "description": "List information about processes made by or on behalf of a user,\nsuch as process type and current status." } } }, "scripts": { "methods": { "run": { "request": { "$ref": "ExecutionRequest" }, "description": "Runs a function in an Apps Script project. The project must be deployed\nfor use with the Apps Script API.\n\nThis method requires authorization with an OAuth 2.0 token that includes at\nleast one of the scopes listed in the [Authorization](#authorization)\nsection; script projects that do not require authorization cannot be\nexecuted through this API. To find the correct scopes to include in the\nauthentication token, open the project in the script editor, then select\n**File > Project properties** and click the **Scopes** tab.", "response": { "$ref": "Operation" }, "parameterOrder": ["scriptId"], "httpMethod": "POST", "scopes": ["https://mail.google.com/", "https://www.google.com/calendar/feeds", "https://www.google.com/m8/feeds", "https://www.googleapis.com/auth/admin.directory.group", "https://www.googleapis.com/auth/admin.directory.user", "https://www.googleapis.com/auth/documents", "https://www.googleapis.com/auth/drive", "https://www.googleapis.com/auth/forms", "https://www.googleapis.com/auth/forms.currentonly", "https://www.googleapis.com/auth/groups", "https://www.googleapis.com/auth/spreadsheets", "https://www.googleapis.com/auth/userinfo.email"], "parameters": { "scriptId": { "location": "path", "description": "The script ID of the script to be executed. To find the script ID, open\nthe project in the script editor and select **File > Project properties**.", "required": true, "type": "string" } }, "flatPath": "v1/scripts/{scriptId}:run", "path": "v1/scripts/{scriptId}:run", "id": "script.scripts.run" } } } }, "parameters": { "uploadType": { "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string", "location": "query" }, "fields": { "description": "Selector specifying which fields to include in a partial response.", "type": "string", "location": "query" }, "$.xgafv": { "enumDescriptions": ["v1 error format", "v2 error format"], "location": "query", "enum": ["1", "2"], "description": "V1 error format.", "type": "string" }, "oauth_token": { "description": "OAuth 2.0 token for the current user.", "type": "string", "location": "query" }, "callback": { "location": "query", "description": "JSONP", "type": "string" }, "alt": { "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response.", "default": "json", "enum": ["json", "media", "proto"], "type": "string" }, "key": { "location": "query", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string" }, "access_token": { "location": "query", "description": "OAuth access token.", "type": "string" }, "upload_protocol": { "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string", "location": "query" }, "prettyPrint": { "location": "query", "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true" }, "quotaUser": { "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string", "location": "query" } }, "version": "v1", "baseUrl": "https://script.googleapis.com/", "servicePath": "", "kind": "discovery#restDescription", "description": "An API for managing and executing Google Apps Script projects.\n", "basePath": "", "revision": "20180917", "documentationLink": "https://developers.google.com/apps-script/api/", "id": "script:v1", "discoveryVersion": "v1", "schemas": { "UpdateDeploymentRequest": { "description": "Request with deployment information to update an existing deployment.", "type": "object", "properties": { "deploymentConfig": { "description": "The deployment configuration.", "$ref": "DeploymentConfig" } }, "id": "UpdateDeploymentRequest" }, "GoogleAppsScriptTypeExecutionApiEntryPoint": { "properties": { "entryPointConfig": { "description": "The entry point's configuration.", "$ref": "GoogleAppsScriptTypeExecutionApiConfig" } }, "id": "GoogleAppsScriptTypeExecutionApiEntryPoint", "description": "An API executable entry point.", "type": "object" }, "ExecutionError": { "description": "An object that provides information about the nature of an error resulting\nfrom an attempted execution of a script function using the Apps Script API.\nIf a run call\nsucceeds but the script function (or Apps Script itself) throws an exception,\nthe response body's error field\ncontains a\nStatus object. The `Status` object's `details` field\ncontains an array with a single one of these `ExecutionError` objects.", "type": "object", "properties": { "scriptStackTraceElements": { "description": "An array of objects that provide a stack trace through the script to show\nwhere the execution failed, with the deepest call first.", "type": "array", "items": { "$ref": "ScriptStackTraceElement" } }, "errorType": { "description": "The error type, for example `TypeError` or `ReferenceError`. If the error\ntype is unavailable, this field is not included.", "type": "string" }, "errorMessage": { "description": "The error message thrown by Apps Script, usually localized into the user's\nlanguage.", "type": "string" } }, "id": "ExecutionError" }, "ListUserProcessesResponse": { "description": "Response with the list of\nProcess resources.", "type": "object", "properties": { "nextPageToken": { "description": "Token for the next page of results. If empty, there are no more pages\nremaining.", "type": "string" }, "processes": { "description": "List of processes matching request parameters.", "type": "array", "items": { "$ref": "GoogleAppsScriptTypeProcess" } } }, "id": "ListUserProcessesResponse" }, "GoogleAppsScriptTypeUser": { "properties": { "domain": { "description": "The user's domain.", "type": "string" }, "photoUrl": { "description": "The user's photo.", "type": "string" }, "email": { "description": "The user's identifying email address.", "type": "string" }, "name": { "description": "The user's display name.", "type": "string" } }, "id": "GoogleAppsScriptTypeUser", "description": "A simple user profile resource.", "type": "object" }, "EntryPoint": { "properties": { "executionApi": { "description": "An entry point specification for Apps Script API execution calls.", "$ref": "GoogleAppsScriptTypeExecutionApiEntryPoint" }, "entryPointType": { "enum": ["ENTRY_POINT_TYPE_UNSPECIFIED", "WEB_APP", "EXECUTION_API", "ADD_ON"], "description": "The type of the entry point.", "type": "string", "enumDescriptions": ["An unspecified entry point.", "A web application entry point.", "An API executable entry point.", "An Add-On entry point."] }, "addOn": { "description": "Add-on properties.", "$ref": "GoogleAppsScriptTypeAddOnEntryPoint" }, "webApp": { "description": "An entry point specification for web apps.", "$ref": "GoogleAppsScriptTypeWebAppEntryPoint" } }, "id": "EntryPoint", "description": "A configuration that defines how a deployment is accessed externally.", "type": "object" }, "ExecutionRequest": { "properties": { "sessionState": { "description": "For Android add-ons only. An ID that represents the user's current session\nin the Android app for Google Docs or Sheets, included as extra data in the\n[Intent](https://developer.android.com/guide/components/intents-filters.html)\nthat launches the add-on. When an Android add-on is run with a session\nstate, it gains the privileges of a\n[bound](https://developers.google.com/apps-script/guides/bound)\nscript&mdash;that is, it can access information like the user's current\ncursor position (in Docs) or selected cell (in Sheets). To retrieve the\nstate, call\n`Intent.getStringExtra(\"com.google.android.apps.docs.addons.SessionState\")`.\nOptional.", "type": "string" }, "function": { "description": "The name of the function to execute in the given script. The name does not\ninclude parentheses or parameters.", "type": "string" }, "devMode": { "description": "If `true` and the user is an owner of the script, the script runs at the\nmost recently saved version rather than the version deployed for use with\nthe Apps Script API. Optional; default is `false`.", "type": "boolean" }, "parameters": { "description": "The parameters to be passed to the function being executed. The object type\nfor each parameter should match the expected type in Apps Script.\nParameters cannot be Apps Script-specific object types (such as a\n`Document` or a `Calendar`); they can only be primitive types such as\n`string`, `number`, `array`, `object`, or `boolean`. Optional.", "type": "array", "items": { "type": "any" } } }, "id": "ExecutionRequest", "description": "A request to run the function in a script. The script is identified by the\nspecified `script_id`. Executing a function on a script returns results\nbased on the implementation of the script.", "type": "object" }, "Version": { "description": "A resource representing a script project version. A version is a \"snapshot\"\nof a script project and is similar to a read-only branched release. When\ncreating deployments, the version to use must be specified.", "type": "object", "properties": { "createTime": { "description": "When the version was created.", "format": "google-datetime", "type": "string" }, "description": { "description": "The description for this version.", "type": "string" }, "versionNumber": { "description": "The incremental ID that is created by Apps Script when a version is\ncreated. This is system assigned number and is immutable once created.", "format": "int32", "type": "integer" }, "scriptId": { "description": "The script project's Drive ID.", "type": "string" } }, "id": "Version" }, "GoogleAppsScriptTypeExecutionApiConfig": { "description": "API executable entry point configuration.", "type": "object", "properties": { "access": { "enumDescriptions": ["Default value, should not be used.", "Only the user who deployed the web app or executable can access it.\nNote that this is not necessarily the owner of the script project.", "Only users in the same domain as the user who deployed the web app or\nexecutable can access it.", "Any logged in user can access the web app or executable.", "Any user, logged in or not, can access the web app or executable."], "enum": ["UNKNOWN_ACCESS", "MYSELF", "DOMAIN", "ANYONE", "ANYONE_ANONYMOUS"], "description": "Who has permission to run the API executable.", "type": "string" } }, "id": "GoogleAppsScriptTypeExecutionApiConfig" }, "GoogleAppsScriptTypeProcess": { "description": "Representation of a single script process execution that was started from\nthe script editor, a trigger, an application, or using the Apps Script API.\nThis is distinct from the `Operation`\nresource, which only represents executions started via the Apps Script API.", "type": "object", "properties": { "userAccessLevel": { "enumDescriptions": ["User access level unspecified", "The user has no access.", "The user has read-only access.", "The user has write access.", "The user is an owner."], "enum": ["USER_ACCESS_LEVEL_UNSPECIFIED", "NONE", "READ", "WRITE", "OWNER"], "description": "The executing users access level to the script.", "type": "string" }, "executingUser": { "description": "User-facing name for the user executing the script.", "type": "string" }, "processType": { "enumDescriptions": ["Unspecified type.", "The process was started from an add-on entry point.", "The process was started using the Apps Script API.", "The process was started from a time-based trigger.", "The process was started from an event-based trigger.", "The process was started from a web app entry point.", "The process was started using the Apps Script IDE.", "The process was started from a G Suite simple trigger.", "The process was started from a G Suite menu item."], "enum": ["PROCESS_TYPE_UNSPECIFIED", "ADD_ON", "EXECUTION_API", "TIME_DRIVEN", "TRIGGER", "WEBAPP", "EDITOR", "SIMPLE_TRIGGER", "MENU"], "description": "The executions type.", "type": "string" }, "projectName": { "description": "Name of the script being executed.", "type": "string" }, "processStatus": { "enum": ["PROCESS_STATUS_UNSPECIFIED", "RUNNING", "PAUSED", "COMPLETED", "CANCELED", "FAILED", "TIMED_OUT", "UNKNOWN", "DELAYED"], "description": "The executions status.", "type": "string", "enumDescriptions": ["Unspecified status.", "The process is currently running.", "The process has paused.", "The process has completed.", "The process was cancelled.", "The process failed.", "The process timed out.", "Process status unknown.", "The process is delayed, waiting for quota."] }, "duration": { "description": "Duration the execution spent executing.", "format": "google-duration", "type": "string" }, "functionName": { "description": "Name of the function the started the execution.", "type": "string" }, "startTime": { "description": "Time the execution started.", "format": "google-datetime", "type": "string" } }, "id": "GoogleAppsScriptTypeProcess" }, "DeploymentConfig": { "description": "Metadata the defines how a deployment is configured.", "type": "object", "properties": { "description": { "description": "The description for this deployment.", "type": "string" }, "versionNumber": { "description": "The version number on which this deployment is based.", "format": "int32", "type": "integer" }, "scriptId": { "description": "The script project's Drive ID.", "type": "string" }, "manifestFileName": { "description": "The manifest file name for this deployment.", "type": "string" } }, "id": "DeploymentConfig" }, "CreateProjectRequest": { "description": "Request to create a script project.", "type": "object", "properties": { "parentId": { "description": "The Drive ID of a parent file that the created script project is bound to.\nThis is usually the ID of a Google Doc, Google Sheet, Google Form, or\nGoogle Slides file. If not set, a standalone script project is created.", "type": "string" }, "title": { "description": "The title for the project.", "type": "string" } }, "id": "CreateProjectRequest" }, "Operation": { "properties": { "done": { "description": "This field indicates whether the script execution has completed. A completed execution has a populated `response` field containing the ExecutionResponse from function that was executed.", "type": "boolean" }, "response": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "If the script function returns successfully, this field contains an ExecutionResponse object with the function's return value.", "type": "object" }, "error": { "description": "If a `run` call succeeds but the script function (or Apps Script itself) throws an exception, this field contains a Status object. The `Status` object's `details` field contains an array with a single ExecutionError object that provides information about the nature of the error.", "$ref": "Status" } }, "id": "Operation", "description": "A representation of an execution of an Apps Script function started with run. The execution response does not arrive until the function finishes executing. The maximum execution runtime is listed in the [Apps Script quotas guide](/apps-script/guides/services/quotas#current_limitations). <p>After execution has started, it can have one of four outcomes:</p> <ul> <li> If the script function returns successfully, the\n  response field contains an\n  ExecutionResponse object\n  with the function's return value in the object's `result` field.</li>\n<li> If the script function (or Apps Script itself) throws an exception, the\n  error field contains a\n  Status object. The `Status` object's `details`\n  field contains an array with a single\n  ExecutionError object that\n  provides information about the nature of the error.</li>\n<li> If the execution has not yet completed,\n  the done field is `false` and\n  the neither the `response` nor `error` fields are present.</li>\n<li> If the `run` call itself fails (for example, because of a\n  malformed request or an authorization error), the method returns an HTTP\n  response code in the 4XX range with a different format for the response\n  body. Client libraries automatically convert a 4XX response into an\n  exception class.</li>\n</ul>", "type": "object" }, "Status": { "description": "If a `run` call succeeds but the script function (or Apps Script itself) throws an exception, the response body's error field contains this `Status` object.", "type": "object", "properties": { "details": { "description": "An array that contains a single ExecutionError object that provides information about the nature of the error.", "type": "array", "items": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "type": "object" } }, "code": { "description": "The status code. For this API, this value either: <ul> <li> 10, indicating a `SCRIPT_TIMEOUT` error,</li> <li> 3, indicating an `INVALID_ARGUMENT` error, or</li> <li> 1, indicating a `CANCELLED` execution.</li> </ul>", "format": "int32", "type": "integer" }, "message": { "description": "A developer-facing error message, which is in English. Any user-facing error message is localized and sent in the details field, or localized by the client.", "type": "string" } }, "id": "Status" }, "MetricsValue": { "description": "Metrics value that holds number of executions counted.", "type": "object", "properties": { "endTime": { "description": "Required field indicating the end time of the interval.", "format": "google-datetime", "type": "string" }, "startTime": { "description": "Required field indicating the start time of the interval.", "format": "google-datetime", "type": "string" }, "value": { "description": "Indicates the number of executions counted.", "format": "uint64", "type": "string" } }, "id": "MetricsValue" }, "GoogleAppsScriptTypeFunction": { "description": "Represents a function in a script project.", "type": "object", "properties": { "name": { "description": "The function name in the script project.", "type": "string" } }, "id": "GoogleAppsScriptTypeFunction" }, "Deployment": { "description": "Representation of a single script deployment.", "type": "object", "properties": { "deploymentId": { "description": "The deployment ID for this deployment.", "type": "string" }, "deploymentConfig": { "$ref": "DeploymentConfig", "description": "The deployment configuration." }, "updateTime": { "description": "Last modified date time stamp.", "format": "google-datetime", "type": "string" }, "entryPoints": { "description": "The deployment's entry points.", "type": "array", "items": { "$ref": "EntryPoint" } } }, "id": "Deployment" }, "GoogleAppsScriptTypeAddOnEntryPoint": { "description": "An add-on entry point.", "type": "object", "properties": { "title": { "description": "The add-on's required title.", "type": "string" }, "reportIssueUrl": { "description": "The add-on's optional report issue URL.", "type": "string" }, "postInstallTipUrl": { "description": "The add-on's required post install tip URL.", "type": "string" }, "description": { "description": "The add-on's optional description.", "type": "string" }, "addOnType": { "enumDescriptions": ["Default value, unknown add-on type.", "Add-on type for Gmail.", "Add-on type for Data Studio."], "enum": ["UNKNOWN_ADDON_TYPE", "GMAIL", "DATA_STUDIO"], "description": "The add-on's required list of supported container types.", "type": "string" }, "helpUrl": { "description": "The add-on's optional help URL.", "type": "string" } }, "id": "GoogleAppsScriptTypeAddOnEntryPoint" }, "ScriptStackTraceElement": { "description": "A stack trace through the script that shows where the execution failed.", "type": "object", "properties": { "function": { "description": "The name of the function that failed.", "type": "string" }, "lineNumber": { "description": "The line number where the script failed.", "format": "int32", "type": "integer" } }, "id": "ScriptStackTraceElement" }, "ListScriptProcessesResponse": { "description": "Response with the list of\nProcess resources.", "type": "object", "properties": { "nextPageToken": { "description": "Token for the next page of results. If empty, there are no more pages\nremaining.", "type": "string" }, "processes": { "description": "List of processes matching request parameters.", "type": "array", "items": { "$ref": "GoogleAppsScriptTypeProcess" } } }, "id": "ListScriptProcessesResponse" }, "GoogleAppsScriptTypeWebAppConfig": { "properties": { "access": { "description": "Who has permission to run the web app.", "type": "string", "enumDescriptions": ["Default value, should not be used.", "Only the user who deployed the web app or executable can access it.\nNote that this is not necessarily the owner of the script project.", "Only users in the same domain as the user who deployed the web app or\nexecutable can access it.", "Any logged in user can access the web app or executable.", "Any user, logged in or not, can access the web app or executable."], "enum": ["UNKNOWN_ACCESS", "MYSELF", "DOMAIN", "ANYONE", "ANYONE_ANONYMOUS"] }, "executeAs": { "enumDescriptions": ["Default value, should not be used.", "The script runs as the user accessing the web app.", "The script runs as the user who deployed the web app. Note that this is\nnot necessarily the owner of the script project."], "enum": ["UNKNOWN_EXECUTE_AS", "USER_ACCESSING", "USER_DEPLOYING"], "description": "Who to execute the web app as.", "type": "string" } }, "id": "GoogleAppsScriptTypeWebAppConfig", "description": "Web app entry point configuration.", "type": "object" }, "Project": { "description": "The script project resource.", "type": "object", "properties": { "createTime": { "description": "When the script was created.", "format": "google-datetime", "type": "string" }, "parentId": { "description": "The parent's Drive ID that the script will be attached to. This is usually\nthe ID of a Google Document or Google Sheet. This filed is optional, and\nif not set, a stand-alone script will be created.", "type": "string" }, "updateTime": { "description": "When the script was last updated.", "format": "google-datetime", "type": "string" }, "creator": { "description": "User who originally created the script.", "$ref": "GoogleAppsScriptTypeUser" }, "scriptId": { "description": "The script project's Drive ID.", "type": "string" }, "title": { "description": "The title for the project.", "type": "string" }, "lastModifyUser": { "$ref": "GoogleAppsScriptTypeUser", "description": "User who last modified the script." } }, "id": "Project" }, "ListDeploymentsResponse": { "properties": { "deployments": { "description": "The list of deployments.", "type": "array", "items": { "$ref": "Deployment" } }, "nextPageToken": { "description": "The token that can be used in the next call to get the next page of\nresults.", "type": "string" } }, "id": "ListDeploymentsResponse", "description": "Response with the list of deployments for the specified Apps Script project.", "type": "object" }, "File": { "properties": { "createTime": { "description": "Creation date timestamp.\nThis read-only field is only visible to users who have WRITER\npermission for the script project.", "format": "google-datetime", "type": "string" }, "functionSet": { "$ref": "GoogleAppsScriptTypeFunctionSet", "description": "The defined set of functions in the script file, if any." }, "updateTime": { "description": "Last modified date timestamp.\nThis read-only field is only visible to users who have WRITER\npermission for the script project.", "format": "google-datetime", "type": "string" }, "name": { "description": "The name of the file. The file extension is not part of the file\nname, which can be identified from the type field.", "type": "string" }, "type": { "enumDescriptions": ["Undetermined file type; never actually used.", "An Apps Script server-side code file.", "A file containing client-side HTML.", "A file in JSON format. This type is only used for the script\nproject's manifest. The manifest file content must match the\nstructure of a valid\n[ScriptManifest](/apps-script/concepts/manifests)"], "enum": ["ENUM_TYPE_UNSPECIFIED", "SERVER_JS", "HTML", "JSON"], "description": "The type of the file.", "type": "string" }, "source": { "description": "The file content.", "type": "string" }, "lastModifyUser": { "$ref": "GoogleAppsScriptTypeUser", "description": "The user who modified the file most recently.\nThis read-only field is only visible to users who have WRITER\npermission for the script project." } }, "id": "File", "description": "An individual file within a script project.\nA file is a third-party source code created by one or more\ndevelopers. It can be a server-side JS code, HTML, or a\nconfiguration file. Each script project can contain multiple files.", "type": "object" }, "ExecutionResponse": { "description": "An object that provides the return value of a function executed using the\nApps Script API. If the script function returns successfully, the response\nbody's response field contains this\n`ExecutionResponse` object.", "type": "object", "properties": { "result": { "description": "The return value of the script function. The type matches the object type\nreturned in Apps Script. Functions called using the Apps Script API cannot\nreturn Apps Script-specific objects (such as a `Document` or a `Calendar`);\nthey can only return primitive types such as a `string`, `number`, `array`,\n`object`, or `boolean`.", "type": "any" } }, "id": "ExecutionResponse" }, "ListVersionsResponse": { "properties": { "nextPageToken": { "description": "The token use to fetch the next page of records. if not exist in the\nresponse, that means no more versions to list.", "type": "string" }, "versions": { "description": "The list of versions.", "type": "array", "items": { "$ref": "Version" } } }, "id": "ListVersionsResponse", "description": "Response with the list of the versions for the specified script project.", "type": "object" }, "Metrics": { "description": "Resource containing usage stats for a given script, based on the supplied\nfilter and mask present in the request.", "type": "object", "properties": { "activeUsers": { "description": "Number of active users.", "type": "array", "items": { "$ref": "MetricsValue" } }, "totalExecutions": { "description": "Number of total executions.", "type": "array", "items": { "$ref": "MetricsValue" } }, "failedExecutions": { "description": "Number of failed executions.", "type": "array", "items": { "$ref": "MetricsValue" } } }, "id": "Metrics" }, "GoogleAppsScriptTypeFunctionSet": { "description": "A set of functions. No duplicates are permitted.", "type": "object", "properties": { "values": { "description": "A list of functions composing the set.", "type": "array", "items": { "$ref": "GoogleAppsScriptTypeFunction" } } }, "id": "GoogleAppsScriptTypeFunctionSet" }, "Empty": { "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.", "type": "object", "properties": {}, "id": "Empty" }, "GoogleAppsScriptTypeWebAppEntryPoint": { "description": "A web application entry point.", "type": "object", "properties": { "url": { "description": "The URL for the web application.", "type": "string" }, "entryPointConfig": { "description": "The entry point's configuration.", "$ref": "GoogleAppsScriptTypeWebAppConfig" } }, "id": "GoogleAppsScriptTypeWebAppEntryPoint" }, "Content": { "description": "The Content resource.", "type": "object", "properties": { "files": { "description": "The list of script project files.\nOne of the files is a script manifest; it must be named \"appsscript\",\nmust have type of JSON, and include the manifest configurations for the\nproject.", "type": "array", "items": { "$ref": "File" } }, "scriptId": { "description": "The script project's Drive ID.", "type": "string" } }, "id": "Content" } }, "protocol": "rest", "icons": { "x16": "http://www.google.com/images/icons/product/search-16.gif", "x32": "http://www.google.com/images/icons/product/search-32.gif" }, "canonicalName": "Script", "auth": { "oauth2": { "scopes": { "https://www.google.com/calendar/feeds": { "description": "Manage your calendars" }, "https://www.googleapis.com/auth/drive": { "description": "View and manage the files in your Google Drive" }, "https://mail.google.com/": { "description": "Read, send, delete, and manage your email" }, "https://www.googleapis.com/auth/admin.directory.user": { "description": "View and manage the provisioning of users on your domain" }, "https://www.googleapis.com/auth/userinfo.email": { "description": "View your email address" }, "https://www.googleapis.com/auth/groups": { "description": "View and manage your Google Groups" }, "https://www.googleapis.com/auth/forms.currentonly": { "description": "View and manage forms that this application has been installed in" }, "https://www.googleapis.com/auth/spreadsheets": { "description": "View and manage your spreadsheets in Google Drive" }, "https://www.googleapis.com/auth/admin.directory.group": { "description": "View and manage the provisioning of groups on your domain" }, "https://www.googleapis.com/auth/forms": { "description": "View and manage your forms in Google Drive" }, "https://www.google.com/m8/feeds": { "description": "Manage your contacts" }, "https://www.googleapis.com/auth/documents": { "description": "View and manage your Google Docs documents" } } } }, "rootUrl": "https://script.googleapis.com/" };
//# sourceMappingURL=script-v1.js.map