"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "title": "YouTube Reporting API", "discoveryVersion": "v1", "ownerName": "Google", "resources": { "jobs": { "methods": { "create": { "path": "v1/jobs", "id": "youtubereporting.jobs.create", "description": "Creates a job and returns it.", "request": { "$ref": "Job" }, "response": { "$ref": "Job" }, "parameterOrder": [], "httpMethod": "POST", "parameters": { "onBehalfOfContentOwner": { "location": "query", "description": "The content owner's external ID on which behalf the user is acting on. If\nnot set, the user is acting for himself (his own channel).", "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/yt-analytics-monetary.readonly", "https://www.googleapis.com/auth/yt-analytics.readonly"], "flatPath": "v1/jobs" }, "delete": { "response": { "$ref": "Empty" }, "parameterOrder": ["jobId"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/yt-analytics-monetary.readonly", "https://www.googleapis.com/auth/yt-analytics.readonly"], "parameters": { "jobId": { "description": "The ID of the job to delete.", "required": true, "type": "string", "location": "path" }, "onBehalfOfContentOwner": { "location": "query", "description": "The content owner's external ID on which behalf the user is acting on. If\nnot set, the user is acting for himself (his own channel).", "type": "string" } }, "flatPath": "v1/jobs/{jobId}", "path": "v1/jobs/{jobId}", "id": "youtubereporting.jobs.delete", "description": "Deletes a job." }, "list": { "flatPath": "v1/jobs", "path": "v1/jobs", "id": "youtubereporting.jobs.list", "description": "Lists jobs.", "response": { "$ref": "ListJobsResponse" }, "parameterOrder": [], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/yt-analytics-monetary.readonly", "https://www.googleapis.com/auth/yt-analytics.readonly"], "parameters": { "pageSize": { "location": "query", "description": "Requested page size. Server may return fewer jobs than requested.\nIf unspecified, server will pick an appropriate default.", "format": "int32", "type": "integer" }, "onBehalfOfContentOwner": { "description": "The content owner's external ID on which behalf the user is acting on. If\nnot set, the user is acting for himself (his own channel).", "type": "string", "location": "query" }, "pageToken": { "location": "query", "description": "A token identifying a page of results the server should return. Typically,\nthis is the value of\nListReportTypesResponse.next_page_token\nreturned in response to the previous call to the `ListJobs` method.", "type": "string" }, "includeSystemManaged": { "description": "If set to true, also system-managed jobs will be returned; otherwise only\nuser-created jobs will be returned. System-managed jobs can neither be\nmodified nor deleted.", "type": "boolean", "location": "query" } } }, "get": { "description": "Gets a job.", "httpMethod": "GET", "parameterOrder": ["jobId"], "response": { "$ref": "Job" }, "parameters": { "onBehalfOfContentOwner": { "location": "query", "description": "The content owner's external ID on which behalf the user is acting on. If\nnot set, the user is acting for himself (his own channel).", "type": "string" }, "jobId": { "location": "path", "description": "The ID of the job to retrieve.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/yt-analytics-monetary.readonly", "https://www.googleapis.com/auth/yt-analytics.readonly"], "flatPath": "v1/jobs/{jobId}", "id": "youtubereporting.jobs.get", "path": "v1/jobs/{jobId}" } }, "resources": { "reports": { "methods": { "list": { "description": "Lists reports created by a specific job.\nReturns NOT_FOUND if the job does not exist.", "response": { "$ref": "ListReportsResponse" }, "parameterOrder": ["jobId"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/yt-analytics-monetary.readonly", "https://www.googleapis.com/auth/yt-analytics.readonly"], "parameters": { "jobId": { "location": "path", "description": "The ID of the job.", "required": true, "type": "string" }, "createdAfter": { "location": "query", "description": "If set, only reports created after the specified date/time are returned.", "format": "google-datetime", "type": "string" }, "startTimeAtOrAfter": { "location": "query", "description": "If set, only reports whose start time is greater than or equal the\nspecified date/time are returned.", "format": "google-datetime", "type": "string" }, "pageToken": { "description": "A token identifying a page of results the server should return. Typically,\nthis is the value of\nListReportsResponse.next_page_token\nreturned in response to the previous call to the `ListReports` method.", "type": "string", "location": "query" }, "pageSize": { "location": "query", "description": "Requested page size. Server may return fewer report types than requested.\nIf unspecified, server will pick an appropriate default.", "format": "int32", "type": "integer" }, "onBehalfOfContentOwner": { "description": "The content owner's external ID on which behalf the user is acting on. If\nnot set, the user is acting for himself (his own channel).", "type": "string", "location": "query" }, "startTimeBefore": { "location": "query", "description": "If set, only reports whose start time is smaller than the specified\ndate/time are returned.", "format": "google-datetime", "type": "string" } }, "flatPath": "v1/jobs/{jobId}/reports", "path": "v1/jobs/{jobId}/reports", "id": "youtubereporting.jobs.reports.list" }, "get": { "scopes": ["https://www.googleapis.com/auth/yt-analytics-monetary.readonly", "https://www.googleapis.com/auth/yt-analytics.readonly"], "parameters": { "jobId": { "description": "The ID of the job.", "required": true, "type": "string", "location": "path" }, "onBehalfOfContentOwner": { "location": "query", "description": "The content owner's external ID on which behalf the user is acting on. If\nnot set, the user is acting for himself (his own channel).", "type": "string" }, "reportId": { "location": "path", "description": "The ID of the report to retrieve.", "required": true, "type": "string" } }, "flatPath": "v1/jobs/{jobId}/reports/{reportId}", "path": "v1/jobs/{jobId}/reports/{reportId}", "id": "youtubereporting.jobs.reports.get", "description": "Gets the metadata of a specific report.", "response": { "$ref": "Report" }, "parameterOrder": ["jobId", "reportId"], "httpMethod": "GET" } } } } }, "reportTypes": { "methods": { "list": { "parameters": { "pageToken": { "location": "query", "description": "A token identifying a page of results the server should return. Typically,\nthis is the value of\nListReportTypesResponse.next_page_token\nreturned in response to the previous call to the `ListReportTypes` method.", "type": "string" }, "includeSystemManaged": { "description": "If set to true, also system-managed report types will be returned;\notherwise only the report types that can be used to create new reporting\njobs will be returned.", "type": "boolean", "location": "query" }, "pageSize": { "location": "query", "description": "Requested page size. Server may return fewer report types than requested.\nIf unspecified, server will pick an appropriate default.", "format": "int32", "type": "integer" }, "onBehalfOfContentOwner": { "location": "query", "description": "The content owner's external ID on which behalf the user is acting on. If\nnot set, the user is acting for himself (his own channel).", "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/yt-analytics-monetary.readonly", "https://www.googleapis.com/auth/yt-analytics.readonly"], "flatPath": "v1/reportTypes", "id": "youtubereporting.reportTypes.list", "path": "v1/reportTypes", "description": "Lists report types.", "httpMethod": "GET", "parameterOrder": [], "response": { "$ref": "ListReportTypesResponse" } } } }, "media": { "methods": { "download": { "supportsMediaDownload": true, "httpMethod": "GET", "parameterOrder": ["resourceName"], "response": { "$ref": "GdataMedia" }, "parameters": { "resourceName": { "description": "Name of the media that is being downloaded.", "required": true, "type": "string", "pattern": "^.+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/yt-analytics-monetary.readonly", "https://www.googleapis.com/auth/yt-analytics.readonly"], "flatPath": "v1/media/{mediaId}", "id": "youtubereporting.media.download", "path": "v1/media/{+resourceName}", "description": "Method for media download. Download is supported\non the URI `/v1/media/{+name}?alt=media`." } } } }, "parameters": { "fields": { "location": "query", "description": "Selector specifying which fields to include in a partial response.", "type": "string" }, "uploadType": { "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string", "location": "query" }, "callback": { "location": "query", "description": "JSONP", "type": "string" }, "oauth_token": { "description": "OAuth 2.0 token for the current user.", "type": "string", "location": "query" }, "$.xgafv": { "enum": ["1", "2"], "description": "V1 error format.", "type": "string", "enumDescriptions": ["v1 error format", "v2 error format"], "location": "query" }, "alt": { "type": "string", "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response.", "default": "json", "enum": ["json", "media", "proto"] }, "access_token": { "description": "OAuth access token.", "type": "string", "location": "query" }, "key": { "type": "string", "location": "query", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token." }, "upload_protocol": { "location": "query", "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string" }, "quotaUser": { "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string", "location": "query" }, "prettyPrint": { "location": "query", "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true" } }, "schemas": { "GdataContentTypeInfo": { "description": "gdata", "type": "object", "properties": { "fromFileName": { "description": "gdata", "type": "string" }, "bestGuess": { "type": "string", "description": "gdata" }, "fromUrlPath": { "description": "gdata", "type": "string" }, "fromHeader": { "description": "gdata", "type": "string" }, "fromBytes": { "description": "gdata", "type": "string" } }, "id": "GdataContentTypeInfo" }, "GdataDiffUploadResponse": { "description": "gdata", "type": "object", "properties": { "objectVersion": { "description": "gdata", "type": "string" }, "originalObject": { "description": "gdata", "$ref": "GdataCompositeMedia" } }, "id": "GdataDiffUploadResponse" }, "Report": { "description": "A report's metadata including the URL from which the report itself can be\ndownloaded.", "type": "object", "properties": { "createTime": { "description": "The date/time when this report was created.", "format": "google-datetime", "type": "string" }, "jobId": { "description": "The ID of the job that created this report.", "type": "string" }, "id": { "description": "The server-generated ID of the report.", "type": "string" }, "jobExpireTime": { "description": "The date/time when the job this report belongs to will expire/expired.", "format": "google-datetime", "type": "string" }, "endTime": { "description": "The end of the time period that the report instance covers. The value is\nexclusive.", "format": "google-datetime", "type": "string" }, "downloadUrl": { "description": "The URL from which the report can be downloaded (max. 1000 characters).", "type": "string" }, "startTime": { "description": "The start of the time period that the report instance covers. The value is\ninclusive.", "format": "google-datetime", "type": "string" } }, "id": "Report" }, "GdataDiffChecksumsResponse": { "description": "gdata", "type": "object", "properties": { "objectVersion": { "description": "gdata", "type": "string" }, "chunkSizeBytes": { "description": "gdata", "format": "int64", "type": "string" }, "checksumsLocation": { "$ref": "GdataCompositeMedia", "description": "gdata" }, "objectSizeBytes": { "description": "gdata", "format": "int64", "type": "string" }, "objectLocation": { "$ref": "GdataCompositeMedia", "description": "gdata" } }, "id": "GdataDiffChecksumsResponse" }, "GdataDownloadParameters": { "description": "gdata", "type": "object", "properties": { "ignoreRange": { "description": "gdata", "type": "boolean" }, "allowGzipCompression": { "description": "gdata", "type": "boolean" } }, "id": "GdataDownloadParameters" }, "Job": { "type": "object", "properties": { "name": { "description": "The name of the job (max. 100 characters).", "type": "string" }, "id": { "description": "The server-generated ID of the job (max. 40 characters).", "type": "string" }, "systemManaged": { "description": "True if this a system-managed job that cannot be modified by the user;\notherwise false.", "type": "boolean" }, "createTime": { "description": "The creation date/time of the job.", "format": "google-datetime", "type": "string" }, "reportTypeId": { "description": "The type of reports this job creates. Corresponds to the ID of a\nReportType.", "type": "string" }, "expireTime": { "description": "The date/time when this job will expire/expired. After a job expired, no\nnew reports are generated.", "format": "google-datetime", "type": "string" } }, "id": "Job", "description": "A job creating reports of a specific type." }, "GdataObjectId": { "description": "gdata", "type": "object", "properties": { "bucketName": { "description": "gdata", "type": "string" }, "generation": { "description": "gdata", "format": "int64", "type": "string" }, "objectName": { "description": "gdata", "type": "string" } }, "id": "GdataObjectId" }, "GdataMedia": { "description": "gdata", "type": "object", "properties": { "filename": { "description": "gdata", "type": "string" }, "blobstore2Info": { "$ref": "GdataBlobstore2Info", "description": "gdata" }, "hashVerified": { "description": "gdata", "type": "boolean" }, "diffDownloadResponse": { "description": "gdata", "$ref": "GdataDiffDownloadResponse" }, "cosmoBinaryReference": { "description": "gdata", "format": "byte", "type": "string" }, "isPotentialRetry": { "description": "gdata", "type": "boolean" }, "md5Hash": { "description": "gdata", "format": "byte", "type": "string" }, "algorithm": { "description": "gdata", "type": "string" }, "sha256Hash": { "description": "gdata", "format": "byte", "type": "string" }, "objectId": { "$ref": "GdataObjectId", "description": "gdata" }, "path": { "description": "gdata", "type": "string" }, "bigstoreObjectRef": { "description": "gdata", "format": "byte", "type": "string" }, "referenceType": { "description": "gdata", "type": "string", "enumDescriptions": ["gdata", "gdata", "gdata", "gdata", "gdata", "gdata", "gdata", "gdata", "gdata", "gdata", "gdata", "gdata", "gdata"], "enum": ["PATH", "BLOB_REF", "INLINE", "GET_MEDIA", "COMPOSITE_MEDIA", "BIGSTORE_REF", "DIFF_VERSION_RESPONSE", "DIFF_CHECKSUMS_RESPONSE", "DIFF_DOWNLOAD_RESPONSE", "DIFF_UPLOAD_REQUEST", "DIFF_UPLOAD_RESPONSE", "COSMO_BINARY_REFERENCE", "ARBITRARY_BYTES"] }, "inline": { "description": "gdata", "format": "byte", "type": "string" }, "diffUploadRequest": { "$ref": "GdataDiffUploadRequest", "description": "gdata" }, "diffChecksumsResponse": { "$ref": "GdataDiffChecksumsResponse", "description": "gdata" }, "sha1Hash": { "description": "gdata", "format": "byte", "type": "string" }, "crc32cHash": { "description": "gdata", "format": "uint32", "type": "integer" }, "length": { "description": "gdata", "format": "int64", "type": "string" }, "contentTypeInfo": { "$ref": "GdataContentTypeInfo", "description": "gdata" }, "contentType": { "type": "string", "description": "gdata" }, "downloadParameters": { "$ref": "GdataDownloadParameters", "description": "gdata" }, "mediaId": { "description": "gdata", "format": "byte", "type": "string" }, "compositeMedia": { "description": "gdata", "type": "array", "items": { "$ref": "GdataCompositeMedia" } }, "blobRef": { "description": "gdata", "format": "byte", "type": "string" }, "diffUploadResponse": { "description": "gdata", "$ref": "GdataDiffUploadResponse" }, "diffVersionResponse": { "description": "gdata", "$ref": "GdataDiffVersionResponse" }, "timestamp": { "description": "gdata", "format": "uint64", "type": "string" }, "token": { "description": "gdata", "type": "string" }, "hash": { "description": "gdata", "type": "string" } }, "id": "GdataMedia" }, "GdataDiffVersionResponse": { "description": "gdata", "type": "object", "properties": { "objectSizeBytes": { "type": "string", "description": "gdata", "format": "int64" }, "objectVersion": { "description": "gdata", "type": "string" } }, "id": "GdataDiffVersionResponse" }, "GdataDiffDownloadResponse": { "description": "gdata", "type": "object", "properties": { "objectLocation": { "$ref": "GdataCompositeMedia", "description": "gdata" } }, "id": "GdataDiffDownloadResponse" }, "GdataDiffUploadRequest": { "description": "gdata", "type": "object", "properties": { "objectVersion": { "description": "gdata", "type": "string" }, "objectInfo": { "$ref": "GdataCompositeMedia", "description": "gdata" }, "checksumsInfo": { "description": "gdata", "$ref": "GdataCompositeMedia" } }, "id": "GdataDiffUploadRequest" }, "GdataBlobstore2Info": { "description": "gdata", "type": "object", "properties": { "blobGeneration": { "description": "gdata", "format": "int64", "type": "string" }, "blobId": { "description": "gdata", "type": "string" }, "downloadReadHandle": { "description": "gdata", "format": "byte", "type": "string" }, "readToken": { "description": "gdata", "type": "string" }, "uploadMetadataContainer": { "description": "gdata", "format": "byte", "type": "string" } }, "id": "GdataBlobstore2Info" }, "ListReportTypesResponse": { "properties": { "reportTypes": { "description": "The list of report types.", "type": "array", "items": { "$ref": "ReportType" } }, "nextPageToken": { "description": "A token to retrieve next page of results.\nPass this value in the\nListReportTypesRequest.page_token\nfield in the subsequent call to `ListReportTypes` method to retrieve the next\npage of results.", "type": "string" } }, "id": "ListReportTypesResponse", "description": "Response message for ReportingService.ListReportTypes.", "type": "object" }, "ReportType": { "type": "object", "properties": { "name": { "description": "The name of the report type (max. 100 characters).", "type": "string" }, "id": { "description": "The ID of the report type (max. 100 characters).", "type": "string" }, "systemManaged": { "type": "boolean", "description": "True if this a system-managed report type; otherwise false. Reporting jobs\nfor system-managed report types are created automatically and can thus not\nbe used in the `CreateJob` method." }, "deprecateTime": { "description": "The date/time when this report type was/will be deprecated.", "format": "google-datetime", "type": "string" } }, "id": "ReportType", "description": "A report type." }, "Empty": { "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.", "type": "object", "properties": {}, "id": "Empty" }, "ListJobsResponse": { "description": "Response message for ReportingService.ListJobs.", "type": "object", "properties": { "jobs": { "description": "The list of jobs.", "type": "array", "items": { "$ref": "Job" } }, "nextPageToken": { "type": "string", "description": "A token to retrieve next page of results.\nPass this value in the\nListJobsRequest.page_token\nfield in the subsequent call to `ListJobs` method to retrieve the next\npage of results." } }, "id": "ListJobsResponse" }, "GdataCompositeMedia": { "description": "gdata", "type": "object", "properties": { "md5Hash": { "description": "gdata", "format": "byte", "type": "string" }, "inline": { "description": "gdata", "format": "byte", "type": "string" }, "blobstore2Info": { "description": "gdata", "$ref": "GdataBlobstore2Info" }, "blobRef": { "description": "gdata", "format": "byte", "type": "string" }, "objectId": { "$ref": "GdataObjectId", "description": "gdata" }, "crc32cHash": { "description": "gdata", "format": "uint32", "type": "integer" }, "sha1Hash": { "description": "gdata", "format": "byte", "type": "string" }, "path": { "type": "string", "description": "gdata" }, "length": { "type": "string", "description": "gdata", "format": "int64" }, "cosmoBinaryReference": { "description": "gdata", "format": "byte", "type": "string" }, "referenceType": { "enumDescriptions": ["gdata", "gdata", "gdata", "gdata", "gdata"], "enum": ["PATH", "BLOB_REF", "INLINE", "BIGSTORE_REF", "COSMO_BINARY_REFERENCE"], "description": "gdata", "type": "string" } }, "id": "GdataCompositeMedia" }, "ListReportsResponse": { "description": "Response message for ReportingService.ListReports.", "type": "object", "properties": { "nextPageToken": { "description": "A token to retrieve next page of results.\nPass this value in the\nListReportsRequest.page_token\nfield in the subsequent call to `ListReports` method to retrieve the next\npage of results.", "type": "string" }, "reports": { "description": "The list of report types.", "type": "array", "items": { "$ref": "Report" } } }, "id": "ListReportsResponse" } }, "icons": { "x32": "http://www.google.com/images/icons/product/search-32.gif", "x16": "http://www.google.com/images/icons/product/search-16.gif" }, "protocol": "rest", "version": "v1", "baseUrl": "https://youtubereporting.googleapis.com/", "canonicalName": "YouTube Reporting", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/yt-analytics.readonly": { "description": "View YouTube Analytics reports for your YouTube content" }, "https://www.googleapis.com/auth/yt-analytics-monetary.readonly": { "description": "View monetary and non-monetary YouTube Analytics reports for your YouTube content" } } } }, "kind": "discovery#restDescription", "servicePath": "", "description": "Schedules reporting jobs containing your YouTube Analytics data and downloads the resulting bulk data reports in the form of CSV files.", "rootUrl": "https://youtubereporting.googleapis.com/", "basePath": "", "ownerDomain": "google.com", "name": "youtubereporting", "batchPath": "batch", "revision": "20180918", "documentationLink": "https://developers.google.com/youtube/reporting/v1/reports/", "id": "youtubereporting:v1" };
//# sourceMappingURL=youtubereporting-v1.js.map