export default {"discoveryVersion":"v1","version_module":true,"schemas":{"Status":{"properties":{"details":{"description":"A list of messages that carry the error details.  There is a common set of\nmessage types for APIs to use.","type":"array","items":{"additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"type":"object"}},"code":{"description":"The status code, which should be an enum value of google.rpc.Code.","format":"int32","type":"integer"},"message":{"description":"A developer-facing error message, which should be in English. Any\nuser-facing error message should be localized and sent in the\ngoogle.rpc.Status.details field, or localized by the client.","type":"string"}},"id":"Status","description":"The `Status` type defines a logical error model that is suitable for different\nprogramming environments, including REST APIs and RPC APIs. It is used by\n[gRPC](https://github.com/grpc). The error model is designed to be:\n\n- Simple to use and understand for most users\n- Flexible enough to meet unexpected needs\n\n# Overview\n\nThe `Status` message contains three pieces of data: error code, error message,\nand error details. The error code should be an enum value of\ngoogle.rpc.Code, but it may accept additional error codes if needed.  The\nerror message should be a developer-facing English message that helps\ndevelopers *understand* and *resolve* the error. If a localized user-facing\nerror message is needed, put the localized message in the error details or\nlocalize it in the client. The optional error details may contain arbitrary\ninformation about the error. There is a predefined set of error detail types\nin the package `google.rpc` that can be used for common error conditions.\n\n# Language mapping\n\nThe `Status` message is the logical representation of the error model, but it\nis not necessarily the actual wire format. When the `Status` message is\nexposed in different client libraries and different wire protocols, it can be\nmapped differently. For example, it will likely be mapped to some exceptions\nin Java, but more likely mapped to some error codes in C.\n\n# Other uses\n\nThe error model and the `Status` message can be used in a variety of\nenvironments, either with or without APIs, to provide a\nconsistent developer experience across different environments.\n\nExample uses of this error model include:\n\n- Partial errors. If a service needs to return partial errors to the client,\n    it may embed the `Status` in the normal response to indicate the partial\n    errors.\n\n- Workflow errors. A typical workflow has multiple steps. Each step may\n    have a `Status` message for error reporting.\n\n- Batch operations. If a client uses batch request and batch response, the\n    `Status` message should be used directly inside batch response, one for\n    each error sub-response.\n\n- Asynchronous operations. If an API call embeds asynchronous operation\n    results in its response, the status of those operations should be\n    represented directly using the `Status` message.\n\n- Logging. If some API errors are stored in logs, the message `Status` could\n    be used directly after any stripping needed for security/privacy reasons.","type":"object"},"EnvironmentConfig":{"description":"Configuration information for an environment.","type":"object","properties":{"dagGcsPrefix":{"description":"Output only.\nThe Cloud Storage prefix of the DAGs for this environment. Although Cloud\nStorage objects reside in a flat namespace, a hierarchical file tree\ncan be simulated using \"/\"-delimited object name prefixes. DAG objects for\nthis environment reside in a simulated directory with the given prefix.","type":"string"},"gkeCluster":{"description":"Output only.\nThe Kubernetes Engine cluster used to run this environment.","type":"string"},"nodeConfig":{"$ref":"NodeConfig","description":"The configuration used for the Kubernetes Engine cluster."},"airflowUri":{"description":"The URI of the Apache Airflow Web UI hosted within this environment (see\n[Airflow web interface](/composer/docs/how-to/accessing/airflow-web-interface)).","type":"string"},"softwareConfig":{"description":"The configuration settings for software inside the environment.","$ref":"SoftwareConfig"},"nodeCount":{"description":"The number of nodes in the Kubernetes Engine cluster that will be\nused to run this environment.","format":"int32","type":"integer"}},"id":"EnvironmentConfig"},"Empty":{"description":"A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.","type":"object","properties":{},"id":"Empty"},"ListEnvironmentsResponse":{"description":"The environments in a project and location.","type":"object","properties":{"nextPageToken":{"description":"The page token used to query for the next page if one exists.","type":"string"},"environments":{"description":"The list of environments returned by a ListEnvironmentsRequest.","type":"array","items":{"$ref":"Environment"}}},"id":"ListEnvironmentsResponse"},"ListOperationsResponse":{"description":"The response message for Operations.ListOperations.","type":"object","properties":{"nextPageToken":{"description":"The standard List next-page token.","type":"string"},"operations":{"description":"A list of operations that matches the specified filter in the request.","type":"array","items":{"$ref":"Operation"}}},"id":"ListOperationsResponse"},"Operation":{"description":"This resource represents a long-running operation that is the result of a\nnetwork API call.","type":"object","properties":{"error":{"description":"The error result of the operation in case of failure or cancellation.","$ref":"Status"},"metadata":{"description":"Service-specific metadata associated with the operation.  It typically\ncontains progress information and common metadata such as create time.\nSome services might not provide such metadata.  Any method that returns a\nlong-running operation should document the metadata type, if any.","type":"object","additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"}},"done":{"description":"If the value is `false`, it means the operation is still in progress.\nIf `true`, the operation is completed, and either `error` or `response` is\navailable.","type":"boolean"},"response":{"additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"description":"The normal response of the operation in case of success.  If the original\nmethod returns no data on success, such as `Delete`, the response is\n`google.protobuf.Empty`.  If the original method is standard\n`Get`/`Create`/`Update`, the response should be the resource.  For other\nmethods, the response should have the type `XxxResponse`, where `Xxx`\nis the original method name.  For example, if the original method name\nis `TakeSnapshot()`, the inferred response type is\n`TakeSnapshotResponse`.","type":"object"},"name":{"description":"The server-assigned name, which is only unique within the same service that\noriginally returns it. If you use the default HTTP mapping, the\n`name` should have the format of `operations/some/unique/name`.","type":"string"}},"id":"Operation"},"Environment":{"description":"An environment for running orchestration tasks.","type":"object","properties":{"labels":{"additionalProperties":{"type":"string"},"description":"Optional. User-defined labels for this environment.\nThe labels map can contain no more than 64 entries. Entries of the labels\nmap are UTF8 strings that comply with the following restrictions:\n\n* Keys must conform to regexp: \\p{Ll}\\p{Lo}{0,62}\n* Values must conform to regexp:  [\\p{Ll}\\p{Lo}\\p{N}_-]{0,63}\n* Both keys and values are additionally constrained to be <= 128 bytes in\nsize.","type":"object"},"createTime":{"description":"Output only.\nThe time at which this environment was created.","format":"google-datetime","type":"string"},"updateTime":{"description":"Output only.\nThe time at which this environment was last modified.","format":"google-datetime","type":"string"},"config":{"$ref":"EnvironmentConfig","description":"Configuration parameters for this environment."},"state":{"enumDescriptions":["The state of the environment is unknown.","The environment is in the process of being created.","The environment is currently running and healthy. It is ready for use.","The environment is being updated. It remains usable but cannot receive\nadditional update requests or be deleted at this time.","The environment is undergoing deletion. It cannot be used.","The environment has encountered an error and cannot be used."],"enum":["STATE_UNSPECIFIED","CREATING","RUNNING","UPDATING","DELETING","ERROR"],"description":"The current state of the environment.","type":"string"},"name":{"description":"The resource name of the environment, in the form:\n\"projects/{projectId}/locations/{locationId}/environments/{environmentId}\"","type":"string"},"uuid":{"description":"Output only.\nThe UUID (Universally Unique IDentifier) associated with this environment.\nThis value is generated when the environment is created.","type":"string"}},"id":"Environment"},"OperationMetadata":{"description":"Metadata describing an operation.","type":"object","properties":{"endTime":{"description":"Output only.\nThe time when the operation terminated, regardless of its success.\nThis field is unset if the operation is still ongoing.","format":"google-datetime","type":"string"},"operationType":{"enumDescriptions":["Unused.","A resource creation operation.","A resource deletion operation.","A resource update operation."],"enum":["TYPE_UNSPECIFIED","CREATE","DELETE","UPDATE"],"description":"Output only.\nThe type of operation being performed.","type":"string"},"createTime":{"description":"Output only.\nThe time the operation was submitted to the server.","format":"google-datetime","type":"string"},"resource":{"description":"Output only.\nThe resource being operated on, as a [relative resource name](\n/apis/design/resource_names#relative_resource_name).","type":"string"},"state":{"enumDescriptions":["Unused.","The operation has been created but is not yet started.","The operation is underway.","The operation completed successfully.","","The operation is no longer running but did not succeed."],"enum":["STATE_UNSPECIFIED","PENDING","RUNNING","SUCCEEDED","SUCCESSFUL","FAILED"],"description":"Output only.\nThe current operation state.","type":"string"},"resourceUuid":{"description":"Output only.\nThe UUID of the resource being operated on.","type":"string"}},"id":"OperationMetadata"},"SoftwareConfig":{"description":"Specifies the selection and configuration of software inside the environment.","type":"object","properties":{"pypiPackages":{"additionalProperties":{"type":"string"},"description":"Optional. Custom Python Package Index (PyPI) packages to be installed in\nthe environment.\n\nKeys refer to the lowercase package name such as \"numpy\"\nand values are the lowercase extras and version specifier such as\n\"==1.12.0\", \"[devel,gcp_api]\", or \"[devel]>=1.8.2, <1.9.2\". To specify a\npackage without pinning it to a version specifier, use the empty string as\nthe value.","type":"object"},"imageVersion":{"description":"Output only.\nThe version of the software running in the environment.\nThis encapsulates both the version of Cloud Composer functionality and the\nversion of Apache Airflow. It must match the regular expression\n`composer-[0-9]+\\.[0-9]+(\\.[0-9]+)?-airflow-[0-9]+\\.[0-9]+(\\.[0-9]+.*)?`.\n\nThe Cloud Composer portion of the version is a\n[semantic version](https://semver.org). The portion of the image version\nfollowing _airflow-_ is an official Apache Airflow repository\n[release name](https://github.com/apache/incubator-airflow/releases).\n\nSee also [Release Notes](/composer/docs/release-notes).","type":"string"},"airflowConfigOverrides":{"description":"Optional. Apache Airflow configuration properties to override.\n\nProperty keys contain the section and property names, separated by a hyphen,\nfor example \"core-dags_are_paused_at_creation\". Section names must not\ncontain hyphens (\"-\"), opening square brackets (\"[\"),  or closing square\nbrackets (\"]\"). The property name must not be empty and must not contain\nan equals sign (\"=\") or semicolon (\";\"). Section and property names must\nnot contain a period (\".\"). Apache Airflow configuration property names\nmust be written in [snake_case](https://en.wikipedia.org/wiki/Snake_case).\nProperty values can contain any character, and can be written in any\nlower/upper case format.\n\nCertain Apache Airflow configuration property values are\n[blacklisted](/composer/docs/how-to/managing/setting-airflow-configurations#airflow_configuration_blacklists),\nand cannot be overridden.","type":"object","additionalProperties":{"type":"string"}},"envVariables":{"additionalProperties":{"type":"string"},"description":"Optional. Additional environment variables to provide to the Apache Airflow\nscheduler, worker, and webserver processes.\n\nEnvironment variable names must match the regular expression\n`a-zA-Z_*`. They cannot specify Apache Airflow\nsoftware configuration overrides (they cannot match the regular expression\n`AIRFLOW__[A-Z0-9_]+__[A-Z0-9_]+`), and they cannot match any of the\nfollowing reserved names:\n\n* `AIRFLOW_HOME`\n* `C_FORCE_ROOT`\n* `CONTAINER_NAME`\n* `DAGS_FOLDER`\n* `GCP_PROJECT`\n* `GCS_BUCKET`\n* `GKE_CLUSTER_NAME`\n* `SQL_DATABASE`\n* `SQL_INSTANCE`\n* `SQL_PASSWORD`\n* `SQL_PROJECT`\n* `SQL_REGION`\n* `SQL_USER`","type":"object"}},"id":"SoftwareConfig"},"NodeConfig":{"description":"The configuration information for the Kubernetes Engine nodes running\nthe Apache Airflow software.","type":"object","properties":{"serviceAccount":{"description":"Optional. The Google Cloud Platform Service Account to be used by the node\nVMs. If a service account is not specified, the \"default\" Compute Engine\nservice account is used. Cannot be updated.","type":"string"},"location":{"description":"Optional. The Compute Engine [zone](/compute/docs/regions-zones) in which\nto deploy the VMs used to run the Apache Airflow software, specified as a\n[relative resource name](/apis/design/resource_names#relative_resource_name).\nFor example: \"projects/{projectId}/zones/{zoneId}\".\n\nThis `location` must belong to the enclosing environment's project and\nlocation. If both this field and `nodeConfig.machineType` are specified,\n`nodeConfig.machineType` must belong to this `location`; if both are\nunspecified, the service will pick a zone in the Compute Engine region\ncorresponding to the Cloud Composer location, and propagate that choice to\nboth fields. If only one field (`location` or `nodeConfig.machineType`) is\nspecified, the location information from the specified field will be\npropagated to the unspecified field.","type":"string"},"machineType":{"description":"Optional. The Compute Engine\n[machine type](/compute/docs/machine-types) used for cluster instances,\nspecified as a\n[relative resource name](/apis/design/resource_names#relative_resource_name).\nFor example:\n\"projects/{projectId}/zones/{zoneId}/machineTypes/{machineTypeId}\".\n\nThe `machineType` must belong to the enclosing environment's project and\nlocation. If both this field and `nodeConfig.location` are specified,\nthis `machineType` must belong to the `nodeConfig.location`; if both are\nunspecified, the service will pick a zone in the Compute Engine region\ncorresponding to the Cloud Composer location, and propagate that choice to\nboth fields. If exactly one of this field and `nodeConfig.location` is\nspecified, the location information from the specified field will be\npropagated to the unspecified field.\n\nIf this field is unspecified, the `machineTypeId` defaults\nto \"n1-standard-1\".","type":"string"},"network":{"description":"Optional. The Compute Engine network to be used for machine\ncommunications, specified as a\n[relative resource name](/apis/design/resource_names#relative_resource_name).\nFor example: \"projects/{projectId}/global/networks/{networkId}\".\n\n[Shared VPC](/vpc/docs/shared-vpc) is not currently supported. The\nnetwork must belong to the environment's project. If unspecified, the\n\"default\" network ID in the environment's project is used.  If a\n[Custom Subnet Network](/vpc/docs/vpc#vpc_networks_and_subnets)\nis provided, `nodeConfig.subnetwork` must also be provided.","type":"string"},"oauthScopes":{"description":"Optional. The set of Google API scopes to be made available on all\nnode VMs. If `oauth_scopes` is empty, defaults to\n[\"https://www.googleapis.com/auth/cloud-platform\"]. Cannot be updated.","type":"array","items":{"type":"string"}},"subnetwork":{"description":"Optional. The Compute Engine subnetwork to be used for machine\ncommunications, specified as a\n[relative resource name](/apis/design/resource_names#relative_resource_name).\nFor example:\n\"projects/{projectId}/regions/{regionId}/subnetworks/{subnetworkId}\"\n\nIf a subnetwork is provided, `nodeConfig.network` must also be provided,\nand the subnetwork must belong to the enclosing environment's project and\nlocation.","type":"string"},"diskSizeGb":{"description":"Optional. The disk size in GB used for node VMs. Minimum size is 20GB.\nIf unspecified, defaults to 100GB. Cannot be updated.","format":"int32","type":"integer"},"tags":{"description":"Optional. The list of instance tags applied to all node VMs. Tags are used\nto identify valid sources or targets for network firewalls. Each tag within\nthe list must comply with [RFC1035](https://www.ietf.org/rfc/rfc1035.txt).\nCannot be updated.","type":"array","items":{"type":"string"}}},"id":"NodeConfig"}},"protocol":"rest","icons":{"x32":"http://www.google.com/images/icons/product/search-32.gif","x16":"http://www.google.com/images/icons/product/search-16.gif"},"canonicalName":"Cloud Composer","auth":{"oauth2":{"scopes":{"https://www.googleapis.com/auth/cloud-platform":{"description":"View and manage your data across Google Cloud Platform services"}}}},"rootUrl":"https://composer.googleapis.com/","ownerDomain":"google.com","name":"composer","batchPath":"batch","fullyEncodeReservedExpansion":true,"title":"Cloud Composer API","ownerName":"Google","resources":{"projects":{"resources":{"locations":{"resources":{"environments":{"methods":{"create":{"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/environments","id":"composer.projects.locations.environments.create","path":"v1/{+parent}/environments","description":"Create a new environment.","request":{"$ref":"Environment"},"httpMethod":"POST","parameterOrder":["parent"],"response":{"$ref":"Operation"},"parameters":{"parent":{"description":"The parent must be of the form \"projects/{projectId}/locations/{locationId}\".","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"]},"delete":{"id":"composer.projects.locations.environments.delete","path":"v1/{+name}","description":"Delete an environment.","httpMethod":"DELETE","response":{"$ref":"Operation"},"parameterOrder":["name"],"parameters":{"name":{"pattern":"^projects/[^/]+/locations/[^/]+/environments/[^/]+$","location":"path","description":"The environment to delete, in the form:\n\"projects/{projectId}/locations/{locationId}/environments/{environmentId}\"","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/environments/{environmentsId}"},"get":{"response":{"$ref":"Environment"},"parameterOrder":["name"],"httpMethod":"GET","parameters":{"name":{"pattern":"^projects/[^/]+/locations/[^/]+/environments/[^/]+$","location":"path","description":"The resource name of the environment to get, in the form:\n\"projects/{projectId}/locations/{locationId}/environments/{environmentId}\"","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/environments/{environmentsId}","path":"v1/{+name}","id":"composer.projects.locations.environments.get","description":"Get an existing environment."},"list":{"httpMethod":"GET","parameterOrder":["parent"],"response":{"$ref":"ListEnvironmentsResponse"},"parameters":{"pageToken":{"location":"query","description":"The next_page_token value returned from a previous List request, if any.","type":"string"},"pageSize":{"description":"The maximum number of environments to return.","format":"int32","type":"integer","location":"query"},"parent":{"location":"path","description":"List environments in the given project and location, in the form:\n\"projects/{projectId}/locations/{locationId}\"","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/environments","id":"composer.projects.locations.environments.list","path":"v1/{+parent}/environments","description":"List environments."},"patch":{"response":{"$ref":"Operation"},"parameterOrder":["name"],"httpMethod":"PATCH","parameters":{"updateMask":{"location":"query","description":"Required. A comma-separated list of paths, relative to `Environment`, of\nfields to update.\nFor example, to set the version of scikit-learn to install in the\nenvironment to 0.19.0 and to remove an existing installation of\nnumpy, the `updateMask` parameter would include the following two\n`paths` values: \"config.softwareConfig.pypiPackages.scikit-learn\" and\n\"config.softwareConfig.pypiPackages.numpy\". The included patch\nenvironment would specify the scikit-learn version as follows:\n\n    {\n      \"config\":{\n        \"softwareConfig\":{\n          \"pypiPackages\":{\n            \"scikit-learn\":\"==0.19.0\"\n          }\n        }\n      }\n    }\n\nNote that in the above example, any existing PyPI packages\nother than scikit-learn and numpy will be unaffected.\n\nOnly one update type may be included in a single request's `updateMask`.\nFor example, one cannot update both the PyPI packages and\nlabels in the same request. However, it is possible to update multiple\nmembers of a map field simultaneously in the same request. For example,\nto set the labels \"label1\" and \"label2\" while clearing \"label3\" (assuming\nit already exists), one can\nprovide the paths \"labels.label1\", \"labels.label2\", and \"labels.label3\"\nand populate the patch environment as follows:\n\n    {\n      \"labels\":{\n        \"label1\":\"new-label1-value\"\n        \"label2\":\"new-label2-value\"\n      }\n    }\n\nNote that in the above example, any existing labels that are not\nincluded in the `updateMask` will be unaffected.\n\nIt is also possible to replace an entire map field by providing the\nmap field's path in the `updateMask`. The new value of the field will\nbe that which is provided in the patch environment. For example, to\ndelete all pre-existing user-specified PyPI packages and\ninstall botocore at version 1.7.14, the `updateMask` would contain\nthe path \"config.softwareConfig.pypiPackages\", and\nthe patch environment would be the following:\n\n    {\n      \"config\":{\n        \"softwareConfig\":{\n          \"pypiPackages\":{\n            \"botocore\":\"==1.7.14\"\n          }\n        }\n      }\n    }\n\n**Note:** Only the following fields can be updated:\n\n <table>\n <tbody>\n <tr>\n <td><strong>Mask</strong></td>\n <td><strong>Purpose</strong></td>\n </tr>\n <tr>\n <td>config.softwareConfig.pypiPackages\n </td>\n <td>Replace all custom custom PyPI packages. If a replacement\n package map is not included in `environment`, all custom\n PyPI packages are cleared. It is an error to provide both this mask and a\n mask specifying an individual package.</td>\n </tr>\n <tr>\n <td>config.softwareConfig.pypiPackages.<var>packagename</var></td>\n <td>Update the custom PyPI package <var>packagename</var>,\n preserving other packages. To delete the package, include it in\n `updateMask`, and omit the mapping for it in\n `environment.config.softwareConfig.pypiPackages`. It is an error\n to provide both a mask of this form and the\n \"config.softwareConfig.pypiPackages\" mask.</td>\n </tr>\n <tr>\n <td>labels</td>\n <td>Replace all environment labels. If a replacement labels map is not\n included in `environment`, all labels are cleared. It is an error to\n provide both this mask and a mask specifying one or more individual\n labels.</td>\n </tr>\n <tr>\n <td>labels.<var>labelName</var></td>\n <td>Set the label named <var>labelName</var>, while preserving other\n labels. To delete the label, include it in `updateMask` and omit its\n mapping in `environment.labels`. It is an error to provide both a\n mask of this form and the \"labels\" mask.</td>\n </tr>\n <tr>\n <td>config.nodeCount</td>\n <td>Horizontally scale the number of nodes in the environment. An integer\n greater than or equal to 3 must be provided in the `config.nodeCount` field.\n </td>\n </tr>\n <tr>\n <td>config.softwareConfig.airflowConfigOverrides</td>\n <td>Replace all Apache Airflow config overrides. If a replacement config\n overrides map is not included in `environment`, all config overrides\n are cleared.\n It is an error to provide both this mask and a mask specifying one or\n more individual config overrides.</td>\n </tr>\n <tr>\n <td>config.softwareConfig.airflowConfigOverrides.<var>section</var>-<var>name\n </var></td>\n <td>Override the Apache Airflow config property <var>name</var> in the\n section named <var>section</var>, preserving other properties. To delete\n the property override, include it in `updateMask` and omit its mapping\n in `environment.config.softwareConfig.airflowConfigOverrides`.\n It is an error to provide both a mask of this form and the\n \"config.softwareConfig.airflowConfigOverrides\" mask.</td>\n </tr>\n <tr>\n <td>config.softwareConfig.envVariables</td>\n <td>Replace all environment variables. If a replacement environment\n variable map is not included in `environment`, all custom environment\n variables  are cleared.\n It is an error to provide both this mask and a mask specifying one or\n more individual environment variables.</td>\n </tr>\n </tbody>\n </table>","format":"google-fieldmask","type":"string"},"name":{"description":"The relative resource name of the environment to update, in the form:\n\"projects/{projectId}/locations/{locationId}/environments/{environmentId}\"","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/environments/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/environments/{environmentsId}","path":"v1/{+name}","id":"composer.projects.locations.environments.patch","description":"Update an environment.","request":{"$ref":"Environment"}}}},"operations":{"methods":{"delete":{"id":"composer.projects.locations.operations.delete","path":"v1/{+name}","description":"Deletes a long-running operation. This method indicates that the client is\nno longer interested in the operation result. It does not cancel the\noperation. If the server doesn't support this method, it returns\n`google.rpc.Code.UNIMPLEMENTED`.","httpMethod":"DELETE","response":{"$ref":"Empty"},"parameterOrder":["name"],"parameters":{"name":{"pattern":"^projects/[^/]+/locations/[^/]+/operations/[^/]+$","location":"path","description":"The name of the operation resource to be deleted.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/operations/{operationsId}"},"list":{"httpMethod":"GET","response":{"$ref":"ListOperationsResponse"},"parameterOrder":["name"],"parameters":{"filter":{"location":"query","description":"The standard list filter.","type":"string"},"name":{"pattern":"^projects/[^/]+/locations/[^/]+$","location":"path","description":"The name of the operation's parent resource.","required":true,"type":"string"},"pageToken":{"description":"The standard list page token.","type":"string","location":"query"},"pageSize":{"location":"query","description":"The standard list page size.","format":"int32","type":"integer"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/operations","id":"composer.projects.locations.operations.list","path":"v1/{+name}/operations","description":"Lists operations that match the specified filter in the request. If the\nserver doesn't support this method, it returns `UNIMPLEMENTED`.\n\nNOTE: the `name` binding allows API services to override the binding\nto use different resource name schemes, such as `users/*/operations`. To\noverride the binding, API services can add a binding such as\n`\"/v1/{name=users/*}/operations\"` to their service configuration.\nFor backwards compatibility, the default name includes the operations\ncollection id, however overriding users must ensure the name binding\nis the parent resource, without the operations collection id."},"get":{"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/operations/{operationsId}","path":"v1/{+name}","id":"composer.projects.locations.operations.get","description":"Gets the latest state of a long-running operation.  Clients can use this\nmethod to poll the operation result at intervals as recommended by the API\nservice.","response":{"$ref":"Operation"},"parameterOrder":["name"],"httpMethod":"GET","parameters":{"name":{"pattern":"^projects/[^/]+/locations/[^/]+/operations/[^/]+$","location":"path","description":"The name of the operation resource.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"]}}}}}}}},"parameters":{"upload_protocol":{"description":"Upload protocol for media (e.g. \"raw\", \"multipart\").","type":"string","location":"query"},"prettyPrint":{"description":"Returns response with indentations and line breaks.","type":"boolean","default":"true","location":"query"},"quotaUser":{"description":"Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.","type":"string","location":"query"},"fields":{"location":"query","description":"Selector specifying which fields to include in a partial response.","type":"string"},"uploadType":{"description":"Legacy upload protocol for media (e.g. \"media\", \"multipart\").","type":"string","location":"query"},"$.xgafv":{"enumDescriptions":["v1 error format","v2 error format"],"location":"query","enum":["1","2"],"description":"V1 error format.","type":"string"},"oauth_token":{"location":"query","description":"OAuth 2.0 token for the current user.","type":"string"},"callback":{"location":"query","description":"JSONP","type":"string"},"alt":{"enumDescriptions":["Responses with Content-Type of application/json","Media download with context-dependent Content-Type","Responses with Content-Type of application/x-protobuf"],"location":"query","description":"Data format for response.","default":"json","enum":["json","media","proto"],"type":"string"},"key":{"description":"API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.","type":"string","location":"query"},"access_token":{"description":"OAuth access token.","type":"string","location":"query"}},"version":"v1","baseUrl":"https://composer.googleapis.com/","servicePath":"","description":"Manages Apache Airflow environments on Google Cloud Platform.","kind":"discovery#restDescription","basePath":"","id":"composer:v1","documentationLink":"https://cloud.google.com/composer/","revision":"20180915"};