export default {"basePath":"","id":"firestore:v1","documentationLink":"https://cloud.google.com/firestore","revision":"20180910","discoveryVersion":"v1","version_module":true,"schemas":{"GoogleLongrunningOperation":{"description":"This resource represents a long-running operation that is the result of a\nnetwork API call.","type":"object","properties":{"name":{"type":"string","description":"The server-assigned name, which is only unique within the same service that\noriginally returns it. If you use the default HTTP mapping, the\n`name` should have the format of `operations/some/unique/name`."},"error":{"description":"The error result of the operation in case of failure or cancellation.","$ref":"Status"},"metadata":{"additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"description":"Service-specific metadata associated with the operation.  It typically\ncontains progress information and common metadata such as create time.\nSome services might not provide such metadata.  Any method that returns a\nlong-running operation should document the metadata type, if any.","type":"object"},"done":{"description":"If the value is `false`, it means the operation is still in progress.\nIf `true`, the operation is completed, and either `error` or `response` is\navailable.","type":"boolean"},"response":{"additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"description":"The normal response of the operation in case of success.  If the original\nmethod returns no data on success, such as `Delete`, the response is\n`google.protobuf.Empty`.  If the original method is standard\n`Get`/`Create`/`Update`, the response should be the resource.  For other\nmethods, the response should have the type `XxxResponse`, where `Xxx`\nis the original method name.  For example, if the original method name\nis `TakeSnapshot()`, the inferred response type is\n`TakeSnapshotResponse`.","type":"object"}},"id":"GoogleLongrunningOperation"},"Status":{"id":"Status","description":"The `Status` type defines a logical error model that is suitable for different\nprogramming environments, including REST APIs and RPC APIs. It is used by\n[gRPC](https://github.com/grpc). The error model is designed to be:\n\n- Simple to use and understand for most users\n- Flexible enough to meet unexpected needs\n\n# Overview\n\nThe `Status` message contains three pieces of data: error code, error message,\nand error details. The error code should be an enum value of\ngoogle.rpc.Code, but it may accept additional error codes if needed.  The\nerror message should be a developer-facing English message that helps\ndevelopers *understand* and *resolve* the error. If a localized user-facing\nerror message is needed, put the localized message in the error details or\nlocalize it in the client. The optional error details may contain arbitrary\ninformation about the error. There is a predefined set of error detail types\nin the package `google.rpc` that can be used for common error conditions.\n\n# Language mapping\n\nThe `Status` message is the logical representation of the error model, but it\nis not necessarily the actual wire format. When the `Status` message is\nexposed in different client libraries and different wire protocols, it can be\nmapped differently. For example, it will likely be mapped to some exceptions\nin Java, but more likely mapped to some error codes in C.\n\n# Other uses\n\nThe error model and the `Status` message can be used in a variety of\nenvironments, either with or without APIs, to provide a\nconsistent developer experience across different environments.\n\nExample uses of this error model include:\n\n- Partial errors. If a service needs to return partial errors to the client,\n    it may embed the `Status` in the normal response to indicate the partial\n    errors.\n\n- Workflow errors. A typical workflow has multiple steps. Each step may\n    have a `Status` message for error reporting.\n\n- Batch operations. If a client uses batch request and batch response, the\n    `Status` message should be used directly inside batch response, one for\n    each error sub-response.\n\n- Asynchronous operations. If an API call embeds asynchronous operation\n    results in its response, the status of those operations should be\n    represented directly using the `Status` message.\n\n- Logging. If some API errors are stored in logs, the message `Status` could\n    be used directly after any stripping needed for security/privacy reasons.","type":"object","properties":{"details":{"description":"A list of messages that carry the error details.  There is a common set of\nmessage types for APIs to use.","type":"array","items":{"additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"type":"object"}},"code":{"description":"The status code, which should be an enum value of google.rpc.Code.","format":"int32","type":"integer"},"message":{"description":"A developer-facing error message, which should be in English. Any\nuser-facing error message should be localized and sent in the\ngoogle.rpc.Status.details field, or localized by the client.","type":"string"}}},"Empty":{"properties":{},"id":"Empty","description":"A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.","type":"object"},"ListLocationsResponse":{"description":"The response message for Locations.ListLocations.","type":"object","properties":{"locations":{"description":"A list of locations that matches the specified filter in the request.","type":"array","items":{"$ref":"Location"}},"nextPageToken":{"type":"string","description":"The standard List next-page token."}},"id":"ListLocationsResponse"},"GoogleLongrunningListOperationsResponse":{"description":"The response message for Operations.ListOperations.","type":"object","properties":{"nextPageToken":{"description":"The standard List next-page token.","type":"string"},"operations":{"description":"A list of operations that matches the specified filter in the request.","type":"array","items":{"$ref":"GoogleLongrunningOperation"}}},"id":"GoogleLongrunningListOperationsResponse"},"Location":{"description":"A resource that represents Google Cloud Platform location.","type":"object","properties":{"name":{"description":"Resource name for the location, which may vary between implementations.\nFor example: `\"projects/example-project/locations/us-east1\"`","type":"string"},"locationId":{"description":"The canonical id for this location. For example: `\"us-east1\"`.","type":"string"},"displayName":{"type":"string","description":"The friendly name for this location, typically a nearby city name.\nFor example, \"Tokyo\"."},"metadata":{"description":"Service-specific metadata. For example the available capacity at the given\nlocation.","type":"object","additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"}},"labels":{"additionalProperties":{"type":"string"},"description":"Cross-service attributes for the location. For example\n\n    {\"cloud.googleapis.com/region\": \"us-east1\"}","type":"object"}},"id":"Location"},"GoogleLongrunningCancelOperationRequest":{"type":"object","properties":{},"id":"GoogleLongrunningCancelOperationRequest","description":"The request message for Operations.CancelOperation."}},"protocol":"rest","icons":{"x32":"http://www.google.com/images/icons/product/search-32.gif","x16":"http://www.google.com/images/icons/product/search-16.gif"},"canonicalName":"Firestore","auth":{"oauth2":{"scopes":{"https://www.googleapis.com/auth/cloud-platform":{"description":"View and manage your data across Google Cloud Platform services"},"https://www.googleapis.com/auth/datastore":{"description":"View and manage your Google Cloud Datastore data"}}}},"rootUrl":"https://firestore.googleapis.com/","ownerDomain":"google.com","name":"firestore","batchPath":"batch","fullyEncodeReservedExpansion":true,"title":"Cloud Firestore API","ownerName":"Google","resources":{"projects":{"resources":{"locations":{"methods":{"list":{"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/datastore"],"parameters":{"name":{"description":"The resource that owns the locations collection, if applicable.","required":true,"type":"string","pattern":"^projects/[^/]+$","location":"path"},"pageToken":{"description":"The standard list page token.","type":"string","location":"query"},"pageSize":{"location":"query","description":"The standard list page size.","format":"int32","type":"integer"},"filter":{"location":"query","description":"The standard list filter.","type":"string"}},"flatPath":"v1/projects/{projectsId}/locations","path":"v1/{+name}/locations","id":"firestore.projects.locations.list","description":"Lists information about the supported locations for this service.","response":{"$ref":"ListLocationsResponse"},"parameterOrder":["name"],"httpMethod":"GET"},"get":{"description":"Gets information about a location.","response":{"$ref":"Location"},"parameterOrder":["name"],"httpMethod":"GET","parameters":{"name":{"description":"Resource name for the location.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/datastore"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}","path":"v1/{+name}","id":"firestore.projects.locations.get"}}},"databases":{"resources":{"operations":{"methods":{"cancel":{"request":{"$ref":"GoogleLongrunningCancelOperationRequest"},"description":"Starts asynchronous cancellation on a long-running operation.  The server\nmakes a best effort to cancel the operation, but success is not\nguaranteed.  If the server doesn't support this method, it returns\n`google.rpc.Code.UNIMPLEMENTED`.  Clients can use\nOperations.GetOperation or\nother methods to check whether the cancellation succeeded or whether the\noperation completed despite cancellation. On successful cancellation,\nthe operation is not deleted; instead, it becomes an operation with\nan Operation.error value with a google.rpc.Status.code of 1,\ncorresponding to `Code.CANCELLED`.","response":{"$ref":"Empty"},"parameterOrder":["name"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/datastore"],"parameters":{"name":{"description":"The name of the operation resource to be cancelled.","required":true,"type":"string","pattern":"^projects/[^/]+/databases/[^/]+/operations/[^/]+$","location":"path"}},"flatPath":"v1/projects/{projectsId}/databases/{databasesId}/operations/{operationsId}:cancel","path":"v1/{+name}:cancel","id":"firestore.projects.databases.operations.cancel"},"delete":{"httpMethod":"DELETE","parameterOrder":["name"],"response":{"$ref":"Empty"},"parameters":{"name":{"description":"The name of the operation resource to be deleted.","required":true,"type":"string","pattern":"^projects/[^/]+/databases/[^/]+/operations/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/datastore"],"flatPath":"v1/projects/{projectsId}/databases/{databasesId}/operations/{operationsId}","id":"firestore.projects.databases.operations.delete","path":"v1/{+name}","description":"Deletes a long-running operation. This method indicates that the client is\nno longer interested in the operation result. It does not cancel the\noperation. If the server doesn't support this method, it returns\n`google.rpc.Code.UNIMPLEMENTED`."},"list":{"id":"firestore.projects.databases.operations.list","path":"v1/{+name}/operations","description":"Lists operations that match the specified filter in the request. If the\nserver doesn't support this method, it returns `UNIMPLEMENTED`.\n\nNOTE: the `name` binding allows API services to override the binding\nto use different resource name schemes, such as `users/*/operations`. To\noverride the binding, API services can add a binding such as\n`\"/v1/{name=users/*}/operations\"` to their service configuration.\nFor backwards compatibility, the default name includes the operations\ncollection id, however overriding users must ensure the name binding\nis the parent resource, without the operations collection id.","httpMethod":"GET","parameterOrder":["name"],"response":{"$ref":"GoogleLongrunningListOperationsResponse"},"parameters":{"name":{"pattern":"^projects/[^/]+/databases/[^/]+$","location":"path","description":"The name of the operation's parent resource.","required":true,"type":"string"},"pageToken":{"description":"The standard list page token.","type":"string","location":"query"},"pageSize":{"description":"The standard list page size.","format":"int32","type":"integer","location":"query"},"filter":{"location":"query","description":"The standard list filter.","type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/datastore"],"flatPath":"v1/projects/{projectsId}/databases/{databasesId}/operations"},"get":{"parameters":{"name":{"description":"The name of the operation resource.","required":true,"type":"string","pattern":"^projects/[^/]+/databases/[^/]+/operations/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/datastore"],"flatPath":"v1/projects/{projectsId}/databases/{databasesId}/operations/{operationsId}","path":"v1/{+name}","id":"firestore.projects.databases.operations.get","description":"Gets the latest state of a long-running operation.  Clients can use this\nmethod to poll the operation result at intervals as recommended by the API\nservice.","response":{"$ref":"GoogleLongrunningOperation"},"parameterOrder":["name"],"httpMethod":"GET"}}}}}}}},"parameters":{"upload_protocol":{"location":"query","description":"Upload protocol for media (e.g. \"raw\", \"multipart\").","type":"string"},"prettyPrint":{"location":"query","description":"Returns response with indentations and line breaks.","type":"boolean","default":"true"},"quotaUser":{"location":"query","description":"Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.","type":"string"},"uploadType":{"location":"query","description":"Legacy upload protocol for media (e.g. \"media\", \"multipart\").","type":"string"},"fields":{"location":"query","description":"Selector specifying which fields to include in a partial response.","type":"string"},"$.xgafv":{"description":"V1 error format.","type":"string","enumDescriptions":["v1 error format","v2 error format"],"location":"query","enum":["1","2"]},"oauth_token":{"description":"OAuth 2.0 token for the current user.","type":"string","location":"query"},"callback":{"location":"query","description":"JSONP","type":"string"},"alt":{"enum":["json","media","proto"],"type":"string","enumDescriptions":["Responses with Content-Type of application/json","Media download with context-dependent Content-Type","Responses with Content-Type of application/x-protobuf"],"location":"query","description":"Data format for response.","default":"json"},"key":{"location":"query","description":"API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.","type":"string"},"access_token":{"location":"query","description":"OAuth access token.","type":"string"}},"version":"v1","baseUrl":"https://firestore.googleapis.com/","servicePath":"","description":"Accesses the NoSQL document database built for automatic scaling, high performance, and ease of application development.\n","kind":"discovery#restDescription"};