export default {"id":"oslogin:v1beta","documentationLink":"https://cloud.google.com/compute/docs/oslogin/rest/","revision":"20180908","discoveryVersion":"v1","version_module":true,"schemas":{"LoginProfile":{"type":"object","properties":{"sshPublicKeys":{"additionalProperties":{"$ref":"SshPublicKey"},"description":"A map from SSH public key fingerprint to the associated key object.","type":"object"},"name":{"type":"string","description":"A unique user ID."},"posixAccounts":{"description":"The list of POSIX accounts associated with the user.","type":"array","items":{"$ref":"PosixAccount"}}},"id":"LoginProfile","description":"The user profile information used for logging in to a virtual machine on\nGoogle Compute Engine."},"Empty":{"description":"A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.","type":"object","properties":{},"id":"Empty"},"SshPublicKey":{"properties":{"key":{"description":"Public key text in SSH format, defined by\n<a href=\"https://www.ietf.org/rfc/rfc4253.txt\" target=\"_blank\">RFC4253</a>\nsection 6.6.","type":"string"},"expirationTimeUsec":{"description":"An expiration time in microseconds since epoch.","format":"int64","type":"string"},"fingerprint":{"description":"Output only. The SHA-256 fingerprint of the SSH public key.","type":"string"}},"id":"SshPublicKey","description":"The SSH public key information associated with a Google account.","type":"object"},"ImportSshPublicKeyResponse":{"description":"A response message for importing an SSH public key.","type":"object","properties":{"loginProfile":{"$ref":"LoginProfile","description":"The login profile information for the user."}},"id":"ImportSshPublicKeyResponse"},"PosixAccount":{"description":"The POSIX account information associated with a Google account.","type":"object","properties":{"gid":{"description":"The default group ID.","format":"int64","type":"string"},"uid":{"description":"The user ID.","format":"int64","type":"string"},"username":{"description":"The username of the POSIX account.","type":"string"},"shell":{"description":"The path to the logic shell for this account.","type":"string"},"homeDirectory":{"description":"The path to the home directory for this account.","type":"string"},"systemId":{"description":"System identifier for which account the username or uid applies to.\nBy default, the empty value is used.","type":"string"},"gecos":{"description":"The GECOS (user information) entry for this account.","type":"string"},"primary":{"description":"Only one POSIX account can be marked as primary.","type":"boolean"},"accountId":{"description":"Output only. A POSIX account identifier.","type":"string"},"operatingSystemType":{"enumDescriptions":["The operating system type associated with the user account information is\nunspecified.","Linux user account information.","Windows user account information."],"enum":["OPERATING_SYSTEM_TYPE_UNSPECIFIED","LINUX","WINDOWS"],"description":"The operating system type where this account applies.","type":"string"}},"id":"PosixAccount"}},"protocol":"rest","icons":{"x16":"http://www.google.com/images/icons/product/search-16.gif","x32":"http://www.google.com/images/icons/product/search-32.gif"},"canonicalName":"Cloud OS Login","auth":{"oauth2":{"scopes":{"https://www.googleapis.com/auth/cloud-platform.read-only":{"description":"View your data across Google Cloud Platform services"},"https://www.googleapis.com/auth/cloud-platform":{"description":"View and manage your data across Google Cloud Platform services"},"https://www.googleapis.com/auth/compute.readonly":{"description":"View your Google Compute Engine resources"},"https://www.googleapis.com/auth/compute":{"description":"View and manage your Google Compute Engine resources"}}}},"rootUrl":"https://oslogin.googleapis.com/","ownerDomain":"google.com","name":"oslogin","batchPath":"batch","fullyEncodeReservedExpansion":true,"title":"Cloud OS Login API","ownerName":"Google","resources":{"users":{"resources":{"sshPublicKeys":{"methods":{"delete":{"flatPath":"v1beta/users/{usersId}/sshPublicKeys/{sshPublicKeysId}","path":"v1beta/{+name}","id":"oslogin.users.sshPublicKeys.delete","description":"Deletes an SSH public key.","response":{"$ref":"Empty"},"parameterOrder":["name"],"httpMethod":"DELETE","parameters":{"name":{"description":"The fingerprint of the public key to update. Public keys are identified by\ntheir SHA-256 fingerprint. The fingerprint of the public key is in format\n`users/{user}/sshPublicKeys/{fingerprint}`.","required":true,"type":"string","pattern":"^users/[^/]+/sshPublicKeys/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/compute"]},"get":{"response":{"$ref":"SshPublicKey"},"parameterOrder":["name"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/compute"],"parameters":{"name":{"pattern":"^users/[^/]+/sshPublicKeys/[^/]+$","location":"path","description":"The fingerprint of the public key to retrieve. Public keys are identified\nby their SHA-256 fingerprint. The fingerprint of the public key is in\nformat `users/{user}/sshPublicKeys/{fingerprint}`.","required":true,"type":"string"}},"flatPath":"v1beta/users/{usersId}/sshPublicKeys/{sshPublicKeysId}","path":"v1beta/{+name}","id":"oslogin.users.sshPublicKeys.get","description":"Retrieves an SSH public key."},"patch":{"path":"v1beta/{+name}","id":"oslogin.users.sshPublicKeys.patch","description":"Updates an SSH public key and returns the profile information. This method\nsupports patch semantics.","request":{"$ref":"SshPublicKey"},"response":{"$ref":"SshPublicKey"},"parameterOrder":["name"],"httpMethod":"PATCH","parameters":{"updateMask":{"description":"Mask to control which fields get updated. Updates all if not present.","format":"google-fieldmask","type":"string","location":"query"},"name":{"location":"path","description":"The fingerprint of the public key to update. Public keys are identified by\ntheir SHA-256 fingerprint. The fingerprint of the public key is in format\n`users/{user}/sshPublicKeys/{fingerprint}`.","required":true,"type":"string","pattern":"^users/[^/]+/sshPublicKeys/[^/]+$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/compute"],"flatPath":"v1beta/users/{usersId}/sshPublicKeys/{sshPublicKeysId}"}}},"projects":{"methods":{"delete":{"response":{"$ref":"Empty"},"parameterOrder":["name"],"httpMethod":"DELETE","parameters":{"name":{"location":"path","description":"A reference to the POSIX account to update. POSIX accounts are identified\nby the project ID they are associated with. A reference to the POSIX\naccount is in format `users/{user}/projects/{project}`.","required":true,"type":"string","pattern":"^users/[^/]+/projects/[^/]+$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/compute"],"flatPath":"v1beta/users/{usersId}/projects/{projectsId}","path":"v1beta/{+name}","id":"oslogin.users.projects.delete","description":"Deletes a POSIX account."}}}},"methods":{"importSshPublicKey":{"response":{"$ref":"ImportSshPublicKeyResponse"},"parameterOrder":["parent"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/compute"],"parameters":{"projectId":{"location":"query","description":"The project ID of the Google Cloud Platform project.","type":"string"},"parent":{"description":"The unique ID for the user in format `users/{user}`.","required":true,"type":"string","pattern":"^users/[^/]+$","location":"path"}},"flatPath":"v1beta/users/{usersId}:importSshPublicKey","path":"v1beta/{+parent}:importSshPublicKey","id":"oslogin.users.importSshPublicKey","request":{"$ref":"SshPublicKey"},"description":"Adds an SSH public key and returns the profile information. Default POSIX\naccount information is set when no username and UID exist as part of the\nlogin profile."},"getLoginProfile":{"description":"Retrieves the profile information used for logging in to a virtual machine\non Google Compute Engine.","response":{"$ref":"LoginProfile"},"parameterOrder":["name"],"httpMethod":"GET","parameters":{"name":{"description":"The unique ID for the user in format `users/{user}`.","required":true,"type":"string","pattern":"^users/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloud-platform.read-only","https://www.googleapis.com/auth/compute","https://www.googleapis.com/auth/compute.readonly"],"flatPath":"v1beta/users/{usersId}/loginProfile","path":"v1beta/{+name}/loginProfile","id":"oslogin.users.getLoginProfile"}}}},"parameters":{"alt":{"type":"string","enumDescriptions":["Responses with Content-Type of application/json","Media download with context-dependent Content-Type","Responses with Content-Type of application/x-protobuf"],"location":"query","description":"Data format for response.","default":"json","enum":["json","media","proto"]},"key":{"type":"string","location":"query","description":"API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token."},"access_token":{"description":"OAuth access token.","type":"string","location":"query"},"upload_protocol":{"description":"Upload protocol for media (e.g. \"raw\", \"multipart\").","type":"string","location":"query"},"prettyPrint":{"location":"query","description":"Returns response with indentations and line breaks.","type":"boolean","default":"true"},"quotaUser":{"location":"query","description":"Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.","type":"string"},"uploadType":{"location":"query","description":"Legacy upload protocol for media (e.g. \"media\", \"multipart\").","type":"string"},"fields":{"location":"query","description":"Selector specifying which fields to include in a partial response.","type":"string"},"$.xgafv":{"enum":["1","2"],"description":"V1 error format.","type":"string","enumDescriptions":["v1 error format","v2 error format"],"location":"query"},"oauth_token":{"location":"query","description":"OAuth 2.0 token for the current user.","type":"string"},"callback":{"location":"query","description":"JSONP","type":"string"}},"version":"v1beta","baseUrl":"https://oslogin.googleapis.com/","kind":"discovery#restDescription","description":"Manages OS login configuration for Google account users.","servicePath":"","basePath":""};