export default {"kind":"discovery#restDescription","description":"Enables client applications to check web resources (most commonly URLs) against Google-generated lists of unsafe web resources.","servicePath":"","rootUrl":"https://safebrowsing.googleapis.com/","basePath":"","ownerDomain":"google.com","name":"safebrowsing","batchPath":"batch","revision":"20180913","id":"safebrowsing:v4","documentationLink":"https://developers.google.com/safe-browsing/","title":"Safe Browsing API","discoveryVersion":"v1","ownerName":"Google","resources":{"threatMatches":{"methods":{"find":{"request":{"$ref":"FindThreatMatchesRequest"},"description":"Finds the threat entries that match the Safe Browsing lists.","response":{"$ref":"FindThreatMatchesResponse"},"parameterOrder":[],"httpMethod":"POST","parameters":{},"flatPath":"v4/threatMatches:find","path":"v4/threatMatches:find","id":"safebrowsing.threatMatches.find"}}},"fullHashes":{"methods":{"find":{"description":"Finds the full hashes that match the requested hash prefixes.","request":{"$ref":"FindFullHashesRequest"},"httpMethod":"POST","parameterOrder":[],"response":{"$ref":"FindFullHashesResponse"},"parameters":{},"flatPath":"v4/fullHashes:find","id":"safebrowsing.fullHashes.find","path":"v4/fullHashes:find"}}},"encodedUpdates":{"methods":{"get":{"description":"","response":{"$ref":"FetchThreatListUpdatesResponse"},"parameterOrder":["encodedRequest"],"httpMethod":"GET","parameters":{"clientId":{"location":"query","description":"A client ID that uniquely identifies the client implementation of the Safe\nBrowsing API.","type":"string"},"clientVersion":{"type":"string","location":"query","description":"The version of the client implementation."},"encodedRequest":{"location":"path","description":"A serialized FetchThreatListUpdatesRequest proto.","format":"byte","required":true,"type":"string"}},"flatPath":"v4/encodedUpdates/{encodedRequest}","path":"v4/encodedUpdates/{encodedRequest}","id":"safebrowsing.encodedUpdates.get"}}},"threatListUpdates":{"methods":{"fetch":{"httpMethod":"POST","parameterOrder":[],"response":{"$ref":"FetchThreatListUpdatesResponse"},"parameters":{},"flatPath":"v4/threatListUpdates:fetch","id":"safebrowsing.threatListUpdates.fetch","path":"v4/threatListUpdates:fetch","description":"Fetches the most recent threat list updates. A client can request updates\nfor multiple lists at once.","request":{"$ref":"FetchThreatListUpdatesRequest"}}}},"threatHits":{"methods":{"create":{"request":{"$ref":"ThreatHit"},"description":"Reports a Safe Browsing threat list hit to Google. Only projects with\nTRUSTED_REPORTER visibility can use this method.","httpMethod":"POST","parameterOrder":[],"response":{"$ref":"Empty"},"parameters":{},"flatPath":"v4/threatHits","id":"safebrowsing.threatHits.create","path":"v4/threatHits"}}},"encodedFullHashes":{"methods":{"get":{"id":"safebrowsing.encodedFullHashes.get","path":"v4/encodedFullHashes/{encodedRequest}","description":"","httpMethod":"GET","response":{"$ref":"FindFullHashesResponse"},"parameterOrder":["encodedRequest"],"parameters":{"clientVersion":{"description":"The version of the client implementation.","type":"string","location":"query"},"encodedRequest":{"location":"path","description":"A serialized FindFullHashesRequest proto.","format":"byte","required":true,"type":"string"},"clientId":{"location":"query","description":"A client ID that (hopefully) uniquely identifies the client implementation\nof the Safe Browsing API.","type":"string"}},"flatPath":"v4/encodedFullHashes/{encodedRequest}"}}},"threatLists":{"methods":{"list":{"description":"Lists the Safe Browsing threat lists available for download.","response":{"$ref":"ListThreatListsResponse"},"parameterOrder":[],"httpMethod":"GET","parameters":{},"flatPath":"v4/threatLists","path":"v4/threatLists","id":"safebrowsing.threatLists.list"}}}},"parameters":{"callback":{"type":"string","location":"query","description":"JSONP"},"oauth_token":{"location":"query","description":"OAuth 2.0 token for the current user.","type":"string"},"$.xgafv":{"description":"V1 error format.","type":"string","enumDescriptions":["v1 error format","v2 error format"],"location":"query","enum":["1","2"]},"alt":{"type":"string","enumDescriptions":["Responses with Content-Type of application/json","Media download with context-dependent Content-Type","Responses with Content-Type of application/x-protobuf"],"location":"query","description":"Data format for response.","default":"json","enum":["json","media","proto"]},"access_token":{"location":"query","description":"OAuth access token.","type":"string"},"key":{"description":"API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.","type":"string","location":"query"},"upload_protocol":{"description":"Upload protocol for media (e.g. \"raw\", \"multipart\").","type":"string","location":"query"},"quotaUser":{"location":"query","description":"Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.","type":"string"},"prettyPrint":{"location":"query","description":"Returns response with indentations and line breaks.","type":"boolean","default":"true"},"fields":{"description":"Selector specifying which fields to include in a partial response.","type":"string","location":"query"},"uploadType":{"location":"query","description":"Legacy upload protocol for media (e.g. \"media\", \"multipart\").","type":"string"}},"schemas":{"ListUpdateRequest":{"description":"A single list update request.","type":"object","properties":{"state":{"description":"The current state of the client for the requested list (the encrypted\nclient state that was received from the last successful list update).","format":"byte","type":"string"},"platformType":{"enum":["PLATFORM_TYPE_UNSPECIFIED","WINDOWS","LINUX","ANDROID","OSX","IOS","ANY_PLATFORM","ALL_PLATFORMS","CHROME"],"description":"The type of platform at risk by entries present in the list.","type":"string","enumDescriptions":["Unknown platform.","Threat posed to Windows.","Threat posed to Linux.","Threat posed to Android.","Threat posed to OS X.","Threat posed to iOS.","Threat posed to at least one of the defined platforms.","Threat posed to all defined platforms.","Threat posed to Chrome."]},"threatType":{"enum":["THREAT_TYPE_UNSPECIFIED","MALWARE","SOCIAL_ENGINEERING","UNWANTED_SOFTWARE","POTENTIALLY_HARMFUL_APPLICATION","SOCIAL_ENGINEERING_INTERNAL","API_ABUSE","MALICIOUS_BINARY","CSD_WHITELIST","CSD_DOWNLOAD_WHITELIST","CLIENT_INCIDENT","CLIENT_INCIDENT_WHITELIST","APK_MALWARE_OFFLINE","SUBRESOURCE_FILTER","SUSPICIOUS","TRICK_TO_BILL"],"description":"The type of threat posed by entries present in the list.","type":"string","enumDescriptions":["Unknown.","Malware threat type.","Social engineering threat type.","Unwanted software threat type.","Potentially harmful application threat type.","Social engineering threat type for internal use.","API abuse threat type.","Malicious binary threat type.","Client side detection whitelist threat type.","Client side download detection whitelist threat type.","Client incident threat type.","Whitelist used when detecting client incident threats.\nThis enum was never launched and should be re-used for the next list.","List used for offline APK checks in PAM.","Patterns to be used for activating the subresource filter. Interstitial\nwill not be shown for patterns from this list.","Entities that are suspected to present a threat.","Trick-to-bill threat list."]},"constraints":{"description":"The constraints associated with this request.","$ref":"Constraints"},"threatEntryType":{"enumDescriptions":["Unspecified.","A URL.","An executable program.","An IP range.","Chrome extension.","Filename.","CERT"],"enum":["THREAT_ENTRY_TYPE_UNSPECIFIED","URL","EXECUTABLE","IP_RANGE","CHROME_EXTENSION","FILENAME","CERT"],"description":"The types of entries present in the list.","type":"string"}},"id":"ListUpdateRequest"},"Constraints":{"description":"The constraints for this update.","type":"object","properties":{"maxUpdateEntries":{"description":"The maximum size in number of entries. The update will not contain more\nentries than this value.  This should be a power of 2 between 2**10 and\n2**20.  If zero, no update size limit is set.","format":"int32","type":"integer"},"language":{"description":"Requests the lists for a specific language. Expects ISO 639 alpha-2\nformat.","type":"string"},"region":{"description":"Requests the list for a specific geographic location. If not set the\nserver may pick that value based on the user's IP address. Expects ISO\n3166-1 alpha-2 format.","type":"string"},"supportedCompressions":{"description":"The compression types supported by the client.","type":"array","items":{"type":"string","enum":["COMPRESSION_TYPE_UNSPECIFIED","RAW","RICE"]},"enumDescriptions":["Unknown.","Raw, uncompressed data.","Rice-Golomb encoded data."]},"maxDatabaseEntries":{"description":"Sets the maximum number of entries that the client is willing to have\nin the local database. This should be a power of 2 between 2**10 and\n2**20. If zero, no database size limit is set.","format":"int32","type":"integer"},"deviceLocation":{"description":"A client's physical location, expressed as a ISO 31166-1 alpha-2\nregion code.","type":"string"}},"id":"Constraints"},"ListThreatListsResponse":{"type":"object","properties":{"threatLists":{"type":"array","items":{"$ref":"ThreatListDescriptor"},"description":"The lists available for download by the client."}},"id":"ListThreatListsResponse"},"RiceDeltaEncoding":{"description":"The Rice-Golomb encoded data. Used for sending compressed 4-byte hashes or\ncompressed removal indices.","type":"object","properties":{"firstValue":{"description":"The offset of the first entry in the encoded data, or, if only a single\ninteger was encoded, that single integer's value. If the field is empty or\nmissing, assume zero.","format":"int64","type":"string"},"encodedData":{"description":"The encoded deltas that are encoded using the Golomb-Rice coder.","format":"byte","type":"string"},"numEntries":{"description":"The number of entries that are delta encoded in the encoded data. If only a\nsingle integer was encoded, this will be zero and the single value will be\nstored in `first_value`.","format":"int32","type":"integer"},"riceParameter":{"description":"The Golomb-Rice parameter, which is a number between 2 and 28. This field\nis missing (that is, zero) if `num_entries` is zero.","format":"int32","type":"integer"}},"id":"RiceDeltaEncoding"},"FindThreatMatchesResponse":{"type":"object","properties":{"matches":{"description":"The threat list matches.","type":"array","items":{"$ref":"ThreatMatch"}}},"id":"FindThreatMatchesResponse"},"ThreatListDescriptor":{"properties":{"platformType":{"enumDescriptions":["Unknown platform.","Threat posed to Windows.","Threat posed to Linux.","Threat posed to Android.","Threat posed to OS X.","Threat posed to iOS.","Threat posed to at least one of the defined platforms.","Threat posed to all defined platforms.","Threat posed to Chrome."],"enum":["PLATFORM_TYPE_UNSPECIFIED","WINDOWS","LINUX","ANDROID","OSX","IOS","ANY_PLATFORM","ALL_PLATFORMS","CHROME"],"description":"The platform type targeted by the list's entries.","type":"string"},"threatType":{"type":"string","enumDescriptions":["Unknown.","Malware threat type.","Social engineering threat type.","Unwanted software threat type.","Potentially harmful application threat type.","Social engineering threat type for internal use.","API abuse threat type.","Malicious binary threat type.","Client side detection whitelist threat type.","Client side download detection whitelist threat type.","Client incident threat type.","Whitelist used when detecting client incident threats.\nThis enum was never launched and should be re-used for the next list.","List used for offline APK checks in PAM.","Patterns to be used for activating the subresource filter. Interstitial\nwill not be shown for patterns from this list.","Entities that are suspected to present a threat.","Trick-to-bill threat list."],"enum":["THREAT_TYPE_UNSPECIFIED","MALWARE","SOCIAL_ENGINEERING","UNWANTED_SOFTWARE","POTENTIALLY_HARMFUL_APPLICATION","SOCIAL_ENGINEERING_INTERNAL","API_ABUSE","MALICIOUS_BINARY","CSD_WHITELIST","CSD_DOWNLOAD_WHITELIST","CLIENT_INCIDENT","CLIENT_INCIDENT_WHITELIST","APK_MALWARE_OFFLINE","SUBRESOURCE_FILTER","SUSPICIOUS","TRICK_TO_BILL"],"description":"The threat type posed by the list's entries."},"threatEntryType":{"type":"string","enumDescriptions":["Unspecified.","A URL.","An executable program.","An IP range.","Chrome extension.","Filename.","CERT"],"enum":["THREAT_ENTRY_TYPE_UNSPECIFIED","URL","EXECUTABLE","IP_RANGE","CHROME_EXTENSION","FILENAME","CERT"],"description":"The entry types contained in the list."}},"id":"ThreatListDescriptor","description":"Describes an individual threat list. A list is defined by three parameters:\nthe type of threat posed, the type of platform targeted by the threat, and\nthe type of entries in the list.","type":"object"},"ClientInfo":{"description":"The client metadata associated with Safe Browsing API requests.","type":"object","properties":{"clientVersion":{"type":"string","description":"The version of the client implementation."},"clientId":{"description":"A client ID that (hopefully) uniquely identifies the client implementation\nof the Safe Browsing API.","type":"string"}},"id":"ClientInfo"},"ThreatInfo":{"id":"ThreatInfo","description":"The information regarding one or more threats that a client submits when\nchecking for matches in threat lists.","type":"object","properties":{"threatEntryTypes":{"description":"The entry types to be checked.","type":"array","items":{"enum":["THREAT_ENTRY_TYPE_UNSPECIFIED","URL","EXECUTABLE","IP_RANGE","CHROME_EXTENSION","FILENAME","CERT"],"type":"string"},"enumDescriptions":["Unspecified.","A URL.","An executable program.","An IP range.","Chrome extension.","Filename.","CERT"]},"threatTypes":{"enumDescriptions":["Unknown.","Malware threat type.","Social engineering threat type.","Unwanted software threat type.","Potentially harmful application threat type.","Social engineering threat type for internal use.","API abuse threat type.","Malicious binary threat type.","Client side detection whitelist threat type.","Client side download detection whitelist threat type.","Client incident threat type.","Whitelist used when detecting client incident threats.\nThis enum was never launched and should be re-used for the next list.","List used for offline APK checks in PAM.","Patterns to be used for activating the subresource filter. Interstitial\nwill not be shown for patterns from this list.","Entities that are suspected to present a threat.","Trick-to-bill threat list."],"description":"The threat types to be checked.","type":"array","items":{"enum":["THREAT_TYPE_UNSPECIFIED","MALWARE","SOCIAL_ENGINEERING","UNWANTED_SOFTWARE","POTENTIALLY_HARMFUL_APPLICATION","SOCIAL_ENGINEERING_INTERNAL","API_ABUSE","MALICIOUS_BINARY","CSD_WHITELIST","CSD_DOWNLOAD_WHITELIST","CLIENT_INCIDENT","CLIENT_INCIDENT_WHITELIST","APK_MALWARE_OFFLINE","SUBRESOURCE_FILTER","SUSPICIOUS","TRICK_TO_BILL"],"type":"string"}},"platformTypes":{"type":"array","items":{"type":"string","enum":["PLATFORM_TYPE_UNSPECIFIED","WINDOWS","LINUX","ANDROID","OSX","IOS","ANY_PLATFORM","ALL_PLATFORMS","CHROME"]},"enumDescriptions":["Unknown platform.","Threat posed to Windows.","Threat posed to Linux.","Threat posed to Android.","Threat posed to OS X.","Threat posed to iOS.","Threat posed to at least one of the defined platforms.","Threat posed to all defined platforms.","Threat posed to Chrome."],"description":"The platform types to be checked."},"threatEntries":{"description":"The threat entries to be checked.","type":"array","items":{"$ref":"ThreatEntry"}}}},"ThreatEntryMetadata":{"properties":{"entries":{"description":"The metadata entries.","type":"array","items":{"$ref":"MetadataEntry"}}},"id":"ThreatEntryMetadata","description":"The metadata associated with a specific threat entry. The client is expected\nto know the metadata key/value pairs associated with each threat type.","type":"object"},"RawHashes":{"description":"The uncompressed threat entries in hash format of a particular prefix length.\nHashes can be anywhere from 4 to 32 bytes in size. A large majority are 4\nbytes, but some hashes are lengthened if they collide with the hash of a\npopular URL.\n\nUsed for sending ThreatEntrySet to clients that do not support compression,\nor when sending non-4-byte hashes to clients that do support compression.","type":"object","properties":{"rawHashes":{"description":"The hashes, in binary format, concatenated into one long string. Hashes are\nsorted in lexicographic order. For JSON API users, hashes are\nbase64-encoded.","format":"byte","type":"string"},"prefixSize":{"type":"integer","description":"The number of bytes for each prefix encoded below.  This field can be\nanywhere from 4 (shortest prefix) to 32 (full SHA256 hash).","format":"int32"}},"id":"RawHashes"},"Empty":{"description":"A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.","type":"object","properties":{},"id":"Empty"},"FindFullHashesRequest":{"type":"object","properties":{"apiClient":{"$ref":"ClientInfo","description":"Client metadata associated with callers of higher-level APIs built on top\nof the client's implementation."},"clientStates":{"description":"The current client states for each of the client's local threat lists.","type":"array","items":{"format":"byte","type":"string"}},"client":{"$ref":"ClientInfo","description":"The client metadata."},"threatInfo":{"$ref":"ThreatInfo","description":"The lists and hashes to be checked."}},"id":"FindFullHashesRequest","description":"Request to return full hashes matched by the provided hash prefixes."},"FetchThreatListUpdatesRequest":{"description":"Describes a Safe Browsing API update request. Clients can request updates for\nmultiple lists in a single request.\nNOTE: Field index 2 is unused.\nNEXT: 5","type":"object","properties":{"listUpdateRequests":{"type":"array","items":{"$ref":"ListUpdateRequest"},"description":"The requested threat list updates."},"client":{"$ref":"ClientInfo","description":"The client metadata."}},"id":"FetchThreatListUpdatesRequest"},"ListUpdateResponse":{"description":"An update to an individual list.","type":"object","properties":{"platformType":{"description":"The platform type for which data is returned.","type":"string","enumDescriptions":["Unknown platform.","Threat posed to Windows.","Threat posed to Linux.","Threat posed to Android.","Threat posed to OS X.","Threat posed to iOS.","Threat posed to at least one of the defined platforms.","Threat posed to all defined platforms.","Threat posed to Chrome."],"enum":["PLATFORM_TYPE_UNSPECIFIED","WINDOWS","LINUX","ANDROID","OSX","IOS","ANY_PLATFORM","ALL_PLATFORMS","CHROME"]},"threatEntryType":{"enumDescriptions":["Unspecified.","A URL.","An executable program.","An IP range.","Chrome extension.","Filename.","CERT"],"enum":["THREAT_ENTRY_TYPE_UNSPECIFIED","URL","EXECUTABLE","IP_RANGE","CHROME_EXTENSION","FILENAME","CERT"],"description":"The format of the threats.","type":"string"},"additions":{"description":"A set of entries to add to a local threat type's list. Repeated to allow\nfor a combination of compressed and raw data to be sent in a single\nresponse.","type":"array","items":{"$ref":"ThreatEntrySet"}},"responseType":{"enumDescriptions":["Unknown.","Partial updates are applied to the client's existing local database.","Full updates replace the client's entire local database. This means\nthat either the client was seriously out-of-date or the client is\nbelieved to be corrupt."],"enum":["RESPONSE_TYPE_UNSPECIFIED","PARTIAL_UPDATE","FULL_UPDATE"],"description":"The type of response. This may indicate that an action is required by the\nclient when the response is received.","type":"string"},"checksum":{"$ref":"Checksum","description":"The expected SHA256 hash of the client state; that is, of the sorted list\nof all hashes present in the database after applying the provided update.\nIf the client state doesn't match the expected state, the client must\ndisregard this update and retry later."},"threatType":{"description":"The threat type for which data is returned.","type":"string","enumDescriptions":["Unknown.","Malware threat type.","Social engineering threat type.","Unwanted software threat type.","Potentially harmful application threat type.","Social engineering threat type for internal use.","API abuse threat type.","Malicious binary threat type.","Client side detection whitelist threat type.","Client side download detection whitelist threat type.","Client incident threat type.","Whitelist used when detecting client incident threats.\nThis enum was never launched and should be re-used for the next list.","List used for offline APK checks in PAM.","Patterns to be used for activating the subresource filter. Interstitial\nwill not be shown for patterns from this list.","Entities that are suspected to present a threat.","Trick-to-bill threat list."],"enum":["THREAT_TYPE_UNSPECIFIED","MALWARE","SOCIAL_ENGINEERING","UNWANTED_SOFTWARE","POTENTIALLY_HARMFUL_APPLICATION","SOCIAL_ENGINEERING_INTERNAL","API_ABUSE","MALICIOUS_BINARY","CSD_WHITELIST","CSD_DOWNLOAD_WHITELIST","CLIENT_INCIDENT","CLIENT_INCIDENT_WHITELIST","APK_MALWARE_OFFLINE","SUBRESOURCE_FILTER","SUSPICIOUS","TRICK_TO_BILL"]},"newClientState":{"description":"The new client state, in encrypted format. Opaque to clients.","format":"byte","type":"string"},"removals":{"description":"A set of entries to remove from a local threat type's list. In practice,\nthis field is empty or contains exactly one ThreatEntrySet.","type":"array","items":{"$ref":"ThreatEntrySet"}}},"id":"ListUpdateResponse"},"ThreatMatch":{"type":"object","properties":{"threatType":{"enumDescriptions":["Unknown.","Malware threat type.","Social engineering threat type.","Unwanted software threat type.","Potentially harmful application threat type.","Social engineering threat type for internal use.","API abuse threat type.","Malicious binary threat type.","Client side detection whitelist threat type.","Client side download detection whitelist threat type.","Client incident threat type.","Whitelist used when detecting client incident threats.\nThis enum was never launched and should be re-used for the next list.","List used for offline APK checks in PAM.","Patterns to be used for activating the subresource filter. Interstitial\nwill not be shown for patterns from this list.","Entities that are suspected to present a threat.","Trick-to-bill threat list."],"enum":["THREAT_TYPE_UNSPECIFIED","MALWARE","SOCIAL_ENGINEERING","UNWANTED_SOFTWARE","POTENTIALLY_HARMFUL_APPLICATION","SOCIAL_ENGINEERING_INTERNAL","API_ABUSE","MALICIOUS_BINARY","CSD_WHITELIST","CSD_DOWNLOAD_WHITELIST","CLIENT_INCIDENT","CLIENT_INCIDENT_WHITELIST","APK_MALWARE_OFFLINE","SUBRESOURCE_FILTER","SUSPICIOUS","TRICK_TO_BILL"],"description":"The threat type matching this threat.","type":"string"},"threatEntryMetadata":{"$ref":"ThreatEntryMetadata","description":"Optional metadata associated with this threat."},"threat":{"description":"The threat matching this threat.","$ref":"ThreatEntry"},"platformType":{"type":"string","enumDescriptions":["Unknown platform.","Threat posed to Windows.","Threat posed to Linux.","Threat posed to Android.","Threat posed to OS X.","Threat posed to iOS.","Threat posed to at least one of the defined platforms.","Threat posed to all defined platforms.","Threat posed to Chrome."],"enum":["PLATFORM_TYPE_UNSPECIFIED","WINDOWS","LINUX","ANDROID","OSX","IOS","ANY_PLATFORM","ALL_PLATFORMS","CHROME"],"description":"The platform type matching this threat."},"threatEntryType":{"enumDescriptions":["Unspecified.","A URL.","An executable program.","An IP range.","Chrome extension.","Filename.","CERT"],"enum":["THREAT_ENTRY_TYPE_UNSPECIFIED","URL","EXECUTABLE","IP_RANGE","CHROME_EXTENSION","FILENAME","CERT"],"description":"The threat entry type matching this threat.","type":"string"},"cacheDuration":{"description":"The cache lifetime for the returned match. Clients must not cache this\nresponse for more than this duration to avoid false positives.","format":"google-duration","type":"string"}},"id":"ThreatMatch","description":"A match when checking a threat entry in the Safe Browsing threat lists."},"ThreatEntry":{"description":"An individual threat; for example, a malicious URL or its hash\nrepresentation. Only one of these fields should be set.","type":"object","properties":{"digest":{"description":"The digest of an executable in SHA256 format. The API supports both\nbinary and hex digests. For JSON requests, digests are base64-encoded.","format":"byte","type":"string"},"hash":{"description":"A hash prefix, consisting of the most significant 4-32 bytes of a SHA256\nhash. This field is in binary format. For JSON requests, hashes are\nbase64-encoded.","format":"byte","type":"string"},"url":{"description":"A URL.","type":"string"}},"id":"ThreatEntry"},"MetadataEntry":{"description":"A single metadata entry.","type":"object","properties":{"key":{"description":"The metadata entry key. For JSON requests, the key is base64-encoded.","format":"byte","type":"string"},"value":{"description":"The metadata entry value. For JSON requests, the value is base64-encoded.","format":"byte","type":"string"}},"id":"MetadataEntry"},"FindThreatMatchesRequest":{"type":"object","properties":{"client":{"$ref":"ClientInfo","description":"The client metadata."},"threatInfo":{"$ref":"ThreatInfo","description":"The lists and entries to be checked for matches."}},"id":"FindThreatMatchesRequest","description":"Request to check entries against lists."},"RawIndices":{"type":"object","properties":{"indices":{"description":"The indices to remove from a lexicographically-sorted local list.","type":"array","items":{"format":"int32","type":"integer"}}},"id":"RawIndices","description":"A set of raw indices to remove from a local list."},"ThreatSource":{"properties":{"type":{"enumDescriptions":["Unknown.","The URL that matched the threat list (for which GetFullHash returned a\nvalid hash).","The final top-level URL of the tab that the client was browsing when the\nmatch occurred.","A redirect URL that was fetched before hitting the final TAB_URL.","A resource loaded within the final TAB_URL."],"enum":["THREAT_SOURCE_TYPE_UNSPECIFIED","MATCHING_URL","TAB_URL","TAB_REDIRECT","TAB_RESOURCE"],"description":"The type of source reported.","type":"string"},"url":{"description":"The URL of the resource.","type":"string"},"remoteIp":{"description":"The remote IP of the resource in ASCII format. Either IPv4 or IPv6.","type":"string"},"referrer":{"description":"Referrer of the resource. Only set if the referrer is available.","type":"string"}},"id":"ThreatSource","description":"A single resource related to a threat hit.","type":"object"},"UserInfo":{"description":"Details about the user that encountered the threat.","type":"object","properties":{"regionCode":{"description":"The UN M.49 region code associated with the user's location.","type":"string"},"userId":{"description":"Unique user identifier defined by the client.","format":"byte","type":"string"}},"id":"UserInfo"},"FetchThreatListUpdatesResponse":{"type":"object","properties":{"listUpdateResponses":{"description":"The list updates requested by the clients.","type":"array","items":{"$ref":"ListUpdateResponse"}},"minimumWaitDuration":{"description":"The minimum duration the client must wait before issuing any update\nrequest. If this field is not set clients may update as soon as they want.","format":"google-duration","type":"string"}},"id":"FetchThreatListUpdatesResponse"},"FindFullHashesResponse":{"type":"object","properties":{"minimumWaitDuration":{"description":"The minimum duration the client must wait before issuing any find hashes\nrequest. If this field is not set, clients can issue a request as soon as\nthey want.","format":"google-duration","type":"string"},"matches":{"description":"The full hashes that matched the requested prefixes.","type":"array","items":{"$ref":"ThreatMatch"}},"negativeCacheDuration":{"description":"For requested entities that did not match the threat list, how long to\ncache the response.","format":"google-duration","type":"string"}},"id":"FindFullHashesResponse"},"Checksum":{"description":"The expected state of a client's local database.","type":"object","properties":{"sha256":{"description":"The SHA256 hash of the client state; that is, of the sorted list of all\nhashes present in the database.","format":"byte","type":"string"}},"id":"Checksum"},"ThreatHit":{"type":"object","properties":{"threatType":{"description":"The threat type reported.","type":"string","enumDescriptions":["Unknown.","Malware threat type.","Social engineering threat type.","Unwanted software threat type.","Potentially harmful application threat type.","Social engineering threat type for internal use.","API abuse threat type.","Malicious binary threat type.","Client side detection whitelist threat type.","Client side download detection whitelist threat type.","Client incident threat type.","Whitelist used when detecting client incident threats.\nThis enum was never launched and should be re-used for the next list.","List used for offline APK checks in PAM.","Patterns to be used for activating the subresource filter. Interstitial\nwill not be shown for patterns from this list.","Entities that are suspected to present a threat.","Trick-to-bill threat list."],"enum":["THREAT_TYPE_UNSPECIFIED","MALWARE","SOCIAL_ENGINEERING","UNWANTED_SOFTWARE","POTENTIALLY_HARMFUL_APPLICATION","SOCIAL_ENGINEERING_INTERNAL","API_ABUSE","MALICIOUS_BINARY","CSD_WHITELIST","CSD_DOWNLOAD_WHITELIST","CLIENT_INCIDENT","CLIENT_INCIDENT_WHITELIST","APK_MALWARE_OFFLINE","SUBRESOURCE_FILTER","SUSPICIOUS","TRICK_TO_BILL"]},"resources":{"description":"The resources related to the threat hit.","type":"array","items":{"$ref":"ThreatSource"}},"entry":{"$ref":"ThreatEntry","description":"The threat entry responsible for the hit. Full hash should be reported for\nhash-based hits."},"platformType":{"enum":["PLATFORM_TYPE_UNSPECIFIED","WINDOWS","LINUX","ANDROID","OSX","IOS","ANY_PLATFORM","ALL_PLATFORMS","CHROME"],"description":"The platform type reported.","type":"string","enumDescriptions":["Unknown platform.","Threat posed to Windows.","Threat posed to Linux.","Threat posed to Android.","Threat posed to OS X.","Threat posed to iOS.","Threat posed to at least one of the defined platforms.","Threat posed to all defined platforms.","Threat posed to Chrome."]},"userInfo":{"description":"Details about the user that encountered the threat.","$ref":"UserInfo"},"clientInfo":{"$ref":"ClientInfo","description":"Client-reported identification."}},"id":"ThreatHit"},"ThreatEntrySet":{"description":"A set of threats that should be added or removed from a client's local\ndatabase.","type":"object","properties":{"compressionType":{"description":"The compression type for the entries in this set.","type":"string","enumDescriptions":["Unknown.","Raw, uncompressed data.","Rice-Golomb encoded data."],"enum":["COMPRESSION_TYPE_UNSPECIFIED","RAW","RICE"]},"riceIndices":{"description":"The encoded local, lexicographically-sorted list indices, using a\nGolomb-Rice encoding. Used for sending compressed removal indices. The\nremoval indices (uint32) are sorted in ascending order, then delta encoded\nand stored as encoded_data.","$ref":"RiceDeltaEncoding"},"rawIndices":{"$ref":"RawIndices","description":"The raw removal indices for a local list."},"rawHashes":{"description":"The raw SHA256-formatted entries.","$ref":"RawHashes"},"riceHashes":{"$ref":"RiceDeltaEncoding","description":"The encoded 4-byte prefixes of SHA256-formatted entries, using a\nGolomb-Rice encoding. The hashes are converted to uint32, sorted in\nascending order, then delta encoded and stored as encoded_data."}},"id":"ThreatEntrySet"}},"protocol":"rest","icons":{"x32":"http://www.google.com/images/icons/product/search-32.gif","x16":"http://www.google.com/images/icons/product/search-16.gif"},"version":"v4","baseUrl":"https://safebrowsing.googleapis.com/"};